(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    502234,      22083]*)
(*NotebookOutlinePosition[    503134,      22115]*)
(*  CellTagsIndexPosition[    503056,      22109]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawingTransform3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawingTransform3D",
          "MR"], 
        StyleBox["[",
          "MR"], \(f1, f2, f3\), "]"}]]],
  ", where f1, f2 and f3 are function names of three variables, is a rule \
that transforms all point lists in a set of primitive graphics."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "Usage is ",
  Cell[BoxData[
      \(graphics /. DrawingTransform3D[f1, f2, f3]\)]]
}], "MathCaption"],

Cell[TextData[{
  "The transformation rule is ",
  Cell[BoxData[
      \({x_?NumericQ, y_?NumericQ, \ z_?NumericQ} \[Rule] {f1[x, y, z], 
          f2[x, y, z], f3[x, y, z]}\)]],
  "."
}], "MathCaption"],

Cell["f1, f2 and f3 are usually pure functions.", "MathCaption"],

Cell["\<\
DrawingTransform3D works on graphics built up from Points, Lines and \
Polygons. It will not work on more primitive graphics such as Cuboids.\
\>", "MathCaption"],

Cell[TextData[{
  "A list of points may be fine grained using ",
  ButtonBox["FineGrainPoints",
    ButtonData:>{"FineGrainPoints"},
    ButtonStyle->"AddOnsLink"],
  " before transforming, but this should not often be necessary."
}], "MathCaption"],

Cell["\<\
Fine graining a flat polygon before transforming will not work. A polygon \
needs to be divided into many smaller areas to transform smoothly. I don't \
know of a convenient routine to do that.\
\>", "MathCaption"],

Cell["\<\
For calculation intensive graphics it will be more efficient to build the \
transformations directly into the object parametrizations.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["UseAffineShape",
    ButtonData:>{"UseAffineShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseRotateShape",
    ButtonData:>{"UseRotateShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseTranslateShape",
    ButtonData:>{"UseTranslateShape"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[246]:="],

Cell[TextData[{
  "DrawingTransform3D will be illustrated by mapping a segment of the complex \
plane to the Riemann sphere. One of the advantages of DrawGraphics is that we \
immediately have available the primitive graphics and can easily manipulate \
it. We start with the grid lines for a segment of the complex plane with ",
  Cell[BoxData[
      \(1 \[LessEqual] r \[LessEqual] 2\)]],
  " and ",
  Cell[BoxData[
      \(0 \[LessEqual] \[Theta] \[LessEqual] \[Pi]/4\)]],
  ". We obtain this using ",
  ButtonBox["DrawPolarMap",
    ButtonData:>{"DrawPolarMap"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(g1 = DrawPolarMap[Identity, {1, 2}, {0, \[Pi]/4}];\)\)], "Input",
  CellLabel->"In[247]:="],

Cell["\<\
We then convert the plane points to three dimensional points.\
\>", "Text"],

Cell[BoxData[
    \(\(g2 = g1 /. {x_?NumericQ, y_?NumericQ} \[Rule] {x, y, 0};\)\)], "Input",\

  CellLabel->"In[248]:="],

Cell[TextData[{
  "Often we can just fill in the pure functions needed in DrawingTransform3D. \
But sometimes we need to calculate them. This illustrates one technique for \
constructing the DrawingTransform3D function by calculation. The \
transformation equations for the stereographic mapping of a point ",
  Cell[BoxData[
      \({x, y}\)]],
  "in the complex plane to the three dimensional point ",
  Cell[BoxData[
      \({X, Y, Z}\)]],
  " on the unit Riemann sphere centered at the origin are ",
  Cell[BoxData[
      \(X \[Equal] 2  x/\((1 + x\^2 + y\^2)\)\)]],
  ", ",
  Cell[BoxData[
      \(Y \[Equal] 2 \( \(y\)\(/\)\)\)]],
  Cell[BoxData[
      \(\((1 + x\^2 + y\^2)\)\)]],
  " and ",
  Cell[BoxData[
      \(Z \[Equal] \((x\^2 + y\^2 - 1)\)/\((x\^2 + y\^2 + 1)\)\)]],
  ". We can simplify the calculation with a With statement using slot \
variables. Then, by mapping Function onto the list we obtain a list of pure \
functions. Then all we have to do is Apply DrawingTransform3D to the list."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(With[{t = #1\^2 + #2\^2}, {2  #1/\((1 + t)\), 
        2  #2/\((1 + t)\), \((t - 1)\)/\((t + 
              1)\)}]\), "\[IndentingNewLine]", 
    \(Function /@ %\), "\[IndentingNewLine]", 
    \(\(transform = DrawingTransform3D @@ %;\)\)}], "Input",
  CellLabel->"In[249]:="],

Cell[BoxData[
    \({\(2\ #1\)\/\(1 + #1\^2 + #2\^2\), \(2\ #2\)\/\(1 + #1\^2 + #2\^2\), \(\
\(-1\) + #1\^2 + #2\^2\)\/\(1 + #1\^2 + #2\^2\)}\)], "Output",
  CellLabel->"Out[249]="],

Cell[BoxData[
    \({\(2\ #1\)\/\(1 + #1\^2 + #2\^2\) &, \(2\ #2\)\/\(1 + #1\^2 + #2\^2\) \
&, \(\(-1\) + #1\^2 + #2\^2\)\/\(1 + #1\^2 + #2\^2\) &}\)], "Output",
  CellLabel->"Out[250]="]
}, Open  ]],

Cell["\<\
This parametrizes the Riemann sphere. We wish to make the sphere slightly \
smaller so that our mapping lines will lie cleanly on the surface.\
\>", "Text"],

Cell[BoxData[
    \(\(sphere[r_]\)[\[Phi]_, \[Theta]_] := 
      r {Cos[\[Theta]] Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], 
          Cos[\[Phi]]}\)], "Input",
  CellLabel->"In[252]:="],

Cell["\<\
Now we:
1) Draw the Riemann sphere with a uniform color. We illuminate with neutral \
lighting.
2) Draw the zero meridian and the equator in Black.
3) Draw the complex plane segment in IndianRed.
4) Draw the transformation onto the Rieman sphere in Black.
5) Label the North pole.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], 
          SurfaceColor[RGBColor[0, \ 1, \ 0]], 
          ParametricDraw3D[
            Evaluate[\(sphere[0.995]\)[\[Phi], \[Theta]]], {\[Phi], 
              0, \[Pi]}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {31, 41}], \[IndentingNewLine]Black, 
          ParametricDraw3D[
            Evaluate[\(sphere[1]\)[\[Phi], 0]], {\[Phi], 
              0, \[Pi]}], \[IndentingNewLine]ParametricDraw3D[
            Evaluate[\(sphere[1]\)[\[Pi]/2, \[Theta]]], {\[Theta], 0, 
              2  \[Pi]}], \[IndentingNewLine]RGBColor[0, \ 0, \ 1], 
          g2, \[IndentingNewLine]Black, 
          g2 /. transform, \[IndentingNewLine]Text[
            StyleForm["\<N\>", FontSize \[Rule] 12], {0, 0, 
              1}]}, \[IndentingNewLine]\[IndentingNewLine]NeutralLighting[
          0.3, 0.6, 
          0.0], \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
              2}, {\(-1\), \@2}, {\(-1\), 
              1}}, \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]ViewPoint -> {4, \(-2\), 3}/
            2, \[IndentingNewLine]Boxed \[Rule] 
          False (*\(,\)\(\[IndentingNewLine]\)\(Background \[Rule] 
            SteelBlue\)*) ];\)\)], "Input",
  CellLabel->"In[258]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00694 
%%ImageSize: 400 402.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.110402 1.13227 4.29344e-017 1.13227 [
[ 0 0 0 0 ]
[ 1 1.00694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00694 L
0 1.00694 L
closepath
clip
newpath
0 .97 0 r
.36409 .6026 m .33744 .57798 L .33532 .6015 L F
.36409 .6026 m .36388 .57901 L .33744 .57798 L F
0 .949 0 r
.36417 .62631 m .36409 .6026 L .33532 .6015 L F
0 .945 0 r
.39266 .60126 m .36388 .57901 L .36409 .6026 L F
0 .922 0 r
.39477 .6249 m .36409 .6026 L .36417 .62631 L F
.39477 .6249 m .39266 .60126 L .36409 .6026 L F
0 .949 0 r
.36417 .62631 m .33532 .6015 L .33337 .62514 L F
0 .928 0 r
.36413 .64995 m .36417 .62631 L .33337 .62514 L F
0 .899 0 r
.39645 .64849 m .36417 .62631 L .36413 .64995 L F
.39645 .64849 m .39477 .6249 L .36417 .62631 L F
0 .996 0 r
.33532 .6015 m .31134 .57467 L .30693 .59795 L F
.33532 .6015 m .33744 .57798 L .31134 .57467 L F
0 .977 0 r
.33337 .62514 m .33532 .6015 L .30693 .59795 L F
0 .945 0 r
.39266 .60126 m .39016 .57776 L .36388 .57901 L F
0 .92 0 r
.42049 .59748 m .39016 .57776 L .39266 .60126 L F
0 .895 0 r
.42458 .62092 m .39266 .60126 L .39477 .6249 L F
.42458 .62092 m .42049 .59748 L .39266 .60126 L F
0 .989 0 r
.36388 .57901 m .33969 .55477 L .33744 .57798 L F
.36388 .57901 m .36356 .55572 L .33969 .55477 L F
0 .966 0 r
.39016 .57776 m .36356 .55572 L .36388 .57901 L F
0 .977 0 r
.33337 .62514 m .30693 .59795 L .30296 .62142 L F
0 .957 0 r
.3316 .64874 m .33337 .62514 L .30296 .62142 L F
0 .928 0 r
.36413 .64995 m .33337 .62514 L .3316 .64874 L F
0 .869 0 r
.42795 .64436 m .39477 .6249 L .39645 .64849 L F
.42795 .64436 m .42458 .62092 L .39477 .6249 L F
0 .905 0 r
.36397 .67336 m .36413 .64995 L .3316 .64874 L F
0 .874 0 r
.3977 .67185 m .36413 .64995 L .36397 .67336 L F
.3977 .67185 m .39645 .64849 L .36413 .64995 L F
0 1 0 r
.33744 .57798 m .31616 .55173 L .31134 .57467 L F
.33744 .57798 m .33969 .55477 L .31616 .55173 L F
0 .966 0 r
.39016 .57776 m .38726 .55456 L .36356 .55572 L F
0 .944 0 r
.41573 .57423 m .38726 .55456 L .39016 .57776 L F
0 .92 0 r
.42049 .59748 m .41573 .57423 L .39016 .57776 L F
0 .957 0 r
.3316 .64874 m .30296 .62142 L .29946 .64487 L F
0 .936 0 r
.33001 .67212 m .3316 .64874 L .29946 .64487 L F
0 .905 0 r
.36397 .67336 m .3316 .64874 L .33001 .67212 L F
0 .842 0 r
.43058 .66762 m .39645 .64849 L .3977 .67185 L F
.43058 .66762 m .42795 .64436 L .39645 .64849 L F
0 1 0 r
.36356 .55572 m .34208 .53204 L .33969 .55477 L F
.36356 .55572 m .36311 .53289 L .34208 .53204 L F
0 .987 0 r
.38726 .55456 m .36311 .53289 L .36356 .55572 L F
0 1 0 r
.30693 .59795 m .28611 .56913 L .27946 .59203 L F
.30693 .59795 m .31134 .57467 L .28611 .56913 L F
.30296 .62142 m .30693 .59795 L .27946 .59203 L F
0 .895 0 r
.44702 .59133 m .41573 .57423 L .42049 .59748 L F
0 .867 0 r
.45302 .61444 m .42049 .59748 L .42458 .62092 L F
.45302 .61444 m .44702 .59133 L .42049 .59748 L F
0 1 0 r
.30296 .62142 m .27946 .59203 L .27351 .61517 L F
0 .988 0 r
.29946 .64487 m .30296 .62142 L .27351 .61517 L F
0 1 0 r
.33969 .55477 m .32135 .52932 L .31616 .55173 L F
.33969 .55477 m .34208 .53204 L .32135 .52932 L F
0 .987 0 r
.38726 .55456 m .384 .53186 L .36311 .53289 L F
0 .967 0 r
.41033 .55133 m .384 .53186 L .38726 .55456 L F
0 .944 0 r
.41573 .57423 m .41033 .55133 L .38726 .55456 L F
0 .88 0 r
.36368 .69634 m .36397 .67336 L .33001 .67212 L F
0 .847 0 r
.3985 .69482 m .36397 .67336 L .36368 .69634 L F
.3985 .69482 m .3977 .67185 L .36397 .67336 L F
0 1 0 r
.31134 .57467 m .29343 .54666 L .28611 .56913 L F
.31134 .57467 m .31616 .55173 L .29343 .54666 L F
0 .839 0 r
.45802 .63763 m .42458 .62092 L .42795 .64436 L F
.45802 .63763 m .45302 .61444 L .42458 .62092 L F
0 .922 0 r
.44009 .56848 m .41033 .55133 L .41573 .57423 L F
0 .895 0 r
.44702 .59133 m .44009 .56848 L .41573 .57423 L F
0 .936 0 r
.33001 .67212 m .29946 .64487 L .29646 .66815 L F
0 .913 0 r
.32863 .69509 m .33001 .67212 L .29646 .66815 L F
0 .88 0 r
.36368 .69634 m .33001 .67212 L .32863 .69509 L F
0 .813 0 r
.43245 .69052 m .3977 .67185 L .3985 .69482 L F
.43245 .69052 m .43058 .66762 L .3977 .67185 L F
0 .988 0 r
.29946 .64487 m .27351 .61517 L .26833 .63839 L F
0 .968 0 r
.29646 .66815 m .29946 .64487 L .26833 .63839 L F
0 .808 0 r
.46199 .66071 m .42795 .64436 L .43058 .66762 L F
.46199 .66071 m .45802 .63763 L .42795 .64436 L F
0 1 0 r
.31616 .55173 m .30135 .52479 L .29343 .54666 L F
.31616 .55173 m .32135 .52932 L .30135 .52479 L F
0 .967 0 r
.41033 .55133 m .40432 .52896 L .384 .53186 L F
0 .948 0 r
.43227 .54606 m .40432 .52896 L .41033 .55133 L F
0 .922 0 r
.44009 .56848 m .43227 .54606 L .41033 .55133 L F
0 1 0 r
.36311 .53289 m .34458 .50998 L .34208 .53204 L F
.36311 .53289 m .36255 .51071 L .34458 .50998 L F
.384 .53186 m .36255 .51071 L .36311 .53289 L F
.34208 .53204 m .32688 .50762 L .32135 .52932 L F
.34208 .53204 m .34458 .50998 L .32688 .50762 L F
.384 .53186 m .3804 .50982 L .36255 .51071 L F
0 .991 0 r
.40432 .52896 m .3804 .50982 L .384 .53186 L F
0 1 0 r
.27946 .59203 m .26228 .56146 L .25347 .58381 L F
.27946 .59203 m .28611 .56913 L .26228 .56146 L F
.27351 .61517 m .27946 .59203 L .25347 .58381 L F
0 .854 0 r
.36328 .71873 m .36368 .69634 L .32863 .69509 L F
0 .818 0 r
.39885 .7172 m .36368 .69634 L .36328 .71873 L F
.39885 .7172 m .3985 .69482 L .36368 .69634 L F
0 .968 0 r
.29646 .66815 m .26833 .63839 L .26394 .6615 L F
0 .946 0 r
.29399 .69106 m .29646 .66815 L .26394 .6615 L F
0 .913 0 r
.32863 .69509 m .29646 .66815 L .29399 .69106 L F
0 1 0 r
.28611 .56913 m .27198 .53963 L .26228 .56146 L F
.28611 .56913 m .29343 .54666 L .27198 .53963 L F
0 .87 0 r
.47171 .58289 m .44009 .56848 L .44702 .59133 L F
0 .839 0 r
.47951 .60555 m .44702 .59133 L .45302 .61444 L F
.47951 .60555 m .47171 .58289 L .44702 .59133 L F
0 1 0 r
.27351 .61517 m .25347 .58381 L .24563 .60651 L F
.26833 .63839 m .27351 .61517 L .24563 .60651 L F
0 .776 0 r
.46489 .68351 m .43058 .66762 L .43245 .69052 L F
.46489 .68351 m .46199 .66071 L .43058 .66762 L F
0 .9 0 r
.46272 .56061 m .43227 .54606 L .44009 .56848 L F
0 .87 0 r
.47171 .58289 m .46272 .56061 L .44009 .56848 L F
0 .888 0 r
.32747 .71747 m .32863 .69509 L .29399 .69106 L F
0 .854 0 r
.36328 .71873 m .32863 .69509 L .32747 .71747 L F
0 .781 0 r
.43353 .71289 m .3985 .69482 L .39885 .7172 L F
.43353 .71289 m .43245 .69052 L .3985 .69482 L F
0 .806 0 r
.48606 .62838 m .45302 .61444 L .45802 .63763 L F
.48606 .62838 m .47951 .60555 L .45302 .61444 L F
0 1 0 r
.32135 .52932 m .30982 .50369 L .30135 .52479 L F
.32135 .52932 m .32688 .50762 L .30982 .50369 L F
0 .991 0 r
.40432 .52896 m .39774 .50731 L .3804 .50982 L F
0 .974 0 r
.42362 .52426 m .39774 .50731 L .40432 .52896 L F
0 .948 0 r
.43227 .54606 m .42362 .52426 L .40432 .52896 L F
0 1 0 r
.29343 .54666 m .28251 .51851 L .27198 .53963 L F
.29343 .54666 m .30135 .52479 L .28251 .51851 L F
0 .929 0 r
.45263 .53885 m .42362 .52426 L .43227 .54606 L F
0 .9 0 r
.46272 .56061 m .45263 .53885 L .43227 .54606 L F
0 1 0 r
.26833 .63839 m .24563 .60651 L .23881 .62938 L F
.26394 .6615 m .26833 .63839 L .23881 .62938 L F
0 .772 0 r
.49131 .65122 m .45802 .63763 L .46199 .66071 L F
.49131 .65122 m .48606 .62838 L .45802 .63763 L F
0 1 0 r
.36255 .51071 m .34718 .48876 L .34458 .50998 L F
.36255 .51071 m .36188 .48937 L .34718 .48876 L F
.3804 .50982 m .36188 .48937 L .36255 .51071 L F
.34458 .50998 m .33271 .48681 L .32688 .50762 L F
.34458 .50998 m .34718 .48876 L .33271 .48681 L F
.3804 .50982 m .37647 .48863 L .36188 .48937 L F
.39774 .50731 m .37647 .48863 L .3804 .50982 L F
0 .946 0 r
.29399 .69106 m .26394 .6615 L .2604 .68431 L F
0 .921 0 r
.29207 .71342 m .29399 .69106 L .2604 .68431 L F
0 .888 0 r
.32747 .71747 m .29399 .69106 L .29207 .71342 L F
0 1 0 r
.30135 .52479 m .29378 .49826 L .28251 .51851 L F
.30135 .52479 m .30982 .50369 L .29378 .49826 L F
0 .74 0 r
.46669 .70585 m .43245 .69052 L .43353 .71289 L F
.46669 .70585 m .46489 .68351 L .43245 .69052 L F
0 .823 0 r
.36275 .74033 m .36328 .71873 L .32747 .71747 L F
0 .786 0 r
.39872 .73881 m .36328 .71873 L .36275 .74033 L F
.39872 .73881 m .39885 .7172 L .36328 .71873 L F
0 .974 0 r
.42362 .52426 m .4142 .50323 L .39774 .50731 L F
0 .958 0 r
.4415 .51781 m .4142 .50323 L .42362 .52426 L F
0 .929 0 r
.45263 .53885 m .4415 .51781 L .42362 .52426 L F
0 1 0 r
.26394 .6615 m .23881 .62938 L .23309 .65225 L F
0 .98 0 r
.2604 .68431 m .26394 .6615 L .23309 .65225 L F
0 1 0 r
.32688 .50762 m .31878 .48355 L .30982 .50369 L F
.32688 .50762 m .33271 .48681 L .31878 .48355 L F
.39774 .50731 m .39065 .48655 L .37647 .48863 L F
.4142 .50323 m .39065 .48655 L .39774 .50731 L F
0 .859 0 r
.32653 .73908 m .32747 .71747 L .29207 .71342 L F
0 .823 0 r
.36275 .74033 m .32747 .71747 L .32653 .73908 L F
0 1 0 r
.26228 .56146 m .2523 .53077 L .24036 .55177 L F
.26228 .56146 m .27198 .53963 L .2523 .53077 L F
.25347 .58381 m .26228 .56146 L .24036 .55177 L F
.25347 .58381 m .24036 .55177 L .22952 .57341 L F
.24563 .60651 m .25347 .58381 L .22952 .57341 L F
0 .735 0 r
.49519 .67388 m .46199 .66071 L .46489 .68351 L F
.49519 .67388 m .49131 .65122 L .46199 .66071 L F
0 .746 0 r
.4338 .73452 m .39885 .7172 L .39872 .73881 L F
.4338 .73452 m .43353 .71289 L .39885 .7172 L F
0 .877 0 r
.48314 .55073 m .45263 .53885 L .46272 .56061 L F
0 .843 0 r
.49401 .5723 m .46272 .56061 L .47171 .58289 L F
.49401 .5723 m .48314 .55073 L .46272 .56061 L F
0 .808 0 r
.50349 .59437 m .47171 .58289 L .47951 .60555 L F
.50349 .59437 m .49401 .5723 L .47171 .58289 L F
0 1 0 r
.27198 .53963 m .26525 .5106 L .2523 .53077 L F
.27198 .53963 m .28251 .51851 L .26525 .5106 L F
.24563 .60651 m .22952 .57341 L .21989 .59554 L F
.23881 .62938 m .24563 .60651 L .21989 .59554 L F
0 .91 0 r
.47095 .52982 m .4415 .51781 L .45263 .53885 L F
0 .877 0 r
.48314 .55073 m .47095 .52982 L .45263 .53885 L F
0 .771 0 r
.51148 .61675 m .47951 .60555 L .48606 .62838 L F
.51148 .61675 m .50349 .59437 L .47951 .60555 L F
0 1 0 r
.30982 .50369 m .3057 .47905 L .29378 .49826 L F
.30982 .50369 m .31878 .48355 L .3057 .47905 L F
.4142 .50323 m .40408 .48317 L .39065 .48655 L F
0 .987 0 r
.42942 .49766 m .40408 .48317 L .4142 .50323 L F
0 .958 0 r
.4415 .51781 m .42942 .49766 L .4142 .50323 L F
0 1 0 r
.28251 .51851 m .27911 .49143 L .26525 .5106 L F
.28251 .51851 m .29378 .49826 L .27911 .49143 L F
.36188 .48937 m .34985 .46857 L .34718 .48876 L F
.36188 .48937 m .36109 .46904 L .34985 .46857 L F
.37647 .48863 m .36109 .46904 L .36188 .48937 L F
0 .921 0 r
.29207 .71342 m .2604 .68431 L .25774 .70664 L F
0 .894 0 r
.29073 .73506 m .29207 .71342 L .25774 .70664 L F
0 .859 0 r
.32653 .73908 m .29207 .71342 L .29073 .73506 L F
0 1 0 r
.23881 .62938 m .21989 .59554 L .21154 .61798 L F
.23309 .65225 m .23881 .62938 L .21154 .61798 L F
0 .943 0 r
.45755 .50976 m .42942 .49766 L .4415 .51781 L F
0 .91 0 r
.47095 .52982 m .45755 .50976 L .4415 .51781 L F
0 1 0 r
.34718 .48876 m .33879 .46706 L .33271 .48681 L F
.34718 .48876 m .34985 .46857 L .33879 .46706 L F
0 .98 0 r
.2604 .68431 m .23309 .65225 L .22852 .67492 L F
0 .956 0 r
.25774 .70664 m .2604 .68431 L .22852 .67492 L F
0 1 0 r
.37647 .48863 m .37225 .46847 L .36109 .46904 L F
.39065 .48655 m .37225 .46847 L .37647 .48863 L F
0 .701 0 r
.46734 .72752 m .43353 .71289 L .4338 .73452 L F
.46734 .72752 m .46669 .70585 L .43353 .71289 L F
0 .731 0 r
.51791 .63928 m .48606 .62838 L .49131 .65122 L F
.51791 .63928 m .51148 .61675 L .48606 .62838 L F
0 .694 0 r
.49766 .69617 m .46489 .68351 L .46669 .70585 L F
.49766 .69617 m .49519 .67388 L .46489 .68351 L F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.37164 .74078 m
.35198 .74082 L
s
0 1 0 r
.33271 .48681 m .32816 .46453 L .31878 .48355 L F
.33271 .48681 m .33879 .46706 L .32816 .46453 L F
0 .789 0 r
.3621 .76097 m .36275 .74033 L .32653 .73908 L F
0 .75 0 r
.39812 .75946 m .36275 .74033 L .3621 .76097 L F
.39812 .75946 m .39872 .73881 L .36275 .74033 L F
0 1 0 r
.39065 .48655 m .38308 .46685 L .37225 .46847 L F
.40408 .48317 m .38308 .46685 L .39065 .48655 L F
0 .826 0 r
.32584 .75973 m .32653 .73908 L .29073 .73506 L F
0 0 0 r
.32652 .73956 m
.32744 .73964 L
s
0 .789 0 r
.3621 .76097 m .32653 .73908 L .32584 .75973 L F
0 1 0 r
.29378 .49826 m .29378 .47341 L .27911 .49143 L F
.29378 .49826 m .3057 .47905 L .29378 .47341 L F
0 .706 0 r
.43325 .75524 m .39872 .73881 L .39812 .75946 L F
.43325 .75524 m .4338 .73452 L .39872 .73881 L F
0 .987 0 r
.42942 .49766 m .41648 .47856 L .40408 .48317 L F
0 .975 0 r
.44305 .4907 m .41648 .47856 L .42942 .49766 L F
0 .943 0 r
.45755 .50976 m .44305 .4907 L .42942 .49766 L F
0 1 0 r
.23309 .65225 m .21154 .61798 L .20454 .64053 L F
.22852 .67492 m .23309 .65225 L .20454 .64053 L F
.24036 .55177 m .23482 .52023 L .22085 .54022 L F
.24036 .55177 m .2523 .53077 L .23482 .52023 L F
.22952 .57341 m .24036 .55177 L .22085 .54022 L F
.31878 .48355 m .3182 .46106 L .3057 .47905 L F
.31878 .48355 m .32816 .46453 L .3182 .46106 L F
.2523 .53077 m .24998 .50122 L .23482 .52023 L F
.2523 .53077 m .26525 .5106 L .24998 .50122 L F
.40408 .48317 m .39333 .46424 L .38308 .46685 L F
.41648 .47856 m .39333 .46424 L .40408 .48317 L F
0 .688 0 r
.52271 .66175 m .49131 .65122 L .49519 .67388 L F
.52271 .66175 m .51791 .63928 L .49131 .65122 L F
0 1 0 r
.22952 .57341 m .22085 .54022 L .20816 .56102 L F
.21989 .59554 m .22952 .57341 L .20816 .56102 L F
0 .854 0 r
.50085 .53902 m .47095 .52982 L .48314 .55073 L F
0 .815 0 r
.51342 .55972 m .48314 .55073 L .49401 .5723 L F
.51342 .55972 m .50085 .53902 L .48314 .55073 L F
0 .892 0 r
.4868 .51913 m .45755 .50976 L .47095 .52982 L F
0 .854 0 r
.50085 .53902 m .4868 .51913 L .47095 .52982 L F
0 .774 0 r
.5244 .58108 m .49401 .5723 L .50349 .59437 L F
.5244 .58108 m .51342 .55972 L .49401 .5723 L F
0 1 0 r
.26525 .5106 m .26618 .48333 L .24998 .50122 L F
.26525 .5106 m .27911 .49143 L .26618 .48333 L F
0 .956 0 r
.25774 .70664 m .22852 .67492 L .22514 .69722 L F
0 .928 0 r
.256 .72832 m .25774 .70664 L .22514 .69722 L F
0 .894 0 r
.29073 .73506 m .25774 .70664 L .256 .72832 L F
0 .928 0 r
.47139 .50024 m .44305 .4907 L .45755 .50976 L F
0 .892 0 r
.4868 .51913 m .47139 .50024 L .45755 .50976 L F
0 .862 0 r
.28999 .75577 m .29073 .73506 L .256 .72832 L F
0 0 0 r
.29071 .73559 m
.29174 .73576 L
s
0 .826 0 r
.32584 .75973 m .29073 .73506 L .28999 .75577 L F
0 .649 0 r
.49868 .7179 m .46669 .70585 L .46734 .72752 L F
.49868 .7179 m .49766 .69617 L .46669 .70585 L F
0 1 0 r
.21989 .59554 m .20816 .56102 L .19688 .58245 L F
.21154 .61798 m .21989 .59554 L .19688 .58245 L F
0 .657 0 r
.46683 .74835 m .4338 .73452 L .43325 .75524 L F
.46683 .74835 m .46734 .72752 L .4338 .73452 L F
0 1 0 r
.36109 .46904 m .35258 .44959 L .34985 .46857 L F
.36109 .46904 m .3602 .44991 L .35258 .44959 L F
.37225 .46847 m .3602 .44991 L .36109 .46904 L F
.3057 .47905 m .30914 .4567 L .29378 .47341 L F
.3057 .47905 m .3182 .46106 L .30914 .4567 L F
.34985 .46857 m .34509 .44855 L .33879 .46706 L F
.34985 .46857 m .35258 .44959 L .34509 .44855 L F
0 .73 0 r
.53369 .60292 m .50349 .59437 L .51148 .61675 L F
.53369 .60292 m .5244 .58108 L .50349 .59437 L F
0 1 0 r
.37225 .46847 m .36776 .44952 L .3602 .44991 L F
.38308 .46685 m .36776 .44952 L .37225 .46847 L F
.41648 .47856 m .40277 .46067 L .39333 .46424 L F
.42755 .4728 m .40277 .46067 L .41648 .47856 L F
0 .975 0 r
.44305 .4907 m .42755 .4728 L .41648 .47856 L F
0 1 0 r
.27911 .49143 m .2833 .46672 L .26618 .48333 L F
.27911 .49143 m .29378 .47341 L .2833 .46672 L F
.22852 .67492 m .20454 .64053 L .19898 .66302 L F
0 .991 0 r
.22514 .69722 m .22852 .67492 L .19898 .66302 L F
0 0 0 r
.25556 .72883 m
.25703 .72915 L
s
0 1 0 r
.33879 .46706 m .33789 .44682 L .32816 .46453 L F
.33879 .46706 m .34509 .44855 L .33789 .44682 L F
0 .964 0 r
.45476 .48248 m .42755 .4728 L .44305 .4907 L F
0 .928 0 r
.47139 .50024 m .45476 .48248 L .44305 .4907 L F
0 1 0 r
.38308 .46685 m .3751 .44841 L .36776 .44952 L F
.39333 .46424 m .3751 .44841 L .38308 .46685 L F
0 .64 0 r
.52581 .68398 m .49519 .67388 L .49766 .69617 L F
.52581 .68398 m .52271 .66175 L .49519 .67388 L F
0 .75 0 r
.36134 .78044 m .3621 .76097 L .32584 .75973 L F
0 .708 0 r
.39705 .77897 m .3621 .76097 L .36134 .78044 L F
.39705 .77897 m .39812 .75946 L .3621 .76097 L F
0 1 0 r
.21154 .61798 m .19688 .58245 L .1871 .60435 L F
.20454 .64053 m .21154 .61798 L .1871 .60435 L F
.32816 .46453 m .33117 .44444 L .3182 .46106 L F
.32816 .46453 m .33789 .44682 L .33117 .44444 L F
0 .683 0 r
.5412 .62505 m .51148 .61675 L .51791 .63928 L F
.5412 .62505 m .53369 .60292 L .51148 .61675 L F
0 .788 0 r
.3254 .77923 m .32584 .75973 L .28999 .75577 L F
0 .75 0 r
.36134 .78044 m .32584 .75973 L .3254 .77923 L F
0 1 0 r
.39333 .46424 m .38203 .44662 L .3751 .44841 L F
.40277 .46067 m .38203 .44662 L .39333 .46424 L F
0 .661 0 r
.43186 .77485 m .39812 .75946 L .39705 .77897 L F
.43186 .77485 m .43325 .75524 L .39812 .75946 L F
0 1 0 r
.29378 .47341 m .30121 .45155 L .2833 .46672 L F
.29378 .47341 m .30914 .4567 L .30121 .45155 L F
.42755 .4728 m .41118 .45623 L .40277 .46067 L F
0 .999 0 r
.43702 .46603 m .41118 .45623 L .42755 .4728 L F
0 .964 0 r
.45476 .48248 m .43702 .46603 L .42755 .4728 L F
0 1 0 r
.23482 .52023 m .23707 .49053 L .21999 .50821 L F
.23482 .52023 m .24998 .50122 L .23707 .49053 L F
.22085 .54022 m .23482 .52023 L .21999 .50821 L F
0 .928 0 r
.256 .72832 m .22514 .69722 L .22301 .71894 L F
0 .896 0 r
.25521 .74913 m .256 .72832 L .22301 .71894 L F
0 .862 0 r
.28999 .75577 m .256 .72832 L .25521 .74913 L F
0 1 0 r
.24998 .50122 m .25529 .47413 L .23707 .49053 L F
.24998 .50122 m .26618 .48333 L .25529 .47413 L F
.22085 .54022 m .21999 .50821 L .20422 .52704 L F
.20816 .56102 m .22085 .54022 L .20422 .52704 L F
.3182 .46106 m .32507 .44146 L .30914 .4567 L F
.3182 .46106 m .33117 .44444 L .32507 .44146 L F
0 .873 0 r
.49978 .50698 m .47139 .50024 L .4868 .51913 L F
0 .83 0 r
.51541 .52568 m .4868 .51913 L .50085 .53902 L F
.51541 .52568 m .49978 .50698 L .4868 .51913 L F
0 .598 0 r
.4982 .73887 m .46734 .72752 L .46683 .74835 L F
.4982 .73887 m .49868 .7179 L .46734 .72752 L F
0 1 0 r
.40277 .46067 m .3884 .44418 L .38203 .44662 L F
.41118 .45623 m .3884 .44418 L .40277 .46067 L F
.20454 .64053 m .1871 .60435 L .17893 .62652 L F
.19898 .66302 m .20454 .64053 L .17893 .62652 L F
0 .914 0 r
.48267 .48943 m .45476 .48248 L .47139 .50024 L F
0 .873 0 r
.49978 .50698 m .48267 .48943 L .47139 .50024 L F
0 .784 0 r
.52944 .54538 m .50085 .53902 L .51342 .55972 L F
.52944 .54538 m .51541 .52568 L .50085 .53902 L F
0 .991 0 r
.22514 .69722 m .19898 .66302 L .19492 .68526 L F
0 .963 0 r
.22301 .71894 m .22514 .69722 L .19492 .68526 L F
0 .824 0 r
.28986 .77537 m .28999 .75577 L .25521 .74913 L F
0 .788 0 r
.3254 .77923 m .28999 .75577 L .28986 .77537 L F
0 1 0 r
.26618 .48333 m .27452 .45915 L .25529 .47413 L F
.26618 .48333 m .2833 .46672 L .27452 .45915 L F
.20816 .56102 m .20422 .52704 L .1899 .54684 L F
.19688 .58245 m .20816 .56102 L .1899 .54684 L F
0 .631 0 r
.54683 .64729 m .51791 .63928 L .52271 .66175 L F
.54683 .64729 m .5412 .62505 L .51791 .63928 L F
0 .606 0 r
.46513 .76813 m .43325 .75524 L .43186 .77485 L F
.46513 .76813 m .46683 .74835 L .43325 .75524 L F
0 .954 0 r
.46425 .47318 m .43702 .46603 L .45476 .48248 L F
0 .914 0 r
.48267 .48943 m .46425 .47318 L .45476 .48248 L F
0 .587 0 r
.52717 .70577 m .49766 .69617 L .49868 .7179 L F
.52717 .70577 m .52581 .68398 L .49766 .69617 L F
0 .735 0 r
.54172 .56591 m .51342 .55972 L .5244 .58108 L F
.54172 .56591 m .52944 .54538 L .51342 .55972 L F
0 1 0 r
.3602 .44991 m .35534 .43201 L .35258 .44959 L F
.3602 .44991 m .3592 .43217 L .35534 .43201 L F
.36776 .44952 m .3592 .43217 L .3602 .44991 L F
.35258 .44959 m .35154 .43147 L .34509 .44855 L F
.35258 .44959 m .35534 .43201 L .35154 .43147 L F
.36776 .44952 m .36304 .43197 L .3592 .43217 L F
.3751 .44841 m .36304 .43197 L .36776 .44952 L F
.30914 .4567 m .31974 .43795 L .30121 .45155 L F
.30914 .4567 m .32507 .44146 L .31974 .43795 L F
.41118 .45623 m .39405 .44115 L .3884 .44418 L F
.41834 .45102 m .39405 .44115 L .41118 .45623 L F
0 .999 0 r
.43702 .46603 m .41834 .45102 L .41118 .45623 L F
0 1 0 r
.2833 .46672 m .29459 .44573 L .27452 .45915 L F
.2833 .46672 m .30121 .45155 L .29459 .44573 L F
.34509 .44855 m .3479 .43059 L .33789 .44682 L F
.34509 .44855 m .35154 .43147 L .3479 .43059 L F
0 0 0 r
.49866 .71858 m
.50017 .71807 L
s
0 1 0 r
.3751 .44841 m .36675 .4314 L .36304 .43197 L F
.38203 .44662 m .36675 .4314 L .3751 .44841 L F
.19688 .58245 m .1899 .54684 L .17715 .56745 L F
.1871 .60435 m .19688 .58245 L .17715 .56745 L F
0 .992 0 r
.44467 .45837 m .41834 .45102 L .43702 .46603 L F
0 .954 0 r
.46425 .47318 m .44467 .45837 L .43702 .46603 L F
0 1 0 r
.33789 .44682 m .34451 .42937 L .33117 .44444 L F
.33789 .44682 m .3479 .43059 L .34451 .42937 L F
.38203 .44662 m .37026 .43049 L .36675 .4314 L F
.3884 .44418 m .37026 .43049 L .38203 .44662 L F
0 .682 0 r
.55214 .5871 m .5244 .58108 L .53369 .60292 L F
.55214 .5871 m .54172 .56591 L .5244 .58108 L F
0 .703 0 r
.36047 .79856 m .36134 .78044 L .3254 .77923 L F
0 .659 0 r
.39549 .79715 m .36134 .78044 L .36047 .79856 L F
.39549 .79715 m .39705 .77897 L .36134 .78044 L F
0 1 0 r
.19898 .66302 m .17893 .62652 L .17246 .64878 L F
.19492 .68526 m .19898 .66302 L .17246 .64878 L F
0 .743 0 r
.32522 .79739 m .3254 .77923 L .28986 .77537 L F
0 .703 0 r
.36047 .79856 m .3254 .77923 L .32522 .79739 L F
0 .573 0 r
.5505 .66944 m .52271 .66175 L .52581 .68398 L F
.5505 .66944 m .54683 .64729 L .52271 .66175 L F
0 .607 0 r
.42962 .79317 m .39705 .77897 L .39549 .79715 L F
.42962 .79317 m .43186 .77485 L .39705 .77897 L F
0 1 0 r
.33117 .44444 m .34144 .42785 L .32507 .44146 L F
.33117 .44444 m .34451 .42937 L .34144 .42785 L F
.3884 .44418 m .37347 .42924 L .37026 .43049 L F
.39405 .44115 m .37347 .42924 L .3884 .44418 L F
.30121 .45155 m .31533 .43399 L .29459 .44573 L F
.30121 .45155 m .31974 .43795 L .31533 .43399 L F
0 .896 0 r
.25521 .74913 m .22301 .71894 L .22217 .73989 L F
0 .858 0 r
.25539 .76889 m .25521 .74913 L .22217 .73989 L F
0 .824 0 r
.28986 .77537 m .25521 .74913 L .25539 .76889 L F
0 1 0 r
.41834 .45102 m .39885 .43759 L .39405 .44115 L F
.42408 .44513 m .39885 .43759 L .41834 .45102 L F
0 .992 0 r
.44467 .45837 m .42408 .44513 L .41834 .45102 L F
0 1 0 r
.1871 .60435 m .17715 .56745 L .16611 .58871 L F
.17893 .62652 m .1871 .60435 L .16611 .58871 L F
.23707 .49053 m .24674 .46401 L .22686 .47875 L F
.23707 .49053 m .25529 .47413 L .24674 .46401 L F
.21999 .50821 m .23707 .49053 L .22686 .47875 L F
0 .963 0 r
.22301 .71894 m .19492 .68526 L .19242 .70705 L F
0 .93 0 r
.22217 .73989 m .22301 .71894 L .19242 .70705 L F
0 .539 0 r
.49621 .75888 m .46683 .74835 L .46513 .76813 L F
.49621 .75888 m .4982 .73887 L .46683 .74835 L F
0 1 0 r
.25529 .47413 m .26767 .45084 L .24674 .46401 L F
.25529 .47413 m .27452 .45915 L .26767 .45084 L F
.21999 .50821 m .22686 .47875 L .20821 .49495 L F
.20422 .52704 m .21999 .50821 L .20821 .49495 L F
0 .9 0 r
.49108 .47757 m .46425 .47318 L .48267 .48943 L F
0 .853 0 r
.50952 .49361 m .48267 .48943 L .49978 .50698 L F
.50952 .49361 m .49108 .47757 L .48267 .48943 L F
0 .945 0 r
.47127 .46299 m .44467 .45837 L .46425 .47318 L F
0 .9 0 r
.49108 .47757 m .47127 .46299 L .46425 .47318 L F
0 .526 0 r
.52673 .72692 m .49868 .7179 L .4982 .73887 L F
.52673 .72692 m .52717 .70577 L .49868 .7179 L F
0 1 0 r
.32507 .44146 m .33877 .42606 L .31974 .43795 L F
.32507 .44146 m .34144 .42785 L .33877 .42606 L F
0 .624 0 r
.56057 .60877 m .53369 .60292 L .5412 .62505 L F
.56057 .60877 m .55214 .5871 L .53369 .60292 L F
0 1 0 r
.39405 .44115 m .37632 .42769 L .37347 .42924 L F
.39885 .43759 m .37632 .42769 L .39405 .44115 L F
.27452 .45915 m .28947 .43936 L .26767 .45084 L F
.27452 .45915 m .29459 .44573 L .28947 .43936 L F
0 .803 0 r
.52641 .51098 m .49978 .50698 L .51541 .52568 L F
.52641 .51098 m .50952 .49361 L .49978 .50698 L F
0 .987 0 r
.45027 .45001 m .42408 .44513 L .44467 .45837 L F
0 .945 0 r
.47127 .46299 m .45027 .45001 L .44467 .45837 L F
0 .779 0 r
.29036 .79366 m .28986 .77537 L .25539 .76889 L F
0 .743 0 r
.32522 .79739 m .28986 .77537 L .29036 .79366 L F
0 1 0 r
.20422 .52704 m .20821 .49495 L .19094 .51245 L F
.1899 .54684 m .20422 .52704 L .19094 .51245 L F
0 .546 0 r
.46223 .78667 m .43186 .77485 L .42962 .79317 L F
.46223 .78667 m .46513 .76813 L .43186 .77485 L F
0 .748 0 r
.54161 .52954 m .51541 .52568 L .52944 .54538 L F
.54161 .52954 m .52641 .51098 L .51541 .52568 L F
0 1 0 r
.29459 .44573 m .31193 .42967 L .28947 .43936 L F
.29459 .44573 m .31533 .43399 L .31193 .42967 L F
.31974 .43795 m .33656 .42405 L .31533 .43399 L F
.31974 .43795 m .33877 .42606 L .33656 .42405 L F
.19492 .68526 m .17246 .64878 L .16776 .67094 L F
0 .999 0 r
.19242 .70705 m .19492 .68526 L .16776 .67094 L F
0 1 0 r
.39885 .43759 m .37872 .42588 L .37632 .42769 L F
.40268 .43359 m .37872 .42588 L .39885 .43759 L F
.42408 .44513 m .40268 .43359 L .39885 .43759 L F
.42826 .43872 m .40268 .43359 L .42408 .44513 L F
0 .987 0 r
.45027 .45001 m .42826 .43872 L .42408 .44513 L F
0 1 0 r
.17893 .62652 m .16611 .58871 L .15688 .61043 L F
.17246 .64878 m .17893 .62652 L .15688 .61043 L F
.3592 .43217 m .35811 .41601 L .35534 .43201 L F
.36304 .43197 m .35811 .41601 L .3592 .43217 L F
.35534 .43201 m .35811 .41601 L .35154 .43147 L F
.36675 .4314 m .35811 .41601 L .36304 .43197 L F
0 .508 0 r
.55216 .69131 m .52581 .68398 L .52717 .70577 L F
.55216 .69131 m .5505 .66944 L .52581 .68398 L F
0 1 0 r
.1899 .54684 m .19094 .51245 L .17524 .53113 L F
.17715 .56745 m .1899 .54684 L .17524 .53113 L F
.35154 .43147 m .35811 .41601 L .3479 .43059 L F
.37026 .43049 m .35811 .41601 L .36675 .4314 L F
.3479 .43059 m .35811 .41601 L .34451 .42937 L F
0 .56 0 r
.56692 .63073 m .5412 .62505 L .54683 .64729 L F
.56692 .63073 m .56057 .60877 L .5412 .62505 L F
0 1 0 r
.37347 .42924 m .35811 .41601 L .37026 .43049 L F
0 .689 0 r
.55494 .54913 m .52944 .54538 L .54172 .56591 L F
.55494 .54913 m .54161 .52954 L .52944 .54538 L F
0 1 0 r
.34451 .42937 m .35811 .41601 L .34144 .42785 L F
.31533 .43399 m .33488 .42186 L .31193 .42967 L F
.31533 .43399 m .33656 .42405 L .33488 .42186 L F
.37632 .42769 m .35811 .41601 L .37347 .42924 L F
.40268 .43359 m .38062 .42384 L .37872 .42588 L F
.40543 .42923 m .38062 .42384 L .40268 .43359 L F
.42826 .43872 m .40543 .42923 L .40268 .43359 L F
0 .647 0 r
.35949 .81514 m .36047 .79856 L .32522 .79739 L F
0 .599 0 r
.39345 .81379 m .36047 .79856 L .35949 .81514 L F
.39345 .81379 m .39549 .79715 L .36047 .79856 L F
0 1 0 r
.34144 .42785 m .35811 .41601 L .33877 .42606 L F
.26767 .45084 m .28597 .43259 L .26295 .44199 L F
.26767 .45084 m .28947 .43936 L .28597 .43259 L F
.24674 .46401 m .26767 .45084 L .26295 .44199 L F
.37872 .42588 m .35811 .41601 L .37632 .42769 L F
.24674 .46401 m .26295 .44199 L .24078 .4532 L F
.22686 .47875 m .24674 .46401 L .24078 .4532 L F
0 .93 0 r
.22217 .73989 m .19242 .70705 L .19153 .72818 L F
0 .89 0 r
.22264 .75988 m .22217 .73989 L .19153 .72818 L F
0 .858 0 r
.25539 .76889 m .22217 .73989 L .22264 .75988 L F
0 1 0 r
.28947 .43936 m .30965 .42508 L .28597 .43259 L F
.28947 .43936 m .31193 .42967 L .30965 .42508 L F
0 .983 0 r
.45366 .44111 m .42826 .43872 L .45027 .45001 L F
0 .937 0 r
.4756 .45213 m .45027 .45001 L .47127 .46299 L F
.4756 .45213 m .45366 .44111 L .45027 .45001 L F
0 .811 0 r
.25656 .78741 m .25539 .76889 L .22264 .75988 L F
0 .779 0 r
.29036 .79366 m .25539 .76889 L .25656 .78741 L F
0 1 0 r
.17715 .56745 m .17524 .53113 L .16125 .55081 L F
.16611 .58871 m .17715 .56745 L .16125 .55081 L F
0 .687 0 r
.3253 .81402 m .32522 .79739 L .29036 .79366 L F
0 .647 0 r
.35949 .81514 m .32522 .79739 L .3253 .81402 L F
0 .887 0 r
.49635 .46489 m .47127 .46299 L .49108 .47757 L F
.49635 .46489 m .4756 .45213 L .47127 .46299 L F
0 1 0 r
.43074 .43192 m .40543 .42923 L .42826 .43872 L F
0 .983 0 r
.45366 .44111 m .43074 .43192 L .42826 .43872 L F
0 .542 0 r
.42654 .80998 m .39549 .79715 L .39345 .81379 L F
.42654 .80998 m .42962 .79317 L .39549 .79715 L F
0 .456 0 r
.52446 .74723 m .4982 .73887 L .49621 .75888 L F
.52446 .74723 m .52673 .72692 L .4982 .73887 L F
0 1 0 r
.33877 .42606 m .35811 .41601 L .33656 .42405 L F
0 .47 0 r
.49269 .77774 m .46513 .76813 L .46223 .78667 L F
.49269 .77774 m .49621 .75888 L .46513 .76813 L F
0 1 0 r
.22686 .47875 m .24078 .4532 L .21967 .46615 L F
.20821 .49495 m .22686 .47875 L .21967 .46615 L F
.38062 .42384 m .35811 .41601 L .37872 .42588 L F
0 .623 0 r
.56628 .56958 m .54172 .56591 L .55214 .5871 L F
.56628 .56958 m .55494 .54913 L .54172 .56591 L F
0 1 0 r
.31193 .42967 m .33377 .41954 L .30965 .42508 L F
.31193 .42967 m .33488 .42186 L .33377 .41954 L F
.17246 .64878 m .15688 .61043 L .14958 .63242 L F
.16776 .67094 m .17246 .64878 L .14958 .63242 L F
0 .832 0 r
.51571 .47929 m .49108 .47757 L .50952 .49361 L F
.51571 .47929 m .49635 .46489 L .49108 .47757 L F
0 1 0 r
.40543 .42923 m .38198 .42164 L .38062 .42384 L F
.40703 .42463 m .38198 .42164 L .40543 .42923 L F
.43074 .43192 m .40703 .42463 L .40543 .42923 L F
.33656 .42405 m .35811 .41601 L .33488 .42186 L F
.38198 .42164 m .35811 .41601 L .38062 .42384 L F
0 .999 0 r
.19242 .70705 m .16776 .67094 L .16491 .6928 L F
0 .964 0 r
.19153 .72818 m .19242 .70705 L .16491 .6928 L F
0 1 0 r
.20821 .49495 m .21967 .46615 L .19982 .4807 L F
.19094 .51245 m .20821 .49495 L .19982 .4807 L F
0 .488 0 r
.5711 .65279 m .54683 .64729 L .5505 .66944 L F
.5711 .65279 m .56692 .63073 L .54683 .64729 L F
0 .434 0 r
.55175 .71268 m .52717 .70577 L .52673 .72692 L F
.55175 .71268 m .55216 .69131 L .52717 .70577 L F
0 .772 0 r
.53349 .4952 m .50952 .49361 L .52641 .51098 L F
.53349 .4952 m .51571 .47929 L .50952 .49361 L F
0 1 0 r
.33488 .42186 m .35811 .41601 L .33377 .41954 L F
0 .723 0 r
.29151 .81046 m .29036 .79366 L .25656 .78741 L F
0 .687 0 r
.3253 .81402 m .29036 .79366 L .29151 .81046 L F
0 1 0 r
.38275 .41931 m .35811 .41601 L .38198 .42164 L F
.40703 .42463 m .38275 .41931 L .38198 .42164 L F
0 .473 0 r
.45814 .80377 m .42962 .79317 L .42654 .80998 L F
.45814 .80377 m .46223 .78667 L .42962 .79317 L F
0 1 0 r
.16611 .58871 m .16125 .55081 L .14912 .57134 L F
.15688 .61043 m .16611 .58871 L .14912 .57134 L F
.30965 .42508 m .33325 .41715 L .30854 .42035 L F
.30965 .42508 m .33377 .41954 L .33325 .41715 L F
.28597 .43259 m .30965 .42508 L .30854 .42035 L F
.28597 .43259 m .30854 .42035 L .28422 .42558 L F
.26295 .44199 m .28597 .43259 L .28422 .42558 L F
.40743 .41989 m .38275 .41931 L .40703 .42463 L F
.43144 .42489 m .40703 .42463 L .43074 .43192 L F
.43144 .42489 m .40743 .41989 L .40703 .42463 L F
.33377 .41954 m .35811 .41601 L .33325 .41715 L F
0 .981 0 r
.45473 .4319 m .43074 .43192 L .45366 .44111 L F
.45473 .4319 m .43144 .42489 L .43074 .43192 L F
0 1 0 r
.19094 .51245 m .19982 .4807 L .18141 .49676 L F
.17524 .53113 m .19094 .51245 L .18141 .49676 L F
.38292 .41692 m .35811 .41601 L .38275 .41931 L F
.40743 .41989 m .38292 .41692 L .38275 .41931 L F
0 .55 0 r
.57548 .59072 m .55214 .5871 L .56057 .60877 L F
.57548 .59072 m .56628 .56958 L .55214 .5871 L F
0 1 0 r
.26295 .44199 m .28422 .42558 L .2605 .4328 L F
.24078 .4532 m .26295 .44199 L .2605 .4328 L F
0 .93 0 r
.47708 .44085 m .45366 .44111 L .4756 .45213 L F
.47708 .44085 m .45473 .4319 L .45366 .44111 L F
0 .705 0 r
.54952 .51251 m .52641 .51098 L .54161 .52954 L F
.54952 .51251 m .53349 .4952 L .52641 .51098 L F
0 1 0 r
.36474 .40233 m .35811 .41601 L .36843 .40325 L F
.36087 .40178 m .35811 .41601 L .36474 .40233 L F
0 0 0 r
.35814 .41506 m
.35835 .4148 L
s
0 1 0 r
.35694 .40161 m .35811 .41601 L .36087 .40178 L F
.35303 .40182 m .35811 .41601 L .35694 .40161 L F
.34925 .40241 m .35811 .41601 L .35303 .40182 L F
.34569 .40336 m .35811 .41601 L .34925 .40241 L F
.34244 .40465 m .35811 .41601 L .34569 .40336 L F
.33959 .40624 m .35811 .41601 L .34244 .40465 L F
.33721 .4081 m .35811 .41601 L .33959 .40624 L F
.33534 .41017 m .35811 .41601 L .33721 .4081 L F
.33404 .41241 m .35811 .41601 L .33534 .41017 L F
.33334 .41476 m .35811 .41601 L .33404 .41241 L F
.33325 .41715 m .35811 .41601 L .33334 .41476 L F
.38247 .41453 m .35811 .41601 L .38292 .41692 L F
.38142 .41219 m .35811 .41601 L .38247 .41453 L F
.37979 .40997 m .35811 .41601 L .38142 .41219 L F
.37762 .40791 m .35811 .41601 L .37979 .40997 L F
.37495 .40607 m .35811 .41601 L .37762 .40791 L F
.37187 .40451 m .35811 .41601 L .37495 .40607 L F
.36843 .40325 m .35811 .41601 L .37187 .40451 L F
.30854 .42035 m .33325 .41715 L .33334 .41476 L F
.40662 .41513 m .38292 .41692 L .40743 .41989 L F
.40662 .41513 m .38247 .41453 L .38292 .41692 L F
.24078 .4532 m .2605 .4328 L .23759 .44195 L F
.21967 .46615 m .24078 .4532 L .23759 .44195 L F
.16776 .67094 m .14958 .63242 L .14431 .65448 L F
.16491 .6928 m .16776 .67094 L .14431 .65448 L F
.30854 .42035 m .33334 .41476 L .30865 .41559 L F
.28422 .42558 m .30854 .42035 L .30865 .41559 L F
0 .89 0 r
.22264 .75988 m .19153 .72818 L .19228 .74846 L F
0 .84 0 r
.22446 .77871 m .22264 .75988 L .19228 .74846 L F
0 .811 0 r
.25656 .78741 m .22264 .75988 L .22446 .77871 L F
0 .873 0 r
.49827 .45169 m .4756 .45213 L .49635 .46489 L F
.49827 .45169 m .47708 .44085 L .4756 .45213 L F
0 1 0 r
.43034 .41781 m .40743 .41989 L .43144 .42489 L F
.43034 .41781 m .40662 .41513 L .40743 .41989 L F
.30865 .41559 m .33334 .41476 L .33404 .41241 L F
.17524 .53113 m .18141 .49676 L .16464 .51419 L F
.16125 .55081 m .17524 .53113 L .16464 .51419 L F
.40459 .41046 m .38247 .41453 L .40662 .41513 L F
.40459 .41046 m .38142 .41219 L .38247 .41453 L F
0 .405 0 r
.57303 .67473 m .5505 .66944 L .55216 .69131 L F
.57303 .67473 m .5711 .65279 L .5505 .66944 L F
0 .373 0 r
.52035 .7665 m .49621 .75888 L .49269 .77774 L F
.52035 .7665 m .52446 .74723 L .49621 .75888 L F
0 1 0 r
.15688 .61043 m .14912 .57134 L .13899 .59253 L F
.14958 .63242 m .15688 .61043 L .13899 .59253 L F
0 .753 0 r
.25875 .80448 m .25656 .78741 L .22446 .77871 L F
0 .723 0 r
.29151 .81046 m .25656 .78741 L .25875 .80448 L F
0 .576 0 r
.35841 .82998 m .35949 .81514 L .3253 .81402 L F
0 .525 0 r
.39093 .8287 m .35949 .81514 L .35841 .82998 L F
.39093 .8287 m .39345 .81379 L .35949 .81514 L F
0 1 0 r
.28422 .42558 m .30865 .41559 L .28427 .4185 L F
.2605 .4328 m .28422 .42558 L .28427 .4185 L F
.21967 .46615 m .23759 .44195 L .21573 .45298 L F
.19982 .4807 m .21967 .46615 L .21573 .45298 L F
0 .631 0 r
.56362 .53105 m .54161 .52954 L .55494 .54913 L F
.56362 .53105 m .54952 .51251 L .54161 .52954 L F
0 .964 0 r
.19153 .72818 m .16491 .6928 L .16397 .71415 L F
0 .92 0 r
.19228 .74846 m .19153 .72818 L .16397 .71415 L F
0 .387 0 r
.48763 .79524 m .46223 .78667 L .45814 .80377 L F
.48763 .79524 m .49269 .77774 L .46223 .78667 L F
0 .98 0 r
.45341 .42258 m .43144 .42489 L .45473 .4319 L F
.45341 .42258 m .43034 .41781 L .43144 .42489 L F
0 1 0 r
.30998 .4109 m .33404 .41241 L .33534 .41017 L F
.30865 .41559 m .33404 .41241 L .30998 .4109 L F
.4014 .406 m .38142 .41219 L .40459 .41046 L F
.4014 .406 m .37979 .40997 L .38142 .41219 L F
0 .467 0 r
.58243 .61236 m .56057 .60877 L .56692 .63073 L F
.58243 .61236 m .57548 .59072 L .56057 .60877 L F
0 .618 0 r
.32567 .82893 m .3253 .81402 L .29151 .81046 L F
0 .576 0 r
.35841 .82998 m .3253 .81402 L .32567 .82893 L F
0 .809 0 r
.5181 .46434 m .49635 .46489 L .51571 .47929 L F
.5181 .46434 m .49827 .45169 L .49635 .46489 L F
0 .463 0 r
.42261 .8251 m .39345 .81379 L .39093 .8287 L F
.42261 .8251 m .42654 .80998 L .39345 .81379 L F
0 .347 0 r
.54923 .73335 m .52673 .72692 L .52446 .74723 L F
.54923 .73335 m .55175 .71268 L .52673 .72692 L F
0 1 0 r
.28427 .4185 m .30865 .41559 L .30998 .4109 L F
.42742 .41085 m .40662 .41513 L .43034 .41781 L F
.42742 .41085 m .40459 .41046 L .40662 .41513 L F
.31251 .40642 m .33534 .41017 L .33721 .4081 L F
.30998 .4109 m .33534 .41017 L .31251 .40642 L F
.3971 .40188 m .37979 .40997 L .4014 .406 L F
.3971 .40188 m .37762 .40791 L .37979 .40997 L F
.2605 .4328 m .28427 .4185 L .26042 .42348 L F
.23759 .44195 m .2605 .4328 L .26042 .42348 L F
0 .924 0 r
.47561 .42942 m .45473 .4319 L .47708 .44085 L F
.47561 .42942 m .45341 .42258 L .45473 .4319 L F
0 1 0 r
.16125 .55081 m .16464 .51419 L .14968 .53285 L F
.14912 .57134 m .16125 .55081 L .14968 .53285 L F
.19982 .4807 m .21573 .45298 L .19512 .4658 L F
.18141 .49676 m .19982 .4807 L .19512 .4658 L F
.31618 .40226 m .33721 .4081 L .33959 .40624 L F
.31251 .40642 m .33721 .4081 L .31618 .40226 L F
.39181 .39818 m .37762 .40791 L .3971 .40188 L F
.39181 .39818 m .37495 .40607 L .37762 .40791 L F
0 .736 0 r
.53635 .4787 m .51571 .47929 L .53349 .4952 L F
.53635 .4787 m .5181 .46434 L .51571 .47929 L F
0 .652 0 r
.29331 .82555 m .29151 .81046 L .25875 .80448 L F
0 .618 0 r
.32567 .82893 m .29151 .81046 L .29331 .82555 L F
0 .546 0 r
.57563 .55068 m .55494 .54913 L .56628 .56958 L F
.57563 .55068 m .56362 .53105 L .55494 .54913 L F
0 1 0 r
.16491 .6928 m .14431 .65448 L .14115 .67642 L F
0 .995 0 r
.16397 .71415 m .16491 .6928 L .14115 .67642 L F
0 .385 0 r
.45284 .81924 m .42654 .80998 L .42261 .8251 L F
.45284 .81924 m .45814 .80377 L .42654 .80998 L F
0 1 0 r
.32092 .39852 m .33959 .40624 L .34244 .40465 L F
.31618 .40226 m .33959 .40624 L .32092 .39852 L F
.28614 .41152 m .30998 .4109 L .31251 .40642 L F
.28427 .4185 m .30998 .4109 L .28614 .41152 L F
.38565 .39502 m .37495 .40607 L .39181 .39818 L F
.38565 .39502 m .37187 .40451 L .37495 .40607 L F
.26042 .42348 m .28427 .4185 L .28614 .41152 L F
.42273 .40419 m .40459 .41046 L .42742 .41085 L F
.42273 .40419 m .4014 .406 L .40459 .41046 L F
.14958 .63242 m .13899 .59253 L .13099 .6142 L F
.14431 .65448 m .14958 .63242 L .13099 .6142 L F
0 .981 0 r
.44968 .4134 m .43034 .41781 L .45341 .42258 L F
.44968 .4134 m .42742 .41085 L .43034 .41781 L F
0 1 0 r
.23759 .44195 m .26042 .42348 L .23733 .43052 L F
.21573 .45298 m .23759 .44195 L .23733 .43052 L F
.3266 .3953 m .34244 .40465 L .34569 .40336 L F
.32092 .39852 m .34244 .40465 L .3266 .3953 L F
.37877 .39248 m .37187 .40451 L .38565 .39502 L F
.37877 .39248 m .36843 .40325 L .37187 .40451 L F
0 .31 0 r
.57264 .69635 m .55216 .69131 L .55175 .71268 L F
.57264 .69635 m .57303 .67473 L .55216 .69131 L F
0 .859 0 r
.49672 .43828 m .47708 .44085 L .49827 .45169 L F
.49672 .43828 m .47561 .42942 L .47708 .44085 L F
0 .372 0 r
.58702 .63429 m .56692 .63073 L .5711 .65279 L F
.58702 .63429 m .58243 .61236 L .56692 .63073 L F
0 1 0 r
.33309 .3927 m .34569 .40336 L .34925 .40241 L F
.3266 .3953 m .34569 .40336 L .33309 .3927 L F
.37136 .39063 m .36843 .40325 L .37877 .39248 L F
0 0 0 r
.3678 .40309 m
.36871 .40205 L
s
0 1 0 r
.37136 .39063 m .36474 .40233 L .36843 .40325 L F
.18141 .49676 m .19512 .4658 L .17597 .48031 L F
.16464 .51419 m .18141 .49676 L .17597 .48031 L F
.34023 .39078 m .34925 .40241 L .35303 .40182 L F
.33309 .3927 m .34925 .40241 L .34023 .39078 L F
.36359 .38951 m .36474 .40233 L .37136 .39063 L F
.36359 .38951 m .36087 .40178 L .36474 .40233 L F
0 .84 0 r
.22446 .77871 m .19228 .74846 L .19472 .76768 L F
0 .777 0 r
.22765 .79616 m .22446 .77871 L .19472 .76768 L F
0 .753 0 r
.25875 .80448 m .22446 .77871 L .22765 .79616 L F
0 1 0 r
.34782 .38958 m .35303 .40182 L .35694 .40161 L F
.34023 .39078 m .35303 .40182 L .34782 .38958 L F
.35568 .38916 m .36087 .40178 L .36359 .38951 L F
.35568 .38916 m .35694 .40161 L .36087 .40178 L F
.28982 .40482 m .31251 .40642 L .31618 .40226 L F
.28614 .41152 m .31251 .40642 L .28982 .40482 L F
.34782 .38958 m .35694 .40161 L .35568 .38916 L F
.14912 .57134 m .14968 .53285 L .13669 .55256 L F
.13899 .59253 m .14912 .57134 L .13669 .55256 L F
.41639 .39801 m .4014 .406 L .42273 .40419 L F
.41639 .39801 m .3971 .40188 L .4014 .406 L F
0 .652 0 r
.55285 .49465 m .53349 .4952 L .54952 .51251 L F
.55285 .49465 m .53635 .4787 L .53349 .4952 L F
0 .274 0 r
.51438 .7845 m .49269 .77774 L .48763 .79524 L F
.51438 .7845 m .52035 .7665 L .49269 .77774 L F
0 .92 0 r
.19228 .74846 m .16397 .71415 L .16499 .73478 L F
0 .864 0 r
.19472 .76768 m .19228 .74846 L .16499 .73478 L F
0 1 0 r
.26042 .42348 m .28614 .41152 L .26276 .41428 L F
.23733 .43052 m .26042 .42348 L .26276 .41428 L F
0 .449 0 r
.5854 .57123 m .56628 .56958 L .57548 .59072 L F
.5854 .57123 m .57563 .55068 L .56628 .56958 L F
0 1 0 r
.21573 .45298 m .23733 .43052 L .21523 .43957 L F
.19512 .4658 m .21573 .45298 L .21523 .43957 L F
0 .245 0 r
.54458 .7531 m .52446 .74723 L .52035 .7665 L F
.54458 .7531 m .54923 .73335 L .52446 .74723 L F
0 .92 0 r
.47116 .41812 m .45341 .42258 L .47561 .42942 L F
.47116 .41812 m .44968 .4134 L .45341 .42258 L F
0 1 0 r
.26276 .41428 m .28614 .41152 L .28982 .40482 L F
0 .678 0 r
.26195 .8199 m .25875 .80448 L .22765 .79616 L F
0 .652 0 r
.29331 .82555 m .25875 .80448 L .26195 .8199 L F
0 .985 0 r
.4436 .40459 m .42742 .41085 L .44968 .4134 L F
.4436 .40459 m .42273 .40419 L .42742 .41085 L F
0 .782 0 r
.51651 .44911 m .49827 .45169 L .5181 .46434 L F
.51651 .44911 m .49672 .43828 L .49827 .45169 L F
0 .284 0 r
.48103 .81117 m .45814 .80377 L .45284 .81924 L F
.48103 .81117 m .48763 .79524 L .45814 .80377 L F
0 1 0 r
.29524 .39858 m .31618 .40226 L .32092 .39852 L F
.28982 .40482 m .31618 .40226 L .29524 .39858 L F
.40852 .39246 m .3971 .40188 L .41639 .39801 L F
.40852 .39246 m .39181 .39818 L .3971 .40188 L F
0 .486 0 r
.35724 .84289 m .35841 .82998 L .32567 .82893 L F
0 .431 0 r
.38794 .8417 m .35841 .82998 L .35724 .84289 L F
.38794 .8417 m .39093 .8287 L .35841 .82998 L F
0 1 0 r
.14431 .65448 m .13099 .6142 L .12521 .63615 L F
.14115 .67642 m .14431 .65448 L .12521 .63615 L F
.16464 .51419 m .17597 .48031 L .15848 .4964 L F
.14968 .53285 m .16464 .51419 L .15848 .4964 L F
0 .529 0 r
.32631 .84191 m .32567 .82893 L .29331 .82555 L F
0 .486 0 r
.35724 .84289 m .32567 .82893 L .32631 .84191 L F
0 .995 0 r
.16397 .71415 m .14115 .67642 L .14016 .69802 L F
0 .944 0 r
.16499 .73478 m .16397 .71415 L .14016 .69802 L F
0 .362 0 r
.41785 .83834 m .39093 .8287 L .38794 .8417 L F
.41785 .83834 m .42261 .8251 L .39093 .8287 L F
0 .263 0 r
.58916 .65632 m .5711 .65279 L .57303 .67473 L F
.58916 .65632 m .58702 .63429 L .5711 .65279 L F
0 .555 0 r
.56738 .51207 m .54952 .51251 L .56362 .53105 L F
.56738 .51207 m .55285 .49465 L .54952 .51251 L F
0 1 0 r
.30226 .39296 m .32092 .39852 L .3266 .3953 L F
.29524 .39858 m .32092 .39852 L .30226 .39296 L F
0 .217 0 r
.5699 .71743 m .55175 .71268 L .54923 .73335 L F
.5699 .71743 m .57264 .69635 L .55175 .71268 L F
0 1 0 r
.13899 .59253 m .13669 .55256 L .12583 .57317 L F
.13099 .6142 m .13899 .59253 L .12583 .57317 L F
.39933 .3877 m .39181 .39818 L .40852 .39246 L F
.39933 .3877 m .38565 .39502 L .39181 .39818 L F
.23733 .43052 m .26276 .41428 L .24006 .41919 L F
.21523 .43957 m .23733 .43052 L .24006 .41919 L F
.19512 .4658 m .21523 .43957 L .19434 .45059 L F
.17597 .48031 m .19512 .4658 L .19434 .45059 L F
.26751 .40542 m .28982 .40482 L .29524 .39858 L F
.26276 .41428 m .28982 .40482 L .26751 .40542 L F
0 .844 0 r
.49163 .42498 m .47561 .42942 L .49672 .43828 L F
.49163 .42498 m .47116 .41812 L .47561 .42942 L F
0 .991 0 r
.43529 .39639 m .42273 .40419 L .4436 .40459 L F
.43529 .39639 m .41639 .39801 L .42273 .40419 L F
0 .338 0 r
.59279 .5925 m .57548 .59072 L .58243 .61236 L F
.59279 .5925 m .5854 .57123 L .57548 .59072 L F
0 .691 0 r
.53479 .46184 m .5181 .46434 L .53635 .4787 L F
.53479 .46184 m .51651 .44911 L .5181 .46434 L F
0 .561 0 r
.29576 .83876 m .29331 .82555 L .26195 .8199 L F
0 .529 0 r
.32631 .84191 m .29331 .82555 L .29576 .83876 L F
0 1 0 r
.24006 .41919 m .26276 .41428 L .26751 .40542 L F
.31074 .38812 m .3266 .3953 L .33309 .3927 L F
.30226 .39296 m .3266 .3953 L .31074 .38812 L F
.38904 .38387 m .38565 .39502 L .39933 .3877 L F
.38904 .38387 m .37877 .39248 L .38565 .39502 L F
0 .273 0 r
.44637 .83286 m .42261 .8251 L .41785 .83834 L F
.44637 .83286 m .45284 .81924 L .42261 .8251 L F
0 .917 0 r
.46378 .40724 m .44968 .4134 L .47116 .41812 L F
.46378 .40724 m .4436 .40459 L .44968 .4134 L F
0 1 0 r
.14968 .53285 m .15848 .4964 L .14285 .51393 L F
.13669 .55256 m .14968 .53285 L .14285 .51393 L F
.32044 .38419 m .33309 .3927 L .34023 .39078 L F
.31074 .38812 m .33309 .3927 L .32044 .38419 L F
0 .864 0 r
.19472 .76768 m .16499 .73478 L .16799 .75448 L F
0 .792 0 r
.19886 .78563 m .19472 .76768 L .16799 .75448 L F
0 .777 0 r
.22765 .79616 m .19472 .76768 L .19886 .78563 L F
0 .695 0 r
.23221 .81205 m .22765 .79616 L .19886 .78563 L F
0 .678 0 r
.26195 .8199 m .22765 .79616 L .23221 .81205 L F
0 1 0 r
.37791 .38106 m .37877 .39248 L .38904 .38387 L F
0 0 0 r
.37801 .39229 m
.37871 .39161 L
s
0 1 0 r
.37791 .38106 m .37136 .39063 L .37877 .39248 L F
0 .442 0 r
.57979 .53081 m .56362 .53105 L .57563 .55068 L F
.57979 .53081 m .56738 .51207 L .56362 .53105 L F
0 .194 0 r
.50657 .80104 m .48763 .79524 L .48103 .81117 L F
.50657 .80104 m .51438 .7845 L .48763 .79524 L F
0 1 0 r
.14115 .67642 m .12521 .63615 L .12177 .65817 L F
.14016 .69802 m .14115 .67642 L .12177 .65817 L F
0 .178 0 r
.53779 .77171 m .52035 .7665 L .51438 .7845 L F
.53779 .77171 m .54458 .7531 L .52035 .7665 L F
0 1 0 r
.33114 .38129 m .34023 .39078 L .34782 .38958 L F
.32044 .38419 m .34023 .39078 L .33114 .38129 L F
.27457 .39715 m .29524 .39858 L .30226 .39296 L F
.26751 .40542 m .29524 .39858 L .27457 .39715 L F
.36624 .37937 m .37136 .39063 L .37791 .38106 L F
.36624 .37937 m .36359 .38951 L .37136 .39063 L F
.21523 .43957 m .24006 .41919 L .21827 .42625 L F
.19434 .45059 m .21523 .43957 L .21827 .42625 L F
.17597 .48031 m .19434 .45059 L .17489 .46348 L F
.15848 .4964 m .17597 .48031 L .17489 .46348 L F
0 .999 0 r
.42493 .38901 m .41639 .39801 L .43529 .39639 L F
.42493 .38901 m .40852 .39246 L .41639 .39801 L F
0 1 0 r
.34254 .37949 m .34782 .38958 L .35568 .38916 L F
.33114 .38129 m .34782 .38958 L .34254 .37949 L F
.35435 .37884 m .36359 .38951 L .36624 .37937 L F
.35435 .37884 m .35568 .38916 L .36359 .38951 L F
.13099 .6142 m .12583 .57317 L .11726 .59447 L F
.12521 .63615 m .13099 .6142 L .11726 .59447 L F
.34254 .37949 m .35568 .38916 L .35435 .37884 L F
0 .179 0 r
.58879 .67822 m .57303 .67473 L .57264 .69635 L F
.58879 .67822 m .58916 .65632 L .57303 .67473 L F
0 .751 0 r
.51088 .43398 m .49672 .43828 L .51651 .44911 L F
.51088 .43398 m .49163 .42498 L .49672 .43828 L F
0 .583 0 r
.55133 .47638 m .53635 .4787 L .55285 .49465 L F
.55133 .47638 m .53479 .46184 L .53635 .4787 L F
0 .944 0 r
.16499 .73478 m .14016 .69802 L .14141 .71905 L F
0 .878 0 r
.16799 .75448 m .16499 .73478 L .14141 .71905 L F
0 .581 0 r
.26617 .83348 m .26195 .8199 L .23221 .81205 L F
0 .561 0 r
.29576 .83876 m .26195 .8199 L .26617 .83348 L F
0 .211 0 r
.59769 .6143 m .58243 .61236 L .58702 .63429 L F
.59769 .6143 m .59279 .5925 L .58243 .61236 L F
0 .195 0 r
.47292 .82534 m .45284 .81924 L .44637 .83286 L F
.47292 .82534 m .48103 .81117 L .45284 .81924 L F
0 1 0 r
.24578 .40827 m .26751 .40542 L .27457 .39715 L F
.24006 .41919 m .26751 .40542 L .24578 .40827 L F
.21827 .42625 m .24006 .41919 L .24578 .40827 L F
0 .147 0 r
.56477 .73775 m .54923 .73335 L .54458 .7531 L F
.56477 .73775 m .5699 .71743 L .54923 .73335 L F
0 .916 0 r
.4536 .39709 m .4436 .40459 L .46378 .40724 L F
.4536 .39709 m .43529 .39639 L .4436 .40459 L F
0 .829 0 r
.48306 .41216 m .47116 .41812 L .49163 .42498 L F
.48306 .41216 m .46378 .40724 L .47116 .41812 L F
0 1 0 r
.13669 .55256 m .14285 .51393 L .12927 .53276 L F
.12583 .57317 m .13669 .55256 L .12927 .53276 L F
.2838 .38968 m .30226 .39296 L .31074 .38812 L F
.27457 .39715 m .30226 .39296 L .2838 .38968 L F
.41277 .38267 m .40852 .39246 L .42493 .38901 L F
.41277 .38267 m .39933 .3877 L .40852 .39246 L F
0 .368 0 r
.35598 .85368 m .35724 .84289 L .32631 .84191 L F
0 .31 0 r
.38451 .85258 m .35724 .84289 L .35598 .85368 L F
.38451 .85258 m .38794 .8417 L .35724 .84289 L F
0 .319 0 r
.58989 .5507 m .57563 .55068 L .5854 .57123 L F
.58989 .5507 m .57979 .53081 L .57563 .55068 L F
0 .411 0 r
.32724 .85278 m .32631 .84191 L .29576 .83876 L F
0 .368 0 r
.35598 .85368 m .32631 .84191 L .32724 .85278 L F
0 .232 0 r
.41227 .84949 m .38794 .8417 L .38451 .85258 L F
.41227 .84949 m .41785 .83834 L .38794 .8417 L F
0 1 0 r
.15848 .4964 m .17489 .46348 L .15708 .47815 L F
.14285 .51393 m .15848 .4964 L .15708 .47815 L F
.19434 .45059 m .21827 .42625 L .19762 .43543 L F
.17489 .46348 m .19434 .45059 L .19762 .43543 L F
.29499 .38323 m .31074 .38812 L .32044 .38419 L F
.2838 .38968 m .31074 .38812 L .29499 .38323 L F
0 .635 0 r
.52869 .44506 m .51651 .44911 L .53479 .46184 L F
.52869 .44506 m .51088 .43398 L .51651 .44911 L F
0 .454 0 r
.56594 .49262 m .55285 .49465 L .56738 .51207 L F
.56594 .49262 m .55133 .47638 L .55285 .49465 L F
0 1 0 r
.14016 .69802 m .12177 .65817 L .12075 .68004 L F
0 .956 0 r
.14141 .71905 m .14016 .69802 L .12075 .68004 L F
0 1 0 r
.39912 .37755 m .39933 .3877 L .41277 .38267 L F
.39912 .37755 m .38904 .38387 L .39933 .3877 L F
.12521 .63615 m .11726 .59447 L .11108 .61628 L F
.12177 .65817 m .12521 .63615 L .11108 .61628 L F
0 .792 0 r
.19886 .78563 m .16799 .75448 L .17301 .77303 L F
0 .697 0 r
.2047 .8021 m .19886 .78563 L .17301 .77303 L F
0 .695 0 r
.23221 .81205 m .19886 .78563 L .2047 .8021 L F
0 .44 0 r
.29886 .84988 m .29576 .83876 L .26617 .83348 L F
0 .411 0 r
.32724 .85278 m .29576 .83876 L .29886 .84988 L F
0 1 0 r
.25439 .39803 m .27457 .39715 L .2838 .38968 L F
.24578 .40827 m .27457 .39715 L .25439 .39803 L F
0 .117 0 r
.58586 .69976 m .57264 .69635 L .5699 .71743 L F
.58586 .69976 m .58879 .67822 L .57264 .69635 L F
0 .177 0 r
.43873 .84446 m .41785 .83834 L .41227 .84949 L F
.43873 .84446 m .44637 .83286 L .41785 .83834 L F
0 .918 0 r
.44085 .38794 m .43529 .39639 L .4536 .39709 L F
.44085 .38794 m .42493 .38901 L .43529 .39639 L F
0 .17 0 r
.6 .6364 m .58702 .63429 L .58916 .65632 L F
.6 .6364 m .59769 .6143 L .58702 .63429 L F
0 .587 0 r
.23813 .82616 m .23221 .81205 L .2047 .8021 L F
0 .581 0 r
.26617 .83348 m .23221 .81205 L .23813 .82616 L F
0 .098 0 r
.52888 .78897 m .51438 .7845 L .50657 .80104 L F
.52888 .78897 m .53779 .77171 L .51438 .7845 L F
0 1 0 r
.21827 .42625 m .24578 .40827 L .22486 .41337 L F
.19762 .43543 m .21827 .42625 L .22486 .41337 L F
.30786 .37799 m .32044 .38419 L .33114 .38129 L F
.29499 .38323 m .32044 .38419 L .30786 .37799 L F
.12583 .57317 m .12927 .53276 L .11791 .55272 L F
.11726 .59447 m .12583 .57317 L .11791 .55272 L F
.38433 .37381 m .38904 .38387 L .39912 .37755 L F
0 0 0 r
.38806 .38362 m
.3887 .38316 L
s
0 1 0 r
.38433 .37381 m .37791 .38106 L .38904 .38387 L F
0 .113 0 r
.49694 .8159 m .48103 .81117 L .47292 .82534 L F
.49694 .8159 m .50657 .80104 L .48103 .81117 L F
0 .878 0 r
.16799 .75448 m .14141 .71905 L .14493 .73931 L F
0 .791 0 r
.17301 .77303 m .16799 .75448 L .14493 .73931 L F
0 1 0 r
.22486 .41337 m .24578 .40827 L .25439 .39803 L F
0 .714 0 r
.50122 .41935 m .49163 .42498 L .51088 .43398 L F
.50122 .41935 m .48306 .41216 L .49163 .42498 L F
0 .813 0 r
.47114 .40015 m .46378 .40724 L .48306 .41216 L F
.47114 .40015 m .4536 .39709 L .46378 .40724 L F
0 .223 0 r
.59756 .57157 m .5854 .57123 L .59279 .5925 L F
.59756 .57157 m .58989 .5507 L .5854 .57123 L F
0 .064 0 r
.55726 .75707 m .54458 .7531 L .53779 .77171 L F
.55726 .75707 m .56477 .73775 L .54458 .7531 L F
0 1 0 r
.32206 .37411 m .33114 .38129 L .34254 .37949 L F
.30786 .37799 m .33114 .38129 L .32206 .37411 L F
.3688 .37155 m .37791 .38106 L .38433 .37381 L F
.3688 .37155 m .36624 .37937 L .37791 .38106 L F
.14285 .51393 m .15708 .47815 L .14114 .4945 L F
.12927 .53276 m .14285 .51393 L .14114 .4945 L F
.17489 .46348 m .19762 .43543 L .17834 .44667 L F
.15708 .47815 m .17489 .46348 L .17834 .44667 L F
.33724 .3717 m .34254 .37949 L .35435 .37884 L F
.32206 .37411 m .34254 .37949 L .33724 .3717 L F
.35296 .37083 m .36624 .37937 L .3688 .37155 L F
.35296 .37083 m .35435 .37884 L .36624 .37937 L F
0 .451 0 r
.27139 .84503 m .26617 .83348 L .23813 .82616 L F
0 .44 0 r
.29886 .84988 m .26617 .83348 L .27139 .84503 L F
0 1 0 r
.33724 .3717 m .35435 .37884 L .35296 .37083 L F
0 .345 0 r
.57843 .51041 m .56738 .51207 L .57979 .53081 L F
.57843 .51041 m .56594 .49262 L .56738 .51207 L F
0 1 0 r
.26573 .38877 m .2838 .38968 L .29499 .38323 L F
.25439 .39803 m .2838 .38968 L .26573 .38877 L F
0 .499 0 r
.54484 .45815 m .53479 .46184 L .55133 .47638 L F
.54484 .45815 m .52869 .44506 L .53479 .46184 L F
0 .107 0 r
.46333 .83755 m .44637 .83286 L .43873 .84446 L F
.46333 .83755 m .47292 .82534 L .44637 .83286 L F
0 .923 0 r
.42583 .38006 m .42493 .38901 L .44085 .38794 L F
.42583 .38006 m .41277 .38267 L .42493 .38901 L F
0 1 0 r
.12177 .65817 m .11108 .61628 L .10741 .63838 L F
.12075 .68004 m .12177 .65817 L .10741 .63838 L F
0 .956 0 r
.14141 .71905 m .12075 .68004 L .12219 .70153 L F
0 .872 0 r
.14493 .73931 m .14141 .71905 L .12219 .70153 L F
0 .121 0 r
.59964 .6586 m .58916 .65632 L .58879 .67822 L F
.59964 .6586 m .6 .6364 L .58916 .65632 L F
0 1 0 r
.11726 .59447 m .11791 .55272 L .10892 .57363 L F
.11108 .61628 m .11726 .59447 L .10892 .57363 L F
0 .064 0 r
.58034 .72071 m .5699 .71743 L .56477 .73775 L F
.58034 .72071 m .58586 .69976 L .5699 .71743 L F
0 1 0 r
.19762 .43543 m .22486 .41337 L .20499 .42073 L F
.17834 .44667 m .19762 .43543 L .20499 .42073 L F
0 .22 0 r
.35464 .86218 m .35598 .85368 L .32724 .85278 L F
0 .19 0 r
.38063 .86118 m .35598 .85368 L .35464 .86218 L F
.38063 .86118 m .38451 .85258 L .35598 .85368 L F
0 1 0 r
.23492 .40127 m .25439 .39803 L .26573 .38877 L F
.22486 .41337 m .25439 .39803 L .23492 .40127 L F
0 .566 0 r
.51806 .4288 m .51088 .43398 L .52869 .44506 L F
.51806 .4288 m .50122 .41935 L .51088 .43398 L F
0 .265 0 r
.32846 .86136 m .32724 .85278 L .29886 .84988 L F
0 .22 0 r
.35464 .86218 m .32724 .85278 L .32846 .86136 L F
0 1 0 r
.27954 .38076 m .29499 .38323 L .30786 .37799 L F
.26573 .38877 m .29499 .38323 L .27954 .38076 L F
0 .176 0 r
.60265 .5932 m .59279 .5925 L .59769 .6143 L F
.60265 .5932 m .59756 .57157 L .59279 .5925 L F
0 .158 0 r
.40592 .85839 m .38451 .85258 L .38063 .86118 L F
.40592 .85839 m .41227 .84949 L .38451 .85258 L F
0 .797 0 r
.45612 .38931 m .4536 .39709 L .47114 .40015 L F
.45612 .38931 m .44085 .38794 L .4536 .39709 L F
0 .935 0 r
.40891 .37368 m .41277 .38267 L .42583 .38006 L F
.40891 .37368 m .39912 .37755 L .41277 .38267 L F
0 .697 0 r
.2047 .8021 m .17301 .77303 L .18004 .79022 L F
0 .572 0 r
.21223 .81689 m .2047 .8021 L .18004 .79022 L F
0 .587 0 r
.23813 .82616 m .2047 .8021 L .21223 .81689 L F
0 1 0 r
.20499 .42073 m .22486 .41337 L .23492 .40127 L F
.12927 .53276 m .14114 .4945 L .12727 .51239 L F
.11791 .55272 m .12927 .53276 L .12727 .51239 L F
.15708 .47815 m .17834 .44667 L .16066 .4599 L F
.14114 .4945 m .15708 .47815 L .16066 .4599 L F
0 .014 0 r
.51788 .80467 m .50657 .80104 L .49694 .8159 L F
.51788 .80467 m .52888 .78897 L .50657 .80104 L F
0 .671 0 r
.48769 .40562 m .48306 .41216 L .50122 .41935 L F
.48769 .40562 m .47114 .40015 L .48306 .41216 L F
0 .791 0 r
.17301 .77303 m .14493 .73931 L .15073 .75856 L F
0 .676 0 r
.18004 .79022 m .17301 .77303 L .15073 .75856 L F
0 .234 0 r
.58862 .5296 m .57979 .53081 L .58989 .5507 L F
.58862 .5296 m .57843 .51041 L .57979 .53081 L F
0 .443 0 r
.2454 .8383 m .23813 .82616 L .21223 .81689 L F
0 .451 0 r
.27139 .84503 m .23813 .82616 L .2454 .8383 L F
0 .387 0 r
.55913 .47317 m .55133 .47638 L .56594 .49262 L F
.55913 .47317 m .54484 .45815 L .55133 .47638 L F
0 .299 0 r
.30261 .85873 m .29886 .84988 L .27139 .84503 L F
0 .265 0 r
.32846 .86136 m .29886 .84988 L .30261 .85873 L F
0 0 0 r
.54738 .77518 m .53779 .77171 L .52888 .78897 L F
.54738 .77518 m .55726 .75707 L .53779 .77171 L F
0 .047 0 r
.48555 .82888 m .47292 .82534 L .46333 .83755 L F
.48555 .82888 m .49694 .8159 L .47292 .82534 L F
0 .117 0 r
.42998 .85384 m .41227 .84949 L .40592 .85839 L F
.42998 .85384 m .43873 .84446 L .41227 .84949 L F
0 1 0 r
.29547 .37423 m .30786 .37799 L .32206 .37411 L F
.27954 .38076 m .30786 .37799 L .29547 .37423 L F
0 0 0 r
.59995 .63946 m
.60032 .63873 L
s
0 .953 0 r
.39054 .36901 m .39912 .37755 L .40891 .37368 L F
0 0 0 r
.39784 .37723 m
.39845 .3769 L
s
0 .953 0 r
.39054 .36901 m .38433 .37381 L .39912 .37755 L F
0 1 0 r
.12075 .68004 m .10741 .63838 L .10635 .66055 L F
0 0 0 r
.10685 .6396 m
.10732 .6403 L
s
0 .937 0 r
.12219 .70153 m .12075 .68004 L .10635 .66055 L F
0 1 0 r
.11108 .61628 m .10892 .57363 L .10246 .59527 L F
.10741 .63838 m .11108 .61628 L .10246 .59527 L F
0 .872 0 r
.14493 .73931 m .12219 .70153 L .12615 .72242 L F
0 .759 0 r
.15073 .75856 m .14493 .73931 L .12615 .72242 L F
0 1 0 r
.24824 .3903 m .26573 .38877 L .27954 .38076 L F
.23492 .40127 m .26573 .38877 L .24824 .3903 L F
0 .063 0 r
.59656 .68064 m .58879 .67822 L .58586 .69976 L F
.59656 .68064 m .59964 .6586 L .58879 .67822 L F
0 1 0 r
.3131 .36939 m .32206 .37411 L .33724 .3717 L F
.29547 .37423 m .32206 .37411 L .3131 .36939 L F
0 .98 0 r
.37123 .36619 m .38433 .37381 L .39054 .36901 L F
.37123 .36619 m .3688 .37155 L .38433 .37381 L F
0 .786 0 r
.43836 .37996 m .44085 .38794 L .45612 .38931 L F
.43836 .37996 m .42583 .38006 L .44085 .38794 L F
0 1 0 r
.17834 .44667 m .20499 .42073 L .18638 .43033 L F
.16066 .4599 m .17834 .44667 L .18638 .43033 L F
0 .121 0 r
.60505 .61539 m .59769 .6143 L .6 .6364 L F
.60505 .61539 m .60265 .5932 L .59769 .6143 L F
0 .003 0 r
.57223 .74083 m .56477 .73775 L .55726 .75707 L F
.57223 .74083 m .58034 .72071 L .56477 .73775 L F
0 .319 0 r
.27761 .85435 m .27139 .84503 L .2454 .8383 L F
0 .299 0 r
.30261 .85873 m .27139 .84503 L .27761 .85435 L F
0 1 0 r
.11791 .55272 m .12727 .51239 L .11564 .53165 L F
.10892 .57363 m .11791 .55272 L .11564 .53165 L F
0 .449 0 r
.53336 .44045 m .52869 .44506 L .54484 .45815 L F
.53336 .44045 m .51806 .4288 L .52869 .44506 L F
0 1 0 r
.33196 .36638 m .33724 .3717 L .35296 .37083 L F
.3131 .36939 m .33724 .3717 L .33196 .36638 L F
0 .066 0 r
.45232 .8476 m .43873 .84446 L .42998 .85384 L F
.45232 .8476 m .46333 .83755 L .43873 .84446 L F
0 1 0 r
.35152 .3653 m .3688 .37155 L .37123 .36619 L F
.35152 .3653 m .35296 .37083 L .3688 .37155 L F
.14114 .4945 m .16066 .4599 L .14479 .47503 L F
.12727 .51239 m .14114 .4945 L .14479 .47503 L F
.33196 .36638 m .35296 .37083 L .35152 .3653 L F
.21636 .4069 m .23492 .40127 L .24824 .3903 L F
.20499 .42073 m .23492 .40127 L .21636 .4069 L F
0 .181 0 r
.59635 .55003 m .58989 .5507 L .59756 .57157 L F
.59635 .55003 m .58862 .5296 L .58989 .5507 L F
0 1 0 r
.18638 .43033 m .20499 .42073 L .21636 .4069 L F
0 0 0 r
.40696 .37319 m
.40788 .37286 L
s
0 .632 0 r
.47055 .3932 m .47114 .40015 L .48769 .40562 L F
.47055 .3932 m .45612 .38931 L .47114 .40015 L F
0 .25 0 r
.57136 .48998 m .56594 .49262 L .57843 .51041 L F
.57136 .48998 m .55913 .47317 L .56594 .49262 L F
0 .533 0 r
.50306 .4135 m .50122 .41935 L .51806 .4288 L F
.50306 .4135 m .48769 .40562 L .50122 .41935 L F
0 .572 0 r
.21223 .81689 m .18004 .79022 L .18905 .80582 L F
0 .441 0 r
.22142 .82979 m .21223 .81689 L .18905 .80582 L F
0 .443 0 r
.2454 .8383 m .21223 .81689 L .22142 .82979 L F
0 .676 0 r
.18004 .79022 m .15073 .75856 L .15882 .77658 L F
0 .535 0 r
.18905 .80582 m .18004 .79022 L .15882 .77658 L F
0 1 0 r
.26454 .38079 m .27954 .38076 L .29547 .37423 L F
.24824 .3903 m .27954 .38076 L .26454 .38079 L F
0 .783 0 r
.4183 .37238 m .42583 .38006 L .43836 .37996 L F
.4183 .37238 m .40891 .37368 L .42583 .38006 L F
0 0 0 r
.50485 .81858 m .49694 .8159 L .48555 .82888 L F
.50485 .81858 m .51788 .80467 L .49694 .8159 L F
0 .174 0 r
.35324 .8682 m .35464 .86218 L .32846 .86136 L F
0 .147 0 r
.37635 .86732 m .35464 .86218 L .35324 .8682 L F
.37635 .86732 m .38063 .86118 L .35464 .86218 L F
0 .937 0 r
.12219 .70153 m .10635 .66055 L .10796 .68254 L F
0 .82 0 r
.12615 .72242 m .12219 .70153 L .10796 .68254 L F
0 0 0 r
.53519 .79184 m .52888 .78897 L .51788 .80467 L F
.53519 .79184 m .54738 .77518 L .52888 .78897 L F
0 1 0 r
.10741 .63838 m .10246 .59527 L .09863 .61745 L F
0 .979 0 r
.10635 .66055 m .10741 .63838 L .09863 .61745 L F
0 .195 0 r
.32995 .86747 m .32846 .86136 L .30261 .85873 L F
0 .174 0 r
.35324 .8682 m .32846 .86136 L .32995 .86747 L F
0 .112 0 r
.39882 .86484 m .38063 .86118 L .37635 .86732 L F
.39882 .86484 m .40592 .85839 L .38063 .86118 L F
0 0 0 r
.59074 .70229 m .58586 .69976 L .58034 .72071 L F
.59074 .70229 m .59656 .68064 L .58586 .69976 L F
0 .323 0 r
.25398 .84827 m .2454 .8383 L .22142 .82979 L F
0 .319 0 r
.27761 .85435 m .2454 .8383 L .25398 .84827 L F
0 1 0 r
.16066 .4599 m .18638 .43033 L .16928 .44212 L F
.14479 .47503 m .16066 .4599 L .16928 .44212 L F
0 .001 0 r
.47245 .83978 m .46333 .83755 L .45232 .8476 L F
.47245 .83978 m .48555 .82888 L .46333 .83755 L F
0 .057 0 r
.60469 .63789 m .6 .6364 L .59964 .6586 L F
.60469 .63789 m .60505 .61539 L .6 .6364 L F
0 .759 0 r
.15073 .75856 m .12615 .72242 L .13264 .74246 L F
0 .613 0 r
.15882 .77658 m .15073 .75856 L .13264 .74246 L F
0 1 0 r
.10892 .57363 m .11564 .53165 L .10644 .55212 L F
.10246 .59527 m .10892 .57363 L .10644 .55212 L F
0 .209 0 r
.30698 .86515 m .30261 .85873 L .27761 .85435 L F
0 .195 0 r
.32995 .86747 m .30261 .85873 L .30698 .86515 L F
0 .303 0 r
.54691 .45424 m .54484 .45815 L .55913 .47317 L F
.54691 .45424 m .53336 .44045 L .54484 .45815 L F
0 1 0 r
.28341 .37303 m .29547 .37423 L .3131 .36939 L F
.26454 .38079 m .29547 .37423 L .28341 .37303 L F
.12727 .51239 m .14479 .47503 L .13095 .49194 L F
.11564 .53165 m .12727 .51239 L .13095 .49194 L F
0 .068 0 r
.42017 .86082 m .40592 .85839 L .39882 .86484 L F
.42017 .86082 m .42998 .85384 L .40592 .85839 L F
0 0 0 r
.56156 .75989 m .55726 .75707 L .54738 .77518 L F
.56156 .75989 m .57223 .74083 L .55726 .75707 L F
0 .793 0 r
.39648 .36682 m .40891 .37368 L .4183 .37238 L F
.39648 .36682 m .39054 .36901 L .40891 .37368 L F
0 .118 0 r
.60149 .57148 m .59756 .57157 L .60265 .5932 L F
.60149 .57148 m .59635 .55003 L .59756 .57157 L F
0 1 0 r
.23154 .39433 m .24824 .3903 L .26454 .38079 L F
.21636 .4069 m .24824 .3903 L .23154 .39433 L F
0 .615 0 r
.4502 .38246 m .45612 .38931 L .47055 .3932 L F
.4502 .38246 m .43836 .37996 L .45612 .38931 L F
0 .185 0 r
.58135 .50845 m .57843 .51041 L .58862 .5296 L F
.58135 .50845 m .57136 .48998 L .57843 .51041 L F
0 1 0 r
.18638 .43033 m .21636 .4069 L .19895 .41492 L F
.16928 .44212 m .18638 .43033 L .19895 .41492 L F
.19895 .41492 m .21636 .4069 L .23154 .39433 L F
0 .997 0 r
.30435 .36726 m .3131 .36939 L .33196 .36638 L F
0 1 0 r
.28341 .37303 m .3131 .36939 L .30435 .36726 L F
0 .383 0 r
.51704 .42377 m .51806 .4288 L .53336 .44045 L F
.51704 .42377 m .50306 .4135 L .51806 .4288 L F
0 .819 0 r
.37351 .36346 m .39054 .36901 L .39648 .36682 L F
.37351 .36346 m .37123 .36619 L .39054 .36901 L F
0 0 0 r
.41462 .37145 m
.41562 .3713 L
s
0 .49 0 r
.48396 .39963 m .48769 .40562 L .50306 .4135 L F
.48396 .39963 m .47055 .3932 L .48769 .40562 L F
0 .216 0 r
.28478 .86128 m .27761 .85435 L .25398 .84827 L F
0 .209 0 r
.30698 .86515 m .27761 .85435 L .28478 .86128 L F
0 .013 0 r
.43997 .85532 m .42998 .85384 L .42017 .86082 L F
.43997 .85532 m .45232 .8476 L .42998 .85384 L F
0 .82 0 r
.12615 .72242 m .10796 .68254 L .11227 .70412 L F
0 .668 0 r
.13264 .74246 m .12615 .72242 L .11227 .70412 L F
0 .979 0 r
.10635 .66055 m .09863 .61745 L .09754 .63993 L F
0 .849 0 r
.10796 .68254 m .10635 .66055 L .09754 .63993 L F
0 .924 0 r
.32677 .36368 m .33196 .36638 L .35152 .3653 L F
0 .997 0 r
.30435 .36726 m .33196 .36638 L .32677 .36368 L F
0 .863 0 r
.35005 .3624 m .37123 .36619 L .37351 .36346 L F
.35005 .3624 m .35152 .3653 L .37123 .36619 L F
0 .535 0 r
.18905 .80582 m .15882 .77658 L .16917 .79314 L F
0 .413 0 r
.20002 .81964 m .18905 .80582 L .16917 .79314 L F
0 .441 0 r
.22142 .82979 m .18905 .80582 L .20002 .81964 L F
0 0 0 r
.60493 .62335 m
.60627 .61596 L
s
0 .924 0 r
.32677 .36368 m .35152 .3653 L .35005 .3624 L F
0 .305 0 r
.23224 .8406 m .22142 .82979 L .20002 .81964 L F
0 .323 0 r
.25398 .84827 m .22142 .82979 L .23224 .8406 L F
0 0 0 r
.58218 .7233 m .58034 .72071 L .57223 .74083 L F
.58218 .7233 m .59074 .70229 L .58034 .72071 L F
.60152 .66048 m .59964 .6586 L .59656 .68064 L F
.60152 .66048 m .60469 .63789 L .59964 .6586 L F
0 1 0 r
.10246 .59527 m .10644 .55212 L .09981 .57359 L F
0 .982 0 r
.09863 .61745 m .10246 .59527 L .09981 .57359 L F
0 0 0 r
.52076 .80684 m .51788 .80467 L .50485 .81858 L F
.52076 .80684 m .53519 .79184 L .51788 .80467 L F
0 1 0 r
.14479 .47503 m .16928 .44212 L .1539 .45603 L F
.13095 .49194 m .14479 .47503 L .1539 .45603 L F
0 0 0 r
.48989 .83051 m .48555 .82888 L .47245 .83978 L F
.48989 .83051 m .50485 .81858 L .48555 .82888 L F
0 1 0 r
.25018 .38342 m .26454 .38079 L .28341 .37303 L F
.23154 .39433 m .26454 .38079 L .25018 .38342 L F
.11564 .53165 m .13095 .49194 L .11933 .51048 L F
.10644 .55212 m .11564 .53165 L .11933 .51048 L F
0 .601 0 r
.42717 .37375 m .43836 .37996 L .4502 .38246 L F
.42717 .37375 m .4183 .37238 L .43836 .37996 L F
0 .613 0 r
.15882 .77658 m .13264 .74246 L .14164 .76143 L F
0 .493 0 r
.16917 .79314 m .15882 .77658 L .14164 .76143 L F
0 .048 0 r
.60392 .59374 m .60265 .5932 L .60505 .61539 L F
.60392 .59374 m .60149 .57148 L .60265 .5932 L F
0 .192 0 r
.55853 .47007 m .55913 .47317 L .57136 .48998 L F
.55853 .47007 m .54691 .45424 L .55913 .47317 L F
0 0 0 r
.54839 .77765 m .54738 .77518 L .53519 .79184 L F
.54839 .77765 m .56156 .75989 L .54738 .77518 L F
0 .115 0 r
.58893 .52841 m .58862 .5296 L .59635 .55003 L F
.58893 .52841 m .58135 .50845 L .58862 .5296 L F
0 .214 0 r
.26383 .85592 m .25398 .84827 L .23224 .8406 L F
0 .216 0 r
.28478 .86128 m .25398 .84827 L .26383 .85592 L F
0 .112 0 r
.35178 .87158 m .35324 .8682 L .32995 .86747 L F
0 .084 0 r
.37168 .87083 m .35324 .8682 L .35178 .87158 L F
.37168 .87083 m .37635 .86732 L .35324 .8682 L F
0 0 0 r
.45775 .84843 m .45232 .8476 L .43997 .85532 L F
.45775 .84843 m .47245 .83978 L .45232 .8476 L F
0 .131 0 r
.33173 .87096 m .32995 .86747 L .30698 .86515 L F
0 .112 0 r
.35178 .87158 m .32995 .86747 L .33173 .87096 L F
0 .049 0 r
.39102 .86871 m .37635 .86732 L .37168 .87083 L F
.39102 .86871 m .39882 .86484 L .37635 .86732 L F
0 1 0 r
.16928 .44212 m .19895 .41492 L .1829 .42532 L F
.1539 .45603 m .16928 .44212 L .1829 .42532 L F
.21582 .4009 m .23154 .39433 L .25018 .38342 L F
.19895 .41492 m .23154 .39433 L .21582 .4009 L F
0 .447 0 r
.46122 .38762 m .47055 .3932 L .48396 .39963 L F
.46122 .38762 m .4502 .38246 L .47055 .3932 L F
0 .209 0 r
.52944 .43638 m .53336 .44045 L .54691 .45424 L F
.52944 .43638 m .51704 .42377 L .53336 .44045 L F
0 .922 0 r
.27183 .37449 m .28341 .37303 L .30435 .36726 L F
0 1 0 r
.25018 .38342 m .28341 .37303 L .27183 .37449 L F
0 .849 0 r
.10796 .68254 m .09754 .63993 L .09925 .66246 L F
0 .683 0 r
.11227 .70412 m .10796 .68254 L .09925 .66246 L F
0 .142 0 r
.31195 .86897 m .30698 .86515 L .28478 .86128 L F
0 .131 0 r
.33173 .87096 m .30698 .86515 L .31195 .86897 L F
0 .597 0 r
.40206 .36735 m .4183 .37238 L .42717 .37375 L F
.40206 .36735 m .39648 .36682 L .4183 .37238 L F
0 0 0 r
.41732 .37124 m
.41937 .37117 L
s
0 1 0 r
.1829 .42532 m .19895 .41492 L .21582 .4009 L F
0 .668 0 r
.13264 .74246 m .11227 .70412 L .11929 .72504 L F
0 .543 0 r
.14164 .76143 m .13264 .74246 L .11929 .72504 L F
0 .005 0 r
.40937 .86526 m .39882 .86484 L .39102 .86871 L F
.40937 .86526 m .42017 .86082 L .39882 .86484 L F
0 .982 0 r
.09863 .61745 m .09981 .57359 L .09589 .59584 L F
0 .829 0 r
.09754 .63993 m .09863 .61745 L .09589 .59584 L F
0 0 0 r
.41937 .37117 m
.42304 .37148 L
s
0 .177 0 r
.49617 .40861 m .50306 .4135 L .51704 .42377 L F
.49617 .40861 m .48396 .39963 L .50306 .4135 L F
0 .811 0 r
.5955 .68288 m .59656 .68064 L .59074 .70229 L F
.5955 .68288 m .60152 .66048 L .59656 .68064 L F
0 0 0 r
.57091 .74341 m .57223 .74083 L .56156 .75989 L F
.57091 .74341 m .58218 .7233 L .57223 .74083 L F
0 1 0 r
.13095 .49194 m .1539 .45603 L .14046 .47195 L F
.11933 .51048 m .13095 .49194 L .14046 .47195 L F
0 0 0 r
.60655 .60425 m
.60627 .61596 L
s
0 1 0 r
.10644 .55212 m .11933 .51048 L .11013 .53048 L F
0 .933 0 r
.09981 .57359 m .10644 .55212 L .11013 .53048 L F
0 .413 0 r
.20002 .81964 m .16917 .79314 L .1817 .80803 L F
0 .257 0 r
.21287 .83147 m .20002 .81964 L .1817 .80803 L F
0 .305 0 r
.23224 .8406 m .20002 .81964 L .21287 .83147 L F
0 .719 0 r
.60355 .61656 m .60505 .61539 L .60469 .63789 L F
.60355 .61656 m .60392 .59374 L .60505 .61539 L F
0 .802 0 r
.2959 .36786 m .30435 .36726 L .32677 .36368 L F
0 .922 0 r
.27183 .37449 m .30435 .36726 L .2959 .36786 L F
0 .449 0 r
.56802 .4878 m .57136 .48998 L .58135 .50845 L F
.56802 .4878 m .55853 .47007 L .57136 .48998 L F
0 0 0 r
.5042 .81996 m .50485 .81858 L .48989 .83051 L F
.5042 .81996 m .52076 .80684 L .50485 .81858 L F
0 .144 0 r
.29286 .86565 m .28478 .86128 L .26383 .85592 L F
0 .142 0 r
.31195 .86897 m .28478 .86128 L .29286 .86565 L F
0 .606 0 r
.3756 .36347 m .39648 .36682 L .40206 .36735 L F
.3756 .36347 m .37351 .36346 L .39648 .36682 L F
.59397 .54966 m .59635 .55003 L .60149 .57148 L F
.59397 .54966 m .58893 .52841 L .59635 .55003 L F
0 0 0 r
.42635 .86055 m .42017 .86082 L .40937 .86526 L F
.42635 .86055 m .43997 .85532 L .42017 .86082 L F
0 .493 0 r
.16917 .79314 m .14164 .76143 L .15311 .77907 L F
0 .345 0 r
.1817 .80803 m .16917 .79314 L .15311 .77907 L F
0 .199 0 r
.24459 .84915 m .23224 .8406 L .21287 .83147 L F
0 .214 0 r
.26383 .85592 m .23224 .8406 L .24459 .84915 L F
0 0 0 r
.47311 .84027 m .47245 .83978 L .45775 .84843 L F
.47311 .84027 m .48989 .83051 L .47245 .83978 L F
0 .93 0 r
.53282 .79387 m .53519 .79184 L .52076 .80684 L F
.53282 .79387 m .54839 .77765 L .53519 .79184 L F
0 .7 0 r
.32173 .36373 m .32677 .36368 L .35005 .3624 L F
0 .802 0 r
.2959 .36786 m .32677 .36368 L .32173 .36373 L F
0 .633 0 r
.34856 .36225 m .37351 .36346 L .3756 .36347 L F
.34856 .36225 m .35005 .3624 L .37351 .36346 L F
0 .863 0 r
.23663 .38869 m .25018 .38342 L .27183 .37449 L F
0 1 0 r
.21582 .4009 m .25018 .38342 L .23663 .38869 L F
0 0 0 r
.42304 .37148 m
.42661 .37224 L
s
0 .7 0 r
.32173 .36373 m .35005 .3624 L .34856 .36225 L F
0 .135 0 r
.4354 .37786 m .4502 .38246 L .46122 .38762 L F
.4354 .37786 m .42717 .37375 L .4502 .38246 L F
0 .683 0 r
.11227 .70412 m .09925 .66246 L .10381 .68478 L F
0 .553 0 r
.11929 .72504 m .11227 .70412 L .10381 .68478 L F
0 1 0 r
.1539 .45603 m .1829 .42532 L .16844 .43804 L F
0 .935 0 r
.14046 .47195 m .1539 .45603 L .16844 .43804 L F
0 .543 0 r
.14164 .76143 m .11929 .72504 L .12902 .74505 L F
0 .396 0 r
.15311 .77907 m .14164 .76143 L .12902 .74505 L F
0 .829 0 r
.09754 .63993 m .09589 .59584 L .09478 .61864 L F
0 0 0 r
.09501 .60518 m
.09534 .60697 L
s
0 .65 0 r
.09925 .66246 m .09754 .63993 L .09478 .61864 L F
0 .392 0 r
.54006 .45124 m .54691 .45424 L .55853 .47007 L F
.54006 .45124 m .52944 .43638 L .54691 .45424 L F
0 .136 0 r
.27488 .86106 m .26383 .85592 L .24459 .84915 L F
0 .144 0 r
.29286 .86565 m .26383 .85592 L .27488 .86106 L F
0 .975 0 r
.58666 .70483 m .59074 .70229 L .58218 .7233 L F
.58666 .70483 m .5955 .68288 L .59074 .70229 L F
0 .836 0 r
.44156 .85465 m .43997 .85532 L .42635 .86055 L F
.44156 .85465 m .45775 .84843 L .43997 .85532 L F
0 1 0 r
.1829 .42532 m .21582 .4009 L .2013 .41 L F
0 0 0 r
.2013 .41 m .21582 .4009 L .23663 .38869 L F
0 1 0 r
.55702 .76237 m .56156 .75989 L .54839 .77765 L F
.55702 .76237 m .57091 .74341 L .56156 .75989 L F
0 0 0 r
.16844 .43804 m .1829 .42532 L .2013 .41 L F
0 .896 0 r
.60034 .63971 m .60469 .63789 L .60152 .66048 L F
.60034 .63971 m .60355 .61656 L .60469 .63789 L F
0 .933 0 r
.09981 .57359 m .11013 .53048 L .10349 .55175 L F
0 .753 0 r
.09589 .59584 m .09981 .57359 L .10349 .55175 L F
0 1 0 r
.11933 .51048 m .14046 .47195 L .12915 .48976 L F
0 0 0 r
.11013 .53048 m .11933 .51048 L .12915 .48976 L F
0 .206 0 r
.47124 .39547 m .48396 .39963 L .49617 .40861 L F
.47124 .39547 m .46122 .38762 L .48396 .39963 L F
0 .03 0 r
.35029 .87221 m .35178 .87158 L .33173 .87096 L F
0 .005 0 r
.36668 .87158 m .35178 .87158 L .35029 .87221 L F
.36668 .87158 m .37168 .87083 L .35178 .87158 L F
0 .293 0 r
.50701 .42012 m .51704 .42377 L .52944 .43638 L F
.50701 .42012 m .49617 .40861 L .51704 .42377 L F
0 .047 0 r
.33377 .87169 m .33173 .87096 L .31195 .86897 L F
0 .03 0 r
.35029 .87221 m .33173 .87096 L .33377 .87169 L F
0 0 0 r
.38259 .86984 m .37168 .87083 L .36668 .87158 L F
.38259 .86984 m .39102 .86871 L .37168 .87083 L F
.60496 .59244 m
.60655 .60425 L
s
0 .761 0 r
.59634 .57198 m .60149 .57148 L .60392 .59374 L F
.59634 .57198 m .59397 .54966 L .60149 .57148 L F
0 .596 0 r
.57522 .50728 m .58135 .50845 L .58893 .52841 L F
.57522 .50728 m .56802 .4878 L .58135 .50845 L F
0 .863 0 r
.23663 .38869 m .27183 .37449 L .26087 .3787 L F
0 0 0 r
.26087 .3787 m .27183 .37449 L .2959 .36786 L F
0 .135 0 r
.40721 .37068 m .42717 .37375 L .4354 .37786 L F
.40721 .37068 m .40206 .36735 L .42717 .37375 L F
0 0 0 r
.42661 .37224 m
.43008 .37345 L
s
0 .257 0 r
.21287 .83147 m .1817 .80803 L .19635 .82103 L F
0 .168 0 r
.22751 .84111 m .21287 .83147 L .19635 .82103 L F
0 .199 0 r
.24459 .84915 m .21287 .83147 L .22751 .84111 L F
0 .055 0 r
.31749 .87006 m .31195 .86897 L .29286 .86565 L F
0 .047 0 r
.33377 .87169 m .31195 .86897 L .31749 .87006 L F
0 .345 0 r
.1817 .80803 m .15311 .77907 L .16698 .79517 L F
0 .199 0 r
.19635 .82103 m .1817 .80803 L .16698 .79517 L F
0 .788 0 r
.39768 .867 m .39102 .86871 L .38259 .86984 L F
.39768 .867 m .40937 .86526 L .39102 .86871 L F
0 1 0 r
.48564 .83101 m .48989 .83051 L .47311 .84027 L F
.48564 .83101 m .5042 .81996 L .48989 .83051 L F
.51497 .80833 m .52076 .80684 L .5042 .81996 L F
.51497 .80833 m .53282 .79387 L .52076 .80684 L F
0 .553 0 r
.11929 .72504 m .10381 .68478 L .11122 .70664 L F
0 .141 0 r
.12902 .74505 m .11929 .72504 L .11122 .70664 L F
0 .136 0 r
.27488 .86106 m .24459 .84915 L .2584 .85527 L F
0 .457 0 r
.2584 .85527 m .24459 .84915 L .22751 .84111 L F
0 .992 0 r
.45464 .84769 m .45775 .84843 L .44156 .85465 L F
.45464 .84769 m .47311 .84027 L .45775 .84843 L F
0 .65 0 r
.09925 .66246 m .09478 .61864 L .09654 .64173 L F
0 .079 0 r
.10381 .68478 m .09925 .66246 L .09654 .64173 L F
0 .055 0 r
.31749 .87006 m .29286 .86565 L .30179 .86732 L F
0 .577 0 r
.30179 .86732 m .29286 .86565 L .27488 .86106 L F
0 0 0 r
.43008 .37345 m
.43344 .37512 L
s
0 .935 0 r
.14046 .47195 m .16844 .43804 L .15576 .453 L F
0 0 0 r
.12915 .48976 m .14046 .47195 L .15576 .453 L F
0 .01 0 r
.28788 .37126 m .2959 .36786 L .32173 .36373 L F
0 0 0 r
.26087 .3787 m .2959 .36786 L .28788 .37126 L F
0 1 0 r
.57503 .72607 m .58218 .7233 L .57091 .74341 L F
.57503 .72607 m .58666 .70483 L .58218 .7233 L F
0 .896 0 r
.41159 .86313 m .40937 .86526 L .39768 .867 L F
.41159 .86313 m .42635 .86055 L .40937 .86526 L F
0 .396 0 r
.15311 .77907 m .12902 .74505 L .14138 .76388 L F
0 .209 0 r
.16698 .79517 m .15311 .77907 L .14138 .76388 L F
0 .122 0 r
.37748 .36633 m .40206 .36735 L .40721 .37068 L F
.37748 .36633 m .3756 .36347 L .40206 .36735 L F
0 1 0 r
.59426 .66289 m .60152 .66048 L .5955 .68288 L F
.59426 .66289 m .60034 .63971 L .60152 .66048 L F
0 .541 0 r
.54874 .46826 m .55853 .47007 L .56802 .4878 L F
.54874 .46826 m .54006 .45124 L .55853 .47007 L F
0 .753 0 r
.09589 .59584 m .10349 .55175 L .09955 .57407 L F
0 .019 0 r
.09478 .61864 m .09589 .59584 L .09955 .57407 L F
0 0 0 r
.09466 .59337 m
.09491 .60166 L
s
.09491 .60166 m
.09501 .60518 L
s
.22408 .39664 m .23663 .38869 L .26087 .3787 L F
.2013 .41 m .23663 .38869 L .22408 .39664 L F
0 1 0 r
.54062 .77993 m .54839 .77765 L .53282 .79387 L F
.54062 .77993 m .55702 .76237 L .54839 .77765 L F
0 .215 0 r
.44288 .38478 m .46122 .38762 L .47124 .39547 L F
.44288 .38478 m .4354 .37786 L .46122 .38762 L F
0 0 0 r
.11013 .53048 m .12915 .48976 L .12018 .50929 L F
.10349 .55175 m .11013 .53048 L .12018 .50929 L F
0 .059 0 r
.3169 .36663 m .32173 .36373 L .34856 .36225 L F
0 .01 0 r
.28788 .37126 m .32173 .36373 L .3169 .36663 L F
0 .096 0 r
.34707 .36496 m .3756 .36347 L .37748 .36633 L F
.34707 .36496 m .34856 .36225 L .3756 .36347 L F
0 .92 0 r
.59596 .59513 m .60392 .59374 L .60355 .61656 L F
.59596 .59513 m .59634 .57198 L .60392 .59374 L F
0 0 0 r
.16844 .43804 m .2013 .41 L .18817 .42161 L F
.15576 .453 m .16844 .43804 L .18817 .42161 L F
0 .744 0 r
.57999 .52833 m .58893 .52841 L .59397 .54966 L F
.57999 .52833 m .57522 .50728 L .58893 .52841 L F
0 .059 0 r
.3169 .36663 m .34856 .36225 L .34707 .36496 L F
0 0 0 r
.60148 .58059 m
.60496 .59244 L
s
.18817 .42161 m .2013 .41 L .22408 .39664 L F
0 .599 0 r
.28703 .86355 m .27488 .86106 L .2584 .85527 L F
0 .577 0 r
.30179 .86732 m .27488 .86106 L .28703 .86355 L F
0 1 0 r
.42403 .8583 m .42635 .86055 L .41159 .86313 L F
.42403 .8583 m .44156 .85465 L .42635 .86055 L F
0 .451 0 r
.51629 .43409 m .52944 .43638 L .54006 .45124 L F
.51629 .43409 m .50701 .42012 L .52944 .43638 L F
0 .328 0 r
.48013 .406 m .49617 .40861 L .50701 .42012 L F
.48013 .406 m .47124 .39547 L .49617 .40861 L F
0 .199 0 r
.19635 .82103 m .16698 .79517 L .18314 .80949 L F
0 .168 0 r
.22751 .84111 m .19635 .82103 L .213 .83195 L F
0 .419 0 r
.213 .83195 m .19635 .82103 L .18314 .80949 L F
0 .141 0 r
.12902 .74505 m .11122 .70664 L .12145 .72777 L F
0 .208 0 r
.14138 .76388 m .12902 .74505 L .12145 .72777 L F
0 .513 0 r
.24382 .84841 m .22751 .84111 L .213 .83195 L F
0 .457 0 r
.2584 .85527 m .22751 .84111 L .24382 .84841 L F
0 1 0 r
.49501 .82081 m .5042 .81996 L .48564 .83101 L F
.49501 .82081 m .51497 .80833 L .5042 .81996 L F
0 .079 0 r
.10381 .68478 m .09654 .64173 L .10123 .66484 L F
0 .148 0 r
.11122 .70664 m .10381 .68478 L .10123 .66484 L F
0 1 0 r
.46526 .8398 m .47311 .84027 L .45464 .84769 L F
.46526 .8398 m .48564 .83101 L .47311 .84027 L F
0 .819 0 r
.34877 .86995 m .35029 .87221 L .33377 .87169 L F
0 .862 0 r
.36138 .86947 m .35029 .87221 L .34877 .86995 L F
.36138 .86947 m .36668 .87158 L .35029 .87221 L F
0 1 0 r
.56072 .74632 m .57091 .74341 L .55702 .76237 L F
.56072 .74632 m .57503 .72607 L .57091 .74341 L F
0 .791 0 r
.33607 .86955 m .33377 .87169 L .31749 .87006 L F
0 .819 0 r
.34877 .86995 m .33377 .87169 L .33607 .86955 L F
0 .02 0 r
.25068 .38569 m .26087 .3787 L .28788 .37126 L F
0 0 0 r
.22408 .39664 m .26087 .3787 L .25068 .38569 L F
0 .917 0 r
.37361 .86812 m .36668 .87158 L .36138 .86947 L F
.37361 .86812 m .38259 .86984 L .36668 .87158 L F
0 .209 0 r
.16698 .79517 m .14138 .76388 L .15629 .78131 L F
0 .352 0 r
.18314 .80949 m .16698 .79517 L .15629 .78131 L F
0 1 0 r
.58532 .68584 m .5955 .68288 L .58666 .70483 L F
.58532 .68584 m .59426 .66289 L .5955 .68288 L F
0 .209 0 r
.41186 .3769 m .4354 .37786 L .44288 .38478 L F
.41186 .3769 m .40721 .37068 L .4354 .37786 L F
0 0 0 r
.43344 .37512 m
.43668 .37725 L
s
.12915 .48976 m .15576 .453 L .14508 .47008 L F
.12018 .50929 m .12915 .48976 L .14508 .47008 L F
0 .019 0 r
.09478 .61864 m .09955 .57407 L .09843 .59719 L F
0 0 0 r
.09466 .59337 m
.09621 .58153 L
s
0 .089 0 r
.09654 .64173 m .09478 .61864 L .09843 .59719 L F
0 1 0 r
.52185 .79585 m .53282 .79387 L .51497 .80833 L F
.52185 .79585 m .54062 .77993 L .53282 .79387 L F
0 .627 0 r
.27355 .85881 m .2584 .85527 L .24382 .84841 L F
0 .599 0 r
.28703 .86355 m .2584 .85527 L .27355 .85881 L F
0 .777 0 r
.32355 .86829 m .31749 .87006 L .30179 .86732 L F
0 .791 0 r
.33607 .86955 m .31749 .87006 L .32355 .86829 L F
0 .981 0 r
.38518 .86594 m .38259 .86984 L .37361 .86812 L F
.38518 .86594 m .39768 .867 L .38259 .86984 L F
0 0 0 r
.43668 .37725 m
.43979 .37985 L
s
.10349 .55175 m .12018 .50929 L .11369 .53035 L F
0 .028 0 r
.09955 .57407 m .10349 .55175 L .11369 .53035 L F
0 1 0 r
.43467 .85261 m .44156 .85465 L .42403 .8583 L F
.43467 .85261 m .45464 .84769 L .44156 .85465 L F
0 .68 0 r
.55532 .48728 m .56802 .4878 L .57522 .50728 L F
.55532 .48728 m .54874 .46826 L .56802 .4878 L F
0 1 0 r
.59277 .61884 m .60355 .61656 L .60034 .63971 L F
.59277 .61884 m .59596 .59513 L .60355 .61656 L F
0 .889 0 r
.58221 .5507 m .59397 .54966 L .59634 .57198 L F
.58221 .5507 m .57999 .52833 L .59397 .54966 L F
0 .777 0 r
.3115 .86619 m .30179 .86732 L .28703 .86355 L F
.32355 .86829 m .30179 .86732 L .3115 .86619 L F
0 0 0 r
.09621 .58153 m
.09659 .58022 L
s
0 1 0 r
.39584 .86297 m .39768 .867 L .38518 .86594 L F
.39584 .86297 m .41159 .86313 L .39768 .867 L F
0 .081 0 r
.28039 .37753 m .28788 .37126 L .3169 .36663 L F
0 .02 0 r
.25068 .38569 m .28788 .37126 L .28039 .37753 L F
0 0 0 r
.60019 .57778 m
.60148 .58059 L
s
0 .007 0 r
.2127 .40726 m .22408 .39664 L .25068 .38569 L F
0 0 0 r
.18817 .42161 m .22408 .39664 L .2127 .40726 L F
.15576 .453 m .18817 .42161 L .17665 .43566 L F
.14508 .47008 m .15576 .453 L .17665 .43566 L F
0 .192 0 r
.3791 .37212 m .40721 .37068 L .41186 .3769 L F
.3791 .37212 m .37748 .36633 L .40721 .37068 L F
0 .208 0 r
.14138 .76388 m .12145 .72777 L .13442 .74789 L F
0 .31 0 r
.15629 .78131 m .14138 .76388 L .13442 .74789 L F
0 .33 0 r
.44948 .3945 m .47124 .39547 L .48013 .406 L F
.44948 .3945 m .44288 .38478 L .47124 .39547 L F
0 .148 0 r
.11122 .70664 m .10123 .66484 L .10883 .68769 L F
0 .208 0 r
.12145 .72777 m .11122 .70664 L .10883 .68769 L F
0 .579 0 r
.52386 .45044 m .54006 .45124 L .54874 .46826 L F
.52386 .45044 m .51629 .43409 L .54006 .45124 L F
0 .419 0 r
.213 .83195 m .18314 .80949 L .20145 .82183 L F
0 .567 0 r
.23149 .84059 m .213 .83195 L .20145 .82183 L F
0 .513 0 r
.24382 .84841 m .213 .83195 L .23149 .84059 L F
0 0 0 r
.17665 .43566 m .18817 .42161 L .2127 .40726 L F
0 1 0 r
.54383 .76531 m .55702 .76237 L .54062 .77993 L F
.54383 .76531 m .56072 .74632 L .55702 .76237 L F
0 0 0 r
.43979 .37985 m
.44277 .38291 L
s
0 1 0 r
.5736 .70826 m .58666 .70483 L .57503 .72607 L F
.5736 .70826 m .58532 .68584 L .58666 .70483 L F
.47313 .83113 m .48564 .83101 L .46526 .8398 L F
.47313 .83113 m .49501 .82081 L .48564 .83101 L F
0 .465 0 r
.48772 .41918 m .50701 .42012 L .51629 .43409 L F
.48772 .41918 m .48013 .406 L .50701 .42012 L F
0 .789 0 r
.30019 .86329 m .28703 .86355 L .27355 .85881 L F
0 .777 0 r
.3115 .86619 m .28703 .86355 L .30019 .86329 L F
0 .657 0 r
.26165 .85319 m .24382 .84841 L .23149 .84059 L F
0 .627 0 r
.27355 .85881 m .24382 .84841 L .26165 .85319 L F
0 .129 0 r
.31234 .37245 m .3169 .36663 L .34707 .36496 L F
0 .081 0 r
.28039 .37753 m .3169 .36663 L .31234 .37245 L F
0 .089 0 r
.09654 .64173 m .09843 .59719 L .10019 .62085 L F
0 .152 0 r
.10123 .66484 m .09654 .64173 L .10019 .62085 L F
0 1 0 r
.40532 .85926 m .41159 .86313 L .39584 .86297 L F
.40532 .85926 m .42403 .8583 L .41159 .86313 L F
0 .165 0 r
.34559 .37062 m .37748 .36633 L .3791 .37212 L F
.34559 .37062 m .34707 .36496 L .37748 .36633 L F
0 .352 0 r
.18314 .80949 m .15629 .78131 L .17363 .79708 L F
0 .495 0 r
.20145 .82183 m .18314 .80949 L .17363 .79708 L F
0 1 0 r
.44327 .84616 m .45464 .84769 L .43467 .85261 L F
.44327 .84616 m .46526 .8398 L .45464 .84769 L F
0 .129 0 r
.31234 .37245 m .34707 .36496 L .34559 .37062 L F
0 1 0 r
.5009 .8099 m .51497 .80833 L .49501 .82081 L F
.5009 .8099 m .52185 .79585 L .51497 .80833 L F
0 0 0 r
.12018 .50929 m .14508 .47008 L .13658 .48914 L F
0 .03 0 r
.11369 .53035 m .12018 .50929 L .13658 .48914 L F
0 1 0 r
.58676 .64283 m .60034 .63971 L .59426 .66289 L F
.58676 .64283 m .59277 .61884 L .60034 .63971 L F
0 .028 0 r
.09955 .57407 m .11369 .53035 L .10983 .55272 L F
0 .094 0 r
.09843 .59719 m .09955 .57407 L .10983 .55272 L F
0 0 0 r
.09659 .58022 m
.09969 .56974 L
s
0 .822 0 r
.55966 .50811 m .57522 .50728 L .57999 .52833 L F
.55966 .50811 m .55532 .48728 L .57522 .50728 L F
0 .998 0 r
.5818 .57417 m .59634 .57198 L .59596 .59513 L F
.5818 .57417 m .58221 .5507 L .59634 .57198 L F
0 0 0 r
.59608 .56882 m
.60019 .57778 L
s
0 0 1 r
.59761 .57175 m
.60792 .56988 L
s
0 0 0 r
.59761 .57175 m
.59779 .5805 L
s
.59536 .56752 m
.59761 .57175 L
s
0 .809 0 r
.28989 .85965 m .27355 .85881 L .26165 .85319 L F
0 .789 0 r
.30019 .86329 m .27355 .85881 L .28989 .85965 L F
0 .079 0 r
.24142 .39549 m .25068 .38569 L .28039 .37753 L F
0 .007 0 r
.2127 .40726 m .25068 .38569 L .24142 .39549 L F
0 .31 0 r
.15629 .78131 m .13442 .74789 L .15005 .76675 L F
0 .443 0 r
.17363 .79708 m .15629 .78131 L .15005 .76675 L F
0 1 0 r
.41341 .8549 m .42403 .8583 L .40532 .85926 L F
.41341 .8549 m .43467 .85261 L .42403 .8583 L F
0 .208 0 r
.12145 .72777 m .10883 .68769 L .11932 .70999 L F
0 .288 0 r
.13442 .74789 m .12145 .72777 L .11932 .70999 L F
0 .999 0 r
.34725 .86472 m .34877 .86995 L .33607 .86955 L F
0 1 0 r
.35584 .8644 m .34877 .86995 L .34725 .86472 L F
.35584 .8644 m .36138 .86947 L .34877 .86995 L F
0 .307 0 r
.41593 .38602 m .44288 .38478 L .44948 .3945 L F
.41593 .38602 m .41186 .3769 L .44288 .38478 L F
0 0 0 r
.44277 .38291 m
.44561 .38643 L
s
0 0 1 r
.60792 .56988 m
.6192 .56783 L
s
0 .978 0 r
.3386 .86445 m .33607 .86955 L .32355 .86829 L F
0 .999 0 r
.34725 .86472 m .33607 .86955 L .3386 .86445 L F
0 1 0 r
.36416 .86348 m .36138 .86947 L .35584 .8644 L F
.36416 .86348 m .37361 .86812 L .36138 .86947 L F
0 0 0 r
.58874 .55721 m
.59608 .56882 L
s
0 1 0 r
.52456 .78279 m .54062 .77993 L .52185 .79585 L F
.52456 .78279 m .54383 .76531 L .54062 .77993 L F
0 0 1 r
.61343 .5639 m
.61579 .56845 L
s
0 1 0 r
.55918 .72986 m .57503 .72607 L .56072 .74632 L F
.55918 .72986 m .5736 .70826 L .57503 .72607 L F
0 .964 0 r
.33008 .86359 m .32355 .86829 L .3115 .86619 L F
0 .978 0 r
.3386 .86445 m .32355 .86829 L .33008 .86359 L F
0 0 0 r
.59756 .58976 m
.59779 .5805 L
s
0 0 1 r
.6192 .56783 m
.62982 .5659 L
s
0 1 0 r
.37202 .86199 m .37361 .86812 L .36416 .86348 L F
.37202 .86199 m .38518 .86594 L .37361 .86812 L F
0 0 0 r
.14508 .47008 m .17665 .43566 L .1669 .45207 L F
0 .022 0 r
.13658 .48914 m .14508 .47008 L .1669 .45207 L F
0 0 0 r
.59268 .56304 m
.59536 .56752 L
s
0 .152 0 r
.10123 .66484 m .10019 .62085 L .10486 .64476 L F
0 .206 0 r
.10883 .68769 m .10123 .66484 L .10486 .64476 L F
0 .567 0 r
.23149 .84059 m .20145 .82183 L .22174 .832 L F
0 .713 0 r
.25164 .84682 m .23149 .84059 L .22174 .832 L F
0 .657 0 r
.26165 .85319 m .23149 .84059 L .25164 .84682 L F
0 .495 0 r
.20145 .82183 m .17363 .79708 L .19322 .81098 L F
0 .616 0 r
.22174 .832 m .20145 .82183 L .19322 .81098 L F
0 1 0 r
.44957 .83911 m .46526 .8398 L .44327 .84616 L F
.44957 .83911 m .47313 .83113 L .46526 .8398 L F
0 .728 0 r
.52957 .46901 m .54874 .46826 L .55532 .48728 L F
.52957 .46901 m .52386 .45044 L .54874 .46826 L F
0 0 1 r
.62982 .5659 m
.64007 .56404 L
s
0 .06 0 r
.20268 .42051 m .2127 .40726 L .24142 .39549 L F
0 0 0 r
.17665 .43566 m .2127 .40726 L .20268 .42051 L F
0 .957 0 r
.32189 .86215 m .3115 .86619 L .30019 .86329 L F
0 .964 0 r
.33008 .86359 m .3115 .86619 L .32189 .86215 L F
0 1 0 r
.57795 .66679 m .59426 .66289 L .58532 .68584 L F
.57795 .66679 m .58676 .64283 L .59426 .66289 L F
0 0 1 r
.63159 .56025 m
.63405 .56513 L
s
0 1 0 r
.37924 .85996 m .38518 .86594 L .37202 .86199 L F
.37924 .85996 m .39584 .86297 L .38518 .86594 L F
.478 .82188 m .49501 .82081 L .47313 .83113 L F
.478 .82188 m .5009 .8099 L .49501 .82081 L F
0 0 0 r
.44561 .38643 m
.44829 .39042 L
s
0 .031 0 r
.1669 .45207 m .17665 .43566 L .20268 .42051 L F
0 .462 0 r
.4551 .40702 m .48013 .406 L .48772 .41918 L F
.4551 .40702 m .44948 .3945 L .48013 .406 L F
0 .094 0 r
.09843 .59719 m .10983 .55272 L .1087 .57616 L F
0 0 0 r
.09969 .56974 m
.10511 .55811 L
s
0 .152 0 r
.10019 .62085 m .09843 .59719 L .1087 .57616 L F
0 0 1 r
.64007 .56404 m
.651 .56205 L
s
.5933 .56402 m
.60349 .56181 L
s
0 0 0 r
.5933 .56402 m
.59348 .57281 L
s
0 .834 0 r
.28083 .85535 m .26165 .85319 L .25164 .84682 L F
0 .809 0 r
.28989 .85965 m .26165 .85319 L .28083 .85535 L F
0 0 0 r
.59697 .59818 m
.59756 .58976 L
s
0 0 1 r
.61062 .55907 m
.61343 .5639 L
s
0 .135 0 r
.27354 .3867 m .28039 .37753 L .31234 .37245 L F
0 .079 0 r
.24142 .39549 m .28039 .37753 L .27354 .3867 L F
0 .03 0 r
.11369 .53035 m .13658 .48914 L .13041 .50999 L F
0 .093 0 r
.10983 .55272 m .11369 .53035 L .13041 .50999 L F
0 1 0 r
.41989 .84998 m .43467 .85261 L .41341 .8549 L F
.41989 .84998 m .44327 .84616 L .43467 .85261 L F
0 .266 0 r
.38045 .38088 m .41186 .3769 L .41593 .38602 L F
.38045 .38088 m .3791 .37212 L .41186 .3769 L F
0 0 0 r
.5896 .55841 m
.59268 .56304 L
s
0 .61 0 r
.4939 .43492 m .51629 .43409 L .52386 .45044 L F
.4939 .43492 m .48772 .41918 L .51629 .43409 L F
0 0 1 r
.651 .56205 m
.66155 .56014 L
s
0 1 0 r
.57871 .59844 m .59596 .59513 L .59277 .61884 L F
.57871 .59844 m .5818 .57417 L .59596 .59513 L F
0 0 0 r
.59542 .5828 m
.59768 .58699 L
s
0 0 1 r
.60349 .56181 m
.61464 .5594 L
s
.64985 .55659 m
.6524 .5618 L
s
0 .955 0 r
.31422 .86018 m .30019 .86329 L .28989 .85965 L F
0 .957 0 r
.32189 .86215 m .30019 .86329 L .31422 .86018 L F
0 .927 0 r
.56164 .53053 m .57999 .52833 L .58221 .5507 L F
.56164 .53053 m .55966 .50811 L .57999 .52833 L F
0 .288 0 r
.13442 .74789 m .11932 .70999 L .1326 .73146 L F
0 .408 0 r
.15005 .76675 m .13442 .74789 L .1326 .73146 L F
0 .443 0 r
.17363 .79708 m .15005 .76675 L .16816 .78407 L F
0 .554 0 r
.19322 .81098 m .17363 .79708 L .16816 .78407 L F
0 1 0 r
.38564 .85743 m .39584 .86297 L .37924 .85996 L F
.38564 .85743 m .40532 .85926 L .39584 .86297 L F
0 0 0 r
.59274 .57835 m
.59542 .5828 L
s
.5961 .60601 m
.59697 .59818 L
s
0 0 1 r
.62865 .55507 m
.63159 .56025 L
s
.66155 .56014 m
.6728 .55809 L
s
0 0 0 r
.59324 .58211 m
.59348 .57281 L
s
0 1 0 r
.50309 .79852 m .52185 .79585 L .5009 .8099 L F
.50309 .79852 m .52456 .78279 L .52185 .79585 L F
.54221 .75036 m .56072 .74632 L .54383 .76531 L F
.54221 .75036 m .55918 .72986 L .56072 .74632 L F
0 0 1 r
.61464 .5594 m
.62514 .55712 L
s
0 .179 0 r
.30813 .38122 m .31234 .37245 L .34559 .37062 L F
0 .135 0 r
.27354 .3867 m .31234 .37245 L .30813 .38122 L F
0 0 1 r
.60737 .55408 m
.61062 .55907 L
s
0 0 0 r
.59439 .5973 m
.59665 .60144 L
s
0 .214 0 r
.34414 .37926 m .3791 .37212 L .38045 .38088 L F
.34414 .37926 m .34559 .37062 L .3791 .37212 L F
0 0 1 r
.6682 .55291 m
.67083 .55845 L
s
0 0 0 r
.58643 .5541 m
.5896 .55841 L
s
0 .206 0 r
.10883 .68769 m .10486 .64476 L .11246 .66862 L F
0 .281 0 r
.11932 .70999 m .10883 .68769 L .11246 .66862 L F
0 0 1 r
.6728 .55809 m
.68367 .55612 L
s
0 .179 0 r
.30813 .38122 m .34559 .37062 L .34414 .37926 L F
0 0 0 r
.5949 .61407 m
.5961 .60601 L
s
.58837 .55674 m
.58874 .55721 L
s
0 0 1 r
.62514 .55712 m
.63528 .55492 L
s
0 .958 0 r
.30725 .8577 m .28989 .85965 L .28083 .85535 L F
0 .955 0 r
.31422 .86018 m .28989 .85965 L .30725 .8577 L F
0 1 0 r
.39107 .85447 m .40532 .85926 L .38564 .85743 L F
.39107 .85447 m .41341 .8549 L .40532 .85926 L F
0 0 1 r
.64678 .55106 m
.64985 .55659 L
s
.58815 .55639 m
.59818 .55384 L
s
0 0 0 r
.58815 .55639 m
.58832 .5652 L
s
0 1 0 r
.56641 .69043 m .58532 .68584 L .5736 .70826 L F
.56641 .69043 m .57795 .66679 L .58532 .68584 L F
0 .616 0 r
.22174 .832 m .19322 .81098 L .21485 .8228 L F
0 .767 0 r
.24378 .83982 m .22174 .832 L .21485 .8228 L F
0 .713 0 r
.25164 .84682 m .22174 .832 L .24378 .83982 L F
0 0 0 r
.58965 .57377 m
.59274 .57835 L
s
.59265 .59059 m
.59324 .58211 L
s
0 0 1 r
.68367 .55612 m
.69415 .55422 L
s
0 .861 0 r
.27325 .85048 m .25164 .84682 L .24378 .83982 L F
0 .834 0 r
.28083 .85535 m .25164 .84682 L .27325 .85048 L F
0 .022 0 r
.13658 .48914 m .1669 .45207 L .15912 .47068 L F
0 .102 0 r
.13041 .50999 m .13658 .48914 L .15912 .47068 L F
0 1 0 r
.4534 .8316 m .47313 .83113 L .44957 .83911 L F
.4534 .8316 m .478 .82188 L .47313 .83113 L F
.4246 .84461 m .44327 .84616 L .41989 .84998 L F
.4246 .84461 m .44957 .83911 L .44327 .84616 L F
0 0 1 r
.68664 .54921 m
.68935 .55509 L
s
.62524 .54973 m
.62865 .55507 L
s
.63528 .55492 m
.6461 .55257 L
s
0 .135 0 r
.23322 .40806 m .24142 .39549 L .27354 .3867 L F
0 .06 0 r
.20268 .42051 m .24142 .39549 L .23322 .40806 L F
0 0 0 r
.59222 .59374 m
.59439 .5973 L
s
.59172 .59291 m
.59222 .59374 L
s
0 .152 0 r
.10019 .62085 m .1087 .57616 L .11038 .60038 L F
0 .199 0 r
.10486 .64476 m .10019 .62085 L .11038 .60038 L F
0 0 1 r
.69415 .55422 m
.70533 .55219 L
s
.58284 .54966 m
.58643 .5541 L
s
.60401 .54943 m
.60737 .55408 L
s
0 0 0 r
.5935 .62154 m
.5949 .61407 L
s
0 .45 0 r
.41934 .39804 m .44948 .3945 L .4551 .40702 L F
.41934 .39804 m .41593 .38602 L .44948 .3945 L F
0 0 0 r
.44829 .39042 m
.45082 .39487 L
s
0 0 1 r
.59818 .55384 m
.60916 .55105 L
s
0 .838 0 r
.53331 .48963 m .55532 .48728 L .55966 .50811 L F
.53331 .48963 m .52957 .46901 L .55532 .48728 L F
0 .408 0 r
.15005 .76675 m .1326 .73146 L .14855 .75181 L F
0 .521 0 r
.16816 .78407 m .15005 .76675 L .14855 .75181 L F
0 0 1 r
.66501 .54702 m
.6682 .55291 L
s
0 .554 0 r
.19322 .81098 m .16816 .78407 L .18858 .79963 L F
0 .694 0 r
.21485 .8228 m .19322 .81098 L .18858 .79963 L F
0 .093 0 r
.10983 .55272 m .13041 .50999 L .12672 .53241 L F
0 .145 0 r
.1087 .57616 m .10983 .55272 L .12672 .53241 L F
0 0 0 r
.10511 .55811 m
.11249 .54674 L
s
0 0 1 r
.6461 .55257 m
.65655 .55031 L
s
0 1 0 r
.34574 .85649 m .34725 .86472 L .3386 .86445 L F
.35011 .85633 m .34725 .86472 L .34574 .85649 L F
.35011 .85633 m .35584 .8644 L .34725 .86472 L F
.57292 .62323 m .59277 .61884 L .58676 .64283 L F
.57292 .62323 m .57871 .59844 L .59277 .61884 L F
0 0 0 r
.59179 .59848 m
.59243 .59265 L
s
.59243 .59265 m
.59265 .59059 L
s
.59248 .611 m
.59473 .61508 L
s
.58808 .57447 m
.58832 .5652 L
s
.58808 .57456 m
.58808 .57447 L
s
0 1 0 r
.34134 .85635 m .3386 .86445 L .33008 .86359 L F
.34574 .85649 m .3386 .86445 L .34134 .85635 L F
0 0 1 r
.70533 .55219 m
.71613 .55023 L
s
0 1 0 r
.35434 .85585 m .35584 .8644 L .35011 .85633 L F
.35434 .85585 m .36416 .86348 L .35584 .8644 L F
0 0 1 r
.70518 .54549 m
.70796 .55171 L
s
0 0 0 r
.58647 .56949 m
.58965 .57377 L
s
0 .964 0 r
.30115 .85478 m .28083 .85535 L .27325 .85048 L F
0 .958 0 r
.30725 .8577 m .28083 .85535 L .30115 .85478 L F
0 1 0 r
.52288 .76947 m .54383 .76531 L .52456 .78279 L F
.52288 .76947 m .54221 .75036 L .54383 .76531 L F
.47968 .81226 m .5009 .8099 L .478 .82188 L F
.47968 .81226 m .50309 .79852 L .5009 .8099 L F
0 0 0 r
.45082 .39487 m
.45318 .39978 L
s
0 1 0 r
.33701 .85591 m .33008 .86359 L .32189 .86215 L F
.34134 .85635 m .33008 .86359 L .33701 .85591 L F
0 0 0 r
.59179 .6292 m
.5935 .62154 L
s
0 1 0 r
.3954 .85114 m .41341 .8549 L .39107 .85447 L F
.3954 .85114 m .41989 .84998 L .41341 .8549 L F
0 0 1 r
.64322 .54534 m
.64678 .55106 L
s
.60916 .55105 m
.6195 .54843 L
s
0 1 0 r
.35833 .85509 m .36416 .86348 L .35434 .85585 L F
.35833 .85509 m .37202 .86199 L .36416 .86348 L F
0 .031 0 r
.1669 .45207 m .20268 .42051 L .19418 .4363 L F
0 .134 0 r
.15912 .47068 m .1669 .45207 L .19418 .4363 L F
0 1 0 r
.5612 .55429 m .58221 .5507 L .5818 .57417 L F
.5612 .55429 m .56164 .53053 L .58221 .5507 L F
0 0 0 r
.5795 .54586 m
.58837 .55674 L
s
0 .146 0 r
.19418 .4363 m .20268 .42051 L .23322 .40806 L F
0 0 1 r
.65655 .55031 m
.6677 .54789 L
s
0 0 0 r
.58863 .58839 m
.59172 .59291 L
s
0 0 1 r
.71613 .55023 m
.72653 .54833 L
s
0 .281 0 r
.11932 .70999 m .11246 .66862 L .12291 .69214 L F
0 .387 0 r
.1326 .73146 m .11932 .70999 L .12291 .69214 L F
0 0 1 r
.62171 .54474 m
.62524 .54973 L
s
0 0 0 r
.57921 .54554 m
.58284 .54966 L
s
0 0 1 r
.60022 .54465 m
.60401 .54943 L
s
0 0 0 r
.5906 .60661 m
.59179 .59848 L
s
.58982 .60668 m
.59248 .611 L
s
0 1 0 r
.33285 .85518 m .32189 .86215 L .31422 .86018 L F
.33701 .85591 m .32189 .86215 L .33285 .85518 L F
0 .608 0 r
.45963 .42225 m .48772 .41918 L .4939 .43492 L F
.45963 .42225 m .4551 .40702 L .48772 .41918 L F
0 .734 0 r
.49853 .45309 m .52386 .45044 L .52957 .46901 L F
.49853 .45309 m .4939 .43492 L .52386 .45044 L F
0 0 1 r
.68335 .54296 m
.68664 .54921 L
s
0 1 0 r
.36198 .85406 m .37202 .86199 L .35833 .85509 L F
.36198 .85406 m .37924 .85996 L .37202 .86199 L F
0 0 1 r
.58216 .54887 m
.59199 .54598 L
s
0 0 0 r
.58216 .54887 m
.58232 .55771 L
s
.58987 .62388 m
.59211 .62788 L
s
.58749 .58309 m
.58808 .57456 L
s
0 0 1 r
.6195 .54843 m
.62949 .54589 L
s
.72653 .54833 m
.73765 .54632 L
s
.72381 .54175 m
.72666 .54831 L
s
0 0 0 r
.58996 .63628 m
.59179 .6292 L
s
0 1 0 r
.55225 .71341 m .5736 .70826 L .55918 .72986 L F
.55225 .71341 m .56641 .69043 L .5736 .70826 L F
0 0 1 r
.6677 .54789 m
.67847 .54556 L
s
0 0 0 r
.58288 .56509 m
.58647 .56949 L
s
0 .767 0 r
.24378 .83982 m .21485 .8228 L .2383 .83235 L F
0 .887 0 r
.26735 .84514 m .24378 .83982 L .2383 .83235 L F
0 .861 0 r
.27325 .85048 m .24378 .83982 L .26735 .84514 L F
0 0 1 r
.66131 .54093 m
.66501 .54702 L
s
0 .206 0 r
.26744 .39876 m .27354 .3867 L .30813 .38122 L F
0 .135 0 r
.23322 .40806 m .27354 .3867 L .26744 .39876 L F
0 1 0 r
.32897 .85417 m .31422 .86018 L .30725 .8577 L F
.33285 .85518 m .31422 .86018 L .32897 .85417 L F
.36521 .85277 m .37924 .85996 L .36198 .85406 L F
.36521 .85277 m .38564 .85743 L .37924 .85996 L F
0 0 1 r
.73765 .54632 m
.74837 .54437 L
s
0 1 0 r
.4274 .83891 m .44957 .83911 L .4246 .84461 L F
.4274 .83891 m .4534 .8316 L .44957 .83911 L F
0 .417 0 r
.38149 .39259 m .41593 .38602 L .41934 .39804 L F
.38149 .39259 m .38045 .38088 L .41593 .38602 L F
0 0 0 r
.58921 .61417 m
.5906 .60661 L
s
0 0 1 r
.59199 .54598 m
.60276 .54283 L
s
.62949 .54589 m
.64016 .54318 L
s
0 0 0 r
.56837 .53487 m
.5795 .54586 L
s
0 .521 0 r
.16816 .78407 m .14855 .75181 L .16701 .77076 L F
0 .649 0 r
.18858 .79963 m .16816 .78407 L .16701 .77076 L F
0 .199 0 r
.10486 .64476 m .11038 .60038 L .1149 .62509 L F
0 .291 0 r
.11246 .66862 m .10486 .64476 L .1149 .62509 L F
0 0 0 r
.58804 .64284 m
.58996 .63628 L
s
.58545 .58416 m
.58863 .58839 L
s
0 0 1 r
.67847 .54556 m
.68886 .5433 L
s
0 0 0 r
.57517 .54131 m
.57921 .54554 L
s
0 0 1 r
.70179 .53887 m
.70518 .54549 L
s
0 .972 0 r
.29608 .85147 m .27325 .85048 L .26735 .84514 L F
0 .964 0 r
.30115 .85478 m .27325 .85048 L .29608 .85147 L F
0 0 1 r
.63952 .54001 m
.64322 .54534 L
s
0 .694 0 r
.21485 .8228 m .18858 .79963 L .21107 .8132 L F
0 .813 0 r
.2383 .83235 m .21485 .8228 L .21107 .8132 L F
0 0 0 r
.45318 .39978 m
.45537 .40515 L
s
0 0 1 r
.74254 .53799 m
.74544 .5449 L
s
0 0 0 r
.58664 .59104 m
.58749 .58309 L
s
.58208 .56711 m
.58232 .55771 L
s
.58675 .60222 m
.58982 .60668 L
s
0 1 0 r
.39851 .84751 m .41989 .84998 L .3954 .85114 L F
.39851 .84751 m .4246 .84461 L .41989 .84998 L F
0 0 1 r
.61771 .5396 m
.62171 .54474 L
s
.59637 .5402 m
.60022 .54465 L
s
0 0 0 r
.5874 .61993 m
.58987 .62388 L
s
.58722 .61964 m
.5874 .61993 L
s
0 0 1 r
.74837 .54437 m
.75981 .54229 L
s
0 1 0 r
.5014 .78693 m .52456 .78279 L .50309 .79852 L F
.5014 .78693 m .52288 .76947 L .52456 .78279 L F
.4546 .82382 m .478 .82188 L .4534 .8316 L F
.4546 .82382 m .47968 .81226 L .478 .82188 L F
.32545 .8529 m .30725 .8577 L .30115 .85478 L F
.32897 .85417 m .30725 .8577 L .32545 .8529 L F
.56447 .6482 m .58676 .64283 L .57795 .66679 L F
.56447 .6482 m .57292 .62323 L .58676 .64283 L F
0 0 0 r
.58672 .63596 m
.58893 .63988 L
s
0 .102 0 r
.13041 .50999 m .15912 .47068 L .15345 .49132 L F
0 .188 0 r
.12672 .53241 m .13041 .50999 L .15345 .49132 L F
0 0 0 r
.58752 .6219 m
.58921 .61417 L
s
0 0 1 r
.68886 .5433 m
.69996 .5409 L
s
0 1 0 r
.36793 .85126 m .38564 .85743 L .36521 .85277 L F
.36793 .85126 m .39107 .85447 L .38564 .85743 L F
0 0 0 r
.58587 .64955 m
.58804 .64284 L
s
0 0 1 r
.64016 .54318 m
.65047 .54056 L
s
.67951 .5365 m
.68335 .54296 L
s
.60276 .54283 m
.61291 .53986 L
s
0 .387 0 r
.1326 .73146 m .12291 .69214 L .13614 .71499 L F
0 .515 0 r
.14855 .75181 m .1326 .73146 L .13614 .71499 L F
0 .145 0 r
.1087 .57616 m .12672 .53241 L .1256 .55615 L F
0 0 0 r
.11249 .54674 m
.1218 .53572 L
s
0 .221 0 r
.11038 .60038 m .1087 .57616 L .1256 .55615 L F
0 0 1 r
.75981 .54229 m
.77085 .54029 L
s
0 .287 0 r
.30433 .39296 m .30813 .38122 L .34414 .37926 L F
0 .206 0 r
.26744 .39876 m .30813 .38122 L .30433 .39296 L F
0 0 1 r
.72033 .53476 m
.72381 .54175 L
s
0 0 0 r
.58558 .59842 m
.58664 .59104 L
s
.58546 .59924 m
.58558 .59842 L
s
0 .921 0 r
.53497 .51209 m .55966 .50811 L .56164 .53053 L F
.53497 .51209 m .53331 .48963 L .55966 .50811 L F
0 .363 0 r
.34275 .39088 m .38045 .38088 L .38149 .39259 L F
.34275 .39088 m .34414 .37926 L .38045 .38088 L F
0 0 1 r
.57535 .54149 m
.58494 .53828 L
s
0 0 0 r
.57535 .54149 m
.5755 .55037 L
s
0 0 1 r
.76136 .53421 m
.76431 .54147 L
s
0 0 0 r
.57068 .53697 m
.57517 .54131 L
s
.58187 .57982 m
.58545 .58416 L
s
0 0 1 r
.65745 .53525 m
.66131 .54093 L
s
0 0 0 r
.58367 .65574 m
.58587 .64955 L
s
0 0 1 r
.69996 .5409 m
.71068 .53857 L
s
0 1 0 r
.53562 .73544 m .55918 .72986 L .54221 .75036 L F
.53562 .73544 m .55225 .71341 L .55918 .72986 L F
0 0 1 r
.65047 .54056 m
.66147 .53777 L
s
0 1 0 r
.55827 .5791 m .5818 .57417 L .57871 .59844 L F
.55827 .5791 m .5612 .55429 L .5818 .57417 L F
0 0 0 r
.5815 .5757 m
.58208 .56711 L
s
.57924 .561 m
.58288 .56509 L
s
.5857 .62908 m
.58752 .6219 L
s
.58315 .64725 m
.58534 .65108 L
s
0 0 1 r
.77085 .54029 m
.7815 .53835 L
s
.59207 .53563 m
.59637 .5402 L
s
0 0 0 r
.58358 .59807 m
.58675 .60222 L
s
0 .287 0 r
.30433 .39296 m .34414 .37926 L .34275 .39088 L F
0 0 0 r
.58409 .6318 m
.58672 .63596 L
s
0 0 1 r
.63533 .53451 m
.63952 .54001 L
s
0 0 0 r
.58417 .61527 m
.58722 .61964 L
s
0 1 0 r
.32239 .85142 m .30115 .85478 L .29608 .85147 L F
.32545 .8529 m .30115 .85478 L .32239 .85142 L F
0 0 1 r
.61291 .53986 m
.62271 .53698 L
s
.61365 .53482 m
.61771 .5396 L
s
0 1 0 r
.37009 .84957 m .39107 .85447 L .36793 .85126 L F
.37009 .84957 m .3954 .85114 L .39107 .85447 L F
0 .228 0 r
.22623 .42333 m .23322 .40806 L .26744 .39876 L F
0 .146 0 r
.19418 .4363 m .23322 .40806 L .22623 .42333 L F
0 .649 0 r
.18858 .79963 m .16701 .77076 L .18776 .78805 L F
0 .758 0 r
.21107 .8132 m .18858 .79963 L .18776 .78805 L F
0 0 1 r
.69782 .53203 m
.70179 .53887 L
s
0 0 0 r
.58146 .66147 m
.58367 .65574 L
s
0 .887 0 r
.26735 .84514 m .2383 .83235 L .26328 .83947 L F
0 .981 0 r
.29216 .84787 m .26735 .84514 L .26328 .83947 L F
0 .972 0 r
.29608 .85147 m .26735 .84514 L .29216 .84787 L F
0 0 0 r
.57519 .5568 m
.57924 .561 L
s
0 0 1 r
.71068 .53857 m
.72102 .53633 L
s
0 0 0 r
.5841 .60687 m
.58546 .59924 L
s
0 0 1 r
.7815 .53835 m
.79287 .53629 L
s
.58494 .53828 m
.59545 .53476 L
s
0 .585 0 r
.42202 .4129 m .4551 .40702 L .45963 .42225 L F
0 0 0 r
.45537 .40515 m
.45738 .41097 L
s
0 .585 0 r
.42202 .4129 m .41934 .39804 L .4551 .40702 L F
0 1 0 r
.40031 .84367 m .4246 .84461 L .39851 .84751 L F
.40031 .84367 m .4274 .83891 L .4246 .84461 L F
0 0 1 r
.78029 .53042 m
.78327 .53803 L
s
.73898 .53063 m
.74254 .53799 L
s
0 0 0 r
.58381 .63572 m
.5857 .62908 L
s
0 .813 0 r
.2383 .83235 m .21107 .8132 L .23537 .82458 L F
0 .91 0 r
.26328 .83947 m .2383 .83235 L .23537 .82458 L F
0 0 1 r
.66147 .53777 m
.67211 .53507 L
s
0 .134 0 r
.15912 .47068 m .19418 .4363 L .18735 .45451 L F
0 .217 0 r
.15345 .49132 m .15912 .47068 L .18735 .45451 L F
0 1 0 r
.47805 .80249 m .50309 .79852 L .47968 .81226 L F
.47805 .80249 m .5014 .78693 L .50309 .79852 L F
0 0 0 r
.57525 .55982 m
.5755 .55037 L
s
0 .291 0 r
.11246 .66862 m .1149 .62509 L .12225 .64997 L F
0 .417 0 r
.12291 .69214 m .11246 .66862 L .12225 .64997 L F
0 0 0 r
.58066 .58372 m
.5815 .5757 L
s
0 0 1 r
.62271 .53698 m
.63319 .53391 L
s
0 0 0 r
.5662 .53296 m
.57068 .53697 L
s
0 1 0 r
.42818 .83301 m .4534 .8316 L .4274 .83891 L F
.42818 .83301 m .4546 .82382 L .4534 .8316 L F
0 0 0 r
.57904 .66733 m
.58146 .66147 L
s
.57926 .65779 m
.58144 .66154 L
s
.57823 .57578 m
.58187 .57982 L
s
0 0 1 r
.6755 .53046 m
.67951 .5365 L
s
.72102 .53633 m
.73206 .53394 L
s
.79287 .53629 m
.80384 .53429 L
s
0 0 0 r
.58054 .64318 m
.58315 .64725 L
s
0 .825 0 r
.50151 .47352 m .52957 .46901 L .53331 .48963 L F
.50151 .47352 m .49853 .45309 L .52957 .46901 L F
0 .231 0 r
.18735 .45451 m .19418 .4363 L .22623 .42333 L F
0 0 0 r
.58001 .59379 m
.58358 .59807 L
s
0 .515 0 r
.14855 .75181 m .13614 .71499 L .15201 .73687 L F
0 .626 0 r
.16701 .77076 m .14855 .75181 L .15201 .73687 L F
0 0 0 r
.58243 .61469 m
.5841 .60687 L
s
.58106 .62752 m
.58409 .6318 L
s
0 1 0 r
.31985 .84974 m .29608 .85147 L .29216 .84787 L F
.32239 .85142 m .29608 .85147 L .31985 .84974 L F
0 0 1 r
.5873 .53095 m
.59207 .53563 L
s
0 0 0 r
.58166 .64252 m
.58381 .63572 L
s
0 1 0 r
.55342 .67304 m .57795 .66679 L .56641 .69043 L F
.55342 .67304 m .56447 .6482 L .57795 .66679 L F
0 0 0 r
.58103 .61119 m
.58417 .61527 L
s
0 1 0 r
.34427 .84525 m .34574 .85649 L .34134 .85635 L F
.34427 .84525 m .35011 .85633 L .34574 .85649 L F
0 0 1 r
.65307 .52939 m
.65745 .53525 L
s
0 1 0 r
.37162 .84774 m .3954 .85114 L .37009 .84957 L F
.37162 .84774 m .39851 .84751 L .3954 .85114 L F
.34427 .84525 m .34134 .85635 L .33701 .85591 L F
.34427 .84525 m .35434 .85585 L .35011 .85633 L F
0 0 1 r
.67211 .53507 m
.68238 .53247 L
s
0 0 0 r
.57665 .67274 m
.57904 .66733 L
s
0 0 1 r
.6091 .5299 m
.61365 .53482 L
s
.71625 .52754 m
.72033 .53476 L
s
.59545 .53476 m
.60536 .53144 L
s
0 .716 0 r
.46298 .44008 m .4939 .43492 L .49853 .45309 L F
.46298 .44008 m .45963 .42225 L .4939 .43492 L F
0 1 0 r
.34427 .84525 m .33701 .85591 L .33285 .85518 L F
0 0 1 r
.79931 .5266 m
.80233 .53457 L
s
.63105 .5294 m
.63533 .53451 L
s
0 1 0 r
.34427 .84525 m .35833 .85509 L .35434 .85585 L F
0 0 0 r
.57069 .55251 m
.57519 .5568 L
s
0 0 1 r
.80384 .53429 m
.81554 .53217 L
s
.56773 .53429 m
.57704 .53075 L
s
0 0 0 r
.56773 .53429 m
.56786 .5432 L
s
0 0 1 r
.75773 .52648 m
.76136 .53421 L
s
0 0 0 r
.5795 .59199 m
.58066 .58372 L
s
0 1 0 r
.51672 .75621 m .54221 .75036 L .52288 .76947 L F
.51672 .75621 m .53562 .73544 L .54221 .75036 L F
0 0 1 r
.73206 .53394 m
.74272 .53162 L
s
.63319 .53391 m
.64331 .53094 L
s
0 0 0 r
.57516 .66763 m
.57731 .67128 L
s
0 1 0 r
.34427 .84525 m .33285 .85518 L .32897 .85417 L F
.34427 .84525 m .36198 .85406 L .35833 .85509 L F
0 0 0 r
.57468 .56845 m
.57525 .55982 L
s
.57948 .64881 m
.58166 .64252 L
s
.57406 .67826 m
.57665 .67274 L
s
0 .221 0 r
.11038 .60038 m .1256 .55615 L .12713 .58091 L F
0 .343 0 r
.1149 .62509 m .11038 .60038 L .12713 .58091 L F
0 .758 0 r
.21107 .8132 m .18776 .78805 L .21055 .80343 L F
0 .851 0 r
.23537 .82458 m .21107 .8132 L .21055 .80343 L F
0 0 0 r
.58063 .62195 m
.58243 .61469 L
s
.57669 .65382 m
.57926 .65779 L
s
.57419 .57164 m
.57823 .57578 L
s
0 0 1 r
.68238 .53247 m
.69334 .52968 L
s
0 .188 0 r
.12672 .53241 m .15345 .49132 L .15001 .51378 L F
0 .277 0 r
.1256 .55615 m .12672 .53241 L .15001 .51378 L F
0 0 0 r
.1218 .53572 m
.13177 .52634 L
s
.13177 .52634 m
.13303 .52515 L
s
0 1 0 r
.34427 .84525 m .32897 .85417 L .32545 .8529 L F
0 0 0 r
.45738 .41097 m
.45921 .41724 L
s
0 1 0 r
.34427 .84525 m .36521 .85277 L .36198 .85406 L F
0 0 1 r
.81554 .53217 m
.82684 .53012 L
s
.69367 .52564 m
.69782 .53203 L
s
0 1 0 r
.45311 .81593 m .47968 .81226 L .4546 .82382 L F
.45311 .81593 m .47805 .80249 L .47968 .81226 L F
0 0 0 r
.57755 .63899 m
.58054 .64318 L
s
0 0 1 r
.74272 .53162 m
.75409 .52916 L
s
0 .91 0 r
.26328 .83947 m .23537 .82458 L .26117 .83359 L F
0 .991 0 r
.28949 .84405 m .26328 .83947 L .26117 .83359 L F
0 .981 0 r
.29216 .84787 m .26328 .83947 L .28949 .84405 L F
0 0 0 r
.57153 .68335 m
.57406 .67826 L
s
0 0 1 r
.60536 .53144 m
.61494 .52823 L
s
0 0 0 r
.5773 .65463 m
.57948 .64881 L
s
0 1 0 r
.55286 .60465 m .57871 .59844 L .57292 .62323 L F
.55286 .60465 m .55827 .5791 L .57871 .59844 L F
0 0 0 r
.5764 .58982 m
.58001 .59379 L
s
0 0 1 r
.81843 .52276 m
.82147 .53109 L
s
0 0 0 r
.57795 .62352 m
.58106 .62752 L
s
0 1 0 r
.31791 .84792 m .29216 .84787 L .28949 .84405 L F
.31985 .84974 m .29216 .84787 L .31791 .84792 L F
0 0 0 r
.57748 .60699 m
.58103 .61119 L
s
.57815 .59969 m
.5795 .59199 L
s
0 0 1 r
.58253 .52661 m
.5873 .53095 L
s
.64331 .53094 m
.65412 .52778 L
s
0 1 0 r
.40074 .83971 m .4274 .83891 L .40031 .84367 L F
.40074 .83971 m .42818 .83301 L .4274 .83891 L F
0 0 0 r
.57091 .67679 m
.57303 .68036 L
s
0 0 1 r
.57704 .53075 m
.58724 .52687 L
s
0 1 0 r
.34427 .84525 m .32545 .8529 L .32239 .85142 L F
0 0 1 r
.73478 .52302 m
.73898 .53063 L
s
0 1 0 r
.37248 .8458 m .39851 .84751 L .37162 .84774 L F
.37248 .8458 m .40031 .84367 L .39851 .84751 L F
.34427 .84525 m .36793 .85126 L .36521 .85277 L F
0 .337 0 r
.2622 .41364 m .26744 .39876 L .30433 .39296 L F
0 .228 0 r
.22623 .42333 m .26744 .39876 L .2622 .41364 L F
0 .983 0 r
.53447 .53612 m .56164 .53053 L .5612 .55429 L F
.53447 .53612 m .53497 .51209 L .56164 .53053 L F
0 0 0 r
.55542 .52434 m
.56837 .53487 L
s
.56128 .52886 m
.5662 .53296 L
s
0 0 1 r
.67093 .52423 m
.6755 .53046 L
s
.7766 .5223 m
.78029 .53042 L
s
0 0 0 r
.57877 .62868 m
.58063 .62195 L
s
.56761 .55269 m
.56786 .5432 L
s
0 0 1 r
.82684 .53012 m
.83774 .52814 L
s
0 .417 0 r
.12291 .69214 m .12225 .64997 L .13238 .67469 L F
0 .525 0 r
.13614 .71499 m .12291 .69214 L .13238 .67469 L F
0 0 0 r
.5662 .54853 m
.57069 .55251 L
s
.56907 .68805 m
.57153 .68335 L
s
0 0 1 r
.60405 .52487 m
.6091 .5299 L
s
0 .547 0 r
.38221 .40721 m .41934 .39804 L .42202 .4129 L F
.38221 .40721 m .38149 .39259 L .41934 .39804 L F
0 .626 0 r
.16701 .77076 m .15201 .73687 L .17033 .75748 L F
0 .722 0 r
.18776 .78805 m .16701 .77076 L .17033 .75748 L F
0 0 0 r
.57385 .57653 m
.57468 .56845 L
s
0 0 1 r
.69334 .52968 m
.70394 .52699 L
s
0 0 0 r
.57261 .66375 m
.57516 .66763 L
s
0 0 1 r
.62627 .52414 m
.63105 .5294 L
s
.64859 .52393 m
.65307 .52939 L
s
0 0 0 r
.57491 .66058 m
.5773 .65463 L
s
0 0 1 r
.75409 .52916 m
.76508 .52677 L
s
0 0 0 r
.55588 .52469 m
.56128 .52886 L
s
0 1 0 r
.34427 .84525 m .32239 .85142 L .31985 .84974 L F
.34427 .84525 m .37009 .84957 L .36793 .85126 L F
0 0 0 r
.56643 .69285 m
.56907 .68805 L
s
.57373 .64973 m
.57669 .65382 L
s
.5697 .56739 m
.57419 .57164 L
s
0 1 0 r
.49577 .77542 m .52288 .76947 L .5014 .78693 L F
.49577 .77542 m .51672 .75621 L .52288 .76947 L F
0 0 0 r
.56656 .68533 m
.56866 .68881 L
s
0 0 1 r
.61494 .52823 m
.62517 .5248 L
s
0 1 0 r
.5399 .6974 m .56641 .69043 L .55225 .71341 L F
.5399 .6974 m .55342 .67304 L .56641 .69043 L F
0 0 0 r
.57651 .6076 m
.57815 .59969 L
s
0 0 1 r
.83774 .52814 m
.84937 .52603 L
s
0 .851 0 r
.23537 .82458 m .21055 .80343 L .23511 .81669 L F
0 .931 0 r
.26117 .83359 m .23537 .82458 L .23511 .81669 L F
0 0 0 r
.57665 .63558 m
.57877 .62868 L
s
0 0 1 r
.65412 .52778 m
.66458 .52471 L
s
.83766 .51891 m
.8407 .5276 L
s
.71196 .52078 m
.71625 .52754 L
s
0 0 0 r
.57255 .66608 m
.57491 .66058 L
s
0 0 1 r
.5593 .5273 m
.56829 .52344 L
s
0 0 0 r
.5593 .5273 m
.55942 .53623 L
s
.57447 .63509 m
.57755 .63899 L
s
.57237 .58574 m
.5764 .58982 L
s
0 1 0 r
.42691 .82706 m .4546 .82382 L .42818 .83301 L F
.42691 .82706 m .45311 .81593 L .4546 .82382 L F
0 0 0 r
.56389 .69728 m
.56643 .69285 L
s
0 0 1 r
.70394 .52699 m
.71417 .5244 L
s
.58724 .52687 m
.59687 .52321 L
s
0 0 0 r
.56839 .67301 m
.57091 .67679 L
s
.57444 .61941 m
.57795 .62352 L
s
0 0 1 r
.76508 .52677 m
.77569 .52447 L
s
0 0 0 r
.57271 .58487 m
.57385 .57653 L
s
0 1 0 r
.34427 .84525 m .31985 .84974 L .31791 .84792 L F
0 0 0 r
.5739 .60309 m
.57748 .60699 L
s
0 0 1 r
.57727 .52218 m
.58253 .52661 L
s
.79556 .5181 m
.79931 .5266 L
s
.75343 .51847 m
.75773 .52648 L
s
0 1 0 r
.34427 .84525 m .37162 .84774 L .37009 .84957 L F
0 .991 0 r
.28949 .84405 m .26117 .83359 L .28816 .8401 L F
0 1 0 r
.31661 .84599 m .28949 .84405 L .28816 .8401 L F
.31791 .84792 m .28949 .84405 L .31661 .84599 L F
0 0 0 r
.56704 .56138 m
.56761 .55269 L
s
.56126 .54446 m
.5662 .54853 L
s
0 0 1 r
.84937 .52603 m
.86003 .52409 L
s
0 0 0 r
.56217 .69329 m
.56424 .69668 L
s
.56999 .6717 m
.57255 .66608 L
s
.56118 .7018 m
.56389 .69728 L
s
.5745 .64196 m
.57665 .63558 L
s
0 1 0 r
.37265 .84381 m .40031 .84367 L .37248 .8458 L F
.37265 .84381 m .40074 .83971 L .40031 .84367 L F
0 0 1 r
.68892 .51903 m
.69367 .52564 L
s
0 0 0 r
.57475 .61494 m
.57651 .6076 L
s
.56969 .65975 m
.57261 .66375 L
s
0 .217 0 r
.15345 .49132 m .18735 .45451 L .18234 .47496 L F
0 .32 0 r
.15001 .51378 m .15345 .49132 L .18234 .47496 L F
0 .426 0 r
.301 .4076 m .30433 .39296 L .34275 .39088 L F
0 .337 0 r
.2622 .41364 m .30433 .39296 L .301 .4076 L F
0 .722 0 r
.18776 .78805 m .17033 .75748 L .19088 .77652 L F
0 .807 0 r
.21055 .80343 m .18776 .78805 L .19088 .77652 L F
0 .494 0 r
.34143 .40542 m .38149 .39259 L .38221 .40721 L F
.34143 .40542 m .34275 .39088 L .38149 .39259 L F
0 0 1 r
.59899 .52021 m
.60405 .52487 L
s
.62517 .5248 m
.63508 .52149 L
s
.66458 .52471 m
.67468 .52175 L
s
0 0 0 r
.55054 .52085 m
.55588 .52469 L
s
.55858 .70597 m
.56118 .7018 L
s
0 .343 0 r
.1149 .62509 m .12713 .58091 L .13134 .60639 L F
0 .45 0 r
.12225 .64997 m .1149 .62509 L .13134 .60639 L F
0 0 1 r
.77569 .52447 m
.78701 .52202 L
s
.71417 .5244 m
.7251 .52162 L
s
0 0 0 r
.56408 .68164 m
.56656 .68533 L
s
.5407 .51439 m
.55542 .52434 L
s
0 1 0 r
.34427 .84525 m .31791 .84792 L .31661 .84599 L F
0 0 1 r
.66626 .51843 m
.67093 .52423 L
s
0 0 0 r
.56749 .67688 m
.56999 .6717 L
s
0 0 1 r
.62094 .51874 m
.62627 .52414 L
s
0 1 0 r
.34427 .84525 m .37248 .8458 L .37162 .84774 L F
0 0 1 r
.85698 .51503 m
.86003 .52409 L
s
0 .931 0 r
.26117 .83359 m .23511 .81669 L .26111 .82764 L F
0 1 0 r
.28816 .8401 m .26117 .83359 L .26111 .82764 L F
0 0 0 r
.56521 .56346 m
.5697 .56739 L
s
.55778 .7007 m
.55981 .70401 L
s
0 0 1 r
.64357 .51832 m
.64859 .52393 L
s
0 .353 0 r
.22058 .4412 m .22623 .42333 L .2622 .41364 L F
0 .231 0 r
.18735 .45451 m .22623 .42333 L .22058 .4412 L F
0 .895 0 r
.50275 .49601 m .53331 .48963 L .53497 .51209 L F
.50275 .49601 m .50151 .47352 L .53331 .48963 L F
0 .525 0 r
.13614 .71499 m .13238 .67469 L .14519 .69892 L F
0 .62 0 r
.15201 .73687 m .13614 .71499 L .14519 .69892 L F
0 1 0 r
.47306 .79281 m .5014 .78693 L .47805 .80249 L F
.47306 .79281 m .49577 .77542 L .5014 .78693 L F
0 0 0 r
.57139 .59265 m
.57271 .58487 L
s
0 0 1 r
.56829 .52344 m
.57815 .51921 L
s
0 0 0 r
.55608 .70982 m
.55858 .70597 L
s
0 1 0 r
.39979 .83573 m .42818 .83301 L .40074 .83971 L F
.39979 .83573 m .42691 .82706 L .42818 .83301 L F
0 .426 0 r
.301 .4076 m .34275 .39088 L .34143 .40542 L F
0 0 1 r
.59687 .52321 m
.60618 .51967 L
s
.73036 .5159 m
.73478 .52302 L
s
0 0 0 r
.5679 .58157 m
.57237 .58574 L
s
0 .685 0 r
.42393 .43048 m .45963 .42225 L .46298 .44008 L F
.42393 .43048 m .42202 .4129 L .45963 .42225 L F
0 0 0 r
.45921 .41724 m
.46084 .42394 L
s
0 0 1 r
.81464 .51388 m
.81843 .52276 L
s
0 0 0 r
.56506 .68168 m
.56749 .67688 L
s
.56551 .66911 m
.56839 .67301 L
s
.56623 .56952 m
.56704 .56138 L
s
0 1 0 r
.545 .63061 m .57292 .62323 L .56447 .6482 L F
0 0 0 r
.57099 .63107 m
.57447 .63509 L
s
.57236 .64786 m
.57248 .64752 L
s
.57248 .64752 m
.5745 .64196 L
s
.57068 .64591 m
.57373 .64973 L
s
0 1 0 r
.545 .63061 m .55286 .60465 L .57292 .62323 L F
0 0 0 r
.57292 .62176 m
.57475 .61494 L
s
.5699 .59909 m
.5739 .60309 L
s
.57088 .61559 m
.57444 .61941 L
s
.55345 .71376 m
.55608 .70982 L
s
0 0 1 r
.7722 .5139 m
.7766 .5223 L
s
0 .346 0 r
.18234 .47496 m .18735 .45451 L .22058 .4412 L F
0 0 1 r
.57151 .51767 m
.57727 .52218 L
s
0 0 0 r
.55973 .68969 m
.56217 .69329 L
s
.5534 .70762 m
.55541 .71084 L
s
0 .277 0 r
.1256 .55615 m .15001 .51378 L .14892 .53778 L F
0 0 0 r
.13303 .52515 m
.1461 .51515 L
s
0 .388 0 r
.12713 .58091 m .1256 .55615 L .14892 .53778 L F
0 0 1 r
.78701 .52202 m
.79795 .51965 L
s
0 0 0 r
.57 .65391 m
.57236 .64786 L
s
0 1 0 r
.31661 .84599 m .28816 .8401 L .31598 .84401 L F
.34427 .84525 m .31661 .84599 L .31598 .84401 L F
.52405 .72095 m .55225 .71341 L .53562 .73544 L F
.52405 .72095 m .5399 .6974 L .55225 .71341 L F
0 0 1 r
.67468 .52175 m
.68547 .51859 L
s
.7251 .52162 m
.73565 .51894 L
s
0 1 0 r
.34427 .84525 m .37265 .84381 L .37248 .8458 L F
0 0 1 r
.63508 .52149 m
.64565 .51794 L
s
0 0 0 r
.55105 .71721 m
.55345 .71376 L
s
.56245 .68657 m
.56506 .68168 L
s
0 1 0 r
.28816 .8401 m .26111 .82764 L .28821 .83612 L F
.31598 .84401 m .28816 .8401 L .28821 .83612 L F
0 .807 0 r
.21055 .80343 m .19088 .77652 L .2134 .79374 L F
0 .882 0 r
.23511 .81669 m .21055 .80343 L .2134 .79374 L F
0 0 0 r
.56669 .65603 m
.56969 .65975 L
s
0 .798 0 r
.46506 .46036 m .49853 .45309 L .50151 .47352 L F
.46506 .46036 m .46298 .44008 L .49853 .45309 L F
0 0 0 r
.54474 .51694 m
.55054 .52085 L
s
0 0 1 r
.70704 .5138 m
.71196 .52078 L
s
0 0 0 r
.56978 .60064 m
.57139 .59265 L
s
0 1 0 r
.37212 .84182 m .40074 .83971 L .37265 .84381 L F
.37212 .84182 m .39979 .83573 L .40074 .83971 L F
0 0 0 r
.57084 .62874 m
.57292 .62176 L
s
0 0 1 r
.5501 .52054 m
.55873 .51637 L
s
0 0 0 r
.5501 .52054 m
.5502 .5295 L
s
.54908 .71407 m
.55105 .71721 L
s
.56124 .67784 m
.56408 .68164 L
s
0 0 1 r
.59342 .51544 m
.59899 .52021 L
s
0 0 0 r
.55537 .6972 m
.55778 .7007 L
s
.56767 .65951 m
.57 .65391 L
s
0 1 0 r
.53179 .56143 m .5612 .55429 L .55827 .5791 L F
.53179 .56143 m .53447 .53612 L .5612 .55429 L F
0 0 0 r
.55585 .54032 m
.56126 .54446 L
s
.55917 .54577 m
.55942 .53623 L
s
.55994 .6911 m
.56245 .68657 L
s
.46084 .42394 m
.46228 .43107 L
s
.56029 .55945 m
.56521 .56346 L
s
0 1 0 r
.44889 .80815 m .47805 .80249 L .45311 .81593 L F
.44889 .80815 m .47306 .79281 L .47805 .80249 L F
0 0 0 r
.56725 .64199 m
.57068 .64591 L
s
0 0 1 r
.60618 .51967 m
.61614 .51589 L
s
.79795 .51965 m
.80961 .51712 L
s
0 0 0 r
.56512 .57793 m
.56623 .56952 L
s
0 1 0 r
.31598 .84401 m .28821 .83612 L .31606 .84201 L F
.34427 .84525 m .31598 .84401 L .31606 .84201 L F
0 0 1 r
.57815 .51921 m
.58747 .51521 L
s
0 0 0 r
.55861 .55451 m
.55917 .54577 L
s
0 1 0 r
.34427 .84525 m .37212 .84182 L .37265 .84381 L F
0 0 1 r
.68406 .51289 m
.68892 .51903 L
s
.73565 .51894 m
.74692 .51608 L
s
.83383 .50963 m
.83766 .51891 L
s
0 0 0 r
.55727 .69571 m
.55994 .6911 L
s
0 0 1 r
.6156 .51375 m
.62094 .51874 L
s
0 0 0 r
.56747 .62734 m
.57099 .63107 L
s
.56344 .5777 m
.5679 .58157 L
s
0 1 0 r
.34427 .84525 m .35177 .83165 L .356 .83242 L F
.34427 .84525 m .34735 .83119 L .35177 .83165 L F
.34427 .84525 m .34285 .83105 L .34735 .83119 L F
.34427 .84525 m .33839 .83122 L .34285 .83105 L F
.34427 .84525 m .33408 .83171 L .33839 .83122 L F
.34427 .84525 m .33002 .83251 L .33408 .83171 L F
.34427 .84525 m .32633 .83358 L .33002 .83251 L F
.34427 .84525 m .32309 .83491 L .32633 .83358 L F
.34427 .84525 m .32039 .83646 L .32309 .83491 L F
.34427 .84525 m .31828 .83819 L .32039 .83646 L F
.34427 .84525 m .31683 .84006 L .31828 .83819 L F
.34427 .84525 m .31606 .84201 L .31683 .84006 L F
.34427 .84525 m .37091 .83987 L .37212 .84182 L F
.34427 .84525 m .36903 .83802 L .37091 .83987 L F
.34427 .84525 m .36653 .83631 L .36903 .83802 L F
.34427 .84525 m .36348 .83478 L .36653 .83631 L F
.34427 .84525 m .35994 .83347 L .36348 .83478 L F
.34427 .84525 m .356 .83242 L .35994 .83347 L F
0 0 1 r
.68547 .51859 m
.6959 .51553 L
s
0 0 0 r
.56515 .66522 m
.56767 .65951 L
s
0 0 1 r
.74889 .51098 m
.75343 .51847 L
s
0 0 0 r
.55103 .7042 m
.5534 .70762 L
s
0 0 1 r
.66101 .51246 m
.66626 .51843 L
s
0 0 0 r
.56873 .63521 m
.57084 .62874 L
s
.56692 .61167 m
.57088 .61559 L
s
0 0 1 r
.63798 .51256 m
.64357 .51832 L
s
0 0 0 r
.56547 .59499 m
.5699 .59909 L
s
0 .62 0 r
.15201 .73687 m .14519 .69892 L .16053 .72232 L F
0 .704 0 r
.17033 .75748 m .15201 .73687 L .16053 .72232 L F
0 .882 0 r
.23511 .81669 m .2134 .79374 L .23759 .80889 L F
0 .95 0 r
.26111 .82764 m .23511 .81669 L .23759 .80889 L F
0 0 1 r
.79109 .5093 m
.79556 .5181 L
s
0 0 0 r
.55693 .68599 m
.55973 .68969 L
s
.34423 .84648 m
.34898 .84161 L
s
.56806 .60807 m
.56978 .60064 L
s
0 0 1 r
.64565 .51794 m
.65588 .51452 L
s
0 0 0 r
.5505 .53651 m
.55585 .54032 L
s
0 0 1 r
.56581 .51351 m
.57151 .51767 L
s
0 0 0 r
.5547 .69997 m
.55727 .69571 L
s
0 1 0 r
.42357 .82121 m .45311 .81593 L .42691 .82706 L F
.42357 .82121 m .44889 .80815 L .45311 .81593 L F
0 0 1 r
.80961 .51712 m
.82088 .51468 L
s
0 0 0 r
.56269 .6705 m
.56515 .66522 L
s
0 .45 0 r
.12225 .64997 m .13134 .60639 L .13822 .63225 L F
0 .543 0 r
.13238 .67469 m .12225 .64997 L .13822 .63225 L F
0 0 0 r
.53904 .51337 m
.54474 .51694 L
s
.54674 .71073 m
.54908 .71407 L
s
0 1 0 r
.31606 .84201 m .28966 .8322 L .31683 .84006 L F
.31606 .84201 m .28821 .83612 L .28966 .8322 L F
0 0 0 r
.55224 .70391 m
.5547 .69997 L
s
0 1 0 r
.50609 .74335 m .53562 .73544 L .51672 .75621 L F
.50609 .74335 m .52405 .72095 L .53562 .73544 L F
0 .95 0 r
.26111 .82764 m .23759 .80889 L .26313 .82177 L F
0 1 0 r
.28821 .83612 m .26111 .82764 L .26313 .82177 L F
.37091 .83987 m .39979 .83573 L .37212 .84182 L F
0 0 0 r
.56662 .64121 m
.56873 .63521 L
s
.54994 .53908 m
.5502 .5295 L
s
0 0 1 r
.55873 .51637 m
.56821 .51179 L
s
0 0 0 r
.56383 .58578 m
.56512 .57793 L
s
.55261 .69359 m
.55537 .6972 L
s
0 0 1 r
.74692 .51608 m
.75781 .51332 L
s
0 1 0 r
.28821 .83612 m .26313 .82177 L .28966 .8322 L F
0 0 0 r
.55832 .6743 m
.56124 .67784 L
s
0 0 1 r
.72529 .50853 m
.73036 .5159 L
s
.61614 .51589 m
.62578 .51223 L
s
0 1 0 r
.39746 .83183 m .42691 .82706 L .39979 .83573 L F
.39746 .83183 m .42357 .82121 L .42691 .82706 L F
0 0 0 r
.55489 .55536 m
.56029 .55945 L
s
.54964 .70793 m
.55224 .70391 L
s
0 1 0 r
.37091 .83987 m .39746 .83183 L .39979 .83573 L F
0 0 0 r
.55782 .5627 m
.55861 .55451 L
s
0 0 1 r
.6959 .51553 m
.70598 .51258 L
s
0 0 0 r
.56626 .61497 m
.56806 .60807 L
s
0 0 1 r
.58729 .51058 m
.59342 .51544 L
s
.58747 .51521 m
.59647 .51135 L
s
.85312 .50535 m
.85698 .51503 L
s
0 1 0 r
.53476 .65661 m .56447 .6482 L .55342 .67304 L F
0 0 0 r
.5603 .67538 m
.56269 .6705 L
s
.56255 .66548 m
.56551 .66911 L
s
0 1 0 r
.53476 .65661 m .545 .63061 L .56447 .6482 L F
0 0 0 r
.5633 .6522 m
.56669 .65603 L
s
.56378 .63834 m
.56725 .64199 L
s
0 .453 0 r
.25791 .43125 m .2622 .41364 L .301 .4076 L F
0 .353 0 r
.22058 .4412 m .2622 .41364 L .25791 .43125 L F
0 0 0 r
.56431 .64735 m
.56662 .64121 L
s
.54728 .71147 m
.54964 .70793 L
s
0 0 1 r
.82088 .51468 m
.83177 .51232 L
s
0 0 0 r
.56356 .6235 m
.56747 .62734 L
s
.55854 .57375 m
.56344 .5777 L
s
.54832 .70068 m
.55103 .7042 L
s
0 0 1 r
.65588 .51452 m
.66578 .5112 L
s
0 0 0 r
.55774 .68038 m
.5603 .67538 L
s
.55921 .66174 m
.56255 .66548 L
s
0 1 0 r
.31683 .84006 m .29248 .82845 L .31828 .83819 L F
.31683 .84006 m .28966 .8322 L .29248 .82845 L F
0 .644 0 r
.38257 .42464 m .42202 .4129 L .42393 .43048 L F
.38257 .42464 m .38221 .40721 L .42202 .4129 L F
0 0 0 r
.56253 .60766 m
.56692 .61167 L
s
.54014 .51404 m
.54022 .52303 L
s
0 0 1 r
.54014 .51404 m
.54838 .50957 L
s
0 1 0 r
.36903 .83802 m .39746 .83183 L .37091 .83987 L F
0 .704 0 r
.17033 .75748 m .16053 .72232 L .1782 .74457 L F
0 .779 0 r
.19088 .77652 m .17033 .75748 L .1782 .74457 L F
0 0 0 r
.56104 .5912 m
.56547 .59499 L
s
.55405 .68254 m
.55693 .68599 L
s
0 0 1 r
.76755 .50603 m
.7722 .5139 L
s
.81009 .50466 m
.81464 .51388 L
s
0 0 0 r
.54468 .53264 m
.5505 .53651 L
s
0 0 1 r
.702 .5073 m
.70704 .5138 L
s
0 .32 0 r
.15001 .51378 m .18234 .47496 L .17926 .49744 L F
0 .423 0 r
.14892 .53778 m .15001 .51378 L .17926 .49744 L F
0 0 0 r
.1461 .51515 m
.15647 .50861 L
s
.15647 .50861 m
.16094 .5058 L
s
0 0 1 r
.60971 .50863 m
.6156 .51375 L
s
0 0 0 r
.56226 .59385 m
.56383 .58578 L
s
0 0 1 r
.5596 .50929 m
.56581 .51351 L
s
0 0 0 r
.56423 .62204 m
.56626 .61497 L
s
0 0 1 r
.75781 .51332 m
.76833 .51065 L
s
0 0 0 r
.55527 .68499 m
.55774 .68038 L
s
.54407 .7073 m
.54674 .71073 L
s
.56203 .65304 m
.56431 .64735 L
s
0 0 1 r
.67859 .50655 m
.68406 .51289 L
s
0 .388 0 r
.12713 .58091 m .14892 .53778 L .15023 .56305 L F
0 .482 0 r
.13134 .60639 m .12713 .58091 L .15023 .56305 L F
0 0 0 r
.55987 .64864 m
.5633 .6522 L
s
0 0 1 r
.70598 .51258 m
.71675 .50942 L
s
.63236 .50723 m
.63798 .51256 L
s
.65515 .50633 m
.66101 .51246 L
s
0 1 0 r
.48624 .7643 m .51672 .75621 L .49577 .77542 L F
.48624 .7643 m .50609 .74335 L .51672 .75621 L F
0 0 1 r
.83177 .51232 m
.84338 .5098 L
s
0 0 0 r
.5494 .54787 m
.54994 .53908 L
s
0 0 1 r
.62578 .51223 m
.63607 .50831 L
s
0 0 0 r
.34898 .84161 m
.35378 .83625 L
s
0 .948 0 r
.5022 .52027 m .53497 .51209 L .53447 .53612 L F
.5022 .52027 m .50275 .49601 L .53497 .51209 L F
0 0 0 r
.52724 .50675 m
.5407 .51439 L
s
.53289 .50975 m
.53904 .51337 L
s
.52432 .50509 m
.52724 .50675 L
s
.55503 .67066 m
.55832 .6743 L
s
.55264 .6897 m
.55527 .68499 L
s
0 1 0 r
.31828 .83819 m .29661 .82496 L .32039 .83646 L F
.31828 .83819 m .29248 .82845 L .29661 .82496 L F
0 0 1 r
.56821 .51179 m
.57716 .50747 L
s
0 1 0 r
.36903 .83802 m .39379 .8281 L .39746 .83183 L F
.36653 .83631 m .39379 .8281 L .36903 .83802 L F
0 0 0 r
.54955 .5516 m
.55489 .55536 L
s
.55992 .6346 m
.56378 .63834 L
s
.55956 .65885 m
.56203 .65304 L
s
0 0 1 r
.59647 .51135 m
.6061 .50721 L
s
.66578 .5112 m
.67635 .50766 L
s
0 0 0 r
.56217 .6286 m
.56423 .62204 L
s
0 1 0 r
.28966 .8322 m .2672 .81613 L .29248 .82845 L F
.28966 .8322 m .26313 .82177 L .2672 .81613 L F
0 0 1 r
.74366 .50323 m
.74889 .51098 L
s
0 .779 0 r
.19088 .77652 m .1782 .74457 L .19799 .76535 L F
0 .847 0 r
.2134 .79374 m .19088 .77652 L .19799 .76535 L F
0 1 0 r
.52691 .58769 m .55827 .5791 L .55286 .60465 L F
.52691 .58769 m .53179 .56143 L .55827 .5791 L F
0 0 0 r
.55673 .57118 m
.55782 .5627 L
s
.55011 .69405 m
.55264 .6897 L
s
.56058 .60136 m
.56226 .59385 L
s
0 0 1 r
.76833 .51065 m
.77957 .50779 L
s
0 1 0 r
.39379 .8281 m .42357 .82121 L .39746 .83183 L F
0 0 1 r
.58123 .5061 m
.58729 .51058 L
s
0 0 0 r
.55922 .61958 m
.56356 .6235 L
s
0 .543 0 r
.13238 .67469 m .13822 .63225 L .1477 .65814 L F
0 .624 0 r
.14519 .69892 m .13238 .67469 L .1477 .65814 L F
0 0 0 r
.55317 .56973 m
.55854 .57375 L
s
.55583 .65827 m
.55921 .66174 L
s
.55618 .58732 m
.56104 .5912 L
s
.53996 .53265 m
.54022 .52303 L
s
.55714 .66422 m
.55956 .65885 L
s
.53898 .5291 m
.54468 .53264 L
s
.55815 .60395 m
.56253 .60766 L
s
.54769 .69807 m
.55011 .69405 L
s
0 0 1 r
.84338 .5098 m
.85403 .50749 L
s
0 0 0 r
.52624 .5061 m
.53289 .50975 L
s
0 1 0 r
.32039 .83646 m .30196 .82183 L .32309 .83491 L F
.32039 .83646 m .29661 .82496 L .30196 .82183 L F
0 0 1 r
.82921 .5 m
.83383 .50963 L
s
.54838 .50957 m
.55742 .50466 L
s
0 1 0 r
.46478 .78349 m .49577 .77542 L .47306 .79281 L F
.46478 .78349 m .48624 .7643 L .49577 .77542 L F
0 .458 0 r
.21639 .46149 m .22058 .4412 L .25791 .43125 L F
0 .346 0 r
.18234 .47496 m .22058 .4412 L .21639 .46149 L F
0 1 0 r
.36653 .83631 m .38888 .82464 L .39379 .8281 L F
.36348 .83478 m .38888 .82464 L .36653 .83631 L F
0 0 1 r
.71675 .50942 m
.72716 .50637 L
s
0 .447 0 r
.17926 .49744 m .18234 .47496 L .21639 .46149 L F
0 0 1 r
.78633 .50104 m
.79109 .5093 L
s
.55351 .50542 m
.5596 .50929 L
s
0 0 0 r
.56011 .63469 m
.56217 .6286 L
s
.55547 .5791 m
.55673 .57118 L
s
0 .531 0 r
.2982 .42503 m .301 .4076 L .34143 .40542 L F
0 .453 0 r
.25791 .43125 m .301 .4076 L .2982 .42503 L F
0 .967 0 r
.26313 .82177 m .2428 .80137 L .2672 .81613 L F
.26313 .82177 m .23759 .80889 L .2428 .80137 L F
0 0 0 r
.54133 .70411 m
.54407 .7073 L
s
0 .847 0 r
.2134 .79374 m .19799 .76535 L .21962 .78437 L F
0 .909 0 r
.23759 .80889 m .2134 .79374 L .21962 .78437 L F
0 0 0 r
.54513 .70219 m
.54769 .69807 L
s
0 .593 0 r
.34021 .4228 m .38221 .40721 L .38257 .42464 L F
.34021 .4228 m .34143 .40542 L .38221 .40721 L F
0 0 0 r
.54862 .55612 m
.5494 .54787 L
s
.5566 .6455 m
.55987 .64864 L
s
.55607 .64499 m
.5566 .6455 L
s
0 0 1 r
.60323 .50342 m
.60971 .50863 L
s
0 1 0 r
.52226 .68229 m .55342 .67304 L .5399 .6974 L F
0 0 0 r
.54553 .6974 m
.54832 .70068 L
s
.54978 .69022 m
.55261 .69359 L
s
0 1 0 r
.52226 .68229 m .53476 .65661 L .55342 .67304 L F
0 0 0 r
.55082 .67898 m
.55405 .68254 L
s
.5548 .66919 m
.55714 .66422 L
s
0 0 1 r
.72007 .50167 m
.72529 .50853 L
s
0 .761 0 r
.42501 .45063 m .46298 .44008 L .46506 .46036 L F
.42501 .45063 m .42393 .43048 L .46298 .44008 L F
0 0 0 r
.46228 .43107 m
.46351 .43861 L
s
0 .909 0 r
.23759 .80889 m .21962 .78437 L .2428 .80137 L F
0 1 0 r
.41823 .8156 m .44889 .80815 L .42357 .82121 L F
.39379 .8281 m .41823 .8156 L .42357 .82121 L F
0 0 0 r
.55883 .60834 m
.56058 .60136 L
s
0 0 1 r
.63607 .50831 m
.64604 .50453 L
s
0 0 0 r
.46351 .43861 m
.46453 .44656 L
s
.5466 .68676 m
.54978 .69022 L
s
.54281 .7058 m
.54513 .70219 L
s
0 .86 0 r
.46582 .48286 m .50151 .47352 L .50275 .49601 L F
.46582 .48286 m .46506 .46036 L .50151 .47352 L F
0 0 0 r
.55171 .66728 m
.55503 .67066 L
s
0 1 0 r
.442 .80067 m .47306 .79281 L .44889 .80815 L F
.442 .80067 m .46478 .78349 L .47306 .79281 L F
0 0 0 r
.52946 .50784 m
.52952 .51685 L
s
0 0 1 r
.52946 .50784 m
.53727 .50307 L
s
.77957 .50779 m
.79042 .50504 L
s
0 0 0 r
.54374 .54778 m
.54955 .5516 L
s
0 0 1 r
.67635 .50766 m
.68657 .50424 L
s
0 1 0 r
.32309 .83491 m .3084 .81913 L .32633 .83358 L F
.32309 .83491 m .30196 .82183 L .3084 .81913 L F
0 0 0 r
.55785 .64092 m
.56011 .63469 L
s
0 1 0 r
.41823 .8156 m .442 .80067 L .44889 .80815 L F
.36348 .83478 m .38282 .82155 L .38888 .82464 L F
.35994 .83347 m .38282 .82155 L .36348 .83478 L F
0 0 1 r
.57716 .50747 m
.58581 .50328 L
s
0 0 0 r
.55563 .63076 m
.55992 .6346 L
s
.55229 .67428 m
.5548 .66919 L
s
0 0 1 r
.69631 .5006 m
.702 .5073 L
s
.62615 .50176 m
.63236 .50723 L
s
.6061 .50721 m
.61543 .50321 L
s
0 .531 0 r
.2982 .42503 m .34143 .40542 L .34021 .4228 L F
0 0 0 r
.5424 .69403 m
.54553 .6974 L
s
0 0 1 r
.67247 .50005 m
.67859 .50655 L
s
0 0 0 r
.55395 .58725 m
.55547 .5791 L
s
0 0 1 r
.72716 .50637 m
.73827 .50311 L
s
.64926 .50065 m
.65515 .50633 L
s
0 0 0 r
.5328 .52551 m
.53898 .5291 L
s
0 1 0 r
.29248 .82845 m .27325 .81087 L .29661 .82496 L F
.29248 .82845 m .2672 .81613 L .27325 .81087 L F
0 0 0 r
.55489 .61595 m
.55922 .61958 L
s
.54786 .56603 m
.55317 .56973 L
s
.55208 .65471 m
.55583 .65827 L
s
.55685 .61551 m
.55883 .60834 L
s
.54987 .67898 m
.55229 .67428 L
s
0 0 1 r
.57462 .50155 m
.58123 .5061 L
s
.51977 .50278 m
.52624 .5061 L
s
.76217 .49788 m
.76755 .50603 L
s
0 0 0 r
.54755 .67569 m
.55082 .67898 L
s
0 1 0 r
.32633 .83358 m .31577 .81695 L .33002 .83251 L F
.32633 .83358 m .3084 .81913 L .31577 .81695 L F
0 0 0 r
.55562 .6467 m
.55785 .64092 L
s
.55334 .60015 m
.55815 .60395 L
s
0 1 0 r
.38888 .82464 m .41823 .8156 L .39379 .8281 L F
0 0 0 r
.55085 .58338 m
.55618 .58732 L
s
0 1 0 r
.35994 .83347 m .37577 .8189 L .38282 .82155 L F
.356 .83242 m .37577 .8189 L .35994 .83347 L F
0 0 0 r
.53943 .54149 m
.53996 .53265 L
s
.54757 .56466 m
.54862 .55612 L
s
0 0 1 r
.54691 .50149 m
.55351 .50542 L
s
.84845 .49531 m
.85312 .50535 L
s
0 .624 0 r
.14519 .69892 m .1477 .65814 L .15969 .6837 L F
0 .697 0 r
.16053 .72232 m .14519 .69892 L .15969 .6837 L F
0 0 0 r
.54729 .68379 m
.54987 .67898 L
s
.50639 .49656 m
.52432 .50509 L
s
0 0 1 r
.79042 .50504 m
.802 .5021 L
s
.80523 .49602 m
.81009 .50466 L
s
.55742 .50466 m
.56597 .50001 L
s
0 0 0 r
.55185 .64125 m
.55607 .64499 L
s
0 1 0 r
.33002 .83251 m .32389 .81533 L .33408 .83171 L F
.33002 .83251 m .31577 .81695 L .32389 .81533 L F
0 0 1 r
.64604 .50453 m
.65568 .50086 L
s
0 .482 0 r
.13134 .60639 m .15023 .56305 L .15397 .58925 L F
0 .563 0 r
.13822 .63225 m .13134 .60639 L .15397 .58925 L F
0 1 0 r
.35177 .83165 m .3679 .81677 L .356 .83242 L F
.356 .83242 m .3679 .81677 L .37577 .8189 L F
0 0 0 r
.55321 .65261 m
.55562 .6467 L
s
.54338 .68355 m
.5466 .68676 L
s
0 0 1 r
.68657 .50424 m
.69645 .50093 L
s
0 0 0 r
.55484 .62216 m
.55685 .61551 L
s
.54802 .6638 m
.55171 .66728 L
s
.54482 .68823 m
.54729 .68379 L
s
.53804 .54428 m
.54374 .54778 L
s
0 1 0 r
.33408 .83171 m .33255 .81433 L .33839 .83122 L F
.33408 .83171 m .32389 .81533 L .33255 .81433 L F
.35177 .83165 m .35942 .81521 L .3679 .81677 L F
.34735 .83119 m .35942 .81521 L .35177 .83165 L F
.50765 .7073 m .5399 .6974 L .52405 .72095 L F
.50765 .7073 m .52226 .68229 L .5399 .6974 L F
0 0 0 r
.53825 .70082 m
.54133 .70411 L
s
0 0 1 r
.5968 .49862 m
.60323 .50342 L
s
0 .423 0 r
.14892 .53778 m .17926 .49744 L .1782 .52169 L F
0 0 0 r
.16094 .5058 m
.17745 .4972 L
s
0 .509 0 r
.15023 .56305 m .14892 .53778 L .1782 .52169 L F
0 0 1 r
.58581 .50328 m
.59508 .49881 L
s
.73828 .496 m
.74366 .50323 L
s
.61543 .50321 m
.6254 .49893 L
s
0 0 0 r
.54245 .69233 m
.54482 .68823 L
s
0 0 1 r
.73827 .50311 m
.74903 .49996 L
s
.53727 .50307 m
.54584 .49784 L
s
0 0 0 r
.55085 .65807 m
.55321 .65261 L
s
0 1 0 r
.33839 .83122 m .34151 .81397 L .34285 .83105 L F
.33839 .83122 m .33255 .81433 L .34151 .81397 L F
.34735 .83119 m .35055 .81427 L .35942 .81521 L F
0 0 0 r
.35378 .83625 m
.35861 .83043 L
s
0 1 0 r
.34285 .83105 m .35055 .81427 L .34735 .83119 L F
0 0 0 r
.53924 .6909 m
.5424 .69403 L
s
.51281 .49944 m
.51977 .50278 L
s
0 1 0 r
.34285 .83105 m .34151 .81397 L .35055 .81427 L F
0 0 0 r
.46453 .44656 m
.46534 .4549 L
s
0 1 0 r
.51987 .61455 m .55286 .60465 L .545 .63061 L F
0 0 0 r
.55136 .62722 m
.55563 .63076 L
s
0 1 0 r
.51987 .61455 m .52691 .58769 L .55286 .60465 L F
0 0 0 r
.55232 .59484 m
.55395 .58725 L
s
.54635 .57265 m
.54757 .56466 L
s
.54208 .56227 m
.54786 .56603 L
s
.53994 .69654 m
.54245 .69233 L
s
.55014 .61224 m
.55489 .61595 L
s
.54793 .65107 m
.55208 .65471 L
s
.55284 .62832 m
.55484 .62216 L
s
.54392 .67231 m
.54755 .67569 L
s
.53868 .54979 m
.53943 .54149 L
s
0 0 1 r
.802 .5021 m
.8132 .49926 L
s
0 .982 0 r
.2672 .81613 m .25065 .79434 L .27325 .81087 L F
.2672 .81613 m .2428 .80137 L .25065 .79434 L F
0 0 0 r
.51809 .50195 m
.51812 .51099 L
s
0 0 1 r
.51809 .50195 m
.52542 .4969 L
s
0 1 0 r
.29661 .82496 m .28116 .80613 L .30196 .82183 L F
.29661 .82496 m .27325 .81087 L .28116 .80613 L F
0 0 0 r
.54807 .59629 m
.55334 .60015 L
s
0 0 1 r
.61932 .49619 m
.62615 .50176 L
s
0 0 0 r
.54857 .66313 m
.55085 .65807 L
s
0 0 1 r
.71418 .4946 m
.72007 .50167 L
s
0 0 0 r
.54558 .57975 m
.55085 .58338 L
s
0 .991 0 r
.49983 .54602 m .53447 .53612 L .53179 .56143 L F
.49983 .54602 m .5022 .52027 L .53447 .53612 L F
0 0 0 r
.52614 .52189 m
.5328 .52551 L
s
.52926 .52651 m
.52952 .51685 L
s
.53515 .69777 m
.53825 .70082 L
s
.53767 .70023 m
.53994 .69654 L
s
0 0 1 r
.56812 .49738 m
.57462 .50155 L
s
.53979 .49754 m
.54691 .50149 L
s
0 1 0 r
.38888 .82464 m .411 .81038 L .41823 .8156 L F
.38282 .82155 m .411 .81038 L .38888 .82464 L F
0 0 0 r
.55062 .6019 m
.55232 .59484 L
s
0 1 0 r
.411 .81038 m .442 .80067 L .41823 .8156 L F
0 .697 0 r
.16053 .72232 m .15969 .6837 L .17403 .70857 L F
0 .763 0 r
.1782 .74457 m .16053 .72232 L .17403 .70857 L F
0 0 1 r
.78081 .4925 m
.78633 .50104 L
s
.69645 .50093 m
.70702 .49739 L
s
0 0 0 r
.35861 .83043 m
.36346 .82414 L
s
0 0 1 r
.65568 .50086 m
.66598 .49695 L
s
.64274 .49483 m
.64926 .50065 L
s
0 0 0 r
.53981 .68025 m
.54338 .68355 L
s
.55064 .63465 m
.55284 .62832 L
s
0 0 1 r
.68994 .49371 m
.69631 .5006 L
s
0 0 0 r
.54612 .66831 m
.54857 .66313 L
s
.54764 .63779 m
.55185 .64125 L
s
.54393 .66025 m
.54802 .6638 L
s
.53188 .54074 m
.53804 .54428 L
s
0 0 1 r
.66631 .49402 m
.67247 .50005 L
s
0 .544 0 r
.25466 .45141 m .25791 .43125 L .2982 .42503 L F
0 .458 0 r
.21639 .46149 m .25791 .43125 L .25466 .45141 L F
0 0 1 r
.56597 .50001 m
.57424 .49552 L
s
.82426 .49097 m
.82921 .5 L
s
.74903 .49996 m
.75941 .49692 L
s
0 0 0 r
.54488 .58087 m
.54635 .57265 L
s
0 1 0 r
.49114 .73127 m .52405 .72095 L .50609 .74335 L F
.49114 .73127 m .50765 .7073 L .52405 .72095 L F
0 0 0 r
.52873 .53539 m
.52926 .52651 L
s
.50536 .49611 m
.51281 .49944 L
s
.54375 .6731 m
.54612 .66831 L
s
.5487 .60916 m
.55062 .6019 L
s
.54667 .6236 m
.55136 .62722 L
s
0 .719 0 r
.38257 .44472 m .42393 .43048 L .42501 .45063 L F
.38257 .44472 m .38257 .42464 L .42393 .43048 L F
0 0 0 r
.53574 .68769 m
.53924 .6909 L
s
0 0 1 r
.8132 .49926 m
.82402 .49651 L
s
0 .932 0 r
.2428 .80137 m .22913 .77558 L .25065 .79434 L F
.2428 .80137 m .21962 .78437 L .22913 .77558 L F
0 0 0 r
.53766 .55839 m
.53868 .54979 L
s
.54847 .64052 m
.55064 .63465 L
s
.51965 .51859 m
.52614 .52189 L
s
0 0 1 r
.6254 .49893 m
.63505 .49479 L
s
.59508 .49881 m
.60405 .49447 L
s
.58979 .49373 m
.5968 .49862 L
s
0 .763 0 r
.1782 .74457 m .17403 .70857 L .19054 .73239 L F
0 .823 0 r
.19799 .76535 m .1782 .74457 L .19054 .73239 L F
0 0 0 r
.53642 .55883 m
.54208 .56227 L
s
.54124 .678 m
.54375 .6731 L
s
.5399 .66884 m
.54392 .67231 L
s
.54493 .60846 m
.55014 .61224 L
s
0 1 0 r
.43259 .79369 m .46478 .78349 L .442 .80067 L F
.411 .81038 m .43259 .79369 L .442 .80067 L F
0 0 0 r
.5317 .69464 m
.53515 .69777 L
s
0 0 1 r
.75662 .49029 m
.76217 .49788 L
s
0 1 0 r
.30196 .82183 m .29072 .80204 L .3084 .81913 L F
.30196 .82183 m .28116 .80613 L .29072 .80204 L F
0 0 1 r
.54584 .49784 m
.55394 .49289 L
s
0 0 0 r
.53985 .57606 m
.54558 .57975 L
s
.51786 .52069 m
.51812 .51099 L
s
.54286 .59273 m
.54807 .59629 L
s
.54613 .64652 m
.54847 .64052 L
s
0 0 1 r
.53284 .49394 m
.53979 .49754 L
s
0 0 0 r
.53883 .68252 m
.54124 .678 L
s
0 .563 0 r
.13822 .63225 m .15397 .58925 L .16013 .61602 L F
0 .635 0 r
.1477 .65814 m .13822 .63225 L .16013 .61602 L F
0 1 0 r
.38282 .82155 m .40203 .8057 L .411 .81038 L F
.37577 .8189 m .40203 .8057 L .38282 .82155 L F
0 .447 0 r
.17926 .49744 m .21639 .46149 L .21375 .48399 L F
0 .53 0 r
.1782 .52169 m .17926 .49744 L .21375 .48399 L F
0 .879 0 r
.21962 .78437 m .209 .75483 L .22913 .77558 L F
.21962 .78437 m .19799 .76535 L .209 .75483 L F
0 0 1 r
.70702 .49739 m
.71723 .49397 L
s
.56109 .49315 m
.56812 .49738 L
s
0 .823 0 r
.19799 .76535 m .19054 .73239 L .209 .75483 L F
0 0 0 r
.54676 .61589 m
.5487 .60916 L
s
.17745 .4972 m
.19552 .48944 L
s
0 1 0 r
.47295 .75386 m .50609 .74335 L .48624 .7643 L F
.47295 .75386 m .49114 .73127 L .50609 .74335 L F
0 0 0 r
.5433 .58854 m
.54488 .58087 L
s
0 0 1 r
.66598 .49695 m
.67596 .49315 L
s
.75941 .49692 m
.77051 .49367 L
s
.52542 .4969 m
.53348 .49136 L
s
0 0 0 r
.53586 .67688 m
.53981 .68025 L
s
.53652 .68672 m
.53883 .68252 L
s
0 0 1 r
.82402 .49651 m
.83557 .49358 L
s
0 0 0 r
.52524 .53716 m
.53188 .54074 L
s
.50606 .49641 m
.50607 .50547 L
s
0 0 1 r
.50606 .49641 m
.51289 .4911 L
s
0 1 0 r
.45334 .77477 m .48624 .7643 L .46478 .78349 L F
.43259 .79369 m .45334 .77477 L .46478 .78349 L F
0 0 0 r
.53986 .65697 m
.54393 .66025 L
s
0 0 1 r
.61253 .49106 m
.61932 .49619 L
s
0 .542 0 r
.21375 .48399 m .21639 .46149 L .25466 .45141 L F
0 0 1 r
.79959 .48708 m
.80523 .49602 L
s
0 .91 0 r
.46521 .50732 m .50275 .49601 L .5022 .52027 L F
.46521 .50732 m .46582 .48286 L .50275 .49601 L F
0 0 0 r
.49396 .49162 m
.50639 .49656 L
s
.49814 .4931 m
.50536 .49611 L
s
.48705 .48887 m
.49396 .49162 L
s
0 0 1 r
.73218 .48855 m
.73828 .496 L
s
0 1 0 r
.45334 .77477 m .47295 .75386 L .48624 .7643 L F
0 0 0 r
.53407 .691 m
.53652 .68672 L
s
.53648 .56645 m
.53766 .55839 L
s
.52801 .54374 m
.52873 .53539 L
s
0 1 0 r
.51075 .64163 m .545 .63061 L .53476 .65661 L F
0 0 0 r
.54384 .65207 m
.54613 .64652 L
s
.54379 .64769 m
.54793 .65107 L
s
0 1 0 r
.51075 .64163 m .51987 .61455 L .545 .63061 L F
0 0 0 r
.54302 .63426 m
.54764 .63779 L
s
.51268 .51528 m
.51965 .51859 L
s
.53186 .6844 m
.53574 .68769 L
s
0 0 1 r
.57424 .49552 m
.5831 .49071 L
s
0 0 0 r
.54482 .62214 m
.54676 .61589 L
s
.54154 .61991 m
.54667 .6236 L
s
0 .997 0 r
.27325 .81087 m .26098 .78798 L .28116 .80613 L F
.27325 .81087 m .25065 .79434 L .26098 .78798 L F
0 0 1 r
.84342 .48588 m
.84845 .49531 L
s
0 0 0 r
.53186 .69478 m
.53407 .691 L
s
0 .821 0 r
.42522 .47314 m .46506 .46036 L .46582 .48286 L F
0 0 0 r
.46534 .4549 m
.46593 .46362 L
s
0 .821 0 r
.42522 .47314 m .42501 .45063 L .46506 .46036 L F
0 0 0 r
.54161 .65722 m
.54384 .65207 L
s
0 0 1 r
.63556 .4889 m
.64274 .49483 L
s
.63505 .49479 m
.64439 .49078 L
s
0 1 0 r
.40203 .8057 m .43259 .79369 L .411 .81038 L F
0 0 0 r
.54166 .59568 m
.5433 .58854 L
s
0 0 1 r
.70756 .48732 m
.71418 .4946 L
s
0 0 0 r
.53589 .66564 m
.5399 .66884 L
s
0 0 1 r
.60405 .49447 m
.61365 .48983 L
s
0 0 0 r
.52789 .69144 m
.5317 .69464 L
s
.53924 .64425 m
.54379 .64769 L
s
0 1 0 r
.3084 .81913 m .30172 .79872 L .31577 .81695 L F
.3084 .81913 m .29072 .80204 L .30172 .79872 L F
0 0 0 r
.53979 .60499 m
.54493 .60846 L
s
0 1 0 r
.37577 .8189 m .39154 .80168 L .40203 .8057 L F
.3679 .81677 m .39154 .80168 L .37577 .8189 L F
0 0 0 r
.36346 .82414 m
.36832 .8174 L
s
0 .613 0 r
.29599 .44512 m .2982 .42503 L .34021 .4228 L F
0 .544 0 r
.25466 .45141 m .2982 .42503 L .29599 .44512 L F
0 0 1 r
.65949 .48784 m
.66631 .49402 L
s
0 .509 0 r
.15023 .56305 m .1782 .52169 L .17922 .5474 L F
0 .583 0 r
.15397 .58925 m .15023 .56305 L .17922 .5474 L F
0 0 1 r
.71723 .49397 m
.72815 .49031 L
s
.52538 .49032 m
.53284 .49394 L
s
0 0 0 r
.53923 .66249 m
.54161 .65722 L
s
.53424 .57268 m
.53985 .57606 L
s
.53719 .58913 m
.54286 .59273 L
s
.54269 .62856 m
.54482 .62214 L
s
0 0 1 r
.5829 .48925 m
.58979 .49373 L
s
.68352 .48733 m
.68994 .49371 L
s
0 .67 0 r
.3391 .44285 m .38257 .42464 L .38257 .44472 L F
.3391 .44285 m .34021 .4228 L .38257 .42464 L F
0 0 1 r
.77051 .49367 m
.78124 .49052 L
s
.83557 .49358 m
.84617 .49089 L
s
0 0 0 r
.51735 .52961 m
.51786 .52069 L
s
.53507 .57475 m
.53648 .56645 L
s
0 0 1 r
.67596 .49315 m
.68559 .48949 L
s
.55349 .48888 m
.56109 .49315 L
s
0 0 0 r
.49043 .49012 m
.49814 .4931 L
s
0 0 1 r
.55394 .49289 m
.56179 .4881 L
s
0 0 0 r
.53694 .66737 m
.53923 .66249 L
s
.51876 .53391 m
.52524 .53716 L
s
.53796 .63066 m
.54302 .63426 L
s
.53981 .60302 m
.54166 .59568 L
s
.53539 .65361 m
.53986 .65697 L
s
0 0 1 r
.77511 .48453 m
.78081 .4925 L
s
0 1 0 r
.49563 .57291 m .53179 .56143 L .52691 .58769 L F
.49563 .57291 m .49983 .54602 L .53179 .56143 L F
0 0 0 r
.52703 .55241 m
.52801 .54374 L
s
.53029 .55534 m
.53642 .55883 L
s
.54059 .63452 m
.54269 .62856 L
s
.50521 .51198 m
.51268 .51528 L
s
.5058 .5152 m
.50607 .50547 L
s
.5345 .67235 m
.53694 .66737 L
s
.46593 .46362 m
.4663 .4727 L
s
0 .613 0 r
.29599 .44512 m .34021 .4228 L .3391 .44285 L F
0 .635 0 r
.1477 .65814 m .16013 .61602 L .16864 .643 L F
0 .698 0 r
.15969 .6837 m .1477 .65814 L .16864 .643 L F
0 1 0 r
.31577 .81695 m .31386 .79626 L .32389 .81533 L F
.31577 .81695 m .30172 .79872 L .31386 .79626 L F
.3679 .81677 m .3798 .79844 L .39154 .80168 L F
.35942 .81521 m .3798 .79844 L .3679 .81677 L F
0 0 1 r
.53348 .49136 m
.54111 .48612 L
s
0 0 0 r
.53647 .61652 m
.54154 .61991 L
s
.4934 .50033 m
.49341 .49124 L
s
0 0 1 r
.49341 .49124 m
.49971 .48568 L
s
0 0 0 r
.52368 .55183 m
.53029 .55534 L
s
0 0 1 r
.51289 .4911 m
.5204 .48527 L
s
0 0 0 r
.53216 .67697 m
.5345 .67235 L
s
0 0 1 r
.60513 .48583 m
.61253 .49106 L
s
.8185 .48162 m
.82426 .49097 L
s
0 0 0 r
.53832 .64061 m
.54059 .63452 L
s
0 0 1 r
.64439 .49078 m
.65439 .48649 L
s
0 0 0 r
.5241 .68848 m
.52789 .69144 L
s
0 0 1 r
.5831 .49071 m
.59168 .48605 L
s
0 0 0 r
.53794 .60984 m
.53981 .60302 L
s
.53355 .58249 m
.53507 .57475 L
s
0 0 1 r
.78124 .49052 m
.79269 .48717 L
s
0 0 0 r
.53419 .60146 m
.53979 .60499 L
s
.52817 .56926 m
.53424 .57268 L
s
0 0 1 r
.51737 .48671 m
.52538 .49032 L
s
.72815 .49031 m
.73871 .48677 L
s
.75033 .48245 m
.75662 .49029 L
s
0 .953 0 r
.25065 .79434 m .24174 .76761 L .26098 .78798 L F
.25065 .79434 m .22913 .77558 L .24174 .76761 L F
0 1 0 r
.49966 .66854 m .53476 .65661 L .52226 .68229 L F
0 0 0 r
.52991 .68124 m
.53216 .67697 L
s
.52799 .68136 m
.53186 .6844 L
s
.53193 .67376 m
.53586 .67688 L
s
0 1 0 r
.49966 .66854 m .51075 .64163 L .53476 .65661 L F
0 0 0 r
.5315 .66237 m
.53589 .66564 L
s
.53427 .64075 m
.53924 .64425 L
s
.48642 .48865 m
.49043 .49012 L
s
.53164 .58582 m
.53719 .58913 L
s
.51665 .53801 m
.51735 .52961 L
s
0 0 1 r
.61365 .48983 m
.62295 .48534 L
s
0 0 0 r
.5259 .56052 m
.52703 .55241 L
s
.52754 .68561 m
.52991 .68124 L
s
.5361 .64625 m
.53832 .64061 L
s
0 1 0 r
.32389 .81533 m .32682 .79473 L .33255 .81433 L F
.32389 .81533 m .31386 .79626 L .32682 .79473 L F
0 0 0 r
.52761 .67058 m
.53193 .67376 L
s
0 0 1 r
.68559 .48949 m
.69591 .48557 L
s
0 0 0 r
.5118 .53064 m
.51876 .53391 L
s
0 1 0 r
.35942 .81521 m .36712 .79607 L .3798 .79844 L F
0 0 0 r
.36832 .8174 m
.37318 .81022 L
s
0 1 0 r
.35055 .81427 m .36712 .79607 L .35942 .81521 L F
.42084 .78741 m .45334 .77477 L .43259 .79369 L F
.40203 .8057 m .42084 .78741 L .43259 .79369 L F
.28116 .80613 m .27356 .78248 L .29072 .80204 L F
.28116 .80613 m .26098 .78798 L .27356 .78248 L F
0 0 1 r
.57543 .48471 m
.5829 .48925 L
s
0 0 0 r
.52539 .68946 m
.52754 .68561 L
s
.49797 .509 m
.50521 .51198 L
s
0 0 1 r
.62842 .48342 m
.63556 .4889 L
s
.54607 .485 m
.55349 .48888 L
s
0 0 0 r
.46645 .48212 m
.48705 .48887 L
s
.53607 .61618 m
.53794 .60984 L
s
.53297 .62736 m
.53796 .63066 L
s
0 1 0 r
.39154 .80168 m .42084 .78741 L .40203 .8057 L F
0 0 0 r
.5305 .6502 m
.53539 .65361 L
s
.48271 .48734 m
.48642 .48865 L
s
0 0 1 r
.72533 .48088 m
.73218 .48855 L
s
0 0 0 r
.53395 .65148 m
.5361 .64625 L
s
.52375 .67826 m
.52799 .68136 L
s
0 1 0 r
.33255 .81433 m .34026 .79419 L .34151 .81397 L F
.33255 .81433 m .32682 .79473 L .34026 .79419 L F
0 0 0 r
.53198 .58971 m
.53355 .58249 L
s
0 1 0 r
.35055 .81427 m .35382 .79464 L .36712 .79607 L F
.34151 .81397 m .35382 .79464 L .35055 .81427 L F
0 0 1 r
.56179 .4881 m
.57019 .48296 L
s
0 0 0 r
.5053 .52417 m
.5058 .5152 L
s
0 0 1 r
.65196 .48153 m
.65949 .48784 L
s
0 1 0 r
.34151 .81397 m .34026 .79419 L .35382 .79464 L F
0 .698 0 r
.15969 .6837 m .16864 .643 L .17942 .6698 L F
0 .756 0 r
.17403 .70857 m .15969 .6837 L .17942 .6698 L F
0 0 0 r
.53095 .61308 m
.53647 .61652 L
s
.51724 .54863 m
.52368 .55183 L
s
.53165 .65684 m
.53395 .65148 L
s
.47838 .48587 m
.48271 .48734 L
s
.53402 .62268 m
.53607 .61618 L
s
0 0 1 r
.6764 .48078 m
.68352 .48733 L
s
.70088 .48057 m
.70756 .48732 L
s
0 0 0 r
.5267 .65905 m
.5315 .66237 L
s
0 0 1 r
.79269 .48717 m
.80377 .48392 L
s
.79374 .47873 m
.79959 .48708 L
s
0 0 0 r
.52454 .5689 m
.5259 .56052 L
s
.4663 .4727 m
.46645 .48212 L
s
.51571 .54673 m
.51665 .53801 L
s
0 .53 0 r
.1782 .52169 m .21375 .48399 L .21273 .50843 L F
0 0 0 r
.19552 .48944 m
.2035 .48665 L
s
0 .599 0 r
.17922 .5474 m .1782 .52169 L .21273 .50843 L F
0 0 1 r
.73871 .48677 m
.74892 .48335 L
s
0 0 0 r
.52935 .63752 m
.53427 .64075 L
s
.52162 .56581 m
.52817 .56926 L
s
0 0 1 r
.50961 .48345 m
.51737 .48671 L
s
0 0 0 r
.52871 .59823 m
.53419 .60146 L
s
0 .907 0 r
.22913 .77558 m .2237 .74529 L .24174 .76761 L F
.22913 .77558 m .209 .75483 L .2237 .74529 L F
0 0 0 r
.52943 .6618 m
.53165 .65684 L
s
0 0 1 r
.65439 .48649 m
.66406 .48234 L
s
0 0 0 r
.48015 .49557 m
.48019 .48647 L
s
0 0 1 r
.48019 .48647 m
.48592 .48068 L
s
0 .617 0 r
.25252 .47392 m .25466 .45141 L .29599 .44512 L F
0 .542 0 r
.21375 .48399 m .25466 .45141 L .25252 .47392 L F
0 0 0 r
.5302 .59713 m
.53198 .58971 L
s
0 0 1 r
.54111 .48612 m
.54849 .48104 L
s
0 0 0 r
.50435 .52738 m
.5118 .53064 L
s
0 .583 0 r
.15397 .58925 m .17922 .5474 L .18234 .57423 L F
0 .647 0 r
.16013 .61602 m .15397 .58925 L .18234 .57423 L F
0 1 0 r
.48673 .6949 m .52226 .68229 L .50765 .7073 L F
.48673 .6949 m .49966 .66854 L .52226 .68229 L F
0 0 0 r
.51994 .68546 m
.5241 .68848 L
s
0 0 1 r
.59168 .48605 m
.60086 .48107 L
s
.83755 .47612 m
.84342 .48588 L
s
0 0 0 r
.5229 .66734 m
.52761 .67058 L
s
.47645 .48523 m
.47838 .48587 L
s
.532 .62872 m
.53402 .62268 L
s
0 0 1 r
.59784 .48104 m
.60513 .48583 L
s
.49971 .48568 m
.50663 .47957 L
s
0 0 0 r
.52708 .66688 m
.52943 .6618 L
s
0 0 1 r
.69591 .48557 m
.70588 .48178 L
s
0 1 0 r
.43897 .76689 m .47295 .75386 L .45334 .77477 L F
.42084 .78741 m .43897 .76689 L .45334 .77477 L F
0 .779 0 r
.3822 .46723 m .42501 .45063 L .42522 .47314 L F
.3822 .46723 m .38257 .44472 L .42501 .45063 L F
0 0 0 r
.37318 .81022 m
.37802 .80261 L
s
0 .95 0 r
.4632 .53343 m .5022 .52027 L .49983 .54602 L F
.4632 .53343 m .46521 .50732 L .5022 .52027 L F
0 0 0 r
.49025 .50603 m
.49797 .509 L
s
.49312 .51009 m
.4934 .50033 L
s
0 0 1 r
.62295 .48534 m
.63195 .48099 L
s
.5204 .48527 m
.5275 .47974 L
s
0 0 0 r
.47431 .48454 m
.47645 .48523 L
s
.52754 .624 m
.53297 .62736 L
s
0 .756 0 r
.17403 .70857 m .17942 .6698 L .19231 .69603 L F
0 .809 0 r
.19054 .73239 m .17403 .70857 L .19231 .69603 L F
0 0 1 r
.5381 .48109 m
.54607 .485 L
s
0 0 0 r
.52567 .64706 m
.5305 .6502 L
s
.52481 .67158 m
.52708 .66688 L
s
.51912 .67511 m
.52375 .67826 L
s
0 0 1 r
.56735 .48012 m
.57543 .48471 L
s
0 0 0 r
.47221 .48388 m
.47431 .48454 L
s
.52981 .6349 m
.532 .62872 L
s
0 0 1 r
.76863 .4763 m
.77511 .48453 L
s
0 .859 0 r
.209 .75483 m .20715 .72131 L .2237 .74529 L F
.209 .75483 m .19054 .73239 L .20715 .72131 L F
0 1 0 r
.48964 .60057 m .52691 .58769 L .51987 .61455 L F
.48964 .60057 m .49563 .57291 L .52691 .58769 L F
0 0 0 r
.52563 .58247 m
.53164 .58582 L
s
.50463 .53261 m
.5053 .52417 L
s
.5231 .57672 m
.52454 .5689 L
s
.52841 .60403 m
.5302 .59713 L
s
.51033 .54541 m
.51724 .54863 L
s
.52264 .67593 m
.52481 .67158 L
s
0 1 0 r
.29072 .80204 m .28807 .77801 L .30172 .79872 L F
.29072 .80204 m .27356 .78248 L .28807 .77801 L F
0 .612 0 r
.21273 .50843 m .21375 .48399 L .25252 .47392 L F
0 0 0 r
.2035 .48665 m
.215 .48262 L
s
0 .809 0 r
.19054 .73239 m .19231 .69603 L .20715 .72131 L F
0 0 1 r
.80377 .48392 m
.81448 .48078 L
s
0 0 0 r
.47129 .48359 m
.47221 .48388 L
s
.5154 .68239 m
.51994 .68546 L
s
.52555 .60992 m
.53095 .61308 L
s
.51464 .55491 m
.51571 .54673 L
s
0 1 0 r
.39154 .80168 m .40704 .78201 L .42084 .78741 L F
.3798 .79844 m .40704 .78201 L .39154 .80168 L F
0 0 0 r
.4703 .48328 m
.47129 .48359 L
s
.52035 .68039 m
.52264 .67593 L
s
0 1 0 r
.47217 .72031 m .50765 .7073 L .49114 .73127 L F
.47217 .72031 m .48673 .6949 L .50765 .7073 L F
0 0 1 r
.50132 .4802 m
.50961 .48345 L
s
0 0 0 r
.52195 .65599 m
.5267 .65905 L
s
0 0 1 r
.62062 .47785 m
.62842 .48342 L
s
.74892 .48335 m
.75983 .4797 L
s
0 1 0 r
.45617 .74443 m .49114 .73127 L .47295 .75386 L F
.43897 .76689 m .45617 .74443 L .47295 .75386 L F
0 0 0 r
.52768 .64063 m
.52981 .6349 L
s
.46934 .48299 m
.4703 .48328 L
s
.52279 .59496 m
.52871 .59823 L
s
.52401 .63425 m
.52935 .63752 L
s
.51523 .56268 m
.52162 .56581 L
s
.51828 .68431 m
.52035 .68039 L
s
.4688 .48282 m
.46934 .48299 L
s
0 0 1 r
.57019 .48296 m
.57834 .47799 L
s
0 0 0 r
.48623 .50458 m
.49025 .50603 L
s
.51915 .5791 m
.52563 .58247 L
s
0 .869 0 r
.42454 .49774 m .46582 .48286 L .46521 .50732 L F
.42454 .49774 m .42522 .47314 L .46582 .48286 L F
0 0 0 r
.46829 .48267 m
.4688 .48282 L
s
.49264 .51909 m
.49312 .51009 L
s
.49713 .52444 m
.50435 .52738 L
s
.46783 .48253 m
.46829 .48267 L
s
.215 .48262 m
.23572 .4768 L
s
0 1 0 r
.45617 .74443 m .47217 .72031 L .49114 .73127 L F
0 0 0 r
.52662 .61044 m
.52841 .60403 L
s
.4674 .48241 m
.46783 .48253 L
s
0 0 1 r
.74324 .47438 m
.75033 .48245 L
s
0 0 0 r
.46716 .48233 m
.4674 .48241 L
s
0 0 1 r
.66406 .48234 m
.67341 .47832 L
s
0 0 0 r
.46691 .48226 m
.46716 .48233 L
s
.46669 .48219 m
.46691 .48226 L
s
0 .973 0 r
.26098 .78798 m .25716 .76071 L .27356 .78248 L F
.26098 .78798 m .24174 .76761 L .25716 .76071 L F
0 0 0 r
.47987 .50537 m
.48015 .49557 L
s
.52561 .64594 m
.52768 .64063 L
s
.46645 .48212 m
.46669 .48219 L
s
.51824 .66436 m
.5229 .66734 L
s
.46637 .49187 m
.46645 .48212 L
s
.44477 .47638 m
.46645 .48212 L
s
.46645 .48212 m
.46645 .4824 L
s
0 0 1 r
.46645 .48212 m
.4666 .48194 L
s
0 0 0 r
.5216 .584 m
.5231 .57672 L
s
.46645 .4824 m
.46645 .48265 L
s
0 0 1 r
.4666 .48194 m
.46675 .48177 L
s
0 0 0 r
.46645 .48265 m
.46645 .48295 L
s
0 0 1 r
.70588 .48178 m
.71655 .47773 L
s
.46675 .48177 m
.46691 .48158 L
s
0 0 0 r
.46645 .48295 m
.46645 .48322 L
s
0 0 1 r
.81251 .47288 m
.8185 .48162 L
s
0 0 0 r
.46645 .48322 m
.46645 .48348 L
s
0 0 1 r
.46691 .48158 m
.46706 .4814 L
s
.64448 .47571 m
.65196 .48153 L
s
0 1 0 r
.40704 .78201 m .43897 .76689 L .42084 .78741 L F
0 0 0 r
.52222 .62092 m
.52754 .624 L
s
.46645 .48371 m
.46645 .48348 L
s
0 0 1 r
.46706 .4814 m
.46721 .48124 L
s
0 0 0 r
.52042 .64387 m
.52567 .64706 L
s
.4825 .50328 m
.48623 .50458 L
s
.46645 .48397 m
.46645 .48371 L
s
.5234 .65139 m
.52561 .64594 L
s
0 0 1 r
.46721 .48124 m
.46734 .48108 L
s
0 0 0 r
.50374 .54139 m
.50463 .53261 L
s
.46645 .48425 m
.46645 .48397 L
s
.51455 .67221 m
.51912 .67511 L
s
.46645 .48452 m
.46645 .48425 L
s
0 0 1 r
.52954 .47719 m
.5381 .48109 L
s
.46734 .48108 m
.46748 .48091 L
s
0 0 0 r
.51334 .56335 m
.51464 .55491 L
s
0 0 1 r
.60086 .48107 m
.60976 .47623 L
s
0 0 0 r
.52465 .61703 m
.52662 .61044 L
s
0 0 1 r
.54849 .48104 m
.5564 .4756 L
s
.58993 .47617 m
.59784 .48104 L
s
.63195 .48099 m
.64158 .47634 L
s
0 0 0 r
.46645 .48482 m
.46645 .48452 L
s
0 0 1 r
.46748 .48091 m
.46764 .48073 L
s
.71839 .47376 m
.72533 .48088 L
s
0 0 0 r
.50292 .5422 m
.51033 .54541 L
s
.46645 .4851 m
.46645 .48482 L
s
0 0 1 r
.81448 .48078 m
.82592 .47743 L
s
.66853 .47409 m
.6764 .48078 L
s
.46764 .48073 m
.46779 .48055 L
s
0 0 0 r
.46645 .48535 m
.46645 .4851 L
s
0 0 1 r
.48592 .48068 m
.49222 .47432 L
s
.69346 .47365 m
.70088 .48057 L
s
0 0 0 r
.46645 .48565 m
.46645 .48535 L
s
0 0 1 r
.46779 .48055 m
.46796 .48036 L
s
0 0 0 r
.46644 .48582 m
.46645 .48565 L
s
.52126 .65643 m
.5234 .65139 L
s
0 0 1 r
.46796 .48036 m
.46811 .48017 L
s
0 0 0 r
.46644 .48598 m
.46644 .48582 L
s
.51091 .67956 m
.5154 .68239 L
s
.46644 .48627 m
.46644 .48598 L
s
0 0 1 r
.49701 .47861 m
.50132 .4802 L
s
.46811 .48017 m
.46826 .48001 L
s
0 .679 0 r
.29442 .46763 m .29599 .44512 L .3391 .44285 L F
0 .617 0 r
.25252 .47392 m .29599 .44512 L .29442 .46763 L F
0 0 0 r
.46644 .48657 m
.46644 .48627 L
s
0 0 1 r
.55946 .47594 m
.56735 .48012 L
s
0 0 0 r
.5199 .5915 m
.5216 .584 L
s
.47817 .50182 m
.4825 .50328 L
s
0 0 1 r
.46826 .48001 m
.46842 .47981 L
s
0 0 0 r
.46644 .48673 m
.46644 .48657 L
s
.5168 .65289 m
.52195 .65599 L
s
0 1 0 r
.30172 .79872 m .30413 .7747 L .31386 .79626 L F
.30172 .79872 m .28807 .77801 L .30413 .7747 L F
0 0 0 r
.46644 .48689 m
.46644 .48673 L
s
.46643 .48718 m
.46644 .48689 L
s
0 0 1 r
.46842 .47981 m
.46852 .4797 L
s
0 .732 0 r
.33812 .46537 m .38257 .44472 L .3822 .46723 L F
.33812 .46537 m .3391 .44285 L .38257 .44472 L F
0 0 1 r
.5275 .47974 m
.53438 .4744 L
s
0 0 0 r
.50838 .55952 m
.51523 .56268 L
s
.48942 .52151 m
.49713 .52444 L
s
.46643 .48734 m
.46643 .48718 L
s
0 0 1 r
.46852 .4797 m
.46861 .4796 L
s
.75983 .4797 m
.77039 .47616 L
s
0 .647 0 r
.16013 .61602 m .18234 .57423 L .18754 .60182 L F
0 .704 0 r
.16864 .643 m .16013 .61602 L .18754 .60182 L F
0 0 0 r
.52272 .62315 m
.52465 .61703 L
s
.51639 .59166 m
.52279 .59496 L
s
.46643 .48749 m
.46643 .48734 L
s
0 0 1 r
.46861 .4796 m
.46877 .47941 L
s
0 0 0 r
.519 .66159 m
.52126 .65643 L
s
0 1 0 r
.36712 .79607 m .39154 .77764 L .3798 .79844 L F
.3798 .79844 m .39154 .77764 L .40704 .78201 L F
0 0 1 r
.50663 .47957 m
.51318 .47379 L
s
0 0 0 r
.46643 .48766 m
.46643 .48749 L
s
.46643 .48784 m
.46643 .48766 L
s
0 0 1 r
.46877 .47941 m
.46894 .47921 L
s
0 0 0 r
.46643 .48799 m
.46643 .48784 L
s
.46643 .48816 m
.46643 .48799 L
s
.51284 .57602 m
.51915 .5791 L
s
.46642 .48846 m
.46643 .48816 L
s
0 0 1 r
.46894 .47921 m
.46903 .4791 L
s
0 0 0 r
.492 .52758 m
.49264 .51909 L
s
.46642 .48875 m
.46642 .48846 L
s
0 0 1 r
.46903 .4791 m
.46912 .479 L
s
.46912 .479 m
.46928 .47881 L
s
0 0 0 r
.46641 .48902 m
.46642 .48875 L
s
.51682 .66637 m
.519 .66159 L
s
.46641 .48929 m
.46641 .48902 L
s
0 0 1 r
.46928 .47881 m
.46937 .4787 L
s
0 0 0 r
.51318 .66134 m
.51824 .66436 L
s
0 0 1 r
.78708 .4701 m
.79374 .47873 L
s
0 0 0 r
.46641 .48954 m
.46641 .48929 L
s
0 0 1 r
.46937 .4787 m
.46946 .4786 L
s
0 0 0 r
.4664 .48981 m
.46641 .48954 L
s
0 0 1 r
.49302 .47718 m
.49701 .47861 L
s
.46946 .4786 m
.46955 .47849 L
s
0 0 0 r
.47622 .50119 m
.47817 .50182 L
s
0 0 1 r
.46955 .47849 m
.46965 .47837 L
s
0 0 0 r
.4664 .4901 m
.4664 .48981 L
s
.51197 .57124 m
.51334 .56335 L
s
.52062 .62942 m
.52272 .62315 L
s
0 0 1 r
.46965 .47837 m
.46974 .47827 L
s
0 0 0 r
.46639 .49039 m
.4664 .4901 L
s
0 0 1 r
.67341 .47832 m
.68343 .47402 L
s
.46974 .47827 m
.46983 .47816 L
s
0 0 0 r
.51474 .6708 m
.51682 .66637 L
s
.46639 .4907 m
.46639 .49039 L
s
.51819 .59848 m
.5199 .5915 L
s
.50272 .54962 m
.50374 .54139 L
s
0 0 1 r
.46983 .47816 m
.47 .47796 L
s
0 0 0 r
.46638 .49096 m
.46639 .4907 L
s
0 1 0 r
.48193 .6286 m .51987 .61455 L .51075 .64163 L F
0 0 0 r
.51878 .63125 m
.52401 .63425 L
s
0 1 0 r
.48193 .6286 m .48964 .60057 L .51987 .61455 L F
0 0 0 r
.51647 .61781 m
.52222 .62092 L
s
.51971 .60673 m
.52555 .60992 L
s
0 0 1 r
.57834 .47799 m
.58705 .47267 L
s
0 0 0 r
.47941 .51441 m
.47987 .50537 L
s
0 0 1 r
.47 .47796 m
.47017 .47777 L
s
0 0 0 r
.46638 .49124 m
.46638 .49096 L
s
.47409 .5005 m
.47622 .50119 L
s
0 .679 0 r
.29442 .46763 m .3391 .44285 L .33812 .46537 L F
0 0 1 r
.61294 .47273 m
.62062 .47785 L
s
0 0 0 r
.46638 .49141 m
.46638 .49124 L
s
.50959 .66926 m
.51455 .67221 L
s
.51528 .64095 m
.52042 .64387 L
s
0 0 1 r
.47017 .47777 m
.47032 .47759 L
s
0 0 0 r
.46637 .49156 m
.46638 .49141 L
s
0 0 1 r
.71655 .47773 m
.72687 .4738 L
s
0 0 0 r
.51254 .67534 m
.51474 .6708 L
s
.46637 .49173 m
.46637 .49156 L
s
.46637 .49191 m
.46637 .49173 L
s
0 .599 0 r
.17922 .5474 m .21273 .50843 L .2134 .53451 L F
0 .659 0 r
.18234 .57423 m .17922 .5474 L .2134 .53451 L F
0 0 1 r
.47032 .47759 m
.47047 .47741 L
s
0 0 0 r
.46606 .50192 m
.46637 .49187 L
s
.46636 .49221 m
.46637 .49191 L
s
0 0 1 r
.82592 .47743 m
.83642 .47435 L
s
.47047 .47741 m
.47061 .47725 L
s
0 0 0 r
.46636 .49238 m
.46636 .49221 L
s
.46635 .49254 m
.46636 .49238 L
s
.47198 .49985 m
.47409 .5005 L
s
.46635 .49283 m
.46635 .49254 L
s
0 0 1 r
.47061 .47725 m
.47077 .47707 L
s
0 0 0 r
.51858 .63523 m
.52062 .62942 L
s
.51054 .67934 m
.51254 .67534 L
s
0 0 1 r
.52123 .47366 m
.52954 .47719 L
s
.48836 .47559 m
.49302 .47718 L
s
0 0 0 r
.46634 .4931 m
.46635 .49283 L
s
0 0 1 r
.47077 .47707 m
.47093 .47688 L
s
0 0 0 r
.50605 .6767 m
.51091 .67956 L
s
.46634 .49325 m
.46634 .4931 L
s
.46633 .49342 m
.46634 .49325 L
s
.51341 .60351 m
.51971 .60673 L
s
0 0 1 r
.47093 .47688 m
.4711 .47668 L
s
0 0 0 r
.46633 .49371 m
.46633 .49342 L
s
0 1 0 r
.31386 .79626 m .32131 .77264 L .32682 .79473 L F
.31386 .79626 m .30413 .7747 L .32131 .77264 L F
0 0 0 r
.23572 .4768 m
.24094 .47566 L
s
.46632 .49389 m
.46633 .49371 L
s
0 .932 0 r
.24174 .76761 m .24178 .737 L .25716 .76071 L F
.24174 .76761 m .2237 .74529 L .24178 .737 L F
0 0 0 r
.48541 .52007 m
.48942 .52151 L
s
0 0 1 r
.4711 .47668 m
.47127 .47648 L
s
0 0 0 r
.46632 .49406 m
.46632 .49389 L
s
.47105 .49956 m
.47198 .49985 L
s
0 1 0 r
.36712 .79607 m .37474 .77444 L .39154 .77764 L F
0 0 0 r
.37802 .80261 m
.38285 .79458 L
s
0 1 0 r
.35382 .79464 m .37474 .77444 L .36712 .79607 L F
0 0 0 r
.46632 .49421 m
.46632 .49406 L
s
.51648 .60497 m
.51819 .59848 L
s
.46631 .49438 m
.46632 .49421 L
s
0 0 1 r
.47127 .47648 m
.47142 .47631 L
s
0 0 0 r
.51176 .65004 m
.5168 .65289 L
s
.46631 .49456 m
.46631 .49438 L
s
.50104 .55638 m
.50838 .55952 L
s
.43674 .47472 m
.44477 .47638 L
s
.4663 .49474 m
.46631 .49456 L
s
0 0 1 r
.64158 .47634 m
.65091 .47183 L
s
.47142 .47631 m
.47158 .47612 L
s
0 0 0 r
.47006 .49926 m
.47105 .49956 L
s
0 0 1 r
.76132 .46782 m
.76863 .4763 L
s
0 0 0 r
.4663 .4949 m
.4663 .49474 L
s
.51055 .57859 m
.51197 .57124 L
s
0 0 1 r
.60976 .47623 m
.61837 .47155 L
s
0 0 0 r
.46629 .49508 m
.4663 .4949 L
s
.5166 .64062 m
.51858 .63523 L
s
0 0 1 r
.58137 .47126 m
.58993 .47617 L
s
.77039 .47616 m
.78166 .47239 L
s
0 0 0 r
.38285 .79458 m
.38764 .78615 L
s
0 .984 0 r
.45981 .56084 m .49983 .54602 L .49563 .57291 L F
.45981 .56084 m .4632 .53343 L .49983 .54602 L F
0 0 0 r
.49574 .53931 m
.50292 .5422 L
s
.51313 .62822 m
.51878 .63125 L
s
.46629 .49525 m
.46629 .49508 L
s
0 0 1 r
.47158 .47612 m
.47167 .47601 L
s
.83143 .46699 m
.83755 .47612 L
s
0 0 0 r
.51017 .58866 m
.51639 .59166 L
s
.46628 .4954 m
.46629 .49525 L
s
.49116 .53641 m
.492 .52758 L
s
0 0 1 r
.47167 .47601 m
.47176 .47591 L
s
0 0 0 r
.4691 .49896 m
.47006 .49926 L
s
.46628 .49557 m
.46628 .4954 L
s
.50607 .57294 m
.51284 .57602 L
s
0 0 1 r
.55097 .47174 m
.55946 .47594 L
s
0 0 0 r
.46628 .49574 m
.46628 .49557 L
s
0 0 1 r
.47176 .47591 m
.47186 .47579 L
s
0 0 0 r
.46627 .49603 m
.46628 .49574 L
s
0 1 0 r
.42203 .76011 m .45617 .74443 L .43897 .76689 L F
.40704 .78201 m .42203 .76011 L .43897 .76689 L F
0 0 1 r
.47186 .47579 m
.47196 .47568 L
s
0 0 0 r
.46626 .49619 m
.46627 .49603 L
s
0 0 1 r
.63628 .46978 m
.64448 .47571 L
s
0 0 0 r
.46856 .4988 m
.4691 .49896 L
s
0 0 1 r
.47196 .47568 m
.47213 .47548 L
s
0 0 0 r
.46626 .49635 m
.46626 .49619 L
s
0 0 1 r
.5564 .4756 m
.56407 .47033 L
s
.48627 .4749 m
.48836 .47559 L
s
0 0 0 r
.46625 .49662 m
.46626 .49635 L
s
.46805 .49865 m
.46856 .4988 L
s
.5015 .55813 m
.50272 .54962 L
s
0 0 1 r
.47213 .47548 m
.47223 .47536 L
s
0 0 0 r
.46624 .49691 m
.46625 .49662 L
s
.46759 .49851 m
.46805 .49865 L
s
0 0 1 r
.47223 .47536 m
.47232 .47526 L
s
0 .992 0 r
.27356 .78248 m .27502 .75508 L .28807 .77801 L F
.27356 .78248 m .25716 .76071 L .27502 .75508 L F
0 0 0 r
.46623 .49719 m
.46624 .49691 L
s
.51449 .64615 m
.5166 .64062 L
s
0 0 1 r
.47232 .47526 m
.47249 .47506 L
s
0 0 0 r
.46716 .49839 m
.46759 .49851 L
s
.48169 .51879 m
.48541 .52007 L
s
.46622 .49744 m
.46623 .49719 L
s
.46692 .49832 m
.46716 .49839 L
s
.46621 .49772 m
.46622 .49744 L
s
.51461 .61164 m
.51648 .60497 L
s
0 0 1 r
.47249 .47506 m
.47264 .47488 L
s
0 0 0 r
.46666 .49824 m
.46692 .49832 L
s
.4662 .49802 m
.46621 .49772 L
s
.46644 .49818 m
.46666 .49824 L
s
0 0 1 r
.48398 .47415 m
.48627 .4749 L
s
0 0 0 r
.4662 .49811 m
.46644 .49818 L
s
0 1 0 r
.32682 .79473 m .33914 .7719 L .34026 .79419 L F
.32682 .79473 m .32131 .77264 L .33914 .7719 L F
0 0 1 r
.47264 .47488 m
.47273 .47478 L
s
0 0 0 r
.4662 .49818 m
.4662 .49802 L
s
0 .704 0 r
.16864 .643 m .18754 .60182 L .19479 .62976 L F
0 .756 0 r
.17942 .6698 m .16864 .643 L .19479 .62976 L F
0 0 0 r
.46619 .49834 m
.4662 .49818 L
s
0 0 1 r
.47273 .47478 m
.47282 .47467 L
s
0 1 0 r
.35382 .79464 m .35711 .77251 L .37474 .77444 L F
.34026 .79419 m .35711 .77251 L .35382 .79464 L F
.39154 .77764 m .42203 .76011 L .40704 .78201 L F
0 0 0 r
.46618 .49864 m
.46619 .49834 L
s
0 0 1 r
.47282 .47467 m
.47299 .47447 L
s
0 0 0 r
.51028 .61467 m
.51647 .61781 L
s
.46618 .4988 m
.46618 .49864 L
s
.46617 .49895 m
.46618 .4988 L
s
.48808 .53643 m
.49574 .53931 L
s
0 0 1 r
.47299 .47447 m
.47309 .47435 L
s
0 0 0 r
.46617 .49912 m
.46617 .49895 L
s
.51245 .65127 m
.51449 .64615 L
s
0 0 1 r
.53438 .4744 m
.54176 .46866 L
s
0 0 0 r
.46616 .49929 m
.46617 .49912 L
s
0 0 1 r
.73607 .46688 m
.74324 .47438 L
s
0 0 0 r
.4788 .52293 m
.47941 .51441 L
s
0 0 1 r
.47309 .47435 m
.47319 .47424 L
s
0 0 0 r
.46615 .49959 m
.46616 .49929 L
s
0 0 1 r
.49222 .47432 m
.49818 .46829 L
s
0 0 0 r
.50894 .58617 m
.51055 .57859 L
s
0 0 1 r
.47319 .47424 m
.47327 .47414 L
s
0 1 0 r
.34026 .79419 m .33914 .7719 L .35711 .77251 L F
0 0 0 r
.46614 .49975 m
.46615 .49959 L
s
0 0 1 r
.48172 .47343 m
.48398 .47415 L
s
.47327 .47414 m
.47337 .47403 L
s
0 0 0 r
.46614 .49991 m
.46614 .49975 L
s
0 0 1 r
.66069 .46791 m
.66853 .47409 L
s
0 0 0 r
.46613 .5002 m
.46614 .49991 L
s
0 0 1 r
.47337 .47403 m
.47347 .47391 L
s
.68343 .47402 m
.69312 .46986 L
s
0 0 0 r
.46612 .50046 m
.46613 .5002 L
s
0 .678 0 r
.25156 .49851 m .25252 .47392 L .29442 .46763 L F
0 .612 0 r
.21273 .50843 m .25252 .47392 L .25156 .49851 L F
0 0 0 r
.24094 .47566 m
.25751 .47204 L
s
0 0 1 r
.47347 .47391 m
.47358 .47378 L
s
0 0 0 r
.47737 .51735 m
.48169 .51879 L
s
.46611 .50077 m
.46612 .50046 L
s
0 0 1 r
.72687 .4738 m
.73685 .47001 L
s
.51318 .47379 m
.51952 .46819 L
s
.47358 .47378 m
.47367 .47367 L
s
.71069 .46645 m
.71839 .47376 L
s
0 0 0 r
.50128 .67407 m
.50605 .6767 L
s
.46609 .50106 m
.46611 .50077 L
s
.51277 .61783 m
.51461 .61164 L
s
0 0 1 r
.47367 .47367 m
.47377 .47356 L
s
.51236 .47016 m
.52123 .47366 L
s
.68526 .46658 m
.69346 .47365 L
s
0 0 0 r
.46608 .50132 m
.46609 .50106 L
s
0 0 1 r
.47377 .47356 m
.47386 .47345 L
s
0 0 0 r
.46607 .50161 m
.46608 .50132 L
s
0 0 1 r
.47386 .47345 m
.47395 .47334 L
s
.48072 .47311 m
.48172 .47343 L
s
0 0 0 r
.50728 .60058 m
.51341 .60351 L
s
.46606 .50187 m
.46607 .50161 L
s
0 0 1 r
.47395 .47334 m
.47405 .47323 L
s
0 1 0 r
.47259 .6566 m .51075 .64163 L .49966 .66854 L F
0 0 0 r
.50474 .66657 m
.50959 .66926 L
s
.50823 .65857 m
.51318 .66134 L
s
0 1 0 r
.47259 .6566 m .48193 .6286 L .51075 .64163 L F
0 0 0 r
.51028 .65652 m
.51245 .65127 L
s
.50973 .63799 m
.51528 .64095 L
s
.46605 .50212 m
.46606 .50187 L
s
0 .67 0 r
.2134 .53451 m .21273 .50843 L .25156 .49851 L F
0 0 0 r
.50631 .64717 m
.51176 .65004 L
s
0 0 1 r
.47405 .47323 m
.47415 .47312 L
s
0 0 0 r
.46552 .51226 m
.46606 .50192 L
s
.46604 .50239 m
.46605 .50212 L
s
0 .827 0 r
.38144 .49192 m .42522 .47314 L .42454 .49774 L F
.38144 .49192 m .3822 .46723 L .42522 .47314 L F
0 0 0 r
.4222 .47172 m
.43674 .47472 L
s
0 0 1 r
.47415 .47312 m
.47431 .47292 L
s
.47965 .47278 m
.48072 .47311 L
s
0 0 0 r
.5082 .66138 m
.51028 .65652 L
s
.49392 .55354 m
.50104 .55638 L
s
.46603 .50269 m
.46604 .50239 L
s
.4902 .54469 m
.49116 .53641 L
s
.5002 .56608 m
.5015 .55813 L
s
0 0 1 r
.47431 .47292 m
.47441 .47281 L
s
0 0 0 r
.46602 .50284 m
.46603 .50269 L
s
0 0 1 r
.80568 .46385 m
.81251 .47288 L
s
0 0 0 r
.46601 .503 m
.46602 .50284 L
s
0 .891 0 r
.2237 .74529 m .22765 .71167 L .24178 .737 L F
.2237 .74529 m .20715 .72131 L .22765 .71167 L F
0 0 0 r
.50348 .58564 m
.51017 .58866 L
s
0 0 1 r
.47441 .47281 m
.4745 .47271 L
s
0 0 0 r
.466 .50328 m
.46601 .503 L
s
0 0 1 r
.47862 .47246 m
.47965 .47278 L
s
0 0 0 r
.50704 .62516 m
.51313 .62822 L
s
0 0 1 r
.6046 .46754 m
.61294 .47273 L
s
.4745 .47271 m
.47465 .47252 L
s
0 0 0 r
.46599 .50344 m
.466 .50328 L
s
.49881 .56986 m
.50607 .57294 L
s
0 0 1 r
.58705 .47267 m
.59551 .4675 L
s
0 0 0 r
.46599 .50359 m
.46599 .50344 L
s
.46598 .50375 m
.46599 .50359 L
s
.50621 .66588 m
.5082 .66138 L
s
0 0 1 r
.47465 .47252 m
.47482 .47233 L
s
0 0 0 r
.51078 .62419 m
.51277 .61783 L
s
.46597 .50392 m
.46598 .50375 L
s
0 0 1 r
.47804 .47228 m
.47862 .47246 L
s
0 0 0 r
.46596 .5042 m
.46597 .50392 L
s
.50732 .59322 m
.50894 .58617 L
s
.47543 .51673 m
.47737 .51735 L
s
0 0 1 r
.78166 .47239 m
.79257 .46873 L
s
.47482 .47233 m
.47498 .47214 L
s
0 0 0 r
.46595 .50437 m
.46596 .5042 L
s
0 0 1 r
.47749 .47212 m
.47804 .47228 L
s
0 0 0 r
.46594 .50452 m
.46595 .50437 L
s
.50289 .65577 m
.50823 .65857 L
s
.46593 .5048 m
.46594 .50452 L
s
0 0 1 r
.47498 .47214 m
.47512 .47197 L
s
.477 .47197 m
.47749 .47212 L
s
0 .909 0 r
.42295 .52412 m .46521 .50732 L .4632 .53343 L F
.42295 .52412 m .42454 .49774 L .46521 .50732 L F
0 0 0 r
.46593 .5048 m
.46592 .50506 L
s
.50411 .6705 m
.50621 .66588 L
s
.25751 .47204 m
.28017 .46842 L
s
0 0 1 r
.47512 .47197 m
.47529 .47178 L
s
.47654 .47183 m
.477 .47197 L
s
0 0 0 r
.46592 .50506 m
.4659 .50536 L
s
.4659 .50536 m
.46589 .50564 L
s
0 0 1 r
.65091 .47183 m
.65993 .46747 L
s
.47628 .47175 m
.47654 .47183 L
s
0 1 0 r
.43629 .73627 m .47217 .72031 L .45617 .74443 L F
.42203 .76011 m .43629 .73627 L .45617 .74443 L F
0 0 1 r
.47529 .47178 m
.47546 .47158 L
s
0 0 0 r
.4733 .51605 m
.47543 .51673 L
s
0 0 1 r
.47601 .47167 m
.47628 .47175 L
s
.54185 .46755 m
.55097 .47174 L
s
0 0 0 r
.46589 .50564 m
.46588 .5059 L
s
.39894 .46818 m
.4222 .47172 L
s
0 .756 0 r
.17942 .6698 m .19479 .62976 L .20398 .65766 L F
0 .803 0 r
.19231 .69603 m .17942 .6698 L .20398 .65766 L F
0 0 1 r
.47577 .4716 m
.47601 .47167 L
s
0 0 0 r
.5022 .67456 m
.50411 .6705 L
s
.46588 .5059 m
.46586 .50614 L
s
0 0 1 r
.47551 .47152 m
.47577 .4716 L
s
.47546 .47158 m
.47555 .47147 L
s
.61837 .47155 m
.6276 .46654 L
s
0 0 0 r
.46586 .50614 m
.46585 .50642 L
s
.48409 .53502 m
.48808 .53643 L
s
0 0 1 r
.47555 .47147 m
.47565 .47136 L
s
0 0 0 r
.46585 .50642 m
.46584 .50668 L
s
.50884 .63008 m
.51078 .62419 L
s
0 0 1 r
.47565 .47136 m
.47582 .47116 L
s
0 0 0 r
.46584 .50668 m
.46582 .50693 L
s
0 0 1 r
.57301 .46679 m
.58137 .47126 L
s
0 0 0 r
.50375 .63502 m
.50973 .63799 L
s
.46581 .50715 m
.46582 .50693 L
s
.47801 .53181 m
.4788 .52293 L
s
.50424 .61182 m
.51028 .61467 L
s
0 0 1 r
.47582 .47116 m
.47591 .47105 L
s
0 0 0 r
.4658 .50739 m
.46581 .50715 L
s
.4712 .5154 m
.4733 .51605 L
s
0 0 1 r
.47591 .47105 m
.476 .47095 L
s
0 0 0 r
.46579 .50765 m
.4658 .50739 L
s
0 0 1 r
.476 .47095 m
.47609 .47084 L
s
0 0 0 r
.46577 .50791 m
.46579 .50765 L
s
0 0 1 r
.47609 .47084 m
.4762 .47072 L
s
0 0 0 r
.46576 .50819 m
.46577 .50791 L
s
.50571 .59978 m
.50732 .59322 L
s
.49886 .5735 m
.5002 .56608 L
s
0 0 1 r
.4762 .47072 m
.47637 .47052 L
s
0 0 0 r
.46574 .50846 m
.46576 .50819 L
s
0 .848 0 r
.20715 .72131 m .21498 .6851 L .22765 .71167 L F
.20715 .72131 m .19231 .69603 L .21498 .6851 L F
0 0 0 r
.46573 .5087 m
.46574 .50846 L
s
.46571 .50898 m
.46573 .5087 L
s
0 0 1 r
.47637 .47052 m
.47646 .47041 L
s
0 0 0 r
.50696 .63554 m
.50884 .63008 L
s
.46571 .50914 m
.46571 .50898 L
s
0 0 1 r
.47646 .47041 m
.47655 .4703 L
s
0 0 0 r
.47027 .51512 m
.4712 .5154 L
s
.4657 .50929 m
.46571 .50914 L
s
0 0 1 r
.56407 .47033 m
.57228 .46468 L
s
0 0 0 r
.48905 .55326 m
.4902 .54469 L
s
0 .803 0 r
.19231 .69603 m .20398 .65766 L .21498 .6851 L F
0 0 1 r
.47655 .4703 m
.47672 .4701 L
s
0 0 0 r
.46568 .50955 m
.4657 .50929 L
s
0 1 0 r
.46176 .68414 m .49966 .66854 L .48673 .6949 L F
.46176 .68414 m .47259 .6566 L .49966 .66854 L F
0 0 0 r
.49614 .67141 m
.50128 .67407 L
s
.49949 .66384 m
.50474 .66657 L
s
.46566 .50984 m
.46568 .50955 L
s
.50069 .59764 m
.50728 .60058 L
s
0 0 1 r
.50774 .46844 m
.51236 .47016 L
s
0 0 0 r
.46928 .51482 m
.47027 .51512 L
s
0 0 1 r
.47672 .4701 m
.47688 .46992 L
s
.77955 .46121 m
.78708 .4701 L
s
0 0 0 r
.46565 .5101 m
.46566 .50984 L
s
.48633 .55072 m
.49392 .55354 L
s
0 0 1 r
.73685 .47001 m
.74753 .46595 L
s
0 0 0 r
.4804 .53375 m
.48409 .53502 L
s
.46563 .51038 m
.46565 .5101 L
s
.50043 .64427 m
.50631 .64717 L
s
0 .659 0 r
.18234 .57423 m .2134 .53451 L .21576 .56187 L F
0 .712 0 r
.18754 .60182 m .18234 .57423 L .21576 .56187 L F
0 0 1 r
.47688 .46992 m
.47705 .46972 L
s
0 0 0 r
.46562 .51068 m
.46563 .51038 L
s
0 0 1 r
.69312 .46986 m
.70348 .46542 L
s
0 0 0 r
.46832 .51453 m
.46928 .51482 L
s
0 0 1 r
.62821 .46433 m
.63628 .46978 L
s
0 0 0 r
.4656 .51095 m
.46562 .51068 L
s
0 1 0 r
.28807 .77801 m .29484 .7509 L .30413 .7747 L F
.28807 .77801 m .27502 .75508 L .29484 .7509 L F
0 0 1 r
.47705 .46972 m
.47722 .46952 L
s
0 0 0 r
.46558 .51121 m
.4656 .51095 L
s
.50495 .64115 m
.50696 .63554 L
s
.46557 .51144 m
.46558 .51121 L
s
.49632 .58264 m
.50348 .58564 L
s
0 0 1 r
.47722 .46952 m
.47737 .46934 L
s
0 0 0 r
.46778 .51437 m
.46832 .51453 L
s
0 1 0 r
.4496 .71083 m .48673 .6949 L .47217 .72031 L F
.43629 .73627 m .4496 .71083 L .47217 .72031 L F
0 0 0 r
.46555 .51171 m
.46557 .51144 L
s
.50394 .60653 m
.50571 .59978 L
s
.46554 .51197 m
.46555 .51171 L
s
.50111 .62238 m
.50704 .62516 L
s
.46727 .51422 m
.46778 .51437 L
s
0 0 1 r
.47737 .46934 m
.47754 .46915 L
s
0 0 0 r
.46552 .51225 m
.46554 .51197 L
s
0 1 0 r
.39154 .77764 m .40293 .75461 L .42203 .76011 L F
.37474 .77444 m .40293 .75461 L .39154 .77764 L F
0 0 0 r
.38764 .78615 m
.39239 .77734 L
s
.46681 .51409 m
.46727 .51422 L
s
.4655 .51254 m
.46552 .51225 L
s
.46475 .52286 m
.46552 .51226 L
s
0 0 1 r
.47754 .46915 m
.47769 .46897 L
s
0 0 0 r
.46549 .51279 m
.4655 .51254 L
s
.46638 .51396 m
.46681 .51409 L
s
.49713 .65295 m
.50289 .65577 L
s
0 1 0 r
.4496 .71083 m .46176 .68414 L .48673 .6949 L F
0 0 0 r
.46547 .51306 m
.46549 .51279 L
s
0 0 1 r
.47769 .46897 m
.47784 .4688 L
s
0 0 0 r
.46614 .51389 m
.46638 .51396 L
s
.46545 .51336 m
.46547 .51306 L
s
.46589 .51382 m
.46614 .51389 L
s
.50301 .64635 m
.50495 .64115 L
s
.49735 .58115 m
.49886 .5735 L
s
0 0 1 r
.47784 .4688 m
.478 .46861 L
s
0 0 0 r
.46567 .51376 m
.46589 .51382 L
s
.46544 .51353 m
.46545 .51336 L
s
0 0 1 r
.79257 .46873 m
.80312 .4652 L
s
0 0 0 r
.46543 .51369 m
.46567 .51376 L
s
.46543 .51368 m
.46544 .51353 L
s
.4761 .53234 m
.4804 .53375 L
s
0 0 1 r
.54176 .46866 m
.54891 .4631 L
s
0 0 0 r
.46541 .51397 m
.46543 .51368 L
s
0 0 1 r
.478 .46861 m
.47817 .46841 L
s
0 1 0 r
.45506 .58916 m .49563 .57291 L .48964 .60057 L F
.45506 .58916 m .45981 .56084 L .49563 .57291 L F
0 0 0 r
.49178 .56708 m
.49881 .56986 L
s
.46539 .51425 m
.46541 .51397 L
s
0 0 1 r
.50346 .4669 m
.50774 .46844 L
s
0 0 0 r
.46537 .51451 m
.46539 .51425 L
s
.28017 .46842 m
.28113 .46832 L
s
0 0 1 r
.47817 .46841 m
.47826 .46831 L
s
0 0 0 r
.46536 .51474 m
.46537 .51451 L
s
0 0 1 r
.47826 .46831 m
.47835 .4682 L
s
.49818 .46829 m
.50396 .46245 L
s
0 0 0 r
.46534 .51501 m
.46536 .51474 L
s
.49384 .66109 m
.49949 .66384 L
s
0 0 1 r
.47835 .4682 m
.47852 .468 L
s
.51952 .46819 m
.52633 .46218 L
s
0 0 0 r
.39474 .46776 m
.39894 .46818 L
s
.50096 .65168 m
.50301 .64635 L
s
.47711 .54014 m
.47801 .53181 L
s
0 .956 0 r
.25716 .76071 m .26278 .73022 L .27502 .75508 L F
.25716 .76071 m .24178 .737 L .26278 .73022 L F
0 0 0 r
.46532 .51527 m
.46534 .51501 L
s
.5022 .6128 m
.50394 .60653 L
s
.46531 .51551 m
.46532 .51527 L
s
.49776 .60895 m
.50424 .61182 L
s
0 0 1 r
.47852 .468 m
.47861 .46789 L
s
0 0 0 r
.46529 .51572 m
.46531 .51551 L
s
0 0 1 r
.65211 .46162 m
.66069 .46791 L
s
.47861 .46789 m
.4787 .46779 L
s
0 0 0 r
.46527 .51596 m
.46529 .51572 L
s
.49793 .63231 m
.50375 .63502 L
s
0 0 1 r
.7539 .45995 m
.76132 .46782 L
s
0 0 0 r
.46526 .51621 m
.46527 .51596 L
s
.48784 .56127 m
.48905 .55326 L
s
0 0 1 r
.4787 .46779 m
.47879 .46768 L
s
0 0 0 r
.46524 .51647 m
.46526 .51621 L
s
0 0 1 r
.47879 .46768 m
.47889 .46757 L
s
0 0 0 r
.4906 .66874 m
.49614 .67141 L
s
0 .733 0 r
.29353 .49231 m .29442 .46763 L .33812 .46537 L F
0 .678 0 r
.25156 .49851 m .29442 .46763 L .29353 .49231 L F
0 0 0 r
.28113 .46832 m
.3035 .46596 L
s
.46522 .51674 m
.46524 .51647 L
s
.49898 .65661 m
.50096 .65168 L
s
0 0 1 r
.47889 .46757 m
.47906 .46737 L
s
.533 .46375 m
.54185 .46755 L
s
.59556 .4623 m
.6046 .46754 L
s
0 0 0 r
.4652 .517 m
.46522 .51674 L
s
0 0 1 r
.59551 .4675 m
.6037 .4625 L
s
.65993 .46747 m
.6696 .4628 L
s
0 1 0 r
.40293 .75461 m .43629 .73627 L .42203 .76011 L F
0 0 0 r
.46519 .51723 m
.4652 .517 L
s
0 0 1 r
.47906 .46737 m
.47915 .46726 L
s
0 0 0 r
.46517 .51751 m
.46519 .51723 L
s
0 0 1 r
.47915 .46726 m
.47924 .46715 L
s
0 0 0 r
.46515 .51766 m
.46517 .51751 L
s
0 .782 0 r
.33729 .49009 m .3822 .46723 L .38144 .49192 L F
.33729 .49009 m .33812 .46537 L .3822 .46723 L F
0 0 0 r
.37521 .46582 m
.39474 .46776 L
s
.47417 .53172 m
.4761 .53234 L
s
.46514 .5178 m
.46515 .51766 L
s
0 0 1 r
.47924 .46715 m
.47941 .46696 L
s
0 0 0 r
.46512 .51807 m
.46514 .5178 L
s
.48238 .54933 m
.48633 .55072 L
s
.49709 .66119 m
.49898 .65661 L
s
.4651 .51834 m
.46512 .51807 L
s
.49583 .58827 m
.49735 .58115 L
s
0 0 1 r
.82443 .45754 m
.83143 .46699 L
s
0 0 0 r
.49364 .59471 m
.50069 .59764 L
s
0 0 1 r
.47941 .46696 m
.47956 .46678 L
s
0 0 0 r
.46508 .51861 m
.4651 .51834 L
s
.50032 .61923 m
.5022 .6128 L
s
0 0 1 r
.49847 .46517 m
.50346 .4669 L
s
.72808 .45919 m
.73607 .46688 L
s
0 0 0 r
.46506 .5189 m
.46508 .51861 L
s
0 0 1 r
.564 .46228 m
.57301 .46679 L
s
.47956 .46678 m
.47973 .46658 L
s
0 0 0 r
.46504 .51918 m
.46506 .5189 L
s
.49472 .64163 m
.50043 .64427 L
s
.4951 .66588 m
.49709 .66119 L
s
.46502 .51944 m
.46504 .51918 L
s
0 0 1 r
.47973 .46658 m
.4799 .46638 L
s
.67708 .46004 m
.68526 .46658 L
s
0 0 0 r
.465 .51969 m
.46502 .51944 L
s
.47205 .53106 m
.47417 .53172 L
s
0 0 1 r
.6276 .46654 m
.63654 .46169 L
s
0 0 0 r
.46498 .51992 m
.465 .51969 L
s
0 0 1 r
.70215 .45899 m
.71069 .46645 L
s
0 0 0 r
.48427 .56432 m
.49178 .56708 L
s
.46496 .52019 m
.46498 .51992 L
s
0 0 1 r
.4799 .46638 m
.48006 .4662 L
s
0 0 0 r
.49329 .67001 m
.4951 .66588 L
s
.46494 .52044 m
.46496 .52019 L
s
.48938 .57992 m
.49632 .58264 L
s
.49475 .61959 m
.50111 .62238 L
s
.46492 .52071 m
.46494 .52044 L
s
0 0 1 r
.48006 .4662 m
.4802 .46603 L
s
0 0 0 r
.4649 .521 m
.46492 .52071 L
s
0 0 1 r
.4802 .46603 m
.48036 .46584 L
s
0 0 0 r
.46488 .52124 m
.4649 .521 L
s
0 0 1 r
.74753 .46595 m
.75786 .46202 L
s
0 0 0 r
.46486 .52151 m
.46488 .52124 L
s
.49849 .62519 m
.50032 .61923 L
s
.46997 .53042 m
.47205 .53106 L
s
0 0 1 r
.48036 .46584 m
.48052 .46566 L
s
0 0 0 r
.46484 .5218 m
.46486 .52151 L
s
.35125 .46465 m
.37521 .46582 L
s
.49152 .65038 m
.49713 .65295 L
s
.46482 .52196 m
.46484 .5218 L
s
.46481 .52211 m
.46482 .52196 L
s
0 0 1 r
.48052 .46566 m
.48066 .46549 L
s
0 0 0 r
.46479 .5224 m
.46481 .52211 L
s
.47872 .54809 m
.48238 .54933 L
s
.48659 .56875 m
.48784 .56127 L
s
0 1 0 r
.30413 .7747 m .31608 .7483 L .32131 .77264 L F
.30413 .7747 m .29484 .7509 L .31608 .7483 L F
0 0 0 r
.47605 .54876 m
.47711 .54014 L
s
.46477 .52267 m
.46479 .5224 L
s
0 0 1 r
.48066 .46549 m
.48079 .46534 L
s
0 0 0 r
.46475 .5229 m
.46477 .52267 L
s
0 0 1 r
.70348 .46542 m
.71352 .46111 L
s
0 0 0 r
.49432 .5949 m
.49583 .58827 L
s
.46375 .53369 m
.46475 .52286 L
s
0 .733 0 r
.29353 .49231 m .33812 .46537 L .33729 .49009 L F
0 0 0 r
.3035 .46596 m
.32727 .4647 L
s
.46473 .52316 m
.46475 .5229 L
s
0 0 1 r
.48079 .46534 m
.48094 .46517 L
s
0 0 0 r
.4647 .52342 m
.46473 .52316 L
s
0 1 0 r
.37474 .77444 m .3822 .75058 L .40293 .75461 L F
0 0 0 r
.39239 .77734 m
.39708 .76816 L
s
0 1 0 r
.35711 .77251 m .3822 .75058 L .37474 .77444 L F
0 0 0 r
.46904 .53014 m
.46997 .53042 L
s
0 0 1 r
.80312 .4652 m
.8144 .46142 L
s
0 0 0 r
.46468 .52367 m
.4647 .52342 L
s
0 0 1 r
.48094 .46517 m
.48109 .46499 L
s
.49624 .46442 m
.49847 .46517 L
s
0 0 0 r
.46466 .52391 m
.46468 .52367 L
s
.48835 .6586 m
.49384 .66109 L
s
.46464 .52412 m
.46466 .52391 L
s
0 0 1 r
.48109 .46499 m
.48125 .46481 L
s
0 0 0 r
.49671 .63073 m
.49849 .62519 L
s
.46462 .52435 m
.46464 .52412 L
s
.46806 .52985 m
.46904 .53014 L
s
.4646 .5246 m
.46462 .52435 L
s
.49083 .60609 m
.49776 .60895 L
s
.49168 .62959 m
.49793 .63231 L
s
0 0 1 r
.48125 .46481 m
.48141 .46462 L
s
0 0 0 r
.46458 .52485 m
.4646 .5246 L
s
.46456 .52512 m
.46458 .52485 L
s
.32727 .4647 m
.35125 .46465 L
s
0 0 1 r
.57228 .46468 m
.58024 .4592 L
s
0 0 0 r
.46454 .52537 m
.46456 .52512 L
s
0 0 1 r
.48141 .46462 m
.48157 .46443 L
s
0 0 0 r
.4671 .52957 m
.46806 .52985 L
s
.48522 .66631 m
.4906 .66874 L
s
.46452 .5256 m
.46454 .52537 L
s
.46449 .52587 m
.46452 .5256 L
s
0 0 1 r
.48157 .46443 m
.48171 .46427 L
s
.49378 .46361 m
.49624 .46442 L
s
0 0 0 r
.46448 .52602 m
.46449 .52587 L
s
0 0 1 r
.61943 .45881 m
.62821 .46433 L
s
0 0 0 r
.46447 .52616 m
.46448 .52602 L
s
.47446 .5467 m
.47872 .54809 L
s
.46657 .52941 m
.4671 .52957 L
s
.46445 .52641 m
.46447 .52616 L
s
0 0 1 r
.48171 .46427 m
.48188 .46407 L
s
0 0 0 r
.39708 .76816 m
.4017 .75863 L
s
.49481 .63642 m
.49671 .63073 L
s
.46442 .52668 m
.46445 .52641 L
s
.46606 .52926 m
.46657 .52941 L
s
.4644 .52695 m
.46442 .52668 L
s
0 .67 0 r
.2134 .53451 m .25156 .49851 L .25182 .52487 L F
0 .721 0 r
.21576 .56187 m .2134 .53451 L .25182 .52487 L F
0 0 1 r
.48188 .46407 m
.48197 .46396 L
s
0 0 0 r
.49266 .60172 m
.49432 .5949 L
s
0 .712 0 r
.18754 .60182 m .21576 .56187 L .2198 .59013 L F
0 .76 0 r
.19479 .62976 m .18754 .60182 L .2198 .59013 L F
0 0 0 r
.46437 .52724 m
.4644 .52695 L
s
.46561 .52913 m
.46606 .52926 L
s
0 0 1 r
.48197 .46396 m
.48206 .46386 L
s
0 0 0 r
.46435 .52751 m
.46437 .52724 L
s
0 0 1 r
.48206 .46386 m
.48222 .46367 L
s
0 0 0 r
.46518 .52901 m
.46561 .52913 L
s
0 0 1 r
.79794 .45454 m
.80568 .46385 L
s
0 0 0 r
.46432 .52776 m
.46435 .52751 L
s
0 0 1 r
.52354 .45998 m
.533 .46375 L
s
0 0 0 r
.4643 .52801 m
.46432 .52776 L
s
.48518 .57647 m
.48659 .56875 L
s
.48859 .63898 m
.49472 .64163 L
s
.46494 .52894 m
.46518 .52901 L
s
0 0 1 r
.48222 .46367 m
.48239 .46347 L
s
0 0 0 r
.46428 .52823 m
.4643 .52801 L
s
.46469 .52887 m
.46494 .52894 L
s
0 0 1 r
.49136 .46283 m
.49378 .46361 L
s
0 0 0 r
.46426 .52849 m
.46428 .52823 L
s
.46447 .5288 m
.46469 .52887 L
s
.46423 .52874 m
.46426 .52849 L
s
.46423 .52873 m
.46447 .5288 L
s
.49299 .64169 m
.49481 .63642 L
s
0 0 1 r
.48239 .46347 m
.48255 .46329 L
s
0 0 0 r
.48037 .56296 m
.48427 .56432 L
s
.46421 .529 m
.46423 .52874 L
s
.48198 .57722 m
.48938 .57992 L
s
.46418 .52929 m
.46421 .529 L
s
0 0 1 r
.48255 .46329 m
.48272 .46309 L
s
0 0 0 r
.46416 .52953 m
.46418 .52929 L
s
.46413 .52979 m
.46416 .52953 L
s
0 0 1 r
.54891 .4631 m
.55658 .45715 L
s
0 0 0 r
.46411 .53007 m
.46413 .52979 L
s
0 0 1 r
.48272 .46309 m
.48289 .46289 L
s
0 .729 0 r
.25182 .52487 m .25156 .49851 L .29353 .49231 L F
0 0 0 r
.47492 .55683 m
.47605 .54876 L
s
0 1 0 r
.32131 .77264 m .33814 .74737 L .33914 .7719 L F
.32131 .77264 m .31608 .7483 L .33814 .74737 L F
0 0 0 r
.46409 .53023 m
.46411 .53007 L
s
0 .943 0 r
.42047 .55191 m .4632 .53343 L .45981 .56084 L F
.42047 .55191 m .42295 .52412 L .4632 .53343 L F
0 0 0 r
.46408 .53038 m
.46409 .53023 L
s
.46405 .53066 m
.46408 .53038 L
s
.49105 .64709 m
.49299 .64169 L
s
0 0 1 r
.48289 .46289 m
.48306 .46269 L
s
0 0 0 r
.48551 .6478 m
.49152 .65038 L
s
.47255 .5461 m
.47446 .5467 L
s
0 1 0 r
.35711 .77251 m .36039 .74814 L .3822 .75058 L F
.33914 .7719 m .36039 .74814 L .35711 .77251 L F
0 0 1 r
.49029 .46249 m
.49136 .46283 L
s
0 0 0 r
.46403 .53093 m
.46405 .53066 L
s
0 0 1 r
.6696 .4628 m
.67896 .45828 L
s
0 0 0 r
.49103 .60806 m
.49266 .60172 L
s
0 .919 0 r
.24178 .737 m .25155 .70378 L .26278 .73022 L F
.24178 .737 m .22765 .71167 L .25155 .70378 L F
0 0 0 r
.464 .53115 m
.46403 .53093 L
s
0 0 1 r
.48306 .46269 m
.48321 .46251 L
s
0 1 0 r
.44902 .61797 m .48964 .60057 L .48193 .6286 L F
.44902 .61797 m .45506 .58916 L .48964 .60057 L F
0 0 0 r
.48793 .6168 m
.49475 .61959 L
s
.48681 .59206 m
.49364 .59471 L
s
.46398 .5314 m
.464 .53115 L
s
.46395 .53166 m
.46398 .5314 L
s
0 0 1 r
.48321 .46251 m
.48335 .46235 L
s
0 0 0 r
.46393 .53191 m
.46395 .53166 L
s
0 0 1 r
.6037 .4625 m
.61247 .45715 L
s
.48914 .46213 m
.49029 .46249 L
s
.50396 .46245 m
.51016 .45618 L
s
0 0 0 r
.46391 .53214 m
.46393 .53191 L
s
.48919 .6521 m
.49105 .64709 L
s
.46389 .53234 m
.46391 .53214 L
s
0 0 1 r
.48335 .46235 m
.48351 .46216 L
s
0 .868 0 r
.38031 .51846 m .42454 .49774 L .42295 .52412 L F
.38031 .51846 m .38144 .49192 L .42454 .49774 L F
0 0 1 r
.58673 .45751 m
.59556 .4623 L
s
0 0 0 r
.46386 .53257 m
.46389 .53234 L
s
0 0 1 r
.55433 .45778 m
.564 .46228 L
s
0 0 0 r
.46384 .53281 m
.46386 .53257 L
s
.48245 .65609 m
.48835 .6586 L
s
.47046 .54545 m
.47255 .5461 L
s
0 0 1 r
.52633 .46218 m
.53293 .45635 L
s
.48351 .46216 m
.48366 .46198 L
s
0 0 0 r
.46381 .53306 m
.46384 .53281 L
s
0 0 1 r
.48803 .46179 m
.48914 .46213 L
s
0 1 0 r
.33914 .7719 m .33814 .74737 L .36039 .74814 L F
0 0 0 r
.46379 .53332 m
.46381 .53306 L
s
0 0 1 r
.75786 .46202 m
.7689 .45783 L
s
0 0 0 r
.46376 .53356 m
.46379 .53332 L
s
.47675 .56175 m
.48037 .56296 L
s
0 0 1 r
.48366 .46198 m
.48383 .46179 L
s
0 0 0 r
.4874 .65674 m
.48919 .6521 L
s
.48376 .58365 m
.48518 .57647 L
s
.46374 .53379 m
.46376 .53356 L
s
.46252 .54474 m
.46375 .53369 L
s
0 1 0 r
.41381 .72966 m .4496 .71083 L .43629 .73627 L F
.40293 .75461 m .41381 .72966 L .43629 .73627 L F
0 0 0 r
.46371 .53405 m
.46374 .53379 L
s
0 0 1 r
.48741 .4616 m
.48803 .46179 L
s
0 0 0 r
.48499 .62688 m
.49168 .62959 L
s
0 0 1 r
.48383 .46179 m
.48401 .46158 L
s
0 0 0 r
.4637 .5342 m
.46371 .53405 L
s
.47944 .66387 m
.48522 .66631 L
s
.46368 .53433 m
.4637 .5342 L
s
.48927 .61456 m
.49103 .60806 L
s
.48411 .60351 m
.49083 .60609 L
s
0 0 1 r
.63654 .46169 m
.64518 .45699 L
s
0 0 0 r
.46366 .53458 m
.46368 .53433 L
s
0 0 1 r
.64365 .45584 m
.65211 .46162 L
s
0 0 0 r
.46363 .53485 m
.46366 .53458 L
s
0 0 1 r
.48683 .46142 m
.48741 .4616 L
s
0 0 0 r
.48552 .66151 m
.4874 .65674 L
s
0 0 1 r
.48401 .46158 m
.48416 .4614 L
s
0 0 0 r
.4636 .53511 m
.46363 .53485 L
s
.46839 .54482 m
.47046 .54545 L
s
.46358 .53539 m
.4636 .53511 L
s
0 0 1 r
.8144 .46142 m
.82475 .45795 L
s
.48629 .46125 m
.48683 .46142 L
s
.48416 .4614 m
.48432 .46121 L
s
0 0 0 r
.46355 .53565 m
.46358 .53539 L
s
.48382 .6657 m
.48552 .66151 L
s
.46352 .5359 m
.46355 .53565 L
s
0 0 1 r
.4858 .4611 m
.48629 .46125 L
s
0 .979 0 r
.27502 .75508 m .28615 .72519 L .29484 .7509 L F
.27502 .75508 m .26278 .73022 L .28615 .72519 L F
0 0 1 r
.7719 .45295 m
.77955 .46121 L
s
.48432 .46121 m
.4845 .461 L
s
0 0 0 r
.4635 .53612 m
.46352 .5359 L
s
.46347 .53636 m
.4635 .53612 L
s
0 0 1 r
.71352 .46111 m
.72323 .45694 L
s
.48552 .46102 m
.4858 .4611 L
s
0 0 0 r
.46345 .53662 m
.46347 .53636 L
s
0 0 1 r
.48523 .46093 m
.48552 .46102 L
s
.4845 .461 m
.4846 .46088 L
s
0 0 0 r
.46342 .53686 m
.46345 .53662 L
s
0 0 1 r
.48498 .46086 m
.48523 .46093 L
s
0 0 0 r
.46339 .53712 m
.46342 .53686 L
s
0 0 1 r
.4846 .46088 m
.48469 .46078 L
s
0 0 0 r
.47377 .56437 m
.47492 .55683 L
s
.47952 .58943 m
.48681 .59206 L
s
.46747 .54455 m
.46839 .54482 L
s
0 0 1 r
.4847 .46077 m
.48498 .46086 L
s
0 0 0 r
.46336 .53739 m
.46339 .53712 L
s
0 0 1 r
.48469 .46078 m
.48487 .46057 L
s
0 0 0 r
.46334 .53763 m
.46336 .53739 L
s
.48203 .63634 m
.48859 .63898 L
s
.46331 .53789 m
.46334 .53763 L
s
.47254 .56039 m
.47675 .56175 L
s
.48755 .6206 m
.48927 .61456 L
s
0 1 0 r
.3822 .75058 m .41381 .72966 L .40293 .75461 L F
0 0 0 r
.4017 .75863 m
.40623 .74878 L
s
.46328 .53817 m
.46331 .53789 L
s
0 0 1 r
.48487 .46057 m
.48504 .46037 L
s
0 0 0 r
.4665 .54426 m
.46747 .54455 L
s
.46326 .53832 m
.46328 .53817 L
s
.46325 .53846 m
.46326 .53832 L
s
.46321 .53874 m
.46325 .53846 L
s
.47813 .5759 m
.48198 .57722 L
s
.48235 .59034 m
.48376 .58365 L
s
0 0 1 r
.48504 .46037 m
.4852 .46019 L
s
0 0 0 r
.46319 .539 m
.46321 .53874 L
s
.46316 .53922 m
.46319 .539 L
s
.46555 .54398 m
.4665 .54426 L
s
.46313 .53946 m
.46316 .53922 L
s
0 0 1 r
.4852 .46019 m
.48534 .46002 L
s
0 0 0 r
.46311 .53972 m
.46313 .53946 L
s
.46308 .53996 m
.46311 .53972 L
s
.48133 .61429 m
.48793 .6168 L
s
0 0 1 r
.66811 .45338 m
.67708 .46004 L
s
.48534 .46002 m
.4855 .45983 L
s
0 0 0 r
.46305 .54018 m
.46308 .53996 L
s
0 0 1 r
.51862 .45812 m
.52354 .45998 L
s
0 0 0 r
.46502 .54383 m
.46555 .54398 L
s
0 .76 0 r
.19479 .62976 m .2198 .59013 L .22549 .61889 L F
0 .803 0 r
.20398 .65766 m .19479 .62976 L .22549 .61889 L F
0 0 0 r
.46303 .54038 m
.46305 .54018 L
s
0 0 1 r
.74563 .45186 m
.7539 .45995 L
s
0 0 0 r
.463 .54062 m
.46303 .54038 L
s
.48589 .62621 m
.48755 .6206 L
s
0 0 1 r
.4855 .45983 m
.48566 .45965 L
s
0 0 0 r
.46298 .54084 m
.463 .54062 L
s
.46452 .54368 m
.46502 .54383 L
s
.46295 .54108 m
.46298 .54084 L
s
.46292 .54133 m
.46295 .54108 L
s
.46407 .54355 m
.46452 .54368 L
s
0 0 1 r
.48566 .45965 m
.4858 .45948 L
s
0 0 0 r
.46289 .54157 m
.46292 .54133 L
s
.46287 .54179 m
.46289 .54157 L
s
.46365 .54343 m
.46407 .54355 L
s
.46284 .54205 m
.46287 .54179 L
s
0 0 1 r
.4858 .45948 m
.48593 .45933 L
s
0 0 0 r
.46282 .54219 m
.46284 .54205 L
s
.46341 .54337 m
.46365 .54343 L
s
.46281 .54232 m
.46282 .54219 L
s
.46278 .54257 m
.46281 .54232 L
s
0 0 1 r
.48593 .45933 m
.48608 .45916 L
s
0 0 0 r
.46316 .5433 m
.46341 .54337 L
s
.46275 .54282 m
.46278 .54257 L
s
.46295 .54323 m
.46316 .5433 L
s
.47066 .5598 m
.47254 .56039 L
s
0 0 1 r
.58024 .4592 m
.58796 .45389 L
s
0 0 0 r
.46272 .54308 m
.46275 .54282 L
s
0 0 1 r
.71922 .45132 m
.72808 .45919 L
s
0 0 0 r
.46271 .54317 m
.46295 .54323 L
s
0 .882 0 r
.22765 .71167 m .24148 .67614 L .25155 .70378 L F
.22765 .71167 m .21498 .6851 L .24148 .67614 L F
0 0 1 r
.48608 .45916 m
.48623 .45898 L
s
0 0 0 r
.4627 .54322 m
.46272 .54308 L
s
.48411 .63197 m
.48589 .62621 L
s
.46269 .54335 m
.4627 .54322 L
s
.48081 .59723 m
.48235 .59034 L
s
.46266 .5436 m
.46269 .54335 L
s
.47247 .57215 m
.47377 .56437 L
s
.47457 .57471 m
.47813 .5759 L
s
0 0 1 r
.69363 .45209 m
.70215 .45899 L
s
0 0 0 r
.46263 .54385 m
.46266 .5436 L
s
0 0 1 r
.48623 .45898 m
.48639 .4588 L
s
0 0 0 r
.47326 .66143 m
.47944 .66387 L
s
.4626 .54408 m
.46263 .54385 L
s
.46257 .5443 m
.4626 .54408 L
s
.47694 .60094 m
.48411 .60351 L
s
0 0 1 r
.60992 .45323 m
.61943 .45881 L
s
.48639 .4588 m
.48655 .4586 L
s
0 0 0 r
.46255 .54453 m
.46257 .5443 L
s
.46252 .54479 m
.46255 .54453 L
s
.46106 .55598 m
.46252 .54474 L
s
.46248 .54504 m
.46252 .54479 L
s
0 1 0 r
.44175 .64686 m .48193 .6286 L .47259 .6566 L F
0 0 0 r
.47615 .65359 m
.48245 .65609 L
s
0 1 0 r
.44175 .64686 m .44902 .61797 L .48193 .6286 L F
0 0 0 r
.47907 .64523 m
.48551 .6478 L
s
.47851 .62443 m
.48499 .62688 L
s
.46859 .55917 m
.47066 .5598 L
s
0 0 1 r
.48655 .4586 m
.48671 .45842 L
s
0 0 0 r
.46247 .54518 m
.46248 .54504 L
s
.46245 .54532 m
.46247 .54518 L
s
.46242 .54559 m
.46245 .54532 L
s
.4824 .63731 m
.48411 .63197 L
s
.4624 .54574 m
.46242 .54559 L
s
0 0 1 r
.48671 .45842 m
.48685 .45825 L
s
0 0 0 r
.46238 .54588 m
.4624 .54574 L
s
.46235 .54612 m
.46238 .54588 L
s
.46232 .54639 m
.46235 .54612 L
s
0 0 1 r
.67896 .45828 m
.68897 .45344 L
s
.48685 .45825 m
.48702 .45806 L
s
0 0 0 r
.46229 .54664 m
.46232 .54639 L
s
0 1 0 r
.42401 .70312 m .46176 .68414 L .4496 .71083 L F
.41381 .72966 m .42401 .70312 L .4496 .71083 L F
0 0 0 r
.46226 .54687 m
.46229 .54664 L
s
0 0 1 r
.51405 .45647 m
.51862 .45812 L
s
0 0 0 r
.46223 .54709 m
.46226 .54687 L
s
0 0 1 r
.48702 .45806 m
.48711 .45795 L
s
0 0 0 r
.4622 .54732 m
.46223 .54709 L
s
.47573 .58814 m
.47952 .58943 L
s
.46218 .54754 m
.4622 .54732 L
s
0 0 1 r
.48711 .45795 m
.4872 .45784 L
s
0 0 0 r
.48059 .64278 m
.4824 .63731 L
s
.46654 .55855 m
.46859 .55917 L
s
.46215 .54774 m
.46218 .54754 L
s
.46212 .54798 m
.46215 .54774 L
s
.4793 .60364 m
.48081 .59723 L
s
0 0 1 r
.4872 .45784 m
.48736 .45766 L
s
.7689 .45783 m
.7796 .45376 L
s
0 0 0 r
.46209 .54823 m
.46212 .54798 L
s
0 0 1 r
.54493 .45371 m
.55433 .45778 L
s
0 .803 0 r
.20398 .65766 m .22549 .61889 L .23276 .6477 L F
0 .844 0 r
.21498 .6851 m .20398 .65766 L .23276 .6477 L F
0 0 0 r
.47567 .63396 m
.48203 .63634 L
s
.46206 .54847 m
.46209 .54823 L
s
.47042 .57339 m
.47457 .57471 L
s
.46203 .54869 m
.46206 .54847 L
s
0 0 1 r
.48736 .45766 m
.48753 .45746 L
s
0 0 0 r
.462 .54894 m
.46203 .54869 L
s
0 0 1 r
.81649 .44781 m
.82443 .45754 L
s
0 0 0 r
.46197 .54918 m
.462 .54894 L
s
0 0 1 r
.5772 .4527 m
.58673 .45751 L
s
0 .844 0 r
.21498 .6851 m .23276 .6477 L .24148 .67614 L F
0 0 0 r
.46194 .54939 m
.46197 .54918 L
s
.47885 .64785 m
.48059 .64278 L
s
0 0 1 r
.48753 .45746 m
.4877 .45726 L
s
0 0 0 r
.46191 .54962 m
.46194 .54939 L
s
.46188 .54987 m
.46191 .54962 L
s
.46185 .55013 m
.46188 .54987 L
s
.46564 .55829 m
.46654 .55855 L
s
0 0 1 r
.4877 .45726 m
.48788 .45705 L
s
0 0 0 r
.47116 .57939 m
.47247 .57215 L
s
.47429 .61179 m
.48133 .61429 L
s
.46182 .55036 m
.46185 .55013 L
s
.46179 .5506 m
.46182 .55036 L
s
0 0 1 r
.61247 .45715 m
.62097 .45196 L
s
.55658 .45715 m
.56401 .45136 L
s
0 0 0 r
.46175 .55087 m
.46179 .5506 L
s
.47718 .65256 m
.47885 .64785 L
s
0 0 1 r
.48788 .45705 m
.48805 .45686 L
s
0 0 0 r
.46172 .55111 m
.46175 .55087 L
s
.47284 .64292 m
.47907 .64523 L
s
0 0 1 r
.64518 .45699 m
.65445 .45196 L
s
0 0 0 r
.46468 .558 m
.46564 .55829 L
s
.4617 .55124 m
.46172 .55111 L
s
.46168 .55138 m
.4617 .55124 L
s
0 0 1 r
.72323 .45694 m
.73362 .45248 L
s
0 0 0 r
.46167 .55153 m
.46168 .55138 L
s
.46165 .55166 m
.46167 .55153 L
s
0 0 1 r
.48805 .45686 m
.4882 .45667 L
s
0 0 0 r
.46161 .55192 m
.46165 .55166 L
s
.47766 .61021 m
.4793 .60364 L
s
.47543 .65739 m
.47718 .65256 L
s
.46158 .55215 m
.46161 .55192 L
s
0 .779 0 r
.29333 .51884 m .29353 .49231 L .33729 .49009 L F
0 .729 0 r
.25182 .52487 m .29353 .49231 L .29333 .51884 L F
0 0 0 r
.46155 .55241 m
.46158 .55215 L
s
0 .721 0 r
.21576 .56187 m .25182 .52487 L .2533 .55263 L F
0 .766 0 r
.2198 .59013 m .21576 .56187 L .2533 .55263 L F
0 0 0 r
.46374 .55773 m
.46468 .558 L
s
0 0 1 r
.4882 .45667 m
.48836 .45649 L
s
0 0 0 r
.46151 .55266 m
.46155 .55241 L
s
.46148 .55289 m
.46151 .55266 L
s
.47222 .58698 m
.47573 .58814 L
s
.47384 .66165 m
.47543 .65739 L
s
0 1 0 r
.43338 .67539 m .47259 .6566 L .46176 .68414 L F
.43338 .67539 m .44175 .64686 L .47259 .6566 L F
0 0 0 r
.46145 .55313 m
.46148 .55289 L
s
0 0 1 r
.48836 .45649 m
.4885 .45632 L
s
0 0 0 r
.47004 .65133 m
.47615 .65359 L
s
.46142 .55335 m
.46145 .55313 L
s
0 0 1 r
.50873 .45461 m
.51405 .45647 L
s
0 0 0 r
.4614 .55356 m
.46142 .55335 L
s
.46322 .55758 m
.46374 .55773 L
s
0 1 0 r
.42401 .70312 m .43338 .67539 L .46176 .68414 L F
0 0 0 r
.46136 .5538 m
.4614 .55356 L
s
0 0 1 r
.53293 .45635 m
.54 .4501 L
s
0 .825 0 r
.33663 .51668 m .38144 .49192 L .38031 .51846 L F
.33663 .51668 m .33729 .49009 L .38144 .49192 L F
0 0 1 r
.4885 .45632 m
.48866 .45613 L
s
0 0 0 r
.46133 .55406 m
.46136 .5538 L
s
.46856 .57281 m
.47042 .57339 L
s
.46129 .5543 m
.46133 .55406 L
s
.46272 .55744 m
.46322 .55758 L
s
0 0 1 r
.51016 .45618 m
.51617 .4501 L
s
0 0 0 r
.46126 .55453 m
.46129 .5543 L
s
.46728 .65924 m
.47326 .66143 L
s
0 0 1 r
.48866 .45613 m
.48882 .45595 L
s
0 0 0 r
.46123 .55477 m
.46126 .55453 L
s
.46227 .55731 m
.46272 .55744 L
s
.4612 .55503 m
.46123 .55477 L
s
0 1 0 r
.29484 .7509 m .31124 .72205 L .31608 .7483 L F
.29484 .7509 m .28615 .72519 L .31124 .72205 L F
0 0 0 r
.47322 .59968 m
.47694 .60094 L
s
.46116 .55527 m
.4612 .55503 L
s
.4716 .622 m
.47851 .62443 L
s
0 0 1 r
.48882 .45595 m
.48899 .45575 L
s
0 0 0 r
.46186 .5572 m
.46227 .55731 L
s
.46113 .55549 m
.46116 .55527 L
s
.4611 .55575 m
.46113 .55549 L
s
.47607 .61632 m
.47766 .61021 L
s
0 0 1 r
.63444 .44998 m
.64365 .45584 L
s
0 0 0 r
.46108 .5559 m
.4611 .55575 L
s
.46163 .55713 m
.46186 .5572 L
s
.46106 .55603 m
.46108 .5559 L
s
.46986 .58614 m
.47116 .57939 L
s
0 0 1 r
.48899 .45575 m
.48916 .45555 L
s
0 0 0 r
.46102 .55628 m
.46106 .55603 L
s
.46138 .55706 m
.46163 .55713 L
s
.461 .55641 m
.46102 .55628 L
s
.46117 .557 m
.46138 .55706 L
s
.46099 .55655 m
.461 .55641 L
s
.46651 .57219 m
.46856 .57281 L
s
0 1 0 r
.3822 .75058 m .38936 .7248 L .41381 .72966 L F
0 0 0 r
.40623 .74878 m
.41068 .73862 L
s
0 1 0 r
.36039 .74814 m .38936 .7248 L .3822 .75058 L F
0 0 0 r
.46097 .55668 m
.46099 .55655 L
s
.46093 .55693 m
.46117 .557 L
s
.46095 .55682 m
.46097 .55668 L
s
0 .972 0 r
.41713 .58073 m .45981 .56084 L .45506 .58916 L F
.41713 .58073 m .42047 .55191 L .45981 .56084 L F
0 0 0 r
.45938 .56738 m
.46106 .55598 L
s
.46091 .55707 m
.46095 .55682 L
s
0 0 1 r
.48916 .45555 m
.48932 .45537 L
s
0 0 0 r
.46089 .55721 m
.46091 .55707 L
s
.46087 .55734 m
.46089 .55721 L
s
.46085 .55749 m
.46087 .55734 L
s
.46083 .55764 m
.46085 .55749 L
s
0 0 1 r
.48932 .45537 m
.48948 .45517 L
s
0 0 0 r
.46081 .55777 m
.46083 .55764 L
s
.46079 .55791 m
.46081 .55777 L
s
.46813 .58569 m
.47222 .58698 L
s
.46077 .55805 m
.46079 .55791 L
s
.46076 .55818 m
.46077 .55805 L
s
.46072 .55841 m
.46076 .55818 L
s
.46069 .55866 m
.46072 .55841 L
s
0 0 1 r
.48948 .45517 m
.48966 .45496 L
s
0 0 0 r
.46065 .5589 m
.46069 .55866 L
s
.46062 .55916 m
.46065 .5589 L
s
.47453 .62199 m
.47607 .61632 L
s
.4689 .63159 m
.47567 .63396 L
s
.46058 .5594 m
.46062 .55916 L
s
.4645 .57159 m
.46651 .57219 L
s
0 0 1 r
.48966 .45496 m
.48976 .45484 L
s
0 0 0 r
.46055 .55963 m
.46058 .5594 L
s
.46052 .55985 m
.46055 .55963 L
s
.46049 .56005 m
.46052 .55985 L
s
0 0 1 r
.48976 .45484 m
.48986 .45474 L
s
0 0 0 r
.46045 .56028 m
.46049 .56005 L
s
.46042 .5605 m
.46045 .56028 L
s
0 0 1 r
.48986 .45474 m
.49004 .45453 L
s
0 0 0 r
.46039 .56074 m
.46042 .5605 L
s
.46035 .561 m
.46039 .56074 L
s
.46977 .59856 m
.47322 .59968 L
s
0 0 1 r
.50634 .4538 m
.50873 .45461 L
s
0 0 0 r
.46032 .56121 m
.46035 .561 L
s
0 0 1 r
.79006 .44588 m
.79794 .45454 L
s
0 0 0 r
.46028 .56145 m
.46032 .56121 L
s
0 0 1 r
.49004 .45453 m
.4902 .45433 L
s
0 .946 0 r
.26278 .73022 m .2782 .69791 L .28615 .72519 L F
.26278 .73022 m .25155 .70378 L .2782 .69791 L F
0 0 0 r
.46844 .59309 m
.46986 .58614 L
s
.46024 .5617 m
.46028 .56145 L
s
0 .779 0 r
.29333 .51884 m .33729 .49009 L .33663 .51668 L F
0 0 0 r
.47063 .61056 m
.47429 .61179 L
s
.46022 .56185 m
.46024 .5617 L
s
.47288 .62782 m
.47453 .62199 L
s
.4602 .56198 m
.46022 .56185 L
s
.46017 .56223 m
.4602 .56198 L
s
.4662 .64061 m
.47284 .64292 L
s
.46361 .57133 m
.4645 .57159 L
s
0 0 1 r
.4902 .45433 m
.49035 .45416 L
s
0 0 0 r
.46013 .56247 m
.46017 .56223 L
s
.4601 .56267 m
.46013 .56247 L
s
.46007 .56289 m
.4601 .56267 L
s
0 0 1 r
.49035 .45416 m
.49051 .45398 L
s
0 0 0 r
.46003 .56313 m
.46007 .56289 L
s
.46 .56335 m
.46003 .56313 L
s
.46266 .57106 m
.46361 .57133 L
s
.45997 .56355 m
.46 .56335 L
s
.45994 .56374 m
.45997 .56355 L
s
0 .773 0 r
.2533 .55263 m .25182 .52487 L .29333 .51884 L F
0 0 1 r
.49051 .45398 m
.49067 .45378 L
s
0 0 0 r
.45991 .56394 m
.45994 .56374 L
s
.45988 .56415 m
.45991 .56394 L
s
.4663 .58513 m
.46813 .58569 L
s
0 0 1 r
.58796 .45389 m
.59623 .4482 L
s
0 0 0 r
.46353 .64909 m
.47004 .65133 L
s
.45984 .56437 m
.45988 .56415 L
s
.45981 .56461 m
.45984 .56437 L
s
0 1 0 r
.38936 .7248 m .42401 .70312 L .41381 .72966 L F
0 0 0 r
.41068 .73862 m
.41502 .72819 L
s
0 0 1 r
.50372 .45293 m
.50634 .4538 L
s
0 0 0 r
.47129 .63322 m
.47288 .62782 L
s
0 0 1 r
.49067 .45378 m
.49083 .4536 L
s
0 0 0 r
.45978 .56483 m
.45981 .56461 L
s
0 0 1 r
.7796 .45376 m
.78994 .44983 L
s
0 0 0 r
.46173 .57079 m
.46266 .57106 L
s
.45974 .56503 m
.45978 .56483 L
s
0 0 1 r
.53488 .44967 m
.54493 .45371 L
s
0 0 0 r
.45971 .56526 m
.45974 .56503 L
s
.45969 .56539 m
.45971 .56526 L
s
.45967 .56552 m
.45969 .56539 L
s
.4609 .65705 m
.46728 .65924 L
s
0 0 1 r
.49083 .4536 m
.49097 .45343 L
s
0 0 0 r
.45964 .56574 m
.45967 .56552 L
s
.4596 .56598 m
.45964 .56574 L
s
.45956 .56621 m
.4596 .56598 L
s
.46122 .57064 m
.46173 .57079 L
s
0 0 1 r
.68897 .45344 m
.69867 .44876 L
s
.49097 .45343 m
.49111 .45327 L
s
0 0 0 r
.45952 .56646 m
.45956 .56621 L
s
.46575 .5973 m
.46977 .59856 L
s
0 0 1 r
.65926 .44726 m
.66811 .45338 L
s
0 0 0 r
.45949 .5667 m
.45952 .56646 L
s
.45945 .56691 m
.45949 .5667 L
s
.46961 .63876 m
.47129 .63322 L
s
.46073 .57051 m
.46122 .57064 L
s
.46704 .59956 m
.46844 .59309 L
s
.46429 .58452 m
.4663 .58513 L
s
.45942 .56713 m
.45945 .56691 L
s
0 0 1 r
.49111 .45327 m
.49125 .4531 L
s
0 0 0 r
.46801 .6208 m
.4716 .622 L
s
.45939 .56733 m
.45942 .56713 L
s
0 0 1 r
.60061 .44813 m
.60992 .45323 L
s
0 .903 0 r
.37882 .54649 m .42295 .52412 L .42047 .55191 L F
.37882 .54649 m .38031 .51846 L .42295 .52412 L F
0 0 0 r
.45935 .56756 m
.45939 .56733 L
s
.45747 .57892 m
.45938 .56738 L
s
.46029 .57038 m
.46073 .57051 L
s
.45932 .56777 m
.45935 .56756 L
s
0 0 1 r
.49125 .4531 m
.49141 .45292 L
s
0 0 0 r
.46724 .60947 m
.47063 .61056 L
s
.45928 .568 m
.45932 .56777 L
s
.45924 .56825 m
.45928 .568 L
s
.45988 .57027 m
.46029 .57038 L
s
.45921 .56846 m
.45924 .56825 L
s
.45917 .56869 m
.45921 .56846 L
s
0 0 1 r
.76336 .44445 m
.7719 .45295 L
s
.50113 .45209 m
.50372 .45293 L
s
.49141 .45292 m
.49156 .45274 L
s
0 0 0 r
.45965 .5702 m
.45988 .57027 L
s
.45914 .56894 m
.45917 .56869 L
s
.468 .6439 m
.46961 .63876 L
s
.45911 .56907 m
.45914 .56894 L
s
.45941 .57013 m
.45965 .5702 L
s
0 1 0 r
.31608 .7483 m .33731 .72093 L .33814 .74737 L F
.31608 .7483 m .31124 .72205 L .33731 .72093 L F
0 0 0 r
.45909 .5692 m
.45911 .56907 L
s
.45905 .56945 m
.45909 .5692 L
s
.4592 .57007 m
.45941 .57013 L
s
.45902 .56968 m
.45905 .56945 L
s
0 0 1 r
.49156 .45274 m
.49173 .45254 L
s
.56697 .44789 m
.5772 .4527 L
s
0 0 0 r
.45896 .57001 m
.4592 .57007 L
s
.45899 .56987 m
.45902 .56968 L
s
.45895 .57009 m
.45899 .56987 L
s
0 1 0 r
.36039 .74814 m .3636 .72186 L .38936 .7248 L F
.33814 .74737 m .3636 .72186 L .36039 .74814 L F
0 0 0 r
.46231 .58394 m
.46429 .58452 L
s
.45891 .57032 m
.45895 .57009 L
s
.46646 .64867 m
.468 .6439 L
s
.45888 .57053 m
.45891 .57032 L
s
0 0 1 r
.49173 .45254 m
.49189 .45236 L
s
0 0 0 r
.45885 .57073 m
.45888 .57053 L
s
0 0 1 r
.73362 .45248 m
.74368 .44816 L
s
0 0 0 r
.45882 .57091 m
.45885 .57073 L
s
.45879 .57112 m
.45882 .57091 L
s
.41502 .72819 m
.41925 .71749 L
s
.45875 .57132 m
.45879 .57112 L
s
.46538 .63043 m
.4689 .63159 L
s
.45872 .57153 m
.45875 .57132 L
s
0 0 1 r
.49189 .45236 m
.49203 .45219 L
s
0 0 0 r
.46484 .65356 m
.46646 .64867 L
s
.45868 .57176 m
.45872 .57153 L
s
.46554 .6062 m
.46704 .59956 L
s
.45865 .57197 m
.45868 .57176 L
s
.45861 .57216 m
.45865 .57197 L
s
.45858 .57239 m
.45861 .57216 L
s
0 0 1 r
.49203 .45219 m
.4922 .45199 L
s
0 0 0 r
.46336 .65788 m
.46484 .65356 L
s
.45856 .57252 m
.45858 .57239 L
s
.45854 .57264 m
.45856 .57252 L
s
.4585 .57286 m
.45854 .57264 L
s
0 0 1 r
.49999 .45172 m
.50113 .45209 L
s
.68428 .44505 m
.69363 .45209 L
s
0 0 0 r
.45846 .57308 m
.4585 .57286 L
s
.45843 .57331 m
.45846 .57308 L
s
0 0 1 r
.4922 .45199 m
.4923 .45188 L
s
0 0 0 r
.46395 .59675 m
.46575 .5973 L
s
.46143 .58368 m
.46231 .58394 L
s
.45841 .57344 m
.45843 .57331 L
s
0 0 1 r
.62097 .45196 m
.6292 .44693 L
s
.65445 .45196 m
.66343 .44708 L
s
0 0 0 r
.45839 .57355 m
.45841 .57344 L
s
.46468 .61974 m
.46801 .6208 L
s
.45835 .57377 m
.45839 .57355 L
s
0 0 1 r
.4923 .45188 m
.49239 .45178 L
s
0 0 0 r
.45831 .574 m
.45835 .57377 L
s
.4633 .60824 m
.46724 .60947 L
s
0 0 1 r
.73645 .44358 m
.74563 .45186 L
s
0 0 0 r
.45828 .5742 m
.45831 .574 L
s
.45825 .57439 m
.45828 .5742 L
s
0 0 1 r
.49239 .45178 m
.49255 .45159 L
s
0 0 0 r
.45821 .5746 m
.45825 .57439 L
s
.46275 .63948 m
.4662 .64061 L
s
0 0 1 r
.49876 .45134 m
.49999 .45172 L
s
0 0 0 r
.45817 .57483 m
.45821 .5746 L
s
.4605 .58341 m
.46143 .58368 L
s
0 1 0 r
.33814 .74737 m .33731 .72093 L .3636 .72186 L F
0 0 0 r
.45814 .57505 m
.45817 .57483 L
s
.45811 .57518 m
.45814 .57505 L
s
.45809 .5753 m
.45811 .57518 L
s
0 0 1 r
.49255 .45159 m
.49272 .45139 L
s
0 0 0 r
.45805 .57554 m
.45809 .5753 L
s
.45803 .57567 m
.45805 .57554 L
s
.45801 .5758 m
.45803 .57567 L
s
.45797 .57601 m
.45801 .5758 L
s
.45793 .57625 m
.45797 .57601 L
s
.45959 .58315 m
.4605 .58341 L
s
.4579 .57647 m
.45793 .57625 L
s
.46408 .61237 m
.46554 .6062 L
s
0 0 1 r
.49272 .45139 m
.49289 .45119 L
s
0 0 0 r
.46197 .59616 m
.46395 .59675 L
s
0 0 1 r
.56401 .45136 m
.57122 .44576 L
s
0 0 0 r
.45786 .57668 m
.4579 .57647 L
s
0 0 1 r
.49758 .45096 m
.49876 .45134 L
s
.71036 .44405 m
.71922 .45132 L
s
0 0 0 r
.45783 .57687 m
.45786 .57668 L
s
.46015 .64799 m
.46353 .64909 L
s
.45779 .57708 m
.45783 .57687 L
s
.45776 .57727 m
.45779 .57708 L
s
0 .766 0 r
.2198 .59013 m .2533 .55263 L .25601 .5814 L F
0 .807 0 r
.22549 .61889 m .2198 .59013 L .25601 .5814 L F
0 0 0 r
.45773 .57745 m
.45776 .57727 L
s
0 0 1 r
.49289 .45119 m
.49307 .45098 L
s
0 0 0 r
.45769 .57766 m
.45773 .57745 L
s
.45765 .57788 m
.45769 .57766 L
s
.45908 .58301 m
.45959 .58315 L
s
.45762 .57809 m
.45765 .57788 L
s
.45759 .65598 m
.4609 .65705 L
s
.45758 .57829 m
.45762 .57809 L
s
.46211 .62939 m
.46538 .63043 L
s
.45754 .57851 m
.45758 .57829 L
s
0 0 1 r
.49307 .45098 m
.49324 .45078 L
s
0 0 0 r
.45751 .57872 m
.45754 .57851 L
s
.4586 .58287 m
.45908 .58301 L
s
0 0 1 r
.49692 .45076 m
.49758 .45096 L
s
0 0 0 r
.45748 .57891 m
.45751 .57872 L
s
.45744 .57911 m
.45748 .57891 L
s
.45535 .59056 m
.45747 .57892 L
s
.4574 .57934 m
.45744 .57911 L
s
.45736 .57957 m
.4574 .57934 L
s
.45816 .58275 m
.4586 .58287 L
s
.45733 .57977 m
.45736 .57957 L
s
0 0 1 r
.49324 .45078 m
.4934 .45059 L
s
.49629 .45056 m
.49692 .45076 L
s
0 0 0 r
.45729 .57999 m
.45733 .57977 L
s
.46002 .59559 m
.46197 .59616 L
s
.46081 .61854 m
.46468 .61974 L
s
.45725 .58022 m
.45729 .57999 L
s
.45776 .58264 m
.45816 .58275 L
s
.45721 .58044 m
.45725 .58022 L
s
.46266 .6181 m
.46408 .61237 L
s
.45719 .58055 m
.45721 .58044 L
s
.45717 .58067 m
.45719 .58055 L
s
0 0 1 r
.4934 .45059 m
.49356 .45041 L
s
0 0 0 r
.45714 .5808 m
.45717 .58067 L
s
.45712 .58092 m
.45714 .5808 L
s
0 0 1 r
.49572 .45039 m
.49629 .45056 L
s
0 0 0 r
.45754 .58258 m
.45776 .58264 L
s
.45708 .58115 m
.45712 .58092 L
s
.45705 .58135 m
.45708 .58115 L
s
.46153 .60771 m
.4633 .60824 L
s
.4573 .58251 m
.45754 .58258 L
s
.45701 .58157 m
.45705 .58135 L
s
.45955 .63847 m
.46275 .63948 L
s
.45697 .58181 m
.45701 .58157 L
s
.45709 .58245 m
.4573 .58251 L
s
0 0 1 r
.49356 .45041 m
.4937 .45024 L
s
0 0 0 r
.45693 .58201 m
.45697 .58181 L
s
0 0 1 r
.4952 .45023 m
.49572 .45039 L
s
0 0 0 r
.45686 .58239 m
.45709 .58245 L
s
.45689 .58222 m
.45693 .58201 L
s
.45686 .58242 m
.45689 .58222 L
s
.45682 .5826 m
.45686 .58242 L
s
.45679 .58281 m
.45682 .5826 L
s
0 0 1 r
.4937 .45024 m
.49386 .45005 L
s
.4949 .45014 m
.4952 .45023 L
s
0 0 0 r
.45675 .58304 m
.45679 .58281 L
s
.45671 .58326 m
.45675 .58304 L
s
.45667 .58345 m
.45671 .58326 L
s
0 .999 0 r
.41295 .61013 m .45506 .58916 L .44902 .61797 L F
.41295 .61013 m .41713 .58073 L .45506 .58916 L F
0 0 1 r
.49459 .45004 m
.4949 .45014 L
s
0 0 0 r
.45663 .58367 m
.45667 .58345 L
s
.45916 .59534 m
.46002 .59559 L
s
0 0 1 r
.54 .4501 m
.54687 .44403 L
s
.51617 .4501 m
.52262 .44358 L
s
0 0 0 r
.45659 .5839 m
.45663 .58367 L
s
0 0 1 r
.49386 .45005 m
.49402 .44987 L
s
0 0 0 r
.45702 .647 m
.46015 .64799 L
s
0 0 1 r
.49432 .44996 m
.49459 .45004 L
s
0 0 0 r
.45655 .58411 m
.45659 .5839 L
s
.46116 .62399 m
.46266 .6181 L
s
.45652 .58431 m
.45655 .58411 L
s
0 0 1 r
.62445 .44405 m
.63444 .44998 L
s
0 0 0 r
.45647 .58454 m
.45652 .58431 L
s
0 0 1 r
.49402 .44987 m
.49432 .44996 L
s
0 0 0 r
.45645 .58466 m
.45647 .58454 L
s
.45959 .60713 m
.46153 .60771 L
s
.45643 .58478 m
.45645 .58466 L
s
.45639 .585 m
.45643 .58478 L
s
.45832 .62823 m
.46211 .62939 L
s
0 0 1 r
.49402 .44987 m
.49419 .44967 L
s
0 0 0 r
.45637 .58512 m
.45639 .585 L
s
.45452 .65503 m
.45759 .65598 L
s
.45824 .59508 m
.45916 .59534 L
s
.45635 .58524 m
.45637 .58512 L
s
0 0 1 r
.78994 .44983 m
.801 .44563 L
s
0 0 0 r
.45632 .58536 m
.45635 .58524 L
s
.4563 .58548 m
.45632 .58536 L
s
.45626 .5857 m
.4563 .58548 L
s
.45624 .58583 m
.45626 .5857 L
s
0 .914 0 r
.25155 .70378 m .2711 .66946 L .2782 .69791 L F
.25155 .70378 m .24148 .67614 L .2711 .66946 L F
0 0 0 r
.45622 .58594 m
.45624 .58583 L
s
.45619 .58607 m
.45622 .58594 L
s
.45617 .5862 m
.45619 .58607 L
s
0 0 1 r
.49419 .44967 m
.49437 .44946 L
s
.52964 .44767 m
.53488 .44967 L
s
0 0 0 r
.45615 .58632 m
.45617 .5862 L
s
.45612 .58645 m
.45615 .58632 L
s
.4561 .58657 m
.45612 .58645 L
s
.45608 .58668 m
.4561 .58657 L
s
.45604 .58689 m
.45608 .58668 L
s
.45735 .59483 m
.45824 .59508 L
s
.456 .58711 m
.45604 .58689 L
s
.45596 .58731 m
.456 .58711 L
s
.4597 .62945 m
.46116 .62399 L
s
.45592 .58754 m
.45596 .58731 L
s
0 0 1 r
.49437 .44946 m
.49452 .44928 L
s
0 0 0 r
.45588 .58776 m
.45592 .58754 L
s
.45584 .58796 m
.45588 .58776 L
s
.45908 .61802 m
.46081 .61854 L
s
.45581 .58815 m
.45584 .58796 L
s
.45577 .58833 m
.45581 .58815 L
s
.45573 .58854 m
.45577 .58833 L
s
.45583 .63734 m
.45955 .63847 L
s
.4557 .58873 m
.45573 .58854 L
s
0 0 1 r
.49452 .44928 m
.49469 .44908 L
s
0 0 0 r
.45767 .60658 m
.45959 .60713 L
s
.45685 .59469 m
.45735 .59483 L
s
.45566 .58894 m
.4557 .58873 L
s
.45562 .58916 m
.45566 .58894 L
s
.45558 .58935 m
.45562 .58916 L
s
.45554 .58956 m
.45558 .58935 L
s
.4555 .58979 m
.45554 .58956 L
s
.45638 .59456 m
.45685 .59469 L
s
.45547 .58991 m
.4555 .58979 L
s
0 0 1 r
.49469 .44908 m
.49487 .44887 L
s
0 0 0 r
.45545 .59003 m
.45547 .58991 L
s
.45541 .59025 m
.45545 .59003 L
s
.45816 .63505 m
.4597 .62945 L
s
.45537 .59046 m
.45541 .59025 L
s
.45534 .59064 m
.45537 .59046 L
s
.45595 .59444 m
.45638 .59456 L
s
.45301 .60228 m
.45535 .59056 L
s
.4553 .59083 m
.45534 .59064 L
s
0 1 0 r
.39611 .69745 m .43338 .67539 L .42401 .70312 L F
.38936 .7248 m .39611 .69745 L .42401 .70312 L F
0 0 0 r
.41925 .71749 m
.42335 .70656 L
s
.45526 .59104 m
.4553 .59083 L
s
.45337 .6459 m
.45702 .647 L
s
.45522 .59123 m
.45526 .59104 L
s
0 0 1 r
.49487 .44887 m
.49498 .44875 L
s
0 0 0 r
.45519 .59141 m
.45522 .59123 L
s
.45516 .59157 m
.45519 .59141 L
s
.45555 .59433 m
.45595 .59444 L
s
.45512 .59175 m
.45516 .59157 L
s
.45717 .61746 m
.45908 .61802 L
s
.45508 .59194 m
.45512 .59175 L
s
.45505 .59214 m
.45508 .59194 L
s
0 0 1 r
.69867 .44876 m
.70806 .44422 L
s
.49498 .44875 m
.49507 .44864 L
s
0 0 0 r
.45095 .65396 m
.45452 .65503 L
s
.45501 .59234 m
.45505 .59214 L
s
.45533 .59427 m
.45555 .59433 L
s
.45497 .59254 m
.45501 .59234 L
s
.45669 .64025 m
.45816 .63505 L
s
.45494 .59271 m
.45497 .59254 L
s
.45683 .60634 m
.45767 .60658 L
s
.4551 .5942 m
.45533 .59427 L
s
.4549 .59292 m
.45494 .59271 L
s
0 0 1 r
.49507 .44864 m
.49525 .44843 L
s
0 0 0 r
.45487 .59303 m
.4549 .59292 L
s
.45485 .59314 m
.45487 .59303 L
s
.45481 .59334 m
.45485 .59314 L
s
.45489 .59415 m
.4551 .5942 L
s
.45662 .62772 m
.45832 .62823 L
s
.45477 .59355 m
.45481 .59334 L
s
.45473 .59375 m
.45477 .59355 L
s
.45467 .59409 m
.45489 .59415 L
s
.45469 .59397 m
.45473 .59375 L
s
.45465 .59418 m
.45469 .59397 L
s
.45461 .59437 m
.45465 .59418 L
s
0 0 1 r
.49525 .44843 m
.49542 .44823 L
s
0 0 0 r
.42335 .70656 m
.42732 .69543 L
s
.45528 .64508 m
.45669 .64025 L
s
.45457 .59456 m
.45461 .59437 L
s
.45592 .60608 m
.45683 .60634 L
s
.45454 .59474 m
.45457 .59456 L
s
0 .973 0 r
.28615 .72519 m .30684 .69425 L .31124 .72205 L F
.28615 .72519 m .2782 .69791 L .30684 .69425 L F
0 0 0 r
.4545 .59493 m
.45454 .59474 L
s
.45446 .59512 m
.4545 .59493 L
s
.45442 .59533 m
.45446 .59512 L
s
.45438 .59554 m
.45442 .59533 L
s
.45434 .59573 m
.45438 .59554 L
s
0 0 1 r
.49542 .44823 m
.49556 .44806 L
s
0 0 0 r
.45379 .65003 m
.45528 .64508 L
s
.4543 .59593 m
.45434 .59573 L
s
0 0 1 r
.59623 .4482 m
.60425 .44269 L
s
0 0 0 r
.45426 .59615 m
.4543 .59593 L
s
.45529 .61692 m
.45717 .61746 L
s
0 0 1 r
.74368 .44816 m
.75443 .44355 L
s
0 0 0 r
.45424 .59627 m
.45426 .59615 L
s
.45421 .59638 m
.45424 .59627 L
s
0 0 1 r
.59057 .443 m
.60061 .44813 L
s
0 0 0 r
.45417 .59659 m
.45421 .59638 L
s
.45505 .60584 m
.45592 .60608 L
s
.45413 .5968 m
.45417 .59659 L
s
.45244 .6544 m
.45379 .65003 L
s
.45409 .59697 m
.45413 .5968 L
s
0 0 1 r
.49556 .44806 m
.49573 .44787 L
s
0 0 0 r
.45406 .59716 m
.45409 .59697 L
s
.45402 .59736 m
.45406 .59716 L
s
.45416 .63685 m
.45583 .63734 L
s
.45398 .59755 m
.45402 .59736 L
s
.45475 .62718 m
.45662 .62772 L
s
.45394 .59772 m
.45398 .59755 L
s
.45391 .59788 m
.45394 .59772 L
s
.45388 .59806 m
.45391 .59788 L
s
.45384 .59824 m
.45388 .59806 L
s
0 1 0 r
.3636 .72186 m .39611 .69745 L .38936 .7248 L F
0 0 1 r
.55701 .44354 m
.56697 .44789 L
s
0 0 0 r
.4538 .59842 m
.45384 .59824 L
s
0 0 1 r
.49573 .44787 m
.49589 .44768 L
s
0 0 0 r
.45376 .59862 m
.4538 .59842 L
s
.45456 .6057 m
.45505 .60584 L
s
.45372 .59881 m
.45376 .59862 L
s
0 0 1 r
.80839 .43875 m
.81649 .44781 L
s
0 0 0 r
.45369 .59898 m
.45372 .59881 L
s
.45365 .59918 m
.45369 .59898 L
s
.45363 .59929 m
.45365 .59918 L
s
.4536 .5994 m
.45363 .59929 L
s
0 .807 0 r
.22549 .61889 m .25601 .5814 L .25992 .61076 L F
0 .844 0 r
.23276 .6477 m .22549 .61889 L .25992 .61076 L F
0 0 0 r
.45357 .59959 m
.4536 .5994 L
s
.45352 .59979 m
.45357 .59959 L
s
.45409 .60557 m
.45456 .6057 L
s
0 0 1 r
.49589 .44768 m
.49605 .44749 L
s
.52478 .44589 m
.52964 .44767 L
s
0 0 0 r
.45348 .59999 m
.45352 .59979 L
s
0 .819 0 r
.29386 .54686 m .29333 .51884 L .33663 .51668 L F
0 .773 0 r
.2533 .55263 m .29333 .51884 L .29386 .54686 L F
0 0 0 r
.45174 .64543 m
.45337 .6459 L
s
.45346 .6001 m
.45348 .59999 L
s
.45344 .6002 m
.45346 .6001 L
s
.4534 .60039 m
.45344 .6002 L
s
.45336 .60059 m
.4534 .60039 L
s
.45332 .60077 m
.45336 .60059 L
s
.45446 .61669 m
.45529 .61692 L
s
.45329 .60094 m
.45332 .60077 L
s
.45367 .60546 m
.45409 .60557 L
s
.45325 .60112 m
.45329 .60094 L
s
.44935 .65349 m
.45095 .65396 L
s
.45321 .60132 m
.45325 .60112 L
s
0 0 1 r
.49605 .44749 m
.4962 .44732 L
s
0 0 0 r
.45317 .60151 m
.45321 .60132 L
s
.45315 .60163 m
.45317 .60151 L
s
.45312 .60173 m
.45315 .60163 L
s
.45233 .63632 m
.45416 .63685 L
s
.45308 .60194 m
.45312 .60173 L
s
.45329 .60535 m
.45367 .60546 L
s
.45306 .60206 m
.45308 .60194 L
s
.45303 .60217 m
.45306 .60206 L
s
.45299 .60236 m
.45303 .60217 L
s
.4529 .62665 m
.45475 .62718 L
s
.45046 .61405 m
.45301 .60228 L
s
.45295 .60256 m
.45299 .60236 L
s
.45291 .60276 m
.45295 .60256 L
s
0 0 1 r
.4962 .44732 m
.49633 .44716 L
s
0 0 0 r
.45287 .60294 m
.45291 .60276 L
s
.45358 .61644 m
.45446 .61669 L
s
.45307 .60529 m
.45329 .60535 L
s
.45284 .60311 m
.45287 .60294 L
s
0 .862 0 r
.33615 .54478 m .38031 .51846 L .37882 .54649 L F
.33615 .54478 m .33663 .51668 L .38031 .51846 L F
0 0 1 r
.64962 .44104 m
.65926 .44726 L
s
0 0 0 r
.4528 .60329 m
.45284 .60311 L
s
.45276 .60346 m
.4528 .60329 L
s
.45284 .60523 m
.45307 .60529 L
s
.45273 .60361 m
.45276 .60346 L
s
.45269 .6038 m
.45273 .60361 L
s
.45265 .60399 m
.45269 .6038 L
s
0 0 1 r
.49633 .44716 m
.49648 .44699 L
s
0 0 0 r
.45261 .60418 m
.45265 .60399 L
s
.45264 .60517 m
.45284 .60523 L
s
.45258 .60435 m
.45261 .60418 L
s
.45254 .60455 m
.45258 .60435 L
s
.44994 .64491 m
.45174 .64543 L
s
.45242 .60511 m
.45264 .60517 L
s
.4525 .60473 m
.45254 .60455 L
s
0 0 1 r
.66343 .44708 m
.67304 .44186 L
s
0 0 0 r
.45246 .60489 m
.4525 .60473 L
s
.45242 .60507 m
.45246 .60489 L
s
.45238 .60527 m
.45242 .60507 L
s
.45272 .6162 m
.45358 .61644 L
s
.45234 .60547 m
.45238 .60527 L
s
0 0 1 r
.49648 .44699 m
.49663 .44681 L
s
0 0 0 r
.4523 .60564 m
.45234 .60547 L
s
0 .88 0 r
.24148 .67614 m .26498 .64026 L .2711 .66946 L F
.24148 .67614 m .23276 .6477 L .26498 .64026 L F
0 0 0 r
.44759 .65299 m
.44935 .65349 L
s
.45226 .60584 m
.4523 .60564 L
s
.45222 .60604 m
.45226 .60584 L
s
0 0 1 r
.6292 .44693 m
.63802 .44154 L
s
0 0 0 r
.45218 .60623 m
.45222 .60604 L
s
.45216 .60633 m
.45218 .60623 L
s
.45213 .60644 m
.45216 .60633 L
s
.45211 .60655 m
.45213 .60644 L
s
.45209 .60666 m
.45211 .60655 L
s
.45204 .60685 m
.45209 .60666 L
s
.45053 .63581 m
.45233 .63632 L
s
.45201 .60703 m
.45204 .60685 L
s
0 0 1 r
.49663 .44681 m
.49679 .44662 L
s
0 0 0 r
.45196 .60722 m
.45201 .60703 L
s
.45192 .60743 m
.45196 .60722 L
s
0 .813 0 r
.25601 .5814 m .2533 .55263 L .29386 .54686 L F
0 0 0 r
.45209 .62643 m
.4529 .62665 L
s
.45188 .6076 m
.45192 .60743 L
s
.45224 .61607 m
.45272 .6162 L
s
.45184 .60779 m
.45188 .6076 L
s
.45181 .60796 m
.45184 .60779 L
s
.45177 .60812 m
.45181 .60796 L
s
0 1 0 r
.408 .63969 m .44902 .61797 L .44175 .64686 L F
.408 .63969 m .41295 .61013 L .44902 .61797 L F
0 0 0 r
.45173 .6083 m
.45177 .60812 L
s
.45169 .60851 m
.45173 .6083 L
s
.45165 .6087 m
.45169 .60851 L
s
.45161 .60887 m
.45165 .6087 L
s
0 0 1 r
.49679 .44662 m
.49696 .44643 L
s
0 0 0 r
.45157 .60906 m
.45161 .60887 L
s
.45178 .61594 m
.45224 .61607 L
s
.45152 .60925 m
.45157 .60906 L
s
.45148 .60944 m
.45152 .60925 L
s
.45145 .60961 m
.45148 .60944 L
s
.4514 .60981 m
.45145 .60961 L
s
.44817 .64441 m
.44994 .64491 L
s
.45122 .62618 m
.45209 .62643 L
s
.45138 .60993 m
.4514 .60981 L
s
.45135 .61003 m
.45138 .60993 L
s
.45131 .61022 m
.45135 .61003 L
s
.45129 .61032 m
.45131 .61022 L
s
.45137 .61583 m
.45178 .61594 L
s
.45127 .61043 m
.45129 .61032 L
s
.45124 .61053 m
.45127 .61043 L
s
.45122 .61064 m
.45124 .61053 L
s
0 0 1 r
.49696 .44643 m
.49712 .44624 L
s
0 0 0 r
.45118 .61083 m
.45122 .61064 L
s
.45115 .61094 m
.45118 .61083 L
s
.45113 .61104 m
.45115 .61094 L
s
.44586 .6525 m
.44759 .65299 L
s
.45111 .61115 m
.45113 .61104 L
s
.45108 .61127 m
.45111 .61115 L
s
.45106 .61137 m
.45108 .61127 L
s
.45103 .61148 m
.45106 .61137 L
s
.45101 .61159 m
.45103 .61148 L
s
.45099 .61573 m
.45137 .61583 L
s
.45099 .61169 m
.45101 .61159 L
s
.45095 .61187 m
.45099 .61169 L
s
0 .844 0 r
.23276 .6477 m .25992 .61076 L .26498 .64026 L F
0 0 0 r
.45091 .61206 m
.45095 .61187 L
s
.45087 .61224 m
.45091 .61206 L
s
.45082 .61244 m
.45087 .61224 L
s
.44973 .63559 m
.45053 .63581 L
s
.45078 .61263 m
.45082 .61244 L
s
.45038 .62595 m
.45122 .62618 L
s
0 0 1 r
.49712 .44624 m
.49727 .44607 L
s
0 0 0 r
.45074 .6128 m
.45078 .61263 L
s
.45077 .61567 m
.45099 .61573 L
s
.4507 .61297 m
.45074 .6128 L
s
.45067 .61313 m
.4507 .61297 L
s
.45063 .61331 m
.45067 .61313 L
s
.45059 .61348 m
.45063 .61331 L
s
.45055 .61561 m
.45077 .61567 L
s
.45055 .61366 m
.45059 .61348 L
s
.45051 .61386 m
.45055 .61366 L
s
.45047 .61402 m
.45051 .61386 L
s
.45043 .61421 m
.45047 .61402 L
s
0 1 0 r
.40236 .66894 m .44175 .64686 L .43338 .67539 L F
.39611 .69745 m .40236 .66894 L .43338 .67539 L F
0 0 0 r
.42732 .69543 m
.43114 .68412 L
s
.44771 .62585 m
.45046 .61405 L
s
.45035 .61555 m
.45055 .61561 L
s
.45038 .6144 m
.45043 .61421 L
s
0 0 1 r
.49727 .44607 m
.49744 .44587 L
s
0 0 0 r
.45036 .61451 m
.45038 .6144 L
s
.45034 .61461 m
.45036 .61451 L
s
.45029 .6148 m
.45034 .61461 L
s
.45014 .6155 m
.45035 .61555 L
s
.45025 .61499 m
.45029 .6148 L
s
0 .933 0 r
.37697 .57561 m .42047 .55191 L .41713 .58073 L F
.37697 .57561 m .37882 .54649 L .42047 .55191 L F
0 0 0 r
.45021 .61514 m
.45025 .61499 L
s
.44888 .63535 m
.44973 .63559 L
s
.45018 .61532 m
.45021 .61514 L
s
.44991 .62582 m
.45038 .62595 L
s
.45014 .6155 m
.45018 .61532 L
s
.4501 .61566 m
.45014 .6155 L
s
.4474 .6442 m
.44817 .64441 L
s
.45006 .61582 m
.4501 .61566 L
s
.45003 .61596 m
.45006 .61582 L
s
.44999 .61612 m
.45003 .61596 L
s
.44996 .61629 m
.44999 .61612 L
s
0 0 1 r
.51912 .4439 m
.52478 .44589 L
s
0 0 0 r
.44992 .61645 m
.44996 .61629 L
s
0 0 1 r
.78125 .43698 m
.79006 .44588 L
s
0 0 0 r
.44988 .61663 m
.44992 .61645 L
s
0 0 1 r
.49744 .44587 m
.49753 .44576 L
s
0 0 0 r
.44984 .6168 m
.44988 .61663 L
s
.4498 .61696 m
.44984 .6168 L
s
.44946 .6257 m
.44991 .62582 L
s
.44976 .61714 m
.4498 .61696 L
s
.4451 .65229 m
.44586 .6525 L
s
.44974 .61724 m
.44976 .61714 L
s
.44972 .61733 m
.44974 .61724 L
s
.44968 .6175 m
.44972 .61733 L
s
.44963 .61768 m
.44968 .6175 L
s
.44959 .61786 m
.44963 .61768 L
s
.43114 .68412 m
.4348 .67265 L
s
0 0 1 r
.57122 .44576 m
.57895 .43976 L
s
.49753 .44576 m
.49762 .44565 L
s
0 0 0 r
.44955 .61805 m
.44959 .61786 L
s
.44951 .61824 m
.44955 .61805 L
s
.44805 .63512 m
.44888 .63535 L
s
.44947 .6184 m
.44951 .61824 L
s
.44943 .61857 m
.44947 .6184 L
s
.44656 .64397 m
.4474 .6442 L
s
.4494 .61872 m
.44943 .61857 L
s
.44906 .62559 m
.44946 .6257 L
s
.44936 .61889 m
.4494 .61872 L
s
.44932 .61906 m
.44936 .61889 L
s
.44928 .61924 m
.44932 .61906 L
s
0 0 1 r
.49762 .44565 m
.49778 .44546 L
s
0 0 0 r
.44923 .61943 m
.44928 .61924 L
s
.44919 .61959 m
.44923 .61943 L
s
0 0 1 r
.801 .44563 m
.81116 .44176 L
s
0 0 0 r
.44915 .61976 m
.44919 .61959 L
s
.44911 .61995 m
.44915 .61976 L
s
.44428 .65207 m
.4451 .65229 L
s
.44908 .62006 m
.44911 .61995 L
s
.44906 .62015 m
.44908 .62006 L
s
.44868 .62549 m
.44906 .62559 L
s
.44902 .62034 m
.44906 .62015 L
s
.44898 .62052 m
.44902 .62034 L
s
.44894 .62067 m
.44898 .62052 L
s
.4489 .62084 m
.44894 .62067 L
s
.44886 .62101 m
.4489 .62084 L
s
.44882 .62117 m
.44886 .62101 L
s
.44879 .62132 m
.44882 .62117 L
s
.44875 .62146 m
.44879 .62132 L
s
.44759 .635 m
.44805 .63512 L
s
.44872 .62162 m
.44875 .62146 L
s
0 0 1 r
.49778 .44546 m
.49796 .44526 L
s
0 0 0 r
.44868 .62177 m
.44872 .62162 L
s
.44847 .62544 m
.44868 .62549 L
s
.44864 .62194 m
.44868 .62177 L
s
.44575 .64375 m
.44656 .64397 L
s
.4486 .62211 m
.44864 .62194 L
s
.44856 .62227 m
.4486 .62211 L
s
.44853 .62242 m
.44856 .62227 L
s
.44849 .6226 m
.44853 .62242 L
s
0 .819 0 r
.29386 .54686 m .33663 .51668 L .33615 .54478 L F
0 0 0 r
.44825 .62538 m
.44847 .62544 L
s
.44846 .6227 m
.44849 .6226 L
s
.44844 .62279 m
.44846 .6227 L
s
.4484 .62295 m
.44844 .62279 L
s
.44836 .62313 m
.4484 .62295 L
s
.44832 .6233 m
.44836 .62313 L
s
0 1 0 r
.40236 .66894 m .408 .63969 L .44175 .64686 L F
0 0 0 r
.4483 .6234 m
.44832 .6233 L
s
.44349 .65186 m
.44428 .65207 L
s
.44828 .62349 m
.4483 .6234 L
s
.44715 .63488 m
.44759 .635 L
s
.44806 .62532 m
.44825 .62538 L
s
.44824 .62365 m
.44828 .62349 L
s
.44819 .62382 m
.44824 .62365 L
s
.44816 .62398 m
.44819 .62382 L
s
.44812 .62413 m
.44816 .62398 L
s
.44808 .62429 m
.44812 .62413 L
s
.44804 .62446 m
.44808 .62429 L
s
.44785 .62527 m
.44806 .62532 L
s
0 0 1 r
.49796 .44526 m
.49812 .44507 L
s
0 0 0 r
.448 .62463 m
.44804 .62446 L
s
.44798 .62473 m
.448 .62463 L
s
.44796 .62482 m
.44798 .62473 L
s
.44791 .625 m
.44796 .62482 L
s
.44789 .6251 m
.44791 .625 L
s
.44787 .6252 m
.44789 .6251 L
s
.44782 .62536 m
.44787 .6252 L
s
.44778 .62555 m
.44782 .62536 L
s
.44676 .63477 m
.44715 .63488 L
s
.44774 .62572 m
.44778 .62555 L
s
.4453 .64363 m
.44575 .64375 L
s
.4477 .62587 m
.44774 .62572 L
s
.44476 .63763 m
.44771 .62585 L
s
.44767 .62602 m
.4477 .62587 L
s
.44763 .62618 m
.44767 .62602 L
s
.44759 .62632 m
.44763 .62618 L
s
.44756 .62646 m
.44759 .62632 L
s
.44752 .62662 m
.44756 .62646 L
s
.44748 .62679 m
.44752 .62662 L
s
.44744 .62695 m
.44748 .62679 L
s
.4474 .6271 m
.44744 .62695 L
s
.44736 .62727 m
.4474 .6271 L
s
.44304 .65174 m
.44349 .65186 L
s
.44732 .62743 m
.44736 .62727 L
s
.44639 .63468 m
.44676 .63477 L
s
.44729 .62757 m
.44732 .62743 L
s
0 0 1 r
.49812 .44507 m
.49831 .44485 L
s
0 0 0 r
.44725 .62773 m
.44729 .62757 L
s
.44721 .6279 m
.44725 .62773 L
s
0 0 1 r
.67504 .43858 m
.68428 .44505 L
s
0 0 0 r
.44487 .64351 m
.4453 .64363 L
s
.44717 .62808 m
.44721 .6279 L
s
.44713 .62823 m
.44717 .62808 L
s
.44709 .62839 m
.44713 .62823 L
s
.44704 .62857 m
.44709 .62839 L
s
.447 .62874 m
.44704 .62857 L
s
.44698 .62882 m
.447 .62874 L
s
.44696 .62892 m
.44698 .62882 L
s
.44693 .62902 m
.44696 .62892 L
s
.44691 .62911 m
.44693 .62902 L
s
.44687 .62928 m
.44691 .62911 L
s
.44683 .62943 m
.44687 .62928 L
s
.44619 .63462 m
.44639 .63468 L
s
.44679 .6296 m
.44683 .62943 L
s
.4348 .67265 m
.4383 .66106 L
s
.44262 .65163 m
.44304 .65174 L
s
.44675 .62978 m
.44679 .6296 L
s
.44671 .62993 m
.44675 .62978 L
s
.44667 .63009 m
.44671 .62993 L
s
.44663 .63025 m
.44667 .63009 L
s
.44448 .64341 m
.44487 .64351 L
s
.4466 .63038 m
.44663 .63025 L
s
.44656 .63054 m
.4466 .63038 L
s
.44597 .63456 m
.44619 .63462 L
s
.44651 .63072 m
.44656 .63054 L
s
.44647 .63088 m
.44651 .63072 L
s
.44643 .63104 m
.44647 .63088 L
s
.44639 .6312 m
.44643 .63104 L
s
.44635 .63137 m
.44639 .6312 L
s
.44631 .63153 m
.44635 .63137 L
s
0 0 1 r
.49831 .44485 m
.49848 .44465 L
s
0 0 0 r
.44627 .63168 m
.44631 .63153 L
s
.44623 .63186 m
.44627 .63168 L
s
.44578 .63451 m
.44597 .63456 L
s
.4462 .63196 m
.44623 .63186 L
s
.44618 .63205 m
.4462 .63196 L
s
.44614 .63221 m
.44618 .63205 L
s
.44224 .65153 m
.44262 .65163 L
s
.44612 .63231 m
.44614 .63221 L
s
.44609 .63239 m
.44612 .63231 L
s
.44607 .63248 m
.44609 .63239 L
s
.44605 .63258 m
.44607 .63248 L
s
.44601 .63275 m
.44605 .63258 L
s
.44412 .64331 m
.44448 .64341 L
s
.44598 .63284 m
.44601 .63275 L
s
.44596 .63293 m
.44598 .63284 L
s
.44594 .63302 m
.44596 .63293 L
s
.44591 .63313 m
.44594 .63302 L
s
.44557 .63446 m
.44578 .63451 L
s
.44589 .63322 m
.44591 .63313 L
s
.44586 .63331 m
.44589 .63322 L
s
.44584 .6334 m
.44586 .63331 L
s
.44582 .63349 m
.44584 .6334 L
s
.44578 .63365 m
.44582 .63349 L
s
.44574 .63381 m
.44578 .63365 L
s
.4457 .63397 m
.44574 .63381 L
s
.44565 .63415 m
.4457 .63397 L
s
.44561 .63431 m
.44565 .63415 L
s
.44557 .63446 m
.44561 .63431 L
s
.44553 .63461 m
.44557 .63446 L
s
.4455 .63474 m
.44553 .63461 L
s
.44189 .65143 m
.44224 .65153 L
s
.44546 .6349 m
.4455 .63474 L
s
.44542 .63505 m
.44546 .6349 L
s
.44538 .63521 m
.44542 .63505 L
s
.44392 .64326 m
.44412 .64331 L
s
.44534 .63538 m
.44538 .63521 L
s
.4453 .63552 m
.44534 .63538 L
s
.44526 .63568 m
.4453 .63552 L
s
.44522 .63585 m
.44526 .63568 L
s
.44519 .63595 m
.44522 .63585 L
s
.44517 .63603 m
.44519 .63595 L
s
.44513 .6362 m
.44517 .63603 L
s
0 0 1 r
.49848 .44465 m
.49864 .44446 L
s
0 0 0 r
.44509 .63636 m
.44513 .6362 L
s
.44505 .6365 m
.44509 .63636 L
s
.44501 .63665 m
.44505 .6365 L
s
.44497 .6368 m
.44501 .63665 L
s
.44371 .6432 m
.44392 .64326 L
s
.44493 .63695 m
.44497 .6368 L
s
.4449 .63708 m
.44493 .63695 L
s
.44487 .63721 m
.4449 .63708 L
s
.44483 .63735 m
.44487 .63721 L
s
.4448 .63749 m
.44483 .63735 L
s
.44476 .63764 m
.4448 .63749 L
s
.4417 .65138 m
.44189 .65143 L
s
.44162 .64938 m
.44476 .63763 L
s
.44472 .63779 m
.44476 .63764 L
s
.44468 .63794 m
.44472 .63779 L
s
.44464 .63807 m
.44468 .63794 L
s
.4446 .63823 m
.44464 .63807 L
s
.44458 .63832 m
.4446 .63823 L
s
.44456 .6384 m
.44458 .63832 L
s
.44452 .63855 m
.44456 .6384 L
s
.44448 .63871 m
.44452 .63855 L
s
.44353 .64315 m
.44371 .6432 L
s
.44444 .63886 m
.44448 .63871 L
s
.4444 .63903 m
.44444 .63886 L
s
0 .999 0 r
.31124 .72205 m .33664 .69294 L .33731 .72093 L F
.31124 .72205 m .30684 .69425 L .33664 .69294 L F
0 0 0 r
.44435 .63919 m
.4444 .63903 L
s
.44432 .63933 m
.44435 .63919 L
s
.44428 .63948 m
.44432 .63933 L
s
.44149 .65133 m
.4417 .65138 L
s
.44424 .63961 m
.44428 .63948 L
s
.4442 .63976 m
.44424 .63961 L
s
.44417 .6399 m
.4442 .63976 L
s
.44413 .64006 m
.44417 .6399 L
s
.44408 .64022 m
.44413 .64006 L
s
.44405 .64036 m
.44408 .64022 L
s
.44401 .64051 m
.44405 .64036 L
s
.44396 .64068 m
.44401 .64051 L
s
.44332 .6431 m
.44353 .64315 L
s
.44394 .64077 m
.44396 .64068 L
s
.44392 .64086 m
.44394 .64077 L
s
.44387 .64102 m
.44392 .64086 L
s
.44383 .64117 m
.44387 .64102 L
s
.4438 .6413 m
.44383 .64117 L
s
.44376 .64145 m
.4438 .6413 L
s
.4383 .66106 m
.44162 .64938 L
s
.44372 .6416 m
.44376 .64145 L
s
.44368 .64174 m
.44372 .6416 L
s
.44131 .65128 m
.44149 .65133 L
s
.44365 .64187 m
.44368 .64174 L
s
.44362 .64199 m
.44365 .64187 L
s
.44358 .64213 m
.44362 .64199 L
s
.44354 .64226 m
.44358 .64213 L
s
.44351 .64241 m
.44354 .64226 L
s
0 0 1 r
.49864 .44446 m
.49879 .44429 L
s
0 0 0 r
.44347 .64256 m
.44351 .64241 L
s
.44343 .6427 m
.44347 .64256 L
s
0 0 1 r
.75386 .43576 m
.76336 .44445 L
s
0 0 0 r
.44339 .64283 m
.44343 .6427 L
s
.44335 .64298 m
.44339 .64283 L
s
.44333 .64307 m
.44335 .64298 L
s
.44331 .64314 m
.44333 .64307 L
s
.44327 .64329 m
.44331 .64314 L
s
.44323 .64344 m
.44327 .64329 L
s
.44319 .64359 m
.44323 .64344 L
s
.44317 .64367 m
.44319 .64359 L
s
.44315 .64375 m
.44317 .64367 L
s
.44311 .6439 m
.44315 .64375 L
s
.44307 .64405 m
.44311 .6439 L
s
.44303 .64418 m
.44307 .64405 L
s
.443 .64431 m
.44303 .64418 L
s
.44296 .64445 m
.443 .64431 L
s
.44111 .65123 m
.44131 .65128 L
s
.44292 .6446 m
.44296 .64445 L
s
.44288 .64475 m
.44292 .6446 L
s
.44286 .64483 m
.44288 .64475 L
s
.44284 .64491 m
.44286 .64483 L
s
.44279 .64507 m
.44284 .64491 L
s
.44277 .64516 m
.44279 .64507 L
s
.44275 .64524 m
.44277 .64516 L
s
.44271 .64539 m
.44275 .64524 L
s
.44267 .64554 m
.44271 .64539 L
s
.44263 .64569 m
.44267 .64554 L
s
.44259 .64583 m
.44263 .64569 L
s
.44255 .64596 m
.44259 .64583 L
s
.44252 .64609 m
.44255 .64596 L
s
.44248 .64622 m
.44252 .64609 L
s
.44245 .64634 m
.44248 .64622 L
s
.44241 .64648 m
.44245 .64634 L
s
.44237 .64663 m
.44241 .64648 L
s
.44233 .64677 m
.44237 .64663 L
s
.4423 .6469 m
.44233 .64677 L
s
.4423 .6469 m
.44226 .64705 L
s
.44226 .64705 m
.44222 .64718 L
s
.44222 .64718 m
.44219 .64731 L
s
.44219 .64731 m
.44215 .64744 L
s
.44215 .64744 m
.44211 .64759 L
s
.44211 .64759 m
.44207 .64775 L
s
.44207 .64775 m
.44203 .64788 L
s
.44203 .64788 m
.44199 .64802 L
s
.44199 .64802 m
.44196 .64813 L
s
.44196 .64813 m
.44194 .64822 L
s
.44194 .64822 m
.44191 .64833 L
s
.44191 .64833 m
.44188 .64844 L
s
.44188 .64844 m
.44185 .64854 L
s
.44185 .64854 m
.44182 .64863 L
s
.44182 .64863 m
.4418 .64873 L
s
.4418 .64873 m
.44177 .64884 L
s
.44174 .64893 m
.44177 .64884 L
s
.44172 .64903 m
.44174 .64893 L
s
.44169 .64913 m
.44172 .64903 L
s
.44166 .64923 m
.44169 .64913 L
s
.44164 .64932 m
.44166 .64923 L
s
.44161 .6494 m
.44164 .64932 L
s
.44159 .64949 m
.44161 .6494 L
s
.44156 .64958 m
.44159 .64949 L
s
.44154 .64967 m
.44156 .64958 L
s
.44151 .64978 m
.44154 .64967 L
s
.44148 .64989 m
.44151 .64978 L
s
.44145 .64999 m
.44148 .64989 L
s
.44142 .65009 m
.44145 .64999 L
s
.4414 .65018 m
.44142 .65009 L
s
.44137 .65028 m
.4414 .65018 L
s
.44134 .65037 m
.44137 .65028 L
s
.44132 .65048 m
.44134 .65037 L
s
.44128 .65059 m
.44132 .65048 L
s
.44126 .65069 m
.44128 .65059 L
s
.44123 .65078 m
.44126 .65069 L
s
.4412 .65089 m
.44123 .65078 L
s
.44117 .65101 m
.4412 .65089 L
s
.44113 .65112 m
.44117 .65101 L
s
.44111 .65123 m
.44113 .65112 L
s
0 1 0 r
.3636 .72186 m .3667 .69402 L .39611 .69745 L F
.33731 .72093 m .3667 .69402 L .3636 .72186 L F
0 0 1 r
.49879 .44429 m
.49895 .4441 L
s
.70806 .44422 m
.71811 .43936 L
s
.49895 .4441 m
.49911 .44391 L
s
.70063 .43663 m
.71036 .44405 L
s
.61466 .43863 m
.62445 .44405 L
s
.54687 .44403 m
.55353 .43815 L
s
.49911 .44391 m
.49927 .44373 L
s
.51658 .44303 m
.51912 .4439 L
s
.49927 .44373 m
.49944 .44352 L
s
.72726 .43593 m
.73645 .44358 L
s
.52262 .44358 m
.52888 .43725 L
s
.75443 .44355 m
.76485 .43908 L
s
.54636 .43921 m
.55701 .44354 L
s
.49944 .44352 m
.49962 .44331 L
s
.49962 .44331 m
.49978 .44313 L
s
0 1 0 r
.33731 .72093 m .33664 .69294 L .3667 .69402 L F
0 0 1 r
.49978 .44313 m
.49995 .44293 L
s
.51379 .4421 m
.51658 .44303 L
s
.57976 .43787 m
.59057 .443 L
s
.49995 .44293 m
.50013 .44272 L
s
.50013 .44272 m
.50023 .4426 L
s
0 .943 0 r
.2782 .69791 m .30297 .6653 L .30684 .69425 L F
.2782 .69791 m .2711 .66946 L .30297 .6653 L F
0 0 1 r
.60425 .44269 m
.61202 .43735 L
s
.50023 .4426 m
.50033 .44249 L
s
.50033 .44249 m
.50051 .44227 L
s
.50051 .44227 m
.50068 .44207 L
s
0 1 0 r
.3667 .69402 m .40236 .66894 L .39611 .69745 L F
0 0 1 r
.51104 .4412 m
.51379 .4421 L
s
.50068 .44207 m
.50083 .4419 L
s
.50083 .4419 m
.50099 .44171 L
s
.67304 .44186 m
.68235 .4368 L
s
.50099 .44171 m
.50116 .44151 L
s
0 .813 0 r
.25601 .5814 m .29386 .54686 L .29511 .57595 L F
0 .848 0 r
.25992 .61076 m .25601 .5814 L .29511 .57595 L F
0 0 1 r
.63802 .44154 m
.64657 .43632 L
s
.50116 .44151 m
.50132 .44133 L
s
.50132 .44133 m
.50147 .44115 L
s
.50982 .4408 m
.51104 .4412 L
s
.50147 .44115 m
.5016 .441 L
s
.63915 .43476 m
.64962 .44104 L
s
.5016 .441 m
.50176 .44081 L
s
0 .961 0 r
.3748 .60537 m .41713 .58073 L .41295 .61013 L F
.3748 .60537 m .37697 .57561 L .41713 .58073 L F
0 0 1 r
.50176 .44081 m
.50191 .44064 L
s
.50852 .44039 m
.50982 .4408 L
s
.50191 .44064 m
.50207 .44045 L
s
0 .855 0 r
.29511 .57595 m .29386 .54686 L .33615 .54478 L F
0 0 1 r
.50207 .44045 m
.50224 .44025 L
s
.50726 .43999 m
.50852 .44039 L
s
.50224 .44025 m
.5024 .44006 L
s
0 .895 0 r
.33586 .57399 m .37882 .54649 L .37697 .57561 L F
.33586 .57399 m .33615 .54478 L .37882 .54649 L F
0 0 1 r
.5024 .44006 m
.50254 .43989 L
s
.50655 .43977 m
.50726 .43999 L
s
.50254 .43989 m
.50272 .43969 L
s
.50589 .43956 m
.50655 .43977 L
s
.57895 .43976 m
.58645 .43393 L
s
.50272 .43969 m
.50281 .43958 L
s
.50281 .43958 m
.5029 .43947 L
s
.50528 .43937 m
.50589 .43956 L
s
.5029 .43947 m
.50307 .43928 L
s
.50472 .4392 m
.50528 .43937 L
s
.71811 .43936 m
.72784 .43466 L
s
.50307 .43928 m
.50324 .43908 L
s
.54082 .43708 m
.54636 .43921 L
s
.50441 .4391 m
.50472 .4392 L
s
0 .913 0 r
.2711 .66946 m .2997 .63563 L .30297 .6653 L F
.2711 .66946 m .26498 .64026 L .2997 .63563 L F
0 0 1 r
.50408 .439 m
.50441 .4391 L
s
.50324 .43908 m
.50341 .43888 L
s
.76485 .43908 m
.77494 .43475 L
s
.50379 .43891 m
.50408 .439 L
s
.50347 .43881 m
.50379 .43891 L
s
.50341 .43888 m
.50351 .43877 L
s
.50351 .43877 m
.5036 .43866 L
s
.79932 .42943 m
.80839 .43875 L
s
.5036 .43866 m
.50376 .43847 L
s
.6041 .43318 m
.61466 .43863 L
s
0 .848 0 r
.25992 .61076 m .29511 .57595 L .29706 .60569 L F
0 .882 0 r
.26498 .64026 m .25992 .61076 L .29706 .60569 L F
0 0 1 r
.66497 .43201 m
.67504 .43858 L
s
0 1 0 r
.36963 .66503 m .408 .63969 L .40236 .66894 L F
.3667 .69402 m .36963 .66503 L .40236 .66894 L F
0 0 1 r
.50376 .43847 m
.50394 .43827 L
s
0 .855 0 r
.29511 .57595 m .33615 .54478 L .33586 .57399 L F
0 .973 0 r
.30684 .69425 m .33615 .6638 L .33664 .69294 L F
.30684 .69425 m .30297 .6653 L .33615 .6638 L F
0 0 1 r
.50394 .43827 m
.50409 .43809 L
s
.55353 .43815 m
.56067 .43185 L
s
.50409 .43809 m
.50424 .43792 L
s
0 1 0 r
.33664 .69294 m .36963 .66503 L .3667 .69402 L F
0 0 1 r
.50424 .43792 m
.5044 .43773 L
s
0 .986 0 r
.37234 .63533 m .41295 .61013 L .408 .63969 L F
.37234 .63533 m .3748 .60537 L .41295 .61013 L F
0 0 1 r
.56926 .43323 m
.57976 .43787 L
s
0 .882 0 r
.26498 .64026 m .29706 .60569 L .2997 .63563 L F
0 0 1 r
.5044 .43773 m
.50457 .43753 L
s
.50457 .43753 m
.50474 .43732 L
s
.61202 .43735 m
.62035 .43162 L
s
.50474 .43732 m
.50484 .43721 L
s
.52888 .43725 m
.53495 .43111 L
s
.50484 .43721 m
.50493 .4371 L
s
.50493 .4371 m
.50512 .43689 L
s
0 1 0 r
.36963 .66503 m .37234 .63533 L .408 .63969 L F
0 0 1 r
.53567 .43518 m
.54082 .43708 L
s
.77144 .42787 m
.78125 .43698 L
s
.50512 .43689 m
.50522 .43677 L
s
.68235 .4368 m
.69137 .43191 L
s
.50522 .43677 m
.50531 .43666 L
s
0 1 0 r
.33664 .69294 m .33615 .6638 L .36963 .66503 L F
0 0 1 r
.50531 .43666 m
.50548 .43646 L
s
.69101 .4298 m
.70063 .43663 L
s
.50548 .43646 m
.50566 .43625 L
s
.64657 .43632 m
.65572 .43073 L
s
.50566 .43625 m
.50584 .43604 L
s
.50584 .43604 m
.50599 .43586 L
s
.71716 .42811 m
.72726 .43593 L
s
.50599 .43586 m
.50614 .43568 L
s
.74434 .42772 m
.75386 .43576 L
s
.50614 .43568 m
.5063 .4355 L
s
0 .887 0 r
.29706 .60569 m .29511 .57595 L .33586 .57399 L F
0 0 1 r
.5063 .4355 m
.50645 .43532 L
s
.50645 .43532 m
.50659 .43516 L
s
0 .924 0 r
.33576 .60387 m .37697 .57561 L .3748 .60537 L F
.33576 .60387 m .33586 .57399 L .37697 .57561 L F
0 0 1 r
.52966 .43304 m
.53567 .43518 L
s
.50659 .43516 m
.50675 .43497 L
s
.50675 .43497 m
.50693 .43477 L
s
.50693 .43477 m
.50709 .43457 L
s
.62888 .42902 m
.63915 .43476 L
s
.77494 .43475 m
.78572 .43012 L
s
.72784 .43466 m
.73825 .42963 L
s
.50709 .43457 m
.50725 .43439 L
s
.50725 .43439 m
.50742 .43419 L
s
0 .945 0 r
.30297 .6653 m .33586 .63396 L .33615 .6638 L F
.30297 .6653 m .2997 .63563 L .33586 .63396 L F
0 0 1 r
.50742 .43419 m
.50758 .434 L
s
.50758 .434 m
.50773 .43383 L
s
0 .977 0 r
.33615 .6638 m .37234 .63533 L .36963 .66503 L F
0 0 1 r
.58645 .43393 m
.59371 .42829 L
s
.50773 .43383 m
.50789 .43364 L
s
.50789 .43364 m
.50806 .43344 L
s
0 .887 0 r
.29706 .60569 m .33586 .57399 L .33576 .60387 L F
0 0 1 r
.50806 .43344 m
.50825 .43322 L
s
.55801 .42861 m
.56926 .43323 L
s
.50825 .43322 m
.5084 .43304 L
s
.59273 .42773 m
.6041 .43318 L
s
.52697 .43211 m
.52966 .43304 L
s
.5084 .43304 m
.50858 .43284 L
s
0 .917 0 r
.2997 .63563 m .29706 .60569 L .33576 .60387 L F
0 0 1 r
.50858 .43284 m
.50876 .43262 L
s
.50876 .43262 m
.50893 .43242 L
s
0 .952 0 r
.33586 .63396 m .3748 .60537 L .37234 .63533 L F
.33586 .63396 m .33576 .60387 L .3748 .60537 L F
0 .977 0 r
.33615 .6638 m .33586 .63396 L .37234 .63533 L F
0 .917 0 r
.2997 .63563 m .33576 .60387 L .33586 .63396 L F
0 0 1 r
.50893 .43242 m
.50902 .43232 L
s
.50902 .43232 m
.50912 .4322 L
s
.50912 .4322 m
.50922 .43208 L
s
.52401 .43111 m
.52697 .43211 L
s
.50922 .43208 m
.50932 .43197 L
s
.65402 .42536 m
.66497 .43201 L
s
.50932 .43197 m
.50949 .43176 L
s
.69137 .43191 m
.70103 .42666 L
s
.56067 .43185 m
.5676 .42573 L
s
.50949 .43176 m
.50966 .43157 L
s
.62035 .43162 m
.62842 .42606 L
s
.50966 .43157 m
.50984 .43136 L
s
.50984 .43136 m
.51002 .43115 L
s
.51002 .43115 m
.51018 .43096 L
s
.52109 .43015 m
.52401 .43111 L
s
.53495 .43111 m
.54147 .42453 L
s
.51018 .43096 m
.51035 .43077 L
s
.51035 .43077 m
.51051 .43058 L
s
.65572 .43073 m
.6646 .42531 L
s
.51051 .43058 m
.51065 .43041 L
s
.51065 .43041 m
.51082 .43021 L
s
.51082 .43021 m
.511 .43 L
s
.5198 .42973 m
.52109 .43015 L
s
.78572 .43012 m
.79564 .42586 L
s
.511 .43 m
.51118 .42979 L
s
.68051 .42286 m
.69101 .4298 L
s
.51118 .42979 m
.51134 .42961 L
s
.51842 .42928 m
.5198 .42973 L
s
.73825 .42963 m
.74835 .42475 L
s
.51134 .42961 m
.51151 .42941 L
s
.78921 .41989 m
.79932 .42943 L
s
.51151 .42941 m
.51169 .42919 L
s
.51708 .42885 m
.51842 .42928 L
s
.51169 .42919 m
.51187 .42899 L
s
.6178 .42323 m
.62888 .42902 L
s
.51187 .42899 m
.51203 .4288 L
s
.51633 .42862 m
.51708 .42885 L
s
.51203 .4288 m
.51221 .42859 L
s
.51563 .42839 m
.51633 .42862 L
s
.55214 .42634 m
.55801 .42861 L
s
.51221 .42859 m
.51232 .42846 L
s
.51232 .42846 m
.51241 .42835 L
s
.51498 .42819 m
.51563 .42839 L
s
.51241 .42835 m
.51259 .42814 L
s
.59371 .42829 m
.6015 .42223 L
s
.51439 .428 m
.51498 .42819 L
s
.51259 .42814 m
.51268 .42803 L
s
.70715 .42092 m
.71716 .42811 L
s
.51268 .42803 m
.51278 .42792 L
s
.51406 .4279 m
.51439 .428 L
s
.51278 .42792 m
.51288 .42781 L
s
.5137 .42779 m
.51406 .4279 L
s
.7616 .41942 m
.77144 .42787 L
s
.51288 .42781 m
.51298 .42769 L
s
.5134 .4277 m
.5137 .42779 L
s
.58167 .42279 m
.59273 .42773 L
s
.73386 .41951 m
.74434 .42772 L
s
.51306 .42759 m
.5134 .4277 L
s
.51298 .42769 m
.51316 .42748 L
s
.51316 .42748 m
.51326 .42736 L
s
.51326 .42736 m
.51336 .42725 L
s
.51336 .42725 m
.51346 .42713 L
s
.51346 .42713 m
.51357 .427 L
s
.51357 .427 m
.51366 .42689 L
s
.51366 .42689 m
.51377 .42676 L
s
.51377 .42676 m
.51387 .42665 L
s
.70103 .42666 m
.71039 .42158 L
s
.51387 .42665 m
.51396 .42654 L
s
.51396 .42654 m
.51413 .42634 L
s
.51413 .42634 m
.51431 .42613 L
s
.5467 .42431 m
.55214 .42634 L
s
.51431 .42613 m
.51448 .42593 L
s
.62842 .42606 m
.63707 .42012 L
s
.51448 .42593 m
.51467 .42571 L
s
.5676 .42573 m
.57432 .4198 L
s
.51467 .42571 m
.51485 .4255 L
s
.51485 .4255 m
.51501 .42531 L
s
.64329 .41928 m
.65402 .42536 L
s
.6646 .42531 m
.6732 .42006 L
s
.51501 .42531 m
.51517 .42512 L
s
.51517 .42512 m
.51532 .42495 L
s
.51532 .42495 m
.51549 .42475 L
s
.74835 .42475 m
.75812 .42003 L
s
.51549 .42475 m
.51565 .42456 L
s
.51565 .42456 m
.51583 .42436 L
s
.54147 .42453 m
.54779 .41813 L
s
.51583 .42436 m
.51601 .42414 L
s
.54035 .42203 m
.5467 .42431 L
s
.51601 .42414 m
.51617 .42395 L
s
.51617 .42395 m
.51635 .42375 L
s
.51635 .42375 m
.51653 .42353 L
s
.51653 .42353 m
.51664 .42341 L
s
.51664 .42341 m
.51673 .42329 L
s
.51673 .42329 m
.51692 .42308 L
s
.60587 .41744 m
.6178 .42323 L
s
.51692 .42308 m
.5171 .42287 L
s
.5171 .42287 m
.51725 .42269 L
s
.66908 .41584 m
.68051 .42286 L
s
.56981 .41787 m
.58167 .42279 L
s
.51725 .42269 m
.51741 .4225 L
s
.51741 .4225 m
.51759 .4223 L
s
.51759 .4223 m
.51775 .42211 L
s
.6015 .42223 m
.60905 .41636 L
s
.51775 .42211 m
.5179 .42193 L
s
.5375 .42104 m
.54035 .42203 L
s
.5179 .42193 m
.51804 .42177 L
s
.51804 .42177 m
.51819 .42159 L
s
.51819 .42159 m
.51835 .4214 L
s
.71039 .42158 m
.7204 .41614 L
s
.51835 .4214 m
.51851 .42121 L
s
.51851 .42121 m
.51869 .42101 L
s
.53437 .41997 m
.5375 .42104 L
s
.51869 .42101 m
.51885 .42081 L
s
.69622 .41361 m
.70715 .42092 L
s
.51885 .42081 m
.519 .42064 L
s
.519 .42064 m
.51918 .42043 L
s
.51918 .42043 m
.51928 .42032 L
s
.51928 .42032 m
.51937 .42021 L
s
.51937 .42021 m
.51954 .42001 L
s
.63707 .42012 m
.64546 .41435 L
s
.6732 .42006 m
.68241 .41444 L
s
.75812 .42003 m
.76858 .41498 L
s
.51954 .42001 m
.51972 .4198 L
s
.53128 .41894 m
.53437 .41997 L
s
.77905 .41104 m
.78921 .41989 L
s
.51972 .4198 m
.51989 .4196 L
s
.57432 .4198 m
.58152 .41344 L
s
.51989 .4196 m
.52008 .41938 L
s
.72348 .41195 m
.73386 .41951 L
s
.75076 .4108 m
.7616 .41942 L
s
.52008 .41938 m
.52026 .41917 L
s
.63168 .41316 m
.64329 .41928 L
s
.52026 .41917 m
.52043 .41898 L
s
.52043 .41898 m
.52059 .41878 L
s
.52992 .41849 m
.53128 .41894 L
s
.52059 .41878 m
.52074 .41861 L
s
.52074 .41861 m
.52091 .41841 L
s
.52846 .41801 m
.52992 .41849 L
s
.52091 .41841 m
.52107 .41822 L
s
.52107 .41822 m
.52125 .41801 L
s
.54779 .41813 m
.55392 .41194 L
s
.52704 .41756 m
.52846 .41801 L
s
.52125 .41801 m
.52144 .41779 L
s
.56363 .41545 m
.56981 .41787 L
s
.52144 .41779 m
.5216 .4176 L
s
.5216 .4176 m
.52177 .4174 L
s
.52625 .4173 m
.52704 .41756 L
s
.59424 .4122 m
.60587 .41744 L
s
.52177 .4174 m
.52196 .41718 L
s
.5255 .41707 m
.52625 .4173 L
s
.52196 .41718 m
.52207 .41705 L
s
.52482 .41685 m
.5255 .41707 L
s
.52207 .41705 m
.52217 .41694 L
s
.52217 .41694 m
.52235 .41672 L
s
.5242 .41665 m
.52482 .41685 L
s
.52235 .41672 m
.52253 .41651 L
s
.52384 .41654 m
.5242 .41665 L
s
.52347 .41642 m
.52384 .41654 L
s
.52253 .41651 m
.52268 .41633 L
s
.52314 .41632 m
.52347 .41642 L
s
.60905 .41636 m
.61714 .41007 L
s
.52268 .41633 m
.52285 .41614 L
s
.52279 .41621 m
.52314 .41632 L
s
.52285 .41614 m
.52303 .41593 L
s
.7204 .41614 m
.73011 .41086 L
s
.52303 .41593 m
.52319 .41574 L
s
.65787 .40942 m
.66908 .41584 L
s
.52319 .41574 m
.52334 .41556 L
s
.52334 .41556 m
.52348 .4154 L
s
.55789 .41329 m
.56363 .41545 L
s
.52348 .4154 m
.52364 .41521 L
s
.52364 .41521 m
.5238 .41503 L
s
.5238 .41503 m
.52396 .41484 L
s
.76858 .41498 m
.7782 .41033 L
s
.52396 .41484 m
.52414 .41463 L
s
.52414 .41463 m
.52431 .41444 L
s
.52431 .41444 m
.52446 .41426 L
s
.68241 .41444 m
.69134 .40898 L
s
.64546 .41435 m
.65359 .40875 L
s
.52446 .41426 m
.52463 .41405 L
s
.52463 .41405 m
.52473 .41394 L
s
.52473 .41394 m
.52483 .41383 L
s
.52483 .41383 m
.525 .41363 L
s
.525 .41363 m
.52518 .41342 L
s
.68432 .40621 m
.69622 .41361 L
s
.58152 .41344 m
.58851 .40727 L
s
.52518 .41342 m
.52535 .41321 L
s
.55119 .41086 m
.55789 .41329 L
s
.52535 .41321 m
.52545 .4131 L
s
.61918 .40703 m
.63168 .41316 L
s
.52545 .4131 m
.52554 .41299 L
s
.52554 .41299 m
.52571 .41279 L
s
.52571 .41279 m
.52589 .41258 L
s
.52589 .41258 m
.52605 .41239 L
s
.52605 .41239 m
.5262 .41222 L
s
.5262 .41222 m
.52637 .41202 L
s
.58178 .40698 m
.59424 .4122 L
s
.52637 .41202 m
.52655 .41182 L
s
.71212 .40425 m
.72348 .41195 L
s
.55392 .41194 m
.5605 .40529 L
s
.52655 .41182 m
.52672 .41161 L
s
.52672 .41161 m
.52683 .41149 L
s
.52683 .41149 m
.52692 .41138 L
s
.52692 .41138 m
.52711 .41115 L
s
.52711 .41115 m
.52722 .41103 L
s
.76783 .40201 m
.77905 .41104 L
s
.52722 .41103 m
.52731 .41092 L
s
.52731 .41092 m
.52749 .41071 L
s
.54819 .40981 m
.55119 .41086 L
s
.73011 .41086 m
.73952 .40575 L
s
.73999 .40286 m
.75076 .4108 L
s
.52749 .41071 m
.52768 .41049 L
s
.52768 .41049 m
.52785 .41028 L
s
.52785 .41028 m
.52802 .41009 L
s
.52802 .41009 m
.52817 .40991 L
s
.61714 .41007 m
.625 .40396 L
s
.52817 .40991 m
.52834 .40972 L
s
.54488 .40867 m
.54819 .40981 L
s
.52834 .40972 m
.52849 .40954 L
s
.52849 .40954 m
.52864 .40937 L
s
.64574 .40295 m
.65787 .40942 L
s
.52864 .40937 m
.5288 .40918 L
s
.5288 .40918 m
.52898 .40896 L
s
.69134 .40898 m
.7009 .40314 L
s
.52898 .40896 m
.52915 .40876 L
s
.52915 .40876 m
.52931 .40858 L
s
.65359 .40875 m
.66231 .40276 L
s
.54162 .40757 m
.54488 .40867 L
s
.52931 .40858 m
.52949 .40837 L
s
.52949 .40837 m
.52966 .40817 L
s
.52966 .40817 m
.52981 .40799 L
s
.52981 .40799 m
.52998 .4078 L
s
.52998 .4078 m
.53016 .40759 L
s
.53016 .40759 m
.53035 .40737 L
s
.54018 .40709 m
.54162 .40757 L
s
.53035 .40737 m
.53051 .40718 L
s
.58851 .40727 m
.596 .40065 L
s
.53051 .40718 m
.53069 .40697 L
s
.53865 .40659 m
.54018 .40709 L
s
.60699 .40147 m
.61918 .40703 L
s
.57528 .40441 m
.58178 .40698 L
s
.53069 .40697 m
.53088 .40675 L
s
.53088 .40675 m
.53105 .40654 L
s
.53715 .4061 m
.53865 .40659 L
s
.53105 .40654 m
.53115 .40644 L
s
.53115 .40644 m
.53125 .40632 L
s
.53125 .40632 m
.53135 .40619 L
s
.67264 .39944 m
.68432 .40621 L
s
.53135 .40619 m
.53145 .40608 L
s
.53631 .40583 m
.53715 .4061 L
s
.53145 .40608 m
.53163 .40586 L
s
.53163 .40586 m
.5318 .40567 L
s
.53552 .40557 m
.53631 .40583 L
s
.73952 .40575 m
.74959 .40028 L
s
.5318 .40567 m
.53199 .40545 L
s
.53481 .40534 m
.53552 .40557 L
s
.53199 .40545 m
.53218 .40523 L
s
.53414 .40513 m
.53481 .40534 L
s
.5605 .40529 m
.56688 .39883 L
s
.53218 .40523 m
.53234 .40504 L
s
.53377 .40502 m
.53414 .40513 L
s
.53234 .40504 m
.53252 .40483 L
s
.53338 .40489 m
.53377 .40502 L
s
.53303 .40478 m
.53338 .40489 L
s
.53252 .40483 m
.53268 .40464 L
s
.53266 .40466 m
.53303 .40478 L
s
.53268 .40464 m
.53283 .40447 L
s
.53283 .40447 m
.533 .40426 L
s
.56923 .40211 m
.57528 .40441 L
s
.533 .40426 m
.53319 .40404 L
s
.69975 .39646 m
.71212 .40425 L
s
.53319 .40404 m
.53337 .40383 L
s
.625 .40396 m
.63262 .39805 L
s
.53337 .40383 m
.53354 .40363 L
s
.53354 .40363 m
.53372 .40343 L
s
.53372 .40343 m
.53391 .4032 L
s
.53391 .4032 m
.53409 .40299 L
s
.7009 .40314 m
.71018 .39748 L
s
.53409 .40299 m
.53425 .4028 L
s
.63266 .39647 m
.64574 .40295 L
s
.72822 .39478 m
.73999 .40286 L
s
.53425 .4028 m
.53444 .40258 L
s
.66231 .40276 m
.67076 .39695 L
s
.53444 .40258 m
.53455 .40245 L
s
.53455 .40245 m
.53465 .40233 L
s
.53465 .40233 m
.53483 .40212 L
s
.53483 .40212 m
.53493 .40201 L
s
.56219 .39953 m
.56923 .40211 L
s
.53493 .40201 m
.53503 .40189 L
s
.7567 .39368 m
.76783 .40201 L
s
.53503 .40189 m
.53513 .40177 L
s
.53513 .40177 m
.53523 .40165 L
s
.53523 .40165 m
.53542 .40143 L
s
.59391 .39594 m
.60699 .40147 L
s
.53542 .40143 m
.53553 .40131 L
s
.53553 .40131 m
.53562 .4012 L
s
.53562 .4012 m
.53573 .40107 L
s
.53573 .40107 m
.53584 .40094 L
s
.53584 .40094 m
.53594 .40082 L
s
.53594 .40082 m
.53605 .4007 L
s
.53605 .4007 m
.53615 .40058 L
s
.596 .40065 m
.60328 .39423 L
s
.53615 .40058 m
.53624 .40047 L
s
.53624 .40047 m
.53642 .40026 L
s
.74959 .40028 m
.75886 .39525 L
s
.53642 .40026 m
.53661 .40004 L
s
.53661 .40004 m
.53679 .39983 L
s
.53679 .39983 m
.53698 .39961 L
s
.53698 .39961 m
.53716 .39939 L
s
.55903 .39841 m
.56219 .39953 L
s
.65999 .39262 m
.67264 .39944 L
s
.53716 .39939 m
.53733 .3992 L
s
.53733 .3992 m
.5375 .399 L
s
.5375 .399 m
.53765 .39882 L
s
.56688 .39883 m
.57373 .39191 L
s
.53765 .39882 m
.53783 .39861 L
s
.53783 .39861 m
.538 .39842 L
s
.538 .39842 m
.53818 .39821 L
s
.55555 .3972 m
.55903 .39841 L
s
.53818 .39821 m
.53837 .39798 L
s
.63262 .39805 m
.64078 .3917 L
s
.53837 .39798 m
.53853 .39779 L
s
.53853 .39779 m
.53871 .39758 L
s
.53871 .39758 m
.53891 .39736 L
s
.71018 .39748 m
.71917 .39199 L
s
.53891 .39736 m
.53902 .39723 L
s
.53902 .39723 m
.53911 .39711 L
s
.55212 .39604 m
.55555 .3972 L
s
.53911 .39711 m
.53931 .39689 L
s
.67076 .39695 m
.67981 .39072 L
s
.53931 .39689 m
.53949 .39667 L
s
.53949 .39667 m
.53964 .39649 L
s
.53964 .39649 m
.53982 .39629 L
s
.6199 .3906 m
.63266 .39647 L
s
.68759 .38933 m
.69975 .39646 L
s
.53982 .39629 m
.53999 .39608 L
s
.53999 .39608 m
.54016 .39589 L
s
.5506 .39553 m
.55212 .39604 L
s
.58708 .39322 m
.59391 .39594 L
s
.54016 .39589 m
.54032 .3957 L
s
.54032 .3957 m
.54046 .39554 L
s
.54046 .39554 m
.54062 .39535 L
s
.54898 .39499 m
.5506 .39553 L
s
.54062 .39535 m
.54078 .39516 L
s
.54078 .39516 m
.54095 .39496 L
s
.5474 .39447 m
.54898 .39499 L
s
.54095 .39496 m
.54113 .39475 L
s
.71537 .38659 m
.72822 .39478 L
s
.54113 .39475 m
.5413 .39455 L
s
.5413 .39455 m
.54146 .39437 L
s
.54652 .39418 m
.5474 .39447 L
s
.54146 .39437 m
.54164 .39416 L
s
.60328 .39423 m
.61033 .388 L
s
.54569 .39391 m
.54652 .39418 L
s
.54164 .39416 m
.54174 .39404 L
s
.54174 .39404 m
.54184 .39393 L
s
.54184 .39393 m
.54201 .39372 L
s
.54494 .39367 m
.54569 .39391 L
s
.54201 .39372 m
.5422 .39351 L
s
.7445 .38519 m
.7567 .39368 L
s
.54424 .39345 m
.54494 .39367 L
s
.5422 .39351 m
.54238 .3933 L
s
.54385 .39332 m
.54424 .39345 L
s
.54343 .39319 m
.54385 .39332 L
s
.54238 .3933 m
.54257 .39307 L
s
.58074 .39078 m
.58708 .39322 L
s
.54307 .39307 m
.54343 .39319 L
s
.54267 .39295 m
.54307 .39307 L
s
.54257 .39307 m
.54276 .39285 L
s
.54276 .39285 m
.54293 .39265 L
s
.54293 .39265 m
.5431 .39245 L
s
.64633 .38577 m
.65999 .39262 L
s
.5431 .39245 m
.54325 .39227 L
s
.54325 .39227 m
.54343 .39206 L
s
.54343 .39206 m
.5436 .39187 L
s
.71917 .39199 m
.7288 .38611 L
s
.57373 .39191 m
.58038 .38519 L
s
.5436 .39187 m
.54378 .39165 L
s
.64078 .3917 m
.64871 .38554 L
s
.54378 .39165 m
.54398 .39143 L
s
.54398 .39143 m
.54414 .39123 L
s
.54414 .39123 m
.54432 .39102 L
s
.54432 .39102 m
.54452 .39079 L
s
.54452 .39079 m
.54463 .39066 L
s
.57334 .38804 m
.58074 .39078 L
s
.67981 .39072 m
.6886 .38468 L
s
.54463 .39066 m
.54473 .39055 L
s
.60621 .38474 m
.6199 .3906 L
s
.54473 .39055 m
.54492 .39032 L
s
.54492 .39032 m
.54511 .3901 L
s
.54511 .3901 m
.54526 .38992 L
s
.54526 .38992 m
.54544 .38972 L
s
.54544 .38972 m
.54562 .38951 L
s
.54562 .38951 m
.54579 .38931 L
s
.67441 .38214 m
.68759 .38933 L
s
.54579 .38931 m
.54594 .38912 L
s
.54594 .38912 m
.54609 .38895 L
s
.54609 .38895 m
.54625 .38876 L
s
.54625 .38876 m
.54641 .38857 L
s
.54641 .38857 m
.54658 .38837 L
s
.54658 .38837 m
.54677 .38816 L
s
.54677 .38816 m
.54694 .38796 L
s
.57002 .38685 m
.57334 .38804 L
s
.61033 .388 m
.6179 .38132 L
s
.54694 .38796 m
.54709 .38778 L
s
.54709 .38778 m
.54728 .38756 L
s
.54728 .38756 m
.54738 .38744 L
s
.54738 .38744 m
.54748 .38733 L
s
.54748 .38733 m
.54765 .38712 L
s
.54765 .38712 m
.54784 .38691 L
s
.54784 .38691 m
.54802 .38669 L
s
.56637 .38557 m
.57002 .38685 L
s
.54802 .38669 m
.54812 .38657 L
s
.70273 .3791 m
.71537 .38659 L
s
.54812 .38657 m
.54822 .38646 L
s
.54822 .38646 m
.54839 .38626 L
s
.54839 .38626 m
.54858 .38604 L
s
.7288 .38611 m
.73766 .3807 L
s
.54858 .38604 m
.54874 .38585 L
s
.54874 .38585 m
.5489 .38567 L
s
.633 .37957 m
.64633 .38577 L
s
.5489 .38567 m
.54907 .38547 L
s
.56276 .38433 m
.56637 .38557 L
s
.64871 .38554 m
.65719 .37894 L
s
.54907 .38547 m
.54925 .38525 L
s
.54925 .38525 m
.54944 .38503 L
s
.73119 .3766 m
.7445 .38519 L
s
.58038 .38519 m
.58683 .37867 L
s
.54944 .38503 m
.54954 .38491 L
s
.54954 .38491 m
.54964 .3848 L
s
.54964 .3848 m
.54984 .38457 L
s
.59906 .38186 m
.60621 .38474 L
s
.6886 .38468 m
.69712 .37882 L
s
.54984 .38457 m
.54995 .38444 L
s
.54995 .38444 m
.55005 .38432 L
s
.56117 .38379 m
.56276 .38433 L
s
.55005 .38432 m
.55023 .38411 L
s
.55023 .38411 m
.55042 .38388 L
s
.55042 .38388 m
.55061 .38367 L
s
.55946 .38322 m
.56117 .38379 L
s
.55061 .38367 m
.55078 .38347 L
s
.55078 .38347 m
.55093 .38328 L
s
.55093 .38328 m
.5511 .38308 L
s
.55781 .38267 m
.55946 .38322 L
s
.5511 .38308 m
.55127 .3829 L
s
.55127 .3829 m
.55141 .38272 L
s
.55141 .38272 m
.55158 .38252 L
s
.55688 .38237 m
.55781 .38267 L
s
.55158 .38252 m
.55177 .3823 L
s
.55601 .38208 m
.55688 .38237 L
s
.55177 .3823 m
.55195 .3821 L
s
.66018 .37493 m
.67441 .38214 L
s
.55195 .3821 m
.55211 .3819 L
s
.55522 .38182 m
.55601 .38208 L
s
.55211 .3819 m
.5523 .38169 L
s
.59242 .37928 m
.59906 .38186 L
s
.55448 .38159 m
.55522 .38182 L
s
.5523 .38169 m
.55247 .38148 L
s
.55407 .38145 m
.55448 .38159 L
s
.55247 .38148 m
.55263 .3813 L
s
.55363 .38131 m
.55407 .38145 L
s
.6179 .38132 m
.62525 .37483 L
s
.55326 .38119 m
.55363 .38131 L
s
.55263 .3813 m
.5528 .3811 L
s
.55284 .38106 m
.55326 .38119 L
s
.5528 .3811 m
.55299 .38088 L
s
.55299 .38088 m
.55318 .38065 L
s
.55318 .38065 m
.55335 .38046 L
s
.55335 .38046 m
.55353 .38024 L
s
.55353 .38024 m
.55373 .38001 L
s
.55373 .38001 m
.55391 .3798 L
s
.55391 .3798 m
.55401 .37969 L
s
.55401 .37969 m
.55411 .37957 L
s
.61869 .37339 m
.633 .37957 L
s
.55411 .37957 m
.55422 .37944 L
s
.55422 .37944 m
.55432 .37932 L
s
.55432 .37932 m
.55451 .3791 L
s
.58466 .37639 m
.59242 .37928 L
s
.55451 .3791 m
.55469 .3789 L
s
.68903 .37153 m
.70273 .3791 L
s
.65719 .37894 m
.66543 .37254 L
s
.55469 .3789 m
.55488 .37867 L
s
.69712 .37882 m
.70624 .37254 L
s
.55488 .37867 m
.55507 .37844 L
s
.58683 .37867 m
.59375 .37167 L
s
.55507 .37844 m
.55524 .37824 L
s
.55524 .37824 m
.55542 .37803 L
s
.55542 .37803 m
.55559 .37783 L
s
.55559 .37783 m
.55575 .37765 L
s
.55575 .37765 m
.55593 .37744 L
s
.55593 .37744 m
.55613 .37721 L
s
.55613 .37721 m
.55631 .37699 L
s
.55631 .37699 m
.55648 .37679 L
s
.55648 .37679 m
.55667 .37658 L
s
.71807 .36873 m
.73119 .3766 L
s
.55667 .37658 m
.55686 .37635 L
s
.58118 .37513 m
.58466 .37639 L
s
.55686 .37635 m
.55705 .37613 L
s
.55705 .37613 m
.55722 .37594 L
s
.55722 .37594 m
.55741 .3757 L
s
.55741 .3757 m
.55753 .37557 L
s
.55753 .37557 m
.55763 .37545 L
s
.55763 .37545 m
.55782 .37523 L
s
.55782 .37523 m
.55792 .37512 L
s
.57734 .37377 m
.58118 .37513 L
s
.55792 .37512 m
.55802 .37499 L
s
.55802 .37499 m
.55813 .37487 L
s
.64628 .3684 m
.66018 .37493 L
s
.55813 .37487 m
.55823 .37474 L
s
.62525 .37483 m
.63312 .36788 L
s
.55823 .37474 m
.55843 .37452 L
s
.55843 .37452 m
.55854 .37439 L
s
.55854 .37439 m
.55864 .37427 L
s
.55864 .37427 m
.55875 .37415 L
s
.55875 .37415 m
.55886 .37401 L
s
.55886 .37401 m
.55897 .37389 L
s
.55897 .37389 m
.55908 .37376 L
s
.57356 .37246 m
.57734 .37377 L
s
.55908 .37376 m
.55918 .37364 L
s
.55918 .37364 m
.55928 .37352 L
s
.55928 .37352 m
.55946 .37331 L
s
.61121 .37034 m
.61869 .37339 L
s
.55946 .37331 m
.55966 .37308 L
s
.55966 .37308 m
.55984 .37287 L
s
.55984 .37287 m
.56004 .37263 L
s
.56004 .37263 m
.56023 .37241 L
s
.70624 .37254 m
.71465 .36676 L
s
.66543 .37254 m
.67343 .36633 L
s
.57189 .37189 m
.57356 .37246 L
s
.56023 .37241 m
.5604 .37221 L
s
.5604 .37221 m
.56058 .372 L
s
.56058 .372 m
.56073 .37182 L
s
.57011 .37128 m
.57189 .37189 L
s
.56073 .37182 m
.56092 .37161 L
s
.59375 .37167 m
.60047 .36488 L
s
.56092 .37161 m
.56109 .37141 L
s
.67422 .36395 m
.68903 .37153 L
s
.56109 .37141 m
.56128 .37119 L
s
.56837 .3707 m
.57011 .37128 L
s
.56128 .37119 m
.56147 .37095 L
s
.56147 .37095 m
.56164 .37076 L
s
.56164 .37076 m
.56183 .37054 L
s
.5674 .37038 m
.56837 .3707 L
s
.56183 .37054 m
.56203 .3703 L
s
.56648 .37007 m
.5674 .37038 L
s
.60426 .36762 m
.61121 .37034 L
s
.56203 .3703 m
.56214 .37017 L
s
.56214 .37017 m
.56224 .37005 L
s
.56565 .3698 m
.56648 .37007 L
s
.56224 .37005 m
.56244 .36982 L
s
.56244 .36982 m
.56263 .3696 L
s
.56488 .36955 m
.56565 .3698 L
s
.56263 .3696 m
.56279 .36941 L
s
.56445 .36941 m
.56488 .36955 L
s
.56279 .36941 m
.56297 .3692 L
s
.56399 .36926 m
.56445 .36941 L
s
.56359 .36913 m
.56399 .36926 L
s
.56297 .3692 m
.56315 .36899 L
s
.56316 .36899 m
.56359 .36913 L
s
.56315 .36899 m
.56333 .36879 L
s
.56333 .36879 m
.56349 .3686 L
s
.70384 .36078 m
.71807 .36873 L
s
.56349 .3686 m
.56364 .36842 L
s
.56364 .36842 m
.5638 .36823 L
s
.63134 .36188 m
.64628 .3684 L
s
.5638 .36823 m
.56397 .36803 L
s
.56397 .36803 m
.56415 .36783 L
s
.63312 .36788 m
.64076 .36113 L
s
.56415 .36783 m
.56433 .36761 L
s
.59614 .36456 m
.60426 .36762 L
s
.56433 .36761 m
.56451 .3674 L
s
.56451 .3674 m
.56467 .36722 L
s
.56467 .36722 m
.56486 .367 L
s
.56486 .367 m
.56496 .36687 L
s
.56496 .36687 m
.56506 .36676 L
s
.56506 .36676 m
.56524 .36655 L
s
.56524 .36655 m
.56543 .36632 L
s
.67343 .36633 m
.682 .35966 L
s
.56543 .36632 m
.56562 .36611 L
s
.56562 .36611 m
.56582 .36587 L
s
.56582 .36587 m
.56601 .36565 L
s
.56601 .36565 m
.56619 .36544 L
s
.56619 .36544 m
.56636 .36523 L
s
.56636 .36523 m
.56652 .36505 L
s
.56652 .36505 m
.56671 .36483 L
s
.60047 .36488 m
.60767 .3576 L
s
.56671 .36483 m
.56688 .36463 L
s
.56688 .36463 m
.56707 .36441 L
s
.5925 .36323 m
.59614 .36456 L
s
.56707 .36441 m
.56727 .36417 L
s
.56727 .36417 m
.56744 .36397 L
s
.56744 .36397 m
.56763 .36375 L
s
.65974 .35706 m
.67422 .36395 L
s
.56763 .36375 m
.56783 .36352 L
s
.56783 .36352 m
.56794 .36338 L
s
.56794 .36338 m
.56805 .36326 L
s
.56805 .36326 m
.56825 .36303 L
s
.58848 .36179 m
.5925 .36323 L
s
.56825 .36303 m
.56844 .36281 L
s
.56844 .36281 m
.5686 .36262 L
s
.5686 .36262 m
.56878 .36241 L
s
.56878 .36241 m
.56897 .36219 L
s
.56897 .36219 m
.56914 .36198 L
s
.56914 .36198 m
.56931 .36179 L
s
.62353 .35866 m
.63134 .36188 L
s
.56931 .36179 m
.56945 .36162 L
s
.58452 .36041 m
.58848 .36179 L
s
.56945 .36162 m
.56962 .36143 L
s
.56962 .36143 m
.56979 .36122 L
s
.56979 .36122 m
.56997 .36102 L
s
.64076 .36113 m
.64818 .35458 L
s
.56997 .36102 m
.57016 .3608 L
s
.57016 .3608 m
.57033 .36059 L
s
.68845 .35281 m
.70384 .36078 L
s
.57033 .36059 m
.5705 .3604 L
s
.58278 .3598 m
.58452 .36041 L
s
.5705 .3604 m
.57069 .36018 L
s
.57069 .36018 m
.57079 .36005 L
s
.57079 .36005 m
.57089 .35994 L
s
.57089 .35994 m
.57107 .35973 L
s
.58091 .35916 m
.58278 .3598 L
s
.57107 .35973 m
.57126 .3595 L
s
.682 .35966 m
.68989 .35353 L
s
.57126 .3595 m
.57145 .35928 L
s
.57145 .35928 m
.57156 .35916 L
s
.57909 .35855 m
.58091 .35916 L
s
.57156 .35916 m
.57166 .35904 L
s
.57166 .35904 m
.57184 .35883 L
s
.57184 .35883 m
.57203 .35861 L
s
.61627 .35578 m
.62353 .35866 L
s
.57203 .35861 m
.5722 .35841 L
s
.57807 .35821 m
.57909 .35855 L
s
.5722 .35841 m
.57236 .35822 L
s
.57236 .35822 m
.57254 .35801 L
s
.57711 .35789 m
.57807 .35821 L
s
.57254 .35801 m
.57273 .35779 L
s
.57624 .3576 m
.57711 .35789 L
s
.57273 .35779 m
.57292 .35756 L
s
.60767 .3576 m
.61467 .35052 L
s
.57543 .35733 m
.57624 .3576 L
s
.57292 .35756 m
.57303 .35744 L
s
.57303 .35744 m
.57313 .35732 L
s
.57498 .35718 m
.57543 .35733 L
s
.57313 .35732 m
.57333 .35708 L
s
.5745 .35702 m
.57498 .35718 L
s
.57333 .35708 m
.57345 .35695 L
s
.64417 .3502 m
.65974 .35706 L
s
.57408 .35689 m
.5745 .35702 L
s
.57345 .35695 m
.57355 .35683 L
s
.57363 .35674 m
.57408 .35689 L
s
.57355 .35683 m
.57373 .35661 L
s
.57373 .35661 m
.57394 .35637 L
s
.57394 .35637 m
.57413 .35615 L
s
.57413 .35615 m
.5743 .35595 L
s
.5743 .35595 m
.57447 .35575 L
s
.60779 .35256 m
.61627 .35578 L
s
.57447 .35575 m
.57464 .35555 L
s
.57464 .35555 m
.57481 .35535 L
s
.57481 .35535 m
.57496 .35518 L
s
.57496 .35518 m
.57514 .35497 L
s
.57514 .35497 m
.57533 .35474 L
s
.57533 .35474 m
.57552 .35453 L
s
.64818 .35458 m
.65614 .34755 L
s
.57552 .35453 m
.57569 .35433 L
s
.57569 .35433 m
.57588 .3541 L
s
.57588 .3541 m
.57606 .35389 L
s
.57606 .35389 m
.57622 .3537 L
s
.57622 .3537 m
.5764 .3535 L
s
.5764 .3535 m
.57659 .35327 L
s
.57659 .35327 m
.57679 .35304 L
s
.57679 .35304 m
.57696 .35283 L
s
.57696 .35283 m
.57715 .35261 L
s
.67339 .34557 m
.68845 .35281 L
s
.57715 .35261 m
.57736 .35237 L
s
.60398 .35115 m
.60779 .35256 L
s
.57736 .35237 m
.57755 .35215 L
s
.57755 .35215 m
.57764 .35204 L
s
.57764 .35204 m
.57775 .35191 L
s
.57775 .35191 m
.57787 .35178 L
s
.57787 .35178 m
.57797 .35165 L
s
.57797 .35165 m
.57817 .35143 L
s
.57817 .35143 m
.57835 .35122 L
s
.57835 .35122 m
.57854 .35099 L
s
.59979 .34964 m
.60398 .35115 L
s
.57854 .35099 m
.57875 .35075 L
s
.57875 .35075 m
.57892 .35054 L
s
.57892 .35054 m
.57911 .35032 L
s
.61467 .35052 m
.62146 .34365 L
s
.57911 .35032 m
.57928 .35012 L
s
.63603 .34681 m
.64417 .3502 L
s
.57928 .35012 m
.57944 .34993 L
s
.57944 .34993 m
.57963 .34971 L
s
.57963 .34971 m
.57983 .34947 L
s
.59565 .34817 m
.59979 .34964 L
s
.57983 .34947 m
.58003 .34925 L
s
.58003 .34925 m
.5802 .34904 L
s
.5802 .34904 m
.58039 .34882 L
s
.58039 .34882 m
.5806 .34858 L
s
.5806 .34858 m
.58079 .34836 L
s
.58079 .34836 m
.58096 .34816 L
s
.59382 .34754 m
.59565 .34817 L
s
.58096 .34816 m
.58117 .34792 L
s
.58117 .34792 m
.58128 .34778 L
s
.58128 .34778 m
.58139 .34765 L
s
.58139 .34765 m
.58159 .34742 L
s
.65614 .34755 m
.66347 .34108 L
s
.59187 .34686 m
.59382 .34754 L
s
.58159 .34742 m
.5817 .3473 L
s
.5817 .3473 m
.5818 .34718 L
s
.5818 .34718 m
.5819 .34705 L
s
.5819 .34705 m
.58202 .34692 L
s
.58202 .34692 m
.58222 .34669 L
s
.58997 .34621 m
.59187 .34686 L
s
.62846 .34378 m
.63603 .34681 L
s
.58222 .34669 m
.58233 .34656 L
s
.58233 .34656 m
.58243 .34644 L
s
.58243 .34644 m
.58255 .3463 L
s
.58255 .3463 m
.58267 .34616 L
s
.5889 .34585 m
.58997 .34621 L
s
.58267 .34616 m
.58277 .34604 L
s
.58277 .34604 m
.58289 .3459 L
s
.58289 .3459 m
.583 .34578 L
s
.5879 .34551 m
.5889 .34585 L
s
.583 .34578 m
.5831 .34566 L
s
.5831 .34566 m
.58329 .34544 L
s
.65719 .33835 m
.67339 .34557 L
s
.58699 .34521 m
.5879 .34551 L
s
.58329 .34544 m
.58349 .3452 L
s
.58615 .34493 m
.58699 .34521 L
s
.58349 .3452 m
.58368 .34498 L
s
.58368 .34498 m
.58388 .34474 L
s
.58567 .34477 m
.58615 .34493 L
s
.58517 .3446 m
.58567 .34477 L
s
.58388 .34474 m
.58408 .34451 L
s
.58474 .34446 m
.58517 .3446 L
s
.58408 .34451 m
.58426 .3443 L
s
.58426 .3443 m
.58474 .34446 L
s
.58426 .3443 m
.58444 .34409 L
s
.58444 .34409 m
.5846 .3439 L
s
.5846 .3439 m
.58479 .34368 L
s
.61961 .34038 m
.62846 .34378 L
s
.58479 .34368 m
.58497 .34347 L
s
.62146 .34365 m
.62875 .33629 L
s
.58497 .34347 m
.58516 .34324 L
s
.58516 .34324 m
.58537 .343 L
s
.58537 .343 m
.58554 .3428 L
s
.58554 .3428 m
.58573 .34257 L
s
.58573 .34257 m
.58594 .34233 L
s
.58594 .34233 m
.58606 .34219 L
s
.58606 .34219 m
.58616 .34207 L
s
.58616 .34207 m
.58637 .34183 L
s
.58637 .34183 m
.58656 .3416 L
s
.58656 .3416 m
.58673 .34141 L
s
.58673 .34141 m
.58691 .34119 L
s
.58691 .34119 m
.5871 .34097 L
s
.5871 .34097 m
.58728 .34076 L
s
.58728 .34076 m
.58745 .34056 L
s
.58745 .34056 m
.5876 .34038 L
s
.5876 .34038 m
.58777 .34019 L
s
.61564 .3389 m
.61961 .34038 L
s
.58777 .34019 m
.58795 .33998 L
s
.58795 .33998 m
.58813 .33977 L
s
.58813 .33977 m
.58832 .33954 L
s
.58832 .33954 m
.58851 .33933 L
s
.58851 .33933 m
.58867 .33914 L
s
.58867 .33914 m
.58887 .33891 L
s
.58887 .33891 m
.58898 .33878 L
s
.61127 .3373 m
.61564 .3389 L
s
.58898 .33878 m
.58908 .33866 L
s
.58908 .33866 m
.58926 .33844 L
s
.58926 .33844 m
.58946 .33821 L
s
.64872 .33479 m
.65719 .33835 L
s
.58946 .33821 m
.58965 .33799 L
s
.58965 .33799 m
.58986 .33774 L
s
.58986 .33774 m
.59006 .33751 L
s
.59006 .33751 m
.59024 .3373 L
s
.60694 .33576 m
.61127 .3373 L
s
.59024 .3373 m
.59043 .33708 L
s
.59043 .33708 m
.59059 .33689 L
s
.59059 .33689 m
.59078 .33667 L
s
.59078 .33667 m
.59096 .33646 L
s
.59096 .33646 m
.59116 .33623 L
s
.62875 .33629 m
.63547 .3295 L
s
.59116 .33623 m
.59136 .33599 L
s
.59136 .33599 m
.59154 .33578 L
s
.59154 .33578 m
.59173 .33555 L
s
.60504 .33509 m
.60694 .33576 L
s
.59173 .33555 m
.59194 .33531 L
s
.59194 .33531 m
.59206 .33517 L
s
.59206 .33517 m
.59217 .33505 L
s
.603 .33437 m
.60504 .33509 L
s
.59217 .33505 m
.59238 .3348 L
s
.59238 .3348 m
.59257 .33457 L
s
.64083 .3316 m
.64872 .33479 L
s
.59257 .33457 m
.59274 .33438 L
s
.59274 .33438 m
.59292 .33416 L
s
.60101 .33369 m
.603 .33437 L
s
.59292 .33416 m
.59312 .33394 L
s
.59312 .33394 m
.5933 .33372 L
s
.5933 .33372 m
.59347 .33353 L
s
.5999 .33331 m
.60101 .33369 L
s
.59347 .33353 m
.59362 .33334 L
s
.59362 .33334 m
.59379 .33315 L
s
.59886 .33295 m
.5999 .33331 L
s
.59379 .33315 m
.59397 .33294 L
s
.5979 .33263 m
.59886 .33295 L
s
.59397 .33294 m
.59415 .33272 L
s
.59415 .33272 m
.59435 .3325 L
s
.59702 .33233 m
.5979 .33263 L
s
.59435 .3325 m
.59453 .33228 L
s
.59653 .33217 m
.59702 .33233 L
s
.59453 .33228 m
.5947 .33209 L
s
.596 .33199 m
.59653 .33217 L
s
.5947 .33209 m
.5949 .33186 L
s
.59555 .33184 m
.596 .33199 L
s
.5949 .33186 m
.59501 .33173 L
s
.59505 .33167 m
.59555 .33184 L
s
.59501 .33173 m
.59511 .33161 L
s
.59511 .33161 m
.5953 .33139 L
s
.63161 .32802 m
.64083 .3316 L
s
.5953 .33139 m
.5955 .33115 L
s
.5955 .33115 m
.59569 .33093 L
s
.59569 .33093 m
.5958 .3308 L
s
.5958 .3308 m
.5959 .33068 L
s
.5959 .33068 m
.59609 .33046 L
s
.59609 .33046 m
.59629 .33023 L
s
.59629 .33023 m
.59646 .33002 L
s
.59646 .33002 m
.59663 .32983 L
s
.59663 .32983 m
.59681 .32961 L
s
.59681 .32961 m
.59701 .32938 L
s
.59701 .32938 m
.59721 .32915 L
s
.59721 .32915 m
.59732 .32902 L
s
.59732 .32902 m
.59742 .3289 L
s
.59742 .3289 m
.59763 .32865 L
s
.59763 .32865 m
.59775 .32851 L
s
.59775 .32851 m
.59786 .32839 L
s
.59786 .32839 m
.59805 .32816 L
s
.59805 .32816 m
.59826 .32792 L
s
.62747 .32646 m
.63161 .32802 L
s
.59826 .32792 m
.59846 .32769 L
s
.59846 .32769 m
.59864 .32748 L
s
.59864 .32748 m
.59881 .32728 L
s
.59881 .32728 m
.59899 .32707 L
s
.59899 .32707 m
.59916 .32686 L
s
.59916 .32686 m
.59932 .32668 L
s
.59932 .32668 m
.5995 .32647 L
s
.5995 .32647 m
.5997 .32623 L
s
.62291 .32478 m
.62747 .32646 L
s
.5997 .32623 m
.59989 .32601 L
s
.59989 .32601 m
.60007 .3258 L
s
.60007 .3258 m
.60027 .32557 L
s
.60027 .32557 m
.60045 .32535 L
s
.60045 .32535 m
.60062 .32516 L
s
.60062 .32516 m
.6008 .32494 L
s
.6008 .32494 m
.601 .32471 L
s
.61841 .32315 m
.62291 .32478 L
s
.601 .32471 m
.60121 .32446 L
s
.60121 .32446 m
.60139 .32426 L
s
.60139 .32426 m
.60159 .32402 L
s
.60159 .32402 m
.60173 .32386 L
s
.60173 .32386 m
.60186 .3237 L
s
.60186 .3237 m
.60201 .32354 L
s
.60201 .32354 m
.60216 .32336 L
s
.60216 .32336 m
.60229 .3232 L
s
.60229 .3232 m
.60242 .32305 L
s
.61642 .32245 m
.61841 .32315 L
s
.60242 .32305 m
.60256 .32289 L
s
.60256 .32289 m
.6027 .32272 L
s
.6027 .32272 m
.60283 .32258 L
s
.60283 .32258 m
.60296 .32242 L
s
.61429 .3217 m
.61642 .32245 L
s
.60296 .32242 m
.6031 .32225 L
s
.6031 .32225 m
.60323 .3221 L
s
.60323 .3221 m
.60336 .32196 L
s
.60336 .32196 m
.60347 .32183 L
s
.60347 .32183 m
.6036 .32167 L
s
.61223 .32098 m
.61429 .3217 L
s
.6036 .32167 m
.60372 .32153 L
s
.60372 .32153 m
.60385 .32138 L
s
.60385 .32138 m
.604 .32121 L
s
.604 .32121 m
.60415 .32103 L
s
.60415 .32103 m
.60429 .32086 L
s
.61107 .32058 m
.61223 .32098 L
s
.60429 .32086 m
.60442 .32071 L
s
.60442 .32071 m
.60455 .32057 L
s
.60998 .3202 m
.61107 .32058 L
s
.60455 .32057 m
.60469 .3204 L
s
.60469 .3204 m
.60482 .32025 L
s
.60482 .32025 m
.60496 .32008 L
s
.60898 .31986 m
.60998 .3202 L
s
.60496 .32008 m
.60511 .3199 L
s
.60511 .3199 m
.60526 .31973 L
s
.60807 .31955 m
.60898 .31986 L
s
.60526 .31973 m
.60539 .31958 L
s
.60539 .31958 m
.60554 .3194 L
s
.60755 .31937 m
.60807 .31955 L
s
.60554 .3194 m
.60571 .31921 L
s
.607 .31919 m
.60755 .31937 L
s
.60571 .31921 m
.60587 .31902 L
s
.60653 .31903 m
.607 .31919 L
s
.60601 .31885 m
.60653 .31903 L
s
.60587 .31902 m
.60601 .31885 L
s
0 0 0 r
gsave
.34423 .84648 -66.5938 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
70.188 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[258]:=",
  ImageSize->{400, 402.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001TR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00l@3oool20000oid0oooo003`0?ooo`80003o00@0oooo0000o`000?l0
003oVP3oool00>l0oooo0P000?l50?ooo`<0003oU`3oool00>h0oooo0P000?l90?ooo`80003oU@3o
ool00>d0oooo0P000?l<0?ooo`<0003oTP3oool00>d0oooo0P000?l=0?ooo`030000o`3oool0003o
0080003oS`3oool00>`0oooo00<0003o0?ooo`000?l00`000?l90?ooo`030000o`3oool0oooo00<0
oooo0P000?n=0?ooo`00j`3oool20000o`D0oooo0P000?l60?ooo`030000o`3oool0oooo00H0oooo
0P000?n;0?ooo`00jP3oool20000o`P0oooo0P000?l30?ooo`030000o`3oool0oooo00T0oooo0P00
0?n90?ooo`00j@3oool20000o`/0oooo0`000?l>0?ooo`80003oQ`3oool00>P0oooo0`000?l<0?oo
o`030000o`3oool0003o0080003o2P3oool20000o`030?ooo`000?l0003o08D0oooo003W0?ooo`80
003o00@0oooo0000o`000?l0003o2@3oool00`000?l0oooo0?ooo`030?ooo`<0003o1P3oool00`00
0?l0oooo0?ooo`030?ooo`80003oP`3oool00>L0oooo00<0003o0?ooo`3oool00`3oool30000o`H0
oooo00<0003o0?ooo`3oool01P3oool30000o`80oooo00<0003o0?ooo`3oool01P3oool20000oh40
oooo003V0?ooo`80003o203oool30000o`80oooo00<0003o0?ooo`3oool02P3oool20000o`/0oooo
0P000?mo0?ooo`00i@3oool20000o``0oooo0P000?l=0?ooo`040000o`3oool0003o0000o`/0oooo
0`000?ml0?ooo`00i03oool20000o``0oooo00<0003o0?ooo`3oool00P000?l:0?ooo`030000o`3o
ool0oooo0080oooo0P000?l90?ooo`@0003oN`3oool00><0oooo0P000?l0103oool0003o0000o`00
0?l80?ooo`030000o`3oool0oooo00<0oooo0`000?l60?ooo`030000o`3oool0oooo00D0oooo0P00
0?l60?ooo`030000o`3oool0oooo0080oooo0P000?mi0?ooo`00hP3oool20000o`D0oooo0P000?l5
0?ooo`030000o`3oool0oooo00L0oooo0P000?l30?ooo`030000o`3oool0oooo00P0oooo0P000?l3
0?ooo`030000o`3oool0oooo00D0oooo0P000?mg0?ooo`00P03oool:000?00/001P0C03oool20000
o`P0oooo1@000?l<0?ooo`<0003o3@3oool30000o`X0oooo0P000?me0?ooo`00N@3oool2003=00<0
008030008@0<000Z00X001l0@@3oool00`000?l0oooo0?ooo`0:0?ooo`@0003o2`3oool30000o``0
oooo00@0003o0?ooo`000?l0003o2`3oool30000og80oooo001e0?ooo`03003/00000P00008000D0
01@03@008@0=000Z00D003401@007`03000R03`0oooo0`000?l:0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool30000o`L0oooo0P000?l40?oo
o`80003o2@3oool40000og40oooo001a0?ooo`0300000000500001@000P001@03@008@0>000Z00/0
03401@008P04000003@0oooo0P000?l0103oool0003o0000o`000?l70?ooo`030000o`3oool0oooo
00@0oooo0P000?l50?ooo`80003o1`3oool30000o`<0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`80003o103oool20000ofl0oooo001/0?ooo`<000000P001@05000D00H0
02803@00;@0>000f00L004@01@00<@03000e00@0028000<0oooo000000000000<@3oool20000o`D0
oooo0`000?l30?ooo`030000o`3oool0oooo00L0oooo0`000?l00`3oool0003o0?ooo`0;0?ooo`<0
003o2P3oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool20000ofd0oooo001Z0?ooo`800000
0`001@0<000R00h002d03P00=P0=001400H003D00`008P02000002h0oooo0P000?l90?ooo`@0003o
303oool30000o``0oooo0`000?l;0?ooo`<0003o2`3oool00`000?l0oooo0?ooo`1Z0?ooo`00J03o
ool50005008001@030008P0>000]00h003H03P00A003001>00D003D00P008P000`000000oooo0?oo
o`0Z0?ooo`80003o303oool40000o`T0oooo00@0003o0?ooo`3oool0oooo0P000?l90?ooo`040000
o`3oool0oooo0?ooo`80003o2P3oool30000o`/0oooo0P000?mZ0?ooo`00I@3oool00`00g0000000
00050002000500@001@030008P0?001900h005`03P00A007001>00<003D000@00000000g00008P00
0280:@3oool30000o`T0oooo0P000?l40?ooo`80003o1P3oool00`000?l0oooo0?ooo`040?ooo`80
003o1P3oool00`000?l0oooo0?ooo`040?ooo`80003o1P3oool20000o`<0oooo0P000?l;0?ooo`80
003oJ03oool006<0oooo0`0000000`001@0001@0000D0005000D00H002801P00=00?001900l005`0
1P00JP07001400/004h000<00000000g0000=`000P00=`000`008P00oooo0?ooo`0S0?ooo`040000
o`3oool0oooo0?ooo`80003o1P3oool00`000?l0oooo0?ooo`060?ooo`80003o0`3oool00`000?l0
oooo0?ooo`070?ooo`80003o0P3oool20000o`T0oooo0P000?l20?ooo`80003o1`3oool20000o`L0
oooo0P000?l20?ooo`80003oIP3oool00640oooo0`000009000D00d003@03`00B@0?001L00d006X0
3000CP000`00000005@0000g0004000g0280oooo0P000?l50?ooo`<0003o0P3oool00`000?l0oooo
0?ooo`090?ooo`<0003o303oool20000o`d0oooo0P000?l;0?ooo`030000o`3oool0oooo0080oooo
0P000?l60?ooo`030000o`3oool0oooo06<0oooo001N0?ooo`@0000000<00040000D000050001@00
5003000R00d003@03`00B@0?001L00h006X01000L`07001>000400000000E00005@0001D00@003L0
00<003@00?ooo`3oool07@3oool20000o`T0oooo0P000?l=0?ooo`<0003o2P3oool20000o`040?oo
o`000?l0003o0000o`X0oooo00<0003o0?ooo`000?l02`3oool40000o`T0oooo00<0003o0?ooo`3o
ool0HP3oool005d0oooo0P000003000100D001@01@008P0>000d00h004T04000G00>001Z00T007<0
0`00CP000`00000005@0001D0003001D008003L00P00=00L0?ooo`80003o2P3oool00`000?l0oooo
0000o`020000o`P0oooo0P000?l30?ooo`<0003o1P3oool00`000?l0oooo0?ooo`040?ooo`80003o
1`3oool010000?l0oooo0?ooo`3oool20000o`T0oooo10000?l:0?ooo`030000o`3oool0oooo0640
oooo001K0?ooo`03000000000@00004000<000400`005008000R00d003@03`00K@0@001n00D008`0
2P00JP0<001c000300000000E00005@000@005@000@003L0000d0000=00003@06@3oool50000o`L0
oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo00<0003o0?ooo`3oool01P3oool20000o`<0
oooo00<0003o0?ooo`3oool01`3oool20000o`<0oooo0P000?l60?ooo`80003o1@3oool20000o`@0
oooo00<0003o0?ooo`3oool0203oool20000of40oooo001I0?ooo`L000402`008P07000d00L005H0
3`00K@0@001n00X008`01@00JP0<001c000300000000MP0007H000H005@01000=00F0?ooo`80003o
0`3oool30000o`D0oooo00<0003o0?ooo`3oool01@3oool30000o`030?ooo`000?l0oooo00X0oooo
0`000?l<0?ooo`<0003o2P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo0P000?l70?ooo`@0
003oH03oool005L0oooo00<00000000100000@000`000@03000?00X002803`00EP0?001]010007h0
3`00S00=001c000400000000MP0007H0001f00D005@000@005<0000d0000=00003@05@3oool00`00
0?l0oooo0?ooo`050?ooo`D0003o2`3oool30000o`/0oooo0`000?l:0?ooo`80003o00<0oooo0000
o`3oool02P3oool30000o`X0oooo0P000?l40?ooo`030000o`3oool0oooo0080oooo0P000?mN0?oo
o`00EP3oool0100000000040000100000@05000?00P002800`00>P0?001F00l006d04000OP0@002<
00@009D02000L`000`00000007H0001f0004001f00<005@00P00D`02000d0003000]003oool0oooo
0100oooo00<0003o0?ooo`3oool0203oool40000o`T0oooo00@0003o0?ooo`3oool0oooo0`000?l6
0?ooo`80003o0`3oool20000o`L0oooo00<0003o0?ooo`3oool00P3oool20000o`T0oooo10000?l;
0?ooo`040000o`3oool0oooo0000o`L0oooo00<0003o0?ooo`3oool0F`3oool005@0oooo0P000000
0`000@0000l0000?0006000?00D002801P00>P0?001F00l006d04000OP0@002<00T009D01000L`00
0`00000007H0001f0005001f008005@00`00D`000`00=00002d00?ooo`0?0?ooo`80003o2@3oool0
0`000?l0oooo0?ooo`020?ooo`<0003o103oool20000o`L0oooo0P000?l30?ooo`030000o`3oool0
oooo00D0oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo0P000?l60?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02@3oool20000o`T0oooo00<0003o0?ooo`3oool0FP3oool0
0580oooo0P00000:000?00<002802000>P0?001F010006d04000OP0@002<00d009D000<00000001f
0000MP001`00MP05001C0003000]003oool0oooo00`0oooo1P000?l50?ooo`030000o`3oool0oooo
00H0oooo10000?l;0?ooo`<0003o2P3oool40000o`X0oooo00@0003o0?ooo`3oool0oooo0P000?l6
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`000?l02P3oool00`000?l0oooo0?ooo`1I
0?ooo`00D03oool4000000T000l03000>P0:001F00D007<04000Q`0@002G00P00:@02000S00>002E
000300000000V`0007H000L007H00P00M`03001C0003000]003oool0oooo00X0oooo0P000?l50?oo
o`80003o0`3oool00`000?l0oooo0?ooo`080?ooo`<0003o2P3oool010000?l0oooo0000o`000?l:
0?ooo`<0003o2`3oool30000o`T0oooo0P000?l50?ooo`80003o0`3oool00`000?l0oooo0?ooo`08
0?ooo`80003oF@3oool004l0oooo10000008000?008002D03000>P05001F00X007<04000Q`0@002G
01000:@03P00U@000`00000009/0002K0002002K00H007H00`00M`03001C00X0oooo0P000?l80?oo
o`<0003o2`3oool00`000?l0oooo0?ooo`020000o`L0oooo00<0003o0?ooo`3oool00P3oool20000
o`H0oooo0P000?l30?ooo`030000o`3oool0oooo00L0oooo10000?l;0?ooo`030000o`3oool0oooo
0080003o1P3oool00`000?l0oooo0?ooo`060?ooo`<0003oF@3oool004h0oooo10000006000?00@0
02D03000>P0@001c010008L04000U`0A002T00<00:l02P00U@000`00000009/0002K0004002K00@0
07H01@00M`02001C00P0oooo0P000?l:0?ooo`<0003o2@3oool00`000?l0oooo0?ooo`030?ooo`80
003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool20000o`H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`80
003o2@3oool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool00`000?l0oooo0?ooo`1F0?ooo`00
C03oool6000000@000l01P009@09000j00<005X03`00L`0A0027010009L04@00Y007002_00L009D0
00<00000002K0000V`001P00V`02001f00H007L000<005<0001;003oool01@3oool30000o`P0oooo
00@0003o0?ooo`3oool0oooo1P000?l00`3oool0003o0000o`080?ooo`80003o00<0oooo0000o`3o
ool0203oool40000o`T0oooo0P000?l20?ooo`80003o1P3oool20000o`L0oooo0P000?l00`3oool0
003o0000o`090?ooo`80003o00<0oooo0000o`000?l01P3oool20000oeH0oooo001;0?ooo`H00000
0P003`08000U00H003X01`00FP0?001c014008L04000U`0A002T00/00:l00`00U@000`00000009/0
002K0008002K00P007L000<004/00?ooo`3oool00P3oool00`000?l0oooo0?ooo`040000o`@0oooo
00<0003o0?ooo`3oool0203oool20000o`X0oooo0`000?l:0?ooo`<0003o2`3oool20000o`X0oooo
0P000?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`070?ooo`80003o2P3oool00`000?l0oooo
0?ooo`1C0?ooo`00BP3oool6000000/002D00`00>P0:001J00l007<04000Q`0A002G01400:@03P00
[`000`00000009/0002K0009002K0003002L0000M`0007L000D007L000<007<0001;003oool00P00
0?l60?ooo`@0003o2P3oool00`000?l0oooo0?ooo`020000o`H0oooo0P000?l30?ooo`80003o1`3o
ool010000?l0oooo0?ooo`3oool20000o`L0oooo0P000?l20?ooo`80003o2P3oool30000o`P0oooo
00<0003o0?ooo`3oool0103oool20000o`80oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`1B0?ooo`00B03oool700000003000700009@0002D000P002D03@00FP0?001c014009`04@00
Z`0A002T00h00:l000<00000002g0000]`002@00V`03002L00H007L000<007<00000o`000?l02@3o
ool30000o`P0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool20000o`@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`060?ooo`<0003o2P3oool20000o`80oooo0P000?l50?ooo`80003o2@3o
ool00`000?l0oooo0?ooo`1A0?ooo`00B03oool50000008000L02@009@02000k00d005X02P00L`05
002;014009`04@00Z`06002h00/00:@03P00[`000`0000000;L0002g0003002g00L009/01000W004
001g0080003o00<004/00?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0
003o0?ooo`3oool01P3oool30000o`T0oooo0P000?l00`3oool0003o0?ooo`090?ooo`80003o00<0
oooo0000o`3oool01`3oool20000o`@0oooo0P000?l30?ooo`80003o2P3oool20000o`T0oooo00<0
003o0?ooo`3oool01P3oool20000oe80oooo00170?ooo`@0000010001`06000U00D003/03@00FP05
001c00X008/04@00W00A002[00`00;P01@00Y00?002_000300000000]`000;L000D00;L01000V`06
002L0003001g00000?l0003o00<0003o1P3oool00`000?l0oooo0?ooo`040?ooo`D0003o2P3oool3
0000o`T0oooo10000?l:0?ooo`<0003o2P3oool010000?l0oooo0000o`000?l70?ooo`030000o`3o
ool0oooo00D0oooo0P000?l00`3oool0003o0?ooo`090?ooo`030000o`3oool0oooo0080oooo0`00
0?l20?ooo`030000o`3oool0oooo04l0oooo00160?ooo`@0000010001`05000U00L003/03000FP0@
002;014009`04@00Z`0A002h00l00:l000<00000002g0000]`002000]`02002K00D009`00P000?l2
001g008007<00`000?l20?ooo`030000o`3oool0oooo00L0oooo0`000?l80?ooo`80003o0`3oool2
0000o`H0oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo00D0003o0?ooo`3oool0oooo0000
o`090?ooo`80003o2P3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?oo
o`080?ooo`040000o`3oool0003o0000o`H0oooo00<0003o0?ooo`3oool0CP3oool004D0oooo0`00
00060007008002D02@00>`0:001J00<007D04000R`0A002L01400:/04@00^005003200X00:l000<0
0000002g0000]`002P00]`05002L00040000o`00W00009`0002L00@007<000@0oooo0000o`000?l0
003o203oool010000?l0oooo0?ooo`3oool30000o`@0oooo00<0003o0?ooo`3oool01@3oool01000
0?l0oooo0?ooo`3oool20000o`L0oooo0P000?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`04
0?ooo`80003o0P3oool20000o`T0oooo10000?l70?ooo`030000o`3oool0oooo00L0oooo0P000?l9
0?ooo`030000o`3oool0oooo04d0oooo00140?ooo`8000001`001`0<000k00H005X01`00M@0@002;
014009`04@00Z`0A002h00X00<801@00[`000`0000000;L0002g000;002g0003002k0000W00009`0
0080003o1000W0001@00U00007<0001c0000L`00003o0080oooo0P000?l50?ooo`030000o`3oool0
oooo00D0oooo10000?l90?ooo`<0003o2`3oool30000o`P0oooo0P000?l30?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool30000o`T0oooo00<0003o0?ooo`3oool0103oool2
0000o`80oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1<0?ooo`00@`3oool30000
00H000L000<00280000k0000>`002P00>`03001J00X007D04000R`0A002L01400:/04@00^00?0032
000300000000]`000;L000/00;L00P00^`030000o`@009`00P00U0000`00L`00003o001c00040?oo
o`<0003o00<0oooo0000o`3oool02@3oool30000o`P0oooo10000?l90?ooo`@0003o2P3oool30000
o`P0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3oool20000o`D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1;
0?ooo`00@P3oool3000000D000L00`008P0;000k00h007D04000R`0A002L01400:/04@00^00?0032
000300000000c0000<`000/00;L000<00;/00000o`000?l00P00^`030000o`8009`000<009@00000
o`00L`000P00L`060?ooo`80003o2@3oool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0003o
0?ooo`3oool00P3oool20000o`H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`06
0?ooo`@0003o2@3oool20000o`030?ooo`000?l0003o00H0oooo00<0003o0?ooo`3oool01`3oool3
0000o`P0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1:0?ooo`00@@3oool30000
00@000L010008P0:000k008005P03P00M@0@002;01400:d04@00^`0A002h01000<8000@00000003<
0000c0000<`02@00]`020000o`D00;/000@009`00000o`000?l0003o0`00U0000`00L`0006@00?oo
o`030?ooo`030000o`3oool0oooo00<0003o103oool20000o`H0oooo00D0003o0?ooo`3oool0oooo
0000o`070?ooo`80003o0P3oool20000o`H0oooo0P000?l40?ooo`80003o103oool20000o`P0oooo
0P000?l90?ooo`030000o`3oool0oooo00@0oooo0`000?l00`3oool0003o0?ooo`080?ooo`030000
o`3oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`1:0?ooo`00@03oool40000008000L01P00
8P07000k00D005P03P00M@0;002;00D009d04@00[@0A002k00H00<L02`00^00@0032000300000000
c0000<`000<00<`01P00]`020000o`L00;/01P000?l01000U00007<0001T003oool20000o`H0oooo
10000?l90?ooo`<0003o2P3oool20000o`X0oooo10000?l80?ooo`030000o`3oool0oooo00<0oooo
0P000?l20?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0P000?l50?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`000?l40?ooo`030000o`3oool0oooo04P0
oooo000o0?ooo`@0000000<000L0000R00008P001@008P05000k00P005P03P00M@05002;00/009d0
4@00[@0A002k00`00<L01@00^00@0032000300000000c0000<`000H00<`00P00]`020000o`L00;/0
00@0003o002k0000^`000;/00`00U0020000o`03001c00000?l0oooo00T0oooo0`000?l80?ooo`03
0000o`3oool0003o00T0oooo0P000?l00`3oool0003o0000o`080?ooo`<0003o2P3oool00`000?l0
oooo0?ooo`020000o`D0oooo00<0003o0?ooo`3oool01`3oool30000o`P0oooo00<0003o0?ooo`3o
ool01P3oool30000o`P0oooo00<0003o0?ooo`3oool0A`3oool003h0oooo10000009000R008003/0
2P00F00>001e014009d04@00[@0A002k01400<L04000`P000`0000000<`0003<0008003<00030000
o`00]`00003o0080003o0`00^`000`000?l00;/0002k0003002k0004002j0000U00009@0002D0080
003o00<006@00?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20000o`@0oooo0P000?l30?oo
o`80003o1@3oool20000o`D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0
003o00X0oooo0P000?l80?ooo`030000o`3oool0oooo00<0oooo0`000?l20?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`170?ooo`00?P3oool300000003000500008P00028000H002803@00F00;001e
00<008X04@00W@0A002]01400;/04@00a`06003B00X00<8000<00000003<0000c0001`00c0020000
o`04003<0000^`000;/0002k00@0003o1@00^`02002j0004002D00000?l009@0002D00<0003o103o
ool20000o`H0oooo0P000?l00`3oool0003o0?ooo`060?ooo`80003o00<0oooo0000o`000?l0203o
ool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0003o0?ooo`3oool01@3oool20000o`030?oo
o`000?l0oooo00P0oooo00<0003o0?ooo`3oool00P000?l60?ooo`030000o`3oool0oooo00L0oooo
1@000?l50?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0AP3oool003d0oooo0`00
0002000500L0028000<003L0001H0000F0002`00F007001e00L008X04@00W@0A002]01400;/04@00
a`0;003B00D00<8000<00000003<0000c0001P00c0020000o`<00<`00P00d`02002k00<0003o1000
^`02002j00050000o`00U00009@0002D0000RP000P00I0040000o`T0oooo0`000?l90?ooo`80003o
2P3oool30000o`P0oooo0P000?l30?ooo`80003o103oool20000o`P0oooo0P000?l90?ooo`030000
o`3oool0oooo00@0oooo10000?l90?ooo`030000o`3oool0oooo00H0oooo0P000?m60?ooo`00?03o
ool30000008000D01P008P03000g00d005P00`00M@0;002:014009d04@00[@0A002k01400<L04000
dP000`0000000<`0003<0005003<0080003o1000c003003C00040000o`00^`000;/0002k00<0003o
00<00;/0002j00000?l00P00^P03002D0004002:0000I00006@00?ooo`<0003o1`3oool010000?l0
oooo0?ooo`3oool20000o`D0oooo0P000?l20?ooo`80003o1`3oool40000o`X0oooo0`000?l80?oo
o`030000o`3oool0oooo00<0oooo0P000?l20?ooo`030000o`3oool0oooo00L0oooo00@0003o0?oo
o`3oool0oooo0P000?l40?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool2
0000o`030?ooo`000?l0oooo04D0oooo000k0?ooo`80000010001@05000R00@003L03000F00?002:
014009d04@00[@0A002k01400<L04000dP000`0000000=`0003L0004003<00D0003o0P00c002003C
00040000o`00d`000=<0003C00@00;/00P000?l4002j008009@00P00RP000`00I000003o0?ooo`02
0?ooo`80003o0`3oool20000o`H0oooo00<0003o0?ooo`3oool00P000?l60?ooo`80003o0`3oool2
0000o`@0oooo0P000?l60?ooo`80003o0P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
003o0080003o1@3oool00`000?l0oooo0?ooo`070?ooo`<0003o1`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00<0003o0`3oool00`000?l0oooo0?ooo`140?ooo`00>`3oool00`00
000000D000050003000500<002801@00=`0;001H008007803`00RP0A002M00P00:d04`000007002k
01400<L04000dP000`0000000=`0003L0002003L0003003<00000?l0003o00@00<`00P000?l00`00
d`00003o003C0005003C00800;/000<0003o002k00000?l00P000?l2002j008009@000<008X00000
o`00I0001@3oool30000o`T0oooo0P000?l:0?ooo`<0003o203oool20000o`80oooo0P000?l50?oo
o`030000o`3oool0oooo00D0oooo0`000?l90?ooo`030000o`3oool0oooo00D0oooo0`000?l90?oo
o`030000o`3oool0oooo00D0oooo0`000?l70?ooo`030000o`3oool0oooo04<0oooo000j0?ooo`03
000000001@0000D000<000D00`008P06000g00P005P01@00LP0?002:010009d02@000008002k00/0
0<P03@00000;003701000=8000<00000003L0000g0000P00g0020000o`03003L0000c0000<`000@0
0<`00P000?l7003C00030000o`00^`000;/000<00;X01@000?l2002:0003001T003oool0oooo0080
oooo0`000?l80?ooo`030000o`3oool0oooo0080003o203oool30000o`X0oooo0P000?l80?ooo`03
0000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool010000?l30?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`80
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`120?ooo`00>@3oool700050003000R
0000=`0003L000H003L01@00F008001b00l008X01P00W@0:000001400;/04P00b006003C00H00000
1@00a`0@003B0003003L000000000=`000800=`000<0003o003L0000g0000P00g003003<00030000
o`00c0000=<000@0003o0P00d`0010000?l00=<0003C0000d`05002j00<0003o0`00RP030?ooo`04
0000o`3oool0oooo0?ooo`80003o103oool20000o`D0oooo0P000?l40?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`050?ooo`80003o00<0oooo0000o`3oool0203oool010000?l0oooo0000o`000?l6
0?ooo`030000o`3oool0oooo00H0oooo0`000?l80?ooo`030000o`3oool0oooo00L0oooo10000?l5
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0@@3oool003P0oooo00<000000005
00001@0010001@0:000g008005P02`00LP0?002:00H000002P00[@0A002k01800<P03000d`070000
00h00=8000@00=`000000000g0000=`00`000?l5003L00030000o`00c0000<`000D00=<00P000?l5
003C0004003F0000^P00003o0000o`<00;X000H0003o002:0000RP0008X00?ooo`000?l60?ooo`04
0000o`3oool0oooo0000o`T0oooo00@0003o0?ooo`000?l0003o1P3oool00`000?l0oooo0?ooo`02
0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`80003o2@3oool00`000?l0oooo0?ooo`03
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo10000?l9
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0@@3oool003P0oooo00<000000005
00001@000`001@000`006P0003L0000g0007000g00h007803000RP03000001000:d04@00^`0B0038
01400=<00P00dP05000000T00=8000<00=`000000000g0000P000?l00`00g000003o0000o`020000
o`03003L00000?l00=`000800=`01000d`000`000?l00=<0003C00020000o`<00=<000<00=H00000
o`00^P001000^P001@00[P00003o0000o`00RP00003o00P0oooo0P000?l:0?ooo`<0003o203oool4
0000o`L0oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0000o`020000o`D0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o
ool20000o`@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`80003o@P3o
ool003L0oooo00<00000000500001@000`001@02000J00P003L000<00540001b0000LP003000LP06
002:00H000000P00W00A002]01400;/04P00b00A003C00H00=h000<00=800000000000000P000005
003B0004003L00000000003o0000o`H00=`00P000?l3003L00800>D000<00=<00000o`00d`001000
d`040000o`<00=H01000^P02002^00<0003o1@3oool20000o`80oooo0P000?l70?ooo`050000o`3o
ool0oooo0?ooo`000?l01`3oool30000o`T0oooo00<0003o0?ooo`3oool00P000?l50?ooo`80003o
1P3oool30000o`T0oooo00<0003o0?ooo`3oool01P3oool30000o`H0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`040000o`80oooo00<0003o0?ooo`3oool0?`3oool003H0oooo0P00
0004000500<001X01P00=`03001A00h007800P00RP0400000003002:0000W00009`000D009`04@00
[@0A002k01800<P04@00d`0;003N00@0000000@00=80003L00000?l0003o1P00g0000`000?l00=`0
003L00040000o`03003U00000?l00>D000H00=<000@0003o003C00000?l0003o0`00eP03002j0080
003o00<00:h0002:0000RP000P000?l00`3oool0003o0000o`060?ooo`80003o0`3oool20000o`D0
oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo0P000?l70?ooo`<0003o2@3oool010000?l0
oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool4
0000o`030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`3oool01P3oool30000o`H0oooo00<0003o
0?ooo`3oool0?`3oool003H0oooo0P000002000500@001X01P00=`04001A00d007800`0000000`00
RP0009`0002L0009002L01400:d04@00^`0B003801400=<03`00gP02000000030000o`0000000=`0
00@00=`000<0003o003L0000g0001000g0000`00i@00003o0000o`03003U00800=<00P000?l2003C
00800=H00P000?l2003F0080003o00L00;X0002^0000[P000:h0002:0000LP00oooo0080003o2@3o
ool30000o`P0oooo00@0003o0?ooo`000?l0003o1`3oool010000?l0oooo0?ooo`3oool30000o`80
oooo00<0003o0?ooo`3oool0203oool30000o`H0oooo00<0003o0?ooo`3oool01`3oool30000o`H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`@0003o203oool00`000?l0
oooo0?ooo`0n0?ooo`00=@3oool20000008000D01@006P04000g00H005402`00LP02000000l009`0
4@00[@0A002k01800<P04@00d`0@003N0003003X00000000000000<0000000<00=`00000o`00g000
1P00g0000`000?l00>D0003U00020000o`800>D000<0003o003C0000d`000P00d`04003F0080003o
0P00eP000`00^P000:h0002^0002002^0080003o0P3oool00`000?l0oooo0?ooo`050?ooo`@0003o
1`3oool30000o`X0oooo0`000?l60?ooo`80003o1@3oool30000o`030?ooo`000?l0oooo00L0oooo
00<0003o0?ooo`3oool0103oool40000o`P0oooo00<0003o0?ooo`3oool01P3oool50000o`<0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0n0?ooo`00=03oool30000000300050000
6P0001X000@001X00`00=`07001A00P007800`000002002700l009`04@00[@0A002k01800<P04@00
d`0@003N0003003X000000000>P000800>P000<000000000o`0000001P00g0000`000?l00>D0003U
0003003U00<0003o0P00i@02003C00<00=H000<0003o003F0000eP000P000?l01`00eP000:h0002^
0000[P00003o002^0000LP000`3oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`80003o0`3oool20000o`P0oooo00<0003o0?ooo`000?l0203oool00`000?l0
oooo0?ooo`020000o`D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0000o`030000o`<0
oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool60000o`L0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0m0?ooo`00<`3oool3000000P001X000<003L0001A0000
D@001`00D@05001b00<000001@00Q`0?002L01400:d04@00^`0B003801400=<04000gP000`00j000
0000003X0003003X000300000000j000000000<000000P000?l00`00g0000>D0003U0003003U0003
0000o`00i@000>D00080003o0P00i@000`00eP00003o0000o`05003F00040000o`00eP00003o0000
o`<00:h01@3oool010000?l0oooo0000o`000?l60?ooo`@0003o1`3oool00`000?l0oooo0?ooo`03
0?ooo`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`80003o203oool00`000?l0oooo0?ooo`04
0?ooo`<0003o203oool00`000?l0oooo0?ooo`060?ooo`@0003o1@3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0?03oool003<0oooo0`000007000J
00/005400`00LP02000000P008L03`00W00A002]01400<L08`00d`0@003N0003003X000000000>P0
00<00>P000H00000003X0000j0000>P0003L00000?l200000003003L0000i@000>D000800>D000<0
003o003U0000i@000`00i@030000o`03003[0000eP000=H000D00=H00P000?l4002^0004002H003o
ool0oooo0?ooo`@0003o1`3oool30000o`T0oooo1@000?l50?ooo`030000o`3oool0oooo00@0oooo
0P000?l00`3oool0003o0?ooo`070?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool30000o`P0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`80003o?P3oool00380oooo0`0000000`001`0001X0000J
0004000J0003000`0000D@00054000T005400`00000:002700l009`03000[@05002j01400<L04P00
d`09003N00P00=<04000gP000`00j0000000003X0003003X000300000000j0000>P000800>P000<0
0000003X0000g0000P0000000`00i@00003o0000o`06003U00@0003o0P00j`03003F0080003o00@0
0=H0003B00000?l0003o0`00[P000`3oool0003o0000o`040?ooo`030000o`3oool0oooo00<0oooo
00@0003o0?ooo`3oool0oooo0P000?l60?ooo`@0003o203oool00`000?l0oooo0?ooo`030000o`@0
oooo00<0003o0?ooo`3oool01P3oool40000o`D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030000o`80oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0003o00@0003o0P3oool00`000?l0oooo0?ooo`0k0?ooo`00<P3oool20000008000L0
1@006P02000`00T005400P00000=002700l009`01P00[@0;002j01400<L04P00d`0Q003N00800000
1000j0000`0000000>P0003X0002003X000500000000j0000>P0003X0000i@000`000005003U0005
0000o`00i@000>D0003U0000j`000P000?l00`00j`00003o0000o`03003F00<00=8010000?l70?oo
o`80003o00<0oooo0000o`000?l01P3oool010000?l0oooo0?ooo`3oool20000o`@0oooo0P000?l6
0?ooo`<0003o203oool00`000?l0oooo0?ooo`020?ooo`D0003o203oool00`000?l0oooo0?ooo`04
0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo10000?l7
0?ooo`030000o`3oool0oooo03/0oooo000a0?ooo`8000000P001`05000J00<003001`00D@020000
0003001/0000Q`0008L000`008L03`00W00A002j01400<L04P00d`0A003N00@00>P03000gP050000
0003003X000000000>P000<00>P000L00000003X0000j0000>P0003b000000000?8000<0000000<0
0>D00000o`000?l01000i@02003[00<0003o00<00>/0003F0000eP000P00eP02003B00@0003o203o
ool20000o`T0oooo0`000?l80?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`000?l0oooo
0?ooo`060?ooo`040000o`3oool0003o0000o`D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0000o`030000o`<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`D0
003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03X0oooo000a0?ooo`040000
00001`0000L0000700<001X01@00<006001A000400000000K00006`0001/00h008L02`00W004002[
01400;X04@00a`0B003C01400=h02000j008003N000300000000j0000>P000800>P00P000004003X
000600000000j0000>P0003X0000lP0000000`00lP000`00i@00003o00000005003U0003003[0000
0?l00>/000800>/000<0003o003[0000eP000P00eP020000o`800=800P00[P000`000?l0oooo0?oo
o`030?ooo`80003o0P3oool00`000?l0oooo0?ooo`050?ooo`<0003o2P3oool30000o`H0oooo00<0
003o0?ooo`3oool0103oool30000o`P0oooo00<0003o0?ooo`3oool0103oool30000o`P0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`D0003o1`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo03X0oooo000`0?ooo`03000000001`0000L0008000L00P006P05
000`00D005400P000004001/00h008L01`00W008002[01400;X04@00a`0B003C01400=h03000j004
003N000300000000j0000>P000<00>P0100000000`00j0000000003X0002003X0003003b00000000
0?8000<00?8000@00000003U0000000000000P00i@020000o`D00>/00P000?l00`00j`00003o003B
0004003B0004002^0000V000003o0?ooo`<0003o1@3oool010000?l0oooo0?ooo`3oool30000o`<0
oooo0P000?l50?ooo`@0003o203oool00`000?l0oooo0?ooo`040000o`<0oooo00<0003o0?ooo`3o
ool01P3oool010000?l0oooo0?ooo`3oool20000o`80oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`@0003o1@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0>@3oool00300oooo1@001`000`006P000300000`0004000`00@0
054000<00000001/0000K0001000K00>002700<009`03000Z`0A002j01400<L04P00d`0A003N0100
0>P000<00000003X0000j0000`00j000100000000>P0003X0000j002000000<00>P000<00?800000
0000lP000`00lP001`0000000?80003b00000?l000000000o`00i@001`00j`030000o`H00=8000@0
09P00000o`000?l0003o203oool30000o`P0oooo00<0003o0?ooo`3oool00P000?l40?ooo`030000
o`3oool0oooo00D0oooo0`000?l80?ooo`030000o`3oool0oooo00D0oooo10000?l50?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P000?l80?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool20000oc/0oooo000_0?ooo`D000L02000<002001A008000001`00
K00=002701000:/04@00^P0A003701800=<04@00gP0@003X000300000000l`000?<000<00>P000<0
0000003X0000j0000P00j00400000003003b000000000?8000<00?8000<00000003b0000lP000P00
lP02000000D00>/00P000?l3003[00030000o`00dP000=8000800=800P000?l00`00V000oooo0?oo
o`020000o`@0oooo0P000?l20?ooo`030000o`3oool0oooo00H0oooo0`000?l70?ooo`030000o`3o
ool0oooo0080oooo0P000?l20?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01000
0?l00`3oool0003o0?ooo`060?ooo`030000o`3oool0oooo00H0oooo0`000?l60?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0000o`040000o`030?ooo`00
0?l0oooo03X0oooo000_0?ooo`D000L02000<002000000T006`02`00Q`03002I00l00:/04@00^P0A
003701800=<04@00gP0@003X000300000000l`000?<000<00?<000<00000003X0000j0000P00j000
100000000>P0003X0000j003000000<00?8000<00000003b0000lP000P00lP001@0000000?800000
000000000>/00080003o1P00j`0010000?l00=800000o`000?l2003B0003002n0000V000oooo0080
oooo10000?l50?ooo`030000o`3oool0oooo0080oooo0`000?l20?ooo`030000o`3oool0oooo00H0
oooo10000?l50?ooo`030000o`3oool0oooo00D0oooo10000?l60?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool20000o`030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`@0003o1`3oool00`000?l0oooo0?ooo`0h0?ooo`00
;P3oool00`00000000L00007000200070003000G0000<000030000@003000P00000;001/00P008L0
1P00V@0?002[01400;X04@00a`0B003C01400=h04000j004000000800?<000<00000003c0000l`00
0P00j0001`0000000>P0003X0000j0000?8000000000lP000P0000000`00lP000000003b0003003b
000500000000lP000?/0003k000000002000j`030000o`<00=8000@00;h0002H003oool0oooo0`00
0?l80?ooo`040000o`3oool0003o0000o`H0oooo00<0003o0?ooo`3oool00P3oool50000o`P0oooo
00@0003o0?ooo`3oool0oooo0`000?l20?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0000o`020000o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`D0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03P0
oooo000^0?ooo`04000000001`0000L00007008001L01@00<0000`00000004H0001/000;001/00H0
08L02000V@0?002[01400;X04@00a`0B003C01400=h04000j0000`0000000?<0003c0004000000@0
0?<000H00000003X0000j0000>P0003b00000003003b008000001000lP00100000000?80003k0000
n`03000000<00>/00`000?l3003]0080003o00<00=80002n0000_P000P000?l30?ooo`030000o`3o
ool0oooo00@0oooo0`000?l80?ooo`030000o`3oool0003o0080003o103oool00`000?l0oooo0?oo
o`060?ooo`040000o`3oool0003o0000o`H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`D0003o1`3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`D0
003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03P0oooo000]0?ooo`040000
00001`0000L0000700<001L00`00<0020000008004H03000K003002700/009T03`00Z`0A002j0140
0=404@00g00B003N01000>P000<00000003c0000l`000`00l`03000000800?<000H00000003c0000
l`000?<0003b00000004003b008000000`00lP001@0000000?80003k0000n`00000000800?/00P00
000010000?l00>/0003[0000j`04003]0005003B00000?l0003o0000o`00V0001@3oool00`000?l0
oooo0000o`030000o`<0oooo00<0003o0?ooo`3oool01@3oool20000o`P0oooo00<0003o0?ooo`3o
ool0103oool30000o`P0oooo00<0003o0?ooo`3oool01P3oool40000o`@0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`@0003o1@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=`3oool002d0oooo00<00000000700001`00
0`005`03000`000300000000<00004H0008004H03000K00>002I00l00:/02@00^P08003501400=40
4@00g009003W00T00=h04000j0000`0000000?<0003c0003003c000300000000l`000?<000<00000
0`00l`000`00o@000000003b0003003b000300000000lP00000000<0000000@00?80003k0000n`00
00000`00n`02000000<00>/01000k@030000o`800;h01@3oool30000o`L0oooo00@0003o0?ooo`3o
ool0oooo0`000?l20?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l00`000?l30?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@000?l00`3oool0003o0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P000?l80?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0g0?ooo`00;03oool200000003
000700005`0001L0008001L00P00<0000`00000004H000160003001600X006`00P00PP0>002I00l0
0:/04@00a@0A003A01400=`04@00i`0A003X000300000000l`000?<000<00?<000<00000003c0000
l`000P00l`0400000004003m000000000?d0003m00800?8000<00000003b0000lP000P00lP020000
00800?/000@00000003k0000n`000?/00`000002003[0004003]00000?l0003o0000o`800>d000@0
0=800000o`00_P0009P00P3oool20000o`<0oooo00<0003o0?ooo`3oool01@3oool30000o`H0oooo
00<0003o0?ooo`3oool00P3oool50000o`P0oooo00<0003o0?ooo`3oool0103oool40000o`H0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`@0003o1P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool30000ocP0oooo
000/0?ooo`8000001@005`000`00<000000000160005001600P006`01000PP0>002I00`00:/01000
^00@003501400=404@00g00A003W00@00?403@00j0000`0000000?<0003c0002003c000300000000
l`000?<000<00?<000@00000003c0000l`000?<00`000003003m000300000000lP000?8000800?80
00<00000003b000000000P000003003k000300000000n`000?/00080000000<0003o003]0000k@00
1000k@000`00_P00003o002n00020000o`H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?oo
o`000?l0oooo00L0oooo10000?l50?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l0
0`000?l20?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool60000o`80oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
2@000?lk0?ooo`00:`3oool2000000H001L000<0000000160000AP001@00AP06001/00H008803P00
V@08002[00P00;P04000a@0A003A01400=`04@00i`08003a00T00>P00`000002003c000300000000
l`000?<000<00?<000L00000003c0000l`000?<0003m000000000?d00080000000<00?d000000000
o@000`00lP001@0000000?80003k0000n`00000000<00?/000@00000003k0000n`000?/00P000006
003]0003002n00000?l0003o00T0oooo10000?l40?ooo`030000o`3oool0oooo00@0oooo0`000?l8
0?ooo`030000o`3oool0oooo00<0oooo10000?l70?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool40000o`P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`D0003oA03oool002/0oooo0P000004000G008000002000AP04001/00P008803P00V@04002[
00`00;P04000a@0A003A01400=`04@00i`0<003a00D00>P000<00000003c0000l`000`000004003c
000300000000l`000?<000800?<000<00?d000000000o@000P00o@02000000<00?d000<00000003b
0000lP000P00n`0300000003003k000000000?/000800?/00`000003003]00<0003o0P00_P000`00
0?l0oooo0?ooo`030?ooo`@0003o203oool00`000?l0oooo0?ooo`030000o`<0oooo00<0003o0?oo
o`3oool01P3oool50000o`<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`@0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0003o0?oo
o`3oool0oooo1@000?m80?ooo`00:`3oool2000000<001L000<00000000G0000AP002000AP02001/
00X008803P00V@0@002h01000<D04@00d@0A003L01400>L04000l@02000000@00?<0100000000`00
l`000000003c0003003c0003003m000000000?d000<00?d00P000002003m000300000000o@000?80
00800?/000<00000003k0000n`000P000003003k000400000000o`000?l000000080003o0`00k@00
0`00h`000;h0002n00050000o`@0oooo00<0003o0?ooo`3oool0103oool40000o`L0oooo00@0003o
0?ooo`3oool0oooo1@000?l80?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P00
0?l70?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool40000odd0oooo000[
0?ooo`07000000001`0001L0000G0000000001L0000U0009001600`008803000V@03002X00l00;P0
4000a@0A003A01400=`04@00i`0@003a0080000000D00?/0003c0000l`000?<000000003003c0080
00001000l`000`0000000?d0003m0003003m000300000000o@000000008000000P00o@02003k0005
00000000n`000?/0003k000000000`00n`000`0000000?l0003o0002000000@00>d000<00><0002n
0000_P000P000?l80?ooo`030000o`3oool0003o00<0003o0`3oool00`000?l0oooo0?ooo`050?oo
o`@0003o1@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo10000?l60?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0000o`040000
oe40oooo000[0?ooo`05000000001`0001L0000000005`000P009@0800160003001S0000PP000880
00X008802@00V@06002X00l00;P04000a@0A003A01400=`04@00i`0@003a000300000000n`000?/0
00<00?/000<00000003c0000l`000P00l`0400000003003c000000000?d000@00?d000@00000003m
0000o@000?d00`000002003o000400000000n`000?/0003k00<0000000L00?/000000000o`000?l0
00000000o`00000000<00>d00`000?l00`00V`00oooo0000o`050?ooo`@0003o203oool00`000?l0
oooo0?ooo`040000o`030?ooo`000?l0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0000o`030000o`80oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0003o00L0003oEP3oool002X0oooo00D00000000700005`0001L000000003000U00L0
04H00P00H`0<002200H009T02@00Z00?002h01000<D04@00d@0A003L01400>L04000l@000`000000
0?/0003k0003003k000300000000n`000?/000800?<000@00000003c0000l`000?<00`000003003m
000300000000o@000?d000800?d000H00000003m0000o@000000003o00000003003k000300000000
n`000?/0008000000P00o`00100000000?l0003o000000020000o`<00><000D00;h00?ooo`3oool0
003o0?ooo`030000o`@0oooo00<0003o0?ooo`3oool01@3oool30000o`D0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`D0003o1P3oool00`000?l0oooo0?ooo`060?ooo`04
0000o`3oool0oooo0?ooo`D0003oGP3oool002X0oooo00@00000000700005`00000010009@060016
00<006<03000PP03002I00`00:P03`00^00@003501400=404@00g00A003W01000?40100000000`00
n`000000003k0004003k000300000000l`000?<000800?<000H00000003m000000000000003m0000
0004003m000400000000o@000?d0003o008000000P00o`000`00n`000000003k0002003k00040000
0000o`000?l0000000800?l00`000003003S0003002n0000V`00oooo0080003o203oool00`000?l0
oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`P0
003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo10000?mS0?ooo`00
:P3oool200070003000000009@0002D000<002D01@00AP04001S00`008803`00Z00?002h01000<D0
4@00fP0A003U01400>L04000l@00100000000?/0003k0000n`04000000<00?/000H00000003k0000
n`000?/0003m00000003003m008000001000o@00100000000?d0003m0000o`03000000800?l000@0
0000003k0000n`000?/00P0000001`00o`000000003o0000o`000000003o000000000`00h`030000
o`030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`000?l00P000?l40?ooo`030000o`3oool0oooo
00@0oooo1@000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050000ofL0oooo000Z0?ooo`0300070000000002D000D002D01000AP05001S00X0
08800`00U@0>002X00l00;P02000a@08003@01400=X04@00i@08003^00T00>L04000l@000`000000
0?/0003k0002003k000300000000n`000?/000@000000`00n`000`00o`000000003o0003003m0080
00000`00o@001@0000000?d0003m0000o`00000000800?l00`0000001@00o`000?/000000000n`00
0?l0008000000P00o`00100000000?l0003o000000020000o`03003S0000V`00oooo0080oooo00<0
003o0?ooo`3oool00`3oool40000o`L0oooo00<0003o0?ooo`3oool010000?l00`3oool0003o0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l01`000?m/0?ooo`00:@3oool0
0`001`000000000U0006000U00<004H01P00H`08002200D009D03P00Z00?002h01000=004@00fP0A
003U01000>h04000l@02000000@00?/000<00000003k0000n`000`00n`02000000800?/000<00?l0
00000000o`000P00o`000`00o@000000003m0004000000800?d000<00?l000000000o`000P00o`02
000000800?l000@00000003k0000o`000?l00P0000001@00o`000000003o0000o`00000000@00><0
00@009/00?ooo`3oool0oooo1@000?l30?ooo`030000o`3oool0oooo00@0oooo10000?l60?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool50000og@0oooo000Y0?ooo`030007
0000000002D000H002D00P00AP07001S00H008801`00U@0>002X00`00;P01000a00?003@01400=X0
4@00i@0@003^00@00?P03000l@02000000@00?/000<00000003k0000n`000`00n`001P0000000?/0
00000000n`000?l0000000@00?l000<00000003m0000o@000P00o@0200000003003m0000o`000000
00<00?l000<00000003o000000000P000003003o000400000000o`000000000000800?l00P000003
003S00@0003o00<0oooo0000o`3oool01P3oool00`000?l0oooo0000o`030000o`80oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`@0003oN@3oool002T0oooo00<000000007
00009@001P009@09001S00@008802@00U@0>002X00P00;P02000a00?003@01400=X04@00i@0@003^
00P00?P02000l@03000000<00?/000<00000003k0000n`000P00n`00100000000?/0003k0000n`03
000000@00?l000D00000003o0000o`000?d000000002003m00<000000`00o`001@0000000?l0003o
0000o`00000000<00?l000@00000003o0000o`0000000P00o`000`0000000?l0000000020000o`03
002K003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool40000o`L0oooo00<0003o0?ooo`3o
ool0103oool90000ogd0oooo000Y0?ooo`0300000000600002D000H002D02@00H`02002200/009D0
3P00Z004002h00`00<@03`00d00A003J01400>D04000kP0<003h00@00?4000<00000003k0000n`00
10000004003k000400000000n`000?/0003k00800?l01@000004003o000600000000o@000?d0003m
0000o`0000000`00o`00100000000?l0003o0000o`02000000800?l000<00000003o0000o`000P00
00000`00o`000000003o000200000003003S0000`P00oooo00@0oooo1@000?l40?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool010000?l00`3oool0003o0?ooo`230?ooo`00:03oool0
0`00000000L0000H0006000U0003000h0000H`0006<000L006<03@00U@0>002X01000<@03`00d00A
003J01400>D04000kP0@003h000300000000n`000?/000<00?/00`000002003k000600000000n`00
0?/0003k0000o`0000001000o`03000000800?l000<00000003o0000o`000P00o`0300000003003o
000000000?l000800?l000D00000003o000000000?l000000002003o000500000000o`0000000000
0000o`000`0000000`00`P0009/00000o`040000o`P0oooo00<0003o0?ooo`3oool00`3oool40000
ohX0oooo000X0?ooo`0300000000600001P000D002D00P00>008001S008007/03000U@0<002X00<0
0;H03`00a00?003@01400=X04@00i@0@003^01000?P000@00000003o0000o`000?l00P00n`000`00
00000?/0003k0003000000<00?/000<00?l000000000o`000`00o`000`0000000?l0003o00030000
00@00?l000<00000003o0000o`000P000003003o000300000000o`000?l0008000000P00o`002000
00000?l0003o000000000?l000000000o`0000000P000?l50?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`000?l00`000?n>0?ooo`009`3oool01000000000L0000H00006004000U00<003P0
1`00H`03001k00`009D02@00Z006002f00l00<@03`00d00A003J01400>D04000kP0@003h00030000
0000o`000?l000<00?l000<00000003k0000n`000P00n`0400000003003o000000000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0002003o000500000000o`000?l0003o0000
00000`00o`000`0000000?l0003o000300000004003o000000000?l0003o00<0000000@00?l00000
000000000<801@3oool:0000oi80oooo000W0?ooo`0400000000600001P0000H00<002D01000>006
001S00@007/03000U@06002X00T00;H03`00a00?003@01400=X04@00i@0@003^01000?P00P000003
003o000300000000o`000?l000<00?l000@00000003k0000n`000?/00P000004003o000300000000
o`000?l000800?l00`000002003o000500000000o`000?l000000000o`000P0000001@00o`000000
003o0000o`00000000800?l00P000002003o000400000000o`000000003o0080000000<00<800?oo
o`3oool01@000?nJ0?ooo`009`3oool01000000001P0000H00006002000U00D003P01@00H`05001k
00`009D00`00Z00<002f00l00<@03`00d00A003J01400>D04000kP0?003h00D0000000<00?l00000
0000o`001000o`000`0000000?l0003o0002003o00<000000P00o`000`0000000?l0003o0002003o
000300000000o`000?l0008000000`00o`00100000000?l0003o0000o`02000000800?l000D00000
003o0000o`000?l000000002003o000700000000o`000000003o000000000<80000000020000oil0
oooo000V0?ooo`0300000000600001P0008001P000<002D0000h0000>0001000>004001S00H007/0
3000U@0?002f00l00<@03`00d00A003J01000>D04@00kP0?003h008000000`00o`03000000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003000000<00?l000<00000003o0000o`00
0P00o`02000000800?l000<00000003o0000o`000P00o`00100000000?l0003o00000002003o0006
00000000o`000000003o000000000?l00`0000000`00j`0000000032002P0?ooo`009P3oool00`00
000001P0000H0002000H00L003P00`00H`08001k00X009D00P00Y@0>002f00l00<@03`00d00A003S
01000>`02000mP09003^00l00?P000<00000003o0000o`000P00o`000`0000000?l0003o00040000
00D00?l000@00000003o0000o`000?l00`000002003o000300000000o`000?l000800?l000D00000
003o000000000?l000000003003o000300000000o`000000008000000P00o`000`0000000?l0003o
000200000005003o000000000?l000000000j`000P00002P0?ooo`009P3oool00`00000001P0000H
0002000H0003000V0000>00003P000@003P00P00H`09001k00P009D01000Y@0>002f00l00<@02000
d008003I01000><04000k00@003f01000?P000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00@0000000<00?l000000000o`000`00o`000`0000000?l0003o0003000000<00?l000@0
0000003o0000o`000?l00P000003003o000500000000o`000?l0003o000000000P00o`000`000000
0?l0003o000200000005003o000000000?l000000000j`000P00002P0?ooo`009P3oool010000000
01P0000H00006002000V00H003P02`00N`06002E00H00:D03P00]P0?003401000=T04000h`0@003/
01000?H01000o`0<003h008000000`00o`000`0000000?l0003o0003003o000400000000o`000?l0
003o008000001000o`000`0000000?l0003o0002003o00<0000000<00?l000000000o`000`00o`02
000000800?l000P00000003o0000o`000000003o000000000?l0000000800?l00P0000000`00o`00
0000003o000400000:00oooo000V0?ooo`0400000000600001P0000H008002H01P00>0000`00E`00
07/0001k0008001k00@009D02000Y@0>002f00X00<@01P00cP0?003I01000><04000k00@003f00P0
0?l01`00n007000000D00?l000H00000003o0000o`000?l000000000o`02000000800?l000<00000
003o0000o`000P00o`000`0000000?l0003o0002000000@00?l000D00000003o000000000?l00000
0002003o000300000000o`000?l0008000000P00o`001@0000000?l00000000000000?l000<00000
00<00<800000003oool0WP3oool002D0oooo00@000000?ooo`00600001P00`009P05000h008005L0
2P00N`02002E00X00:D03P00]P05003400/00<h03`00f@0@003S01000>`04000mP0<003o00<00?P0
0P000004003o00<000000P00o`000`0000000?l0003o0002003o000400000000o`000?l0003o00<0
00001000o`00100000000?l0003o0000o`02000000800?l000@00000003o0000o`000?l00P000002
003o000500000000o`000?l0003o000000000P00o`002P0000000?l00000000000000?l000000000
j`00000000320000002O0?ooo`009@3oool010000000oooo000H00006003000V00@003P00`00E`0:
001k00d00:D03@00]P0@003>00l00=T04000h`0@003/01000?H03`00o`000`0000000?l0003o0002
003o000400000000o`000?l0003o00<000001000o`000`0000000?l0003o0002003o00<000000P00
o`000`0000000?l0003o0002003o000500000000o`000000003o000000001000o`0200000009003o
000000000?l0003o000000000?l000000000o`00000000800?l000P00000003o000000000>/00000
0000j`00oooo000009h0oooo000U0?ooo`030000003oool001P000@002H00`00>004001G00T007/0
0P00T00<002U00/00;H00`00`P0?003>00l00=T04000h`0@003/01000?H03`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l00`000002003o000300000000o`000?l000800?l0
00<00000003o0000o`000`000004003o000300000000o`000?l0008000000`00o`000`0000000?l0
003o0002000000800?l000<00000003o0000o`000P000002003o00<0000000D00>/000000000j`00
oooo0000002N0?ooo`009@3oool00`00000000@0000H0004000V008003P01@00E`08001k00<00900
3000Y@08002f00H00<803`00cP0?003I01000><04000k00?003f01000?l00`000002003o00030000
0000o`000?l000800?l000@00000003o0000o`000?l00`000004003o000300000000o`000?l00080
0?l00P000002003o000300000000o`000?l000800?l00P000002003o000400000000o`000?l0003o
0080000000<00?l000000000o`000P00o`002`0000000?l0003o000000000?l000000000j`000000
003[00003000000009h0oooo000U0?ooo`0300000000100002H000@002H000<003P0001G0000E`00
1@00E`06001k00@009003000Y@06002f00P00<803`00cP0?003I01000><04000k00?003f00l00?l0
0P000002003o00<000001000o`000`0000000?l0003o0003003o00D000001000o`000`0000000?l0
003o0003000000@00?l000D00000003o000000000?l000000003003o000400000000o`0000000000
00800?l000@00000003o0000000000000P00o`0300000003003[0000^000000009h0oooo000U0?oo
o`0300000000100002H000@002H02000E`04001k00H009003000Y@03002f00/00<803`00cP0?003I
01000><04000k00?003f00l00?l00P000004003o00<000000P00o`000`0000000?l0003o0002003o
000300000000o`000?l000800?l00P000003003o000300000000o`000?l000800?l00P000002003o
000400000000o`000?l0003o008000000P00o`001@0000000?l0003o0000o`00000000800?l000@0
0000003o0000o`0000000P00o`0300000004003[0000^000oooo000009d0oooo000U0?ooo`030000
0000100002H000@002H000<00380001G0000E`001@00E`03001k00L009003000Y@0>003200l00<h0
3`00f@0@003S01000>`03`00mP0?003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`000004003o000300000000o`000?l000800?l000<00000003o000000000P00o`001@0000000?l0
003o0000o`00000000800?l000<00000003o000000000`00o`001@0000000?l000000000o`000000
00<00?l00P0000001000o`000000003o0000o`0200000008003o00000000000000000000j`000;P0
0?ooo`00002M0?ooo`009@3oool00`00000000@0000V0003000V008003801`00E`02001k00T00900
2P00Y@02002d00d00<803`00cP0?003I00l00><04000k00@003f00l00?l00P000003003o00030000
0000o`000?l000<00?l00`0000000`00o`000000003o0004003o000300000000o`000?l000<00000
0`00o`00100000000?l0003o0000o`02000000<00?l000@00000003o0000o`0000000`00o`000`00
00000?l0003o0002000000800?l00`0000001`00o`000000003o0000j`000;P00?ooo`000000W@3o
ool002H0oooo00<000@0000V00009P000P009P02000b00L005L02`00T008002U00@00;@03P00`P0>
003>00P00=T02000h@0?003Z00l00?<02000o008003f00l00?l01P000004003o000400000000o`00
0?l0003o00<000001000o`000`0000000?l0003o0002003o008000000P00o`002@0000000?l0003o
0000o`000000003o000000000?l000000003003o00<0000000<00?l000000000o`000P00o`003@00
00000?l0003o000000000?l000000000o`000000003o0000j`000;P00?ooo`000000W@3oool002H0
oooo00@001H0000V00009P0002H00`00<P06001G008007<02P00T006002U00H00;@03P00`P0>003>
01000>403`00jP0?003c00l00?`03`00o`02000000@00?l00`000002003o000300000000o`000?l0
00800?l000<00000003o000000000`000004003o000300000000o`000?l000<000000`00o`000`00
00000?l0003o0002000000<00?l000<00000003o0000o`000P000003003o000=00000000o`000?l0
00000000o`000000003o000000000?l0003[0000^000oooo0000002M0?ooo`009P3oool00`005P00
02H0000V0004000b00D005L00`00L`0:002@00@00:D02@00]00=003200/00<h01000f00?003Q00l0
0>X03`00l`0?003l00l00?l00P000004003o000300000000o`000?l000<000001000o`000`000000
0?l0003o0002003o008000000`00o`000`0000000?l0003o0002003o008000000P00o`0010000000
0?l0003o0000o`02000000800?l000<00000003o0000o`000P000002003o000400000000o`000000
000000800?l00`000002003o0003002h00000000oooo09d0oooo000V0?ooo`03000F00009P0002H0
00@003801000E`04001c00X009000P00Y@0;002d00d00<801`00cP08003H00l00>403`00jP0?003c
00l00?`03`00o`02000000<00?l000<00000003o0000o`000P00o`00100000000?l0000000000002
003o000300000000o`000?l000800?l000<00000003o000000000P000004003o000300000000o`00
0?l0008000001000o`000`0000000?l000000002000000800?l000D00000003o000000000?l00000
0002003o0080000000@00?l000000000o`0000000P00o`000`00^00000000?ooo`2M0?ooo`009P3o
ool00`005P0002H0000b0004000b00<005L01P00L`09002@00d00;@03@00`P04003>00/00=P03`00
h@0?003Z00l00?<03`00o00?003o00H000001000o`00100000000?l0003o0000o`03000000<00?l0
00<00000003o0000o`000P00o`03000000800?l000@00000003o0000o`000?l00P000003003o0005
00000000o`000?l0003o000000000P00o`000`0000000?l0003o0002000000800?l00P0000001000
o`000000003o00000002003o0003002h00000000oooo09d0oooo000U0?ooo`8001H01P00<P02001G
00L007<02000T002002R00`00;@03@00`P0?003H00l00>403`00jP0?003c00l00?`03P00o`020000
00<00?l010000002003o000300000000o`000?l000800?l000H00000003o000000000000003o0000
0004003o000300000000o`000?l0008000001000o`000`0000000?l000000002000000<00?l000D0
0000003o000000000?l000000002003o0080000000L00?l000000000o`000?l000000000o`000000
00<00?l000<00>D00000003oool0W@3oool002H0oooo00<001H0000V0000<P001000<P000`00E`00
07<0001c0006001c00L009000`00XP0=002d00T00<801000c@0>003H00l00>403`00jP0?003c00l0
0?`03P00o`02000000@00?l000<00000003o0000o`000`000004003o000400000000o`000?l0003o
00<000000P00o`000`0000000?l0003o0002003o008000000`00o`001@0000000?l0003o0000o`00
000000<00?l000D00000003o000000000?l000000002003o0080000000L00?l000000000o`000?l0
00000000o`00000000<00?l000<00>D00000003oool0W@3oool002H0oooo00<001H0000V0000<P00
1000<P0:001c00@009001P00XP0<002d00H00<801`00c@0>003H00l00>403`00jP0?003c00h00?`0
3`00o`02000000@00?l000@00000003o0000o`000?l0100000000`00o`000000003o0003003o0003
00000000o`000?l000<000001000o`000`0000000?l000000002003o000400000000o`000?l0003o
0080000000<00?l000000000o`000P00o`02000000800?l000@00000003o0000000000000P00o`03
000000<00?l000<00>D00?ooo`3oool0W@3oool002H0oooo00<001H0000V0000<P001000<P000`00
BP0007<0001c0007001c00<009001`00XP0<002d00<00<802P00c@0?003H00h00>403`00jP0?003c
00h00?`03`00o`000`0000000?l000000003000000@00?l000@00000003o0000o`000?l00`000003
003o000300000000o`000?l000800?l00P000002003o000400000000o`000?l0003o008000000`00
o`000`0000000?l0003o0002000000<00?l010000002003o0080000000D00?l000000000o`000?l0
00000003003o0003003U003oool0oooo09d0oooo000V0?ooo`03000F00009P00038000<003800P00
BP09001c008009002000XP0<002d00h00<d03P00f00>003Q00l00>X03`00l`0>003l00l00?l000<0
0000003o0000o`000P00o`03000000800?l000<00000003o0000o`000P00o`001P0000000?l00000
000000000?l0000000@00?l000D00000003o000000000?l000000004003o00<0000000<00?l00000
0000o`000P00o`02000000800?l000@00000003o0000000000000P00o`00100000000?l000000000
0002003o000500000000o`000?l0003o0000i@00W`3oool002H0oooo00<001H0000V0000<P000`00
<P02001:00T007<02`00XP09002d00<00<403@00c@0>003H00h00>403`00jP0?003c00h00?`03P00
o`02000000<00?l000@00000003o0000o`000?l00`000004003o000400000000o`000?l0003o0080
00000`00o`00100000000?l0003o0000o`02000000<00?l000D00000003o0000o`000?l000000003
003o000300000000o`000?l0008000000P00o`02000000800?l000@00000003o0000000000000P00
o`001@0000000?l0003o0000o`000>D009l0oooo000V0?ooo`03000F00009P0002H0008003801000
BP07001c008008/02P00XP07002d00D00<403@00c@0>003H00h00>403`00jP0>003c00l00?`03P00
o`03000000800?l000<00000003o0000o`000`00o`0300000003003o000000000?l000<00?l000<0
0000003o000000000`000003003o000600000000o`00000000000000o`0000000`00o`0200000080
0?l000D00000003o0000o`000?l000000002003o000300000000o`0000000080000000<00?l00000
0000o`000P000004003o0003003U003oool0oooo09d0oooo000V0?ooo`03000F00009P0002H00080
03801000BP06001c00<008/02`00XP04002d00P00<403000c@0>003H00L00>402000j@0>003a00h0
0?X01`00o`08003l00h00?l000<00000003o0000o`0010000003003o000400000000o`000?l0003o
008000001000o`000`0000000?l0003o0002003o008000000P00o`00100000000?l0003o0000o`02
000000800?l000<00000003o0000o`000P000003003o000500000000o`000000003o000000000P00
o`0200000003003o000000000?l0008000001000o`000`00i@00oooo0?ooo`2M0?ooo`009P3oool0
10005P0002H0000V0000<P05001:00D007<01000R`0;002R00800;@02P00`@0=003=00d00=P03`00
j@0>003a00h00?X07@00o`000`0000000?l0003o0002003o000300000000o`00000000<000000`00
o`000`0000000?l000000003000000@00?l000<00000003o0000o`000`000003003o000300000000
o`000000008000000`00o`02000000800?l000<00000003o0000o`000P000002003o0080000000@0
0?l000000000o`0000001000o`02003U09l0oooo000V0?ooo`<002H000<00380001:0000BP001000
BP03001c00H008/02P00XP0<003100d00<d02@00f005003Q00h00>T03P00l@0>003j01`00?l00P00
0003003o000300000000o`000?l000800?l0100000000`00o`000000003o0003003o008000000`00
o`000`0000000?l0003o0002003o000400000000o`000?l0000000@00?l000T00000003o0000o`00
0?l000000000o`000000003o000000000`00o`001@0000000?l0003o000000000?l00080000000<0
0?l000000000o`001000o`000`00i@00oooo0?ooo`2M0?ooo`009`3oool2000V00L004X00P00L`07
002;00T00:800P00/P0<003100`00<d01@00f009003Q00h00>T03P00l@0>003j01`00?l01P000004
003o000400000000o`000?l0003o008000000`00o`000`0000000?l0003o0003000000@00?l000D0
0000003o000000000?l000000003003o000500000000o`000000003o000000000`00o`0200000080
0?l000@00000003o0000000000000P00o`0200000003003o000000000?l000@00?l000<00>D00?oo
o`3oool0W@3oool002L0oooo0P009P000`00=00004X0001:0004001:0003001c0000R`0008/000H0
08/01`00XP04002b00`00<403000c@0>003Q00h00>T03P00l@0>003j01`00?l000<00000003o0000
o`000P00o`03000000800?l000<00000003o0000o`000P00o`05000000@00?l00`000002003o0003
00000000o`000?l0008000000`00o`000`0000000?l0003o0002000000<00?l00P000002003o0004
00000000o`000000000000800?l00`000006003o0003003U003oool0oooo09d0oooo000W0?ooo`80
02H000<003@0001:0000BP001000BP0:002;00D00:801P00/P0;003100X00<d00`00f00=003Q00h0
0>T03P00l@0>003j01`00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003000000<0
0?l000<00000003o0000o`000P00o`02000000800?l000@00000003o0000o`000?l00P000003003o
000600000000o`00000000000000o`0000000P00o`02000000800?l000<00000003o0000o`000P00
0003003o000300000000o`000?l000<000001P00o`000`00i@00oooo0?ooo`2M0?ooo`009`3oool2
000V0003000d0000BP0004X000@004X000<006X0002;0000R`001`00R`03002R00P00;803000`@06
003=00H00=P03P00h@0=003Y00h00?403P00nP0K003o00H000001000o`03000000800?l000<00000
003o0000o`000P00o`000`0000000?l000000002000000@00?l00`0000000`00o`000000003o0002
003o008000000P00o`001@0000000?l000000000o`00000000<00?l000D00000003o0000o`000000
003o000200000003003o00000000000000H00?l000<00>D00?ooo`3oool0W@3oool002L0oooo00@0
01@0000V0000=00003@01000BP02001Z00T008/00P00XP09002b00`00<400`00c@09003H00h00>40
3@00j@0>003a00h00?X06`00o`00100000000?l0003o0000o`04000000800?l000<00000003o0000
o`000`000003003o000300000000o`000?l000800?l00P000002003o000400000000o`000?l0003o
008000000`00o`02000000800?l000<00000003o0000o`000P000003003o00@000000P00o`000`00
00000?l000000007003o0003003U003oool0oooo09d0oooo000W0?ooo`04000D00009P0003@0000d
00@004X00`00JP08002;00`00;802`00`@0=003H00d00>403@00j@0>003a00h00?X06P00o`000`00
00000?l0003o0006003o008000001000o`001P0000000?l00000000000000?l0000000@00?l000D0
0000003o000000000?l000000003003o000300000000o`00000000800?l000<00000003o00000000
0P000002003o000500000000o`000000003o000000000P00o`001@0000000?l0003o000000000?l0
008000001`00o`000`00i@00oooo0?ooo`2M0?ooo`009`3oool01000500002H0000d0000=003001:
00@006X02000R`000`00W`000;80002b0009002b00T00<400`00c@0<003H00d00>403@00j@0>003a
00h00?X06P00o`000`0000000?l0003o0008003o008000000P00o`00100000000?l0003o0000o`03
000000800?l000D00000003o0000o`000?l000000004003o000300000000o`000?l0008000000`00
o`04000000<00?l00P000002003o0080000000<00?l000000000o`000P000007003o0:00oooo000W
0?ooo`03000D00009P0003@0008003@00P00BP04001Z00L008/00P00W`0;002b00L00<401@00c@0<
003H00h00>403000j@0>003a00h00?X06P00o`000`0000000?l0003o000:003o00<000000`00o`00
0`0000000?l0003o0003000000<00?l00`000002003o000400000000o`000?l0003o008000000P00
o`00100000000?l0000000000003003o0080000000L00?l000000000o`000000003o000000000?l0
008000001`00o`2P0?ooo`00:03oool4000d0003001:0000JP0006X000@006X01@00R`04002O00/0
0;801000`@08003=00`00=P03@00h@0<003Y00h00?403@00nP0K003o000300000000o`000?l000d0
0?l00P0000000`00o`000000003o0002003o00<0000000<00?l000000000o`000P00o`02000000<0
0?l000<00000003o0000o`000P000002003o008000000`00o`00100000000?l0000000000002003o
000400000000o`000?l0000000P00?l0X03oool002P0oooo00D001@0000d0000=00003@0001:0006
001Z00@008/01@00W`0;002b00800<402P00c@0<003H00d00>401P00j@07003a00d00?T09`00o`00
0`0000000?l0003o000@003o008000000P00o`00100000000?l0003o0000o`02000000@00?l00`00
00000`00o`000000003o0002003o000500000000o`000?l000000000o`000`000002003o00040000
0000o`000?l0003o0080000000<00?l000000000o`001P00o`000`00c`00oooo0?ooo`2N0?ooo`00
:03oool01000500003@0000d0000=008001Z008008/01`00W`0:002b00`00<d03000f00=003Q00d0
0?403@00n@0W003o000300000000o`000?l001800?l00`000004003o00<0000000<00?l000000000
o`000P00o`02000000800?l000@00000003o0000000000001000o`000`0000000?l0003o00020000
0003003o000000000?l0008000002000o`2Q0?ooo`00:03oool01@00500003@0000d0000=00004L0
00L006X000<008/0002O0000W`001P00W`09002b00800<403000c@0<003H00P00>401@00j@0<003a
00d00?T09`00o`000`0000000?l0003o000D003o00<0000000<00?l000000000o`000P00o`020000
00<00?l000D00000003o000000000?l000000002003o008000000P00o`0200000004003o00000000
0?l0003o008000000P00o`000`0000000?l0003o0006003o0:40oooo000Y0?ooo`03000U0000=000
03@0008004L01P00JP0:002O00L00;800`00`@0<003=00`00=P01000h@09003Y00`00?403@00n@0W
003o000300000000o`000?l001L00?l00P000003003o000300000000o`000000008000000`00o`00
100000000?l0003o00000002003o000400000000o`000000003o008000000P00o`00100000000?l0
003o00000008003o0003003?003oool0oooo09l0oooo000Y0?ooo`03000U0000=00003@0008004L0
1P00JP000`00QP0009l0002O0007002O00D00;801P00`@0;003=00`00=P03@00j@0<003a00d00?T0
9`00o`000`0000000?l0003o000I003o000300000000o`00000000<00?l00P000003003o00800000
00@00?l000000000o`000?l00P000002003o008000000P00o`0200000003003o000000000?l000L0
0?l000<00<l00?ooo`3oool0W`3oool002T0oooo00<002D0000d0000=0000`00A`05001Z00030026
0000W`0009l000P009l00`00/P07003100`00<d02000f004003Q00d00>T02`00l@0=003i02H00?l0
00<00000003o0000o`006`00o`02000000<00?l000D00000003o000000000?l000000002003o0080
00000`00o`001@0000000?l0003o000000000?l0008000000P00o`000`0000000?l0003o0007003o
0:80oooo000Y0?ooo`8002D000@003@000170000A`0004L01000JP03002600T009l00P00/P090031
00/00<d01000f008003Q00d00>T03000l@0<003i02H00?l000<00000003o0000o`007@00o`030000
00<00?l00P000002003o000600000000o`000000003o000000000?l00P000003003o000400000000
o`000?l0000000P00?l000<00<l00?ooo`3oool0X03oool002T0oooo0P009@000`00=00004L00017
0002001700<006X00`00QP09002O00/00<402`00c@0=003Q00`00>T03000l@0<003i02H00?l000<0
0000003o0000o`007`00o`02000000800?l00`0000001000o`000000003o0000o`02000000800?l0
0P0000000`00o`000000003o0002000000T00?l000<00<l00?ooo`3oool0X03oool002X0oooo00<0
02D000170000A`000`00A`02001Z00D008H01`00W`02002b00/00<402000c@03003I00`00>403000
j@0<003a00`00?T09@00o`000`0000000?l0003o000R003o008000000`00o`02000000800?l00P00
00001`00o`000000003o000000000?l000000000o`000P000009003o0:<0oooo000Z0?ooo`8002D0
1@00A`000`00JP0008H000260003002600H009l01000/P0:003100H00<d01@00f@0<003Q00d00>T0
2`00l@0<003i02D00?l000<00000003o0000o`008`00o`00100000000?l0003o0000o`0400000080
0?l00P000002003o000400000000o`000?l0000000T00?l000<00?T00?ooo`3oool0X@3oool002X0
oooo0P009@05001700L008H01000W`05002b00/00<400`00c@08003I00`00>403000j@0;003a00`0
0?T09000o`000`0000000?l0003o000U003o000300000000o`00000000800?l00P000002003o0080
000000H00?l000000000o`000000003o00000009003o0003003?003oool0oooo0:40oooo000[0?oo
o`03000U0000=@0004L000<004L000<006<000260000QP001000QP03002O00L00;802P00`@0;003I
00`00>403000j@0;003a03000?l000<00000003o0000o`009P00o`02000000800?l00P000002003o
0080000000<00?l000000000o`000P00000:003o0:@0oooo000[0?ooo`03000U0000=@0004L000<0
04L00P00H`0600260003002O0000/P000;8000L00;802000`@02003?00/00=T02`00h@0<003Y00`0
0?T0;`00o`000`0000000?l0003o000X003o000400000000o`000000003o008000000P00o`000`00
00000?l0003o0002000000T00?l000<00?T00?ooo`3oool0XP3oool002/0oooo00<002D0000e0000
=@000`00A`02001S00H008H02P00/P07003100@00<l02P00f@0<003Q00P00>T01000lP0;003i02h0
0?l000<00000003o0000o`00:P00o`000`0000000?l0003o0002000000800?l00`00000;003o0003
003i003oool0oooo0:80oooo000/0?ooo`8003D00P00A`04001S00D008H000<009h0002b0000/P00
2000/P04003100H00<l02`00f@0;003Q00@00>T02000lP0;003i02h00?l000<00000003o0000o`00
:P00o`000`0000000?l0003o000200000003003o000000000?l0008000002`00o`2U0?ooo`00;03o
ool3000e000300170000H`0006<0008006<01000QP03002N00X00;800P00`@08003?00X00=T02`00
h@0<003b00/00?T0;@00o`000`0000000?l0003o000/003o008000000P00o`0200000003003o0000
0000000000X00?l000<00?T00?ooo`3oool0X`3oool002`0oooo0`00=@000`00A`0006<0001S0003
001S00<008H01000WP09002b00X00<l02`00f@07003Q00@00>/03000lP0:003i02d00?l000<00000
003o0000o`00;@00o`0200000004003o000000000000000000`00?l000<00?T00?ooo`3oool0X`3o
ool002d0oooo0P00=@06001S008008H01P00WP08002b000300330000c`000<l000P00<l02P00f@04
003Q00L00>/03000lP0;003i02`00?l000<00000003o0000o`00;`00o`00100000000?l0003o0000
000<003o0:H0oooo000]0?ooo`<003D01P00H`000`00QP0009h0002N0004002N00L00;800`00``09
003?00X00=T03000j`0;003b00/00?T0:`00o`000`0000000?l0003o000`003o000300000000o`00
000000d00?l0YP3oool002h0oooo0P00=@000`00B@0006<0001S0003001S00P009h01@00/P050033
00T00<l01`00f@03003T00/00>/02`00lP0;003i02/00?l000<00000003o0000o`00<@00o`020000
00`00?l000<00?T00?ooo`3oool0Y03oool002h0oooo0P00=@000`00B@0006<0001S0003001S0003
00230000WP0009h000H009h00`00/P06003300T00<l01@00f@06003T00X00>/03000lP0:003i02/0
0?l000<00000003o0000o`00<@00o`000`0000000?l0003o000;003o0:L0oooo000_0?ooo`03000e
0000B@0004T000@006<00P00P`08002N0003002b0000``000<<000H00<<02@00c`02003I00P00>@0
2`00j`0;003b00X00?T0:P00o`000`0000000?l0003o0010003o0:L0oooo000_0?ooo`03000e0000
B@0004T000@006<00P00P`08002N00X00<<02000c`0;003T00X00>/02`00lP0:003i02X00?l000<0
0000003o0000o`00?`00o`2X0?ooo`00;`3oool01000900004T000190000B@02001S00@008<01`00
WP000`00]0000<<000330007003300L00<l00P00f`0:003T00/00>/02P00lP0c003o000300000000
o`000?l004000?l0Z03oool00300oooo0`00B@02001S00D008<01@00WP03002d00T00<<01000c`05
003K00X00>@02P00j`05003b00H00?X0<P00o`000`0000000?l0003o000o003o0:T0oooo000`0?oo
o`05000T0000B@0004T000190000H`001@00P`04002N00D00;@02@00``02003?00L00=/02P00i009
003[00/00?X0<@00o`000`0000000?l0003o0010003o0:T0oooo000a0?ooo`03000e0000B@0004T0
00L008<00`00WP06002d00P00<<02P00f`09003T00L00>/00`00m00:003j03400?l000<00000003o
0000o`00?`00o`2Z0?ooo`00<@3oool01000900004T000190000B@0700230003002N0000]0000;@0
00D00;@01`00``02003B00T00=/02P00i003003[00H00?@02`00nP0_003o000300000000o`000?l0
03l00?l000<000000?ooo`3oool0Z03oool00380oooo00@003D000190000B@0006P01P00P`09002d
00D00<<01000dP09003K00T00>@02P00m00:003j02l00?l000<00000003o0000o`00?`00o`2[0?oo
o`00<P3oool00`00900003D000190002001X00D008<000<00:00002d0000]0001`00]003003300H0
0=802@00f`06003T00<00>h02@00m00:003j02l00?l000<00000003o0000o`00?P00o`2/0?ooo`00
<`3oool00`00=@0004T0001X0002001X00@008<00P00X009002d000300330000dP000=8000H00=80
2@00f`03003T00H00>h02@00m00:003j02d00?l000<00000003o0000o`00?P00o`000`000000oooo
0?ooo`2Z0?ooo`00<`3oool2000e00@006P00`00P`03002P00P00;@02@00dP09003K00T00>h02@00
m00:003j02d00?l000<00000003o0000o`00?P00o`2]0?ooo`00=03oool00`00=@0006P0001X0003
001X008008<01000X007002d000300370000dP000=8000L00=801`00f`02003X00T00>h02@00m009
003j02d00?l000<00000003o0000o`00?P00o`2]0?ooo`00=@3oool00`00=@0006P0001X0003001X
000300230000X0000:0000<00:001@00]003003700T00=801000f`05003X00T00>h02000m009003j
02`00?l000<00000003o0000o`00?P00o`2^0?ooo`00=@3oool00`00=@0004l0001X0003001X00L0
0:000`00]005003700T00=800P00f`07003X00P00>h02@00m004003j03000?l000<00000003o0000
o`00?P00o`2^0?ooo`00=P3oool00`00=@0004l0001X0002001X000300250000X0000:0000D00:00
00<00;@000370000a`001@00a`08003B00X00>P02000kP08003d03<00?l000<00000003o0000o`00
?P00o`2_0?ooo`00=`3oool01000C`0006P0001X0000J002002500H00:002@00a`06003B00800>40
2@00j009003^00@00?@01000o@0b003o000300000000o`000?l003h00?l0[`3oool003L0oooo00@0
03D0001?0000J00006P00`00Q@05002P00800;P02000a`04003B00@00>402@00j008003^00T00?d0
<000o`000`0000000?l0003o000n003o0;00oooo000h0?ooo`8004l000<006P000250000Q@000P00
Q@04002P00<00;P02000a`02003B00H00>402@00j005003^00<00?T02000o@0`003o000300000000
o`000?l003h00?l0/03oool003P0oooo0`00C`05002500<00:001000^008003700P00>402@00j002
003^00H00?T02000o@0^003o000300000000o`000?l003h00?l0/@3oool003T0oooo0P00C`060025
00800:001@00^00700370003003H0000h@000>4000H00>402000j009003i00L00?d0;P00o`000`00
00000?l0003o000m003o0;80oooo000j0?ooo`8004l000<0074000250000Q@000`00Q@07002h00D0
0<L00`00f008003Q00H00>P00P00l`09003i00L00?d0;000o`000`0000000?l0003o000m003o0;<0
oooo000k0?ooo`8004l000<0074000250000Q@000`00Q@000`00YP000;P0002h0004002h00@00<L0
1000f008003Q00<00>P01@00l`08003i00L00?d0;000o`000`0000000?l0003o000l003o0;@0oooo
000l0?ooo`03001?0000L@00074000@008D00P00YP06002h00800<L01P00f008003Q00P00?<02000
n@07003m02X00?l000<00000003o0000o`00?000o`2e0?ooo`00?@3oool00`00C`000740001a0003
002500<00:H01P00^008003H00H00>400`00kP07003c00P00?T01P00o@0Z003o000300000000o`00
0?l003/00?l0]P3oool003d0oooo00@003D0001a0000L@0007400P00Q@04002V00D00;P00P00cP07
003H00@00>401@00kP07003c00P00?T00`00o@0[003o000300000000o`000?l003/00?l000<00>h0
0?ooo`3oool0]03oool003h0oooo00D003D0001a0000L@00074000250005002V00<00;P01000cP07
003H00800>401`00kP07003c00L00?T0;P00o`000`0000000?l0003o000j003o0003003^003oool0
oooo0;D0oooo000o0?ooo`04000e0000L@000740001a00H00:H00P00^006003>00H00=P02@00kP07
003c00@00?T0;`00o`000`0000000?l0003o000j003o0003003^003oool0oooo0;H0oooo00100?oo
o`05001J0000L@000740001a0000S@001@00YP08003>00D00=P00P00j008003^00L00?<0<@00o`00
0`0000000?l0003o000j003o0003003^003oool0oooo0;L0oooo00110?ooo`03001J0000L@000740
008008d01@00YP000`00`P000<h0003>0006003>00800=P01000j008003^00D00?<0<P00o`000`00
00000?l0003o000i003o0003003^003oool0oooo0;P0oooo00120?ooo`03001J0000L@0007400080
08d01000YP03003200L00<h01`00j007003^00<00?<0<P00o`000`0000000?l0003o000i003o0003
003^003oool0oooo0;T0oooo00120?ooo`8005X000<00740002=0000S@000P00S@02002V00@00<80
1P00cP02003Q00H00>P01`00kP0d003o000300000000o`000?l003T00?l0_03oool004@0oooo00<0
05X0002=0000S@000`00S@000`00YP000<8000320004003200@00<h00`00h@07003X00<00>h01000
n`0a003o000300000000o`000?l003T00?l0_@3oool004D0oooo00<005X0001n0000S@000`00S@08
003200800<h01@00h@06003X00L00?/0<000o`000`0000000?l0003o000h003o0;h0oooo00160?oo
o`03001J0000OP0007h000<008d000<00;4000320000`P001@00`P07003Q00D00>P00P00m`07003k
02d00?l000<00000003o0000o`00>000o`2o0?ooo`00A`3oool00`00FP0007h0001n0002002=00<0
0;401@00`P02003I00L00>400P00j005003g00H00?/0:`00o`000`0000000?l0003o000h003o0<00
oooo00180?ooo`05001J0000OP0007h0001n0000S@001000/@03003200<00=T01`00h@07003g00L0
0?/0:@00o`000`0000000?l0003o000g003o0<40oooo00190?ooo`@007h01P00/@000`00`P000=T0
003I0003003I00D00>400P00l`07003g00H00?/09`00o`000`0000000?l0003o000g003o0<80oooo
001;0?ooo`<007h000<009d0002a0000/@000`00/@06003I00@00>401000l`07003g00<00?/09`00
o`000`0000000?l0003o000g003o0<<0oooo001<0?ooo`<007h00P00W@04002a0003003@0000f@00
0=T000@00=T00P00h@05003c00L00?L0:@00o`000`0000000?l0003o000f003o0<@0oooo001=0?oo
o`03001[0000OP0009d0008009d00`00/@03003@00D00=T02000l`05003g02P00?l000<00000003o
0000o`00=P00o`350?ooo`00CP3oool00`00J`0007h0002M0003002M0003002a0000d0000=0000<0
0=000`00f@03003^00L00?<00P00m`0Y003o000300000000o`000?l003@00?l0a`3oool00500oooo
1@00W@07003@0003003I0000kP000>h000@00>h01@00l`0Y003o000300000000o`000?l003@00?l0
b03oool00540oooo00<00940002M0000W@000P00W@02003400D00=002@00kP02003c02T00?l000<0
0000003o0000o`00<P00o`3:0?ooo`00DP3oool2002A00<009d00`00a004003@00<00>P01`00kP0X
003o000300000000o`000?l003800?l0b`3oool005<0oooo0`00T@02002M00D00<@00P00d006003X
00<00>h09`00o`000`0000000?l0003o000a003o0<d0oooo001D0?ooo`@009401`00a009003X02H0
0?l000<00000003o0000o`00<@00o`3>0?ooo`00EP3oool01@00P`000940002A0000T@000;H000D0
0<@00`00h`06003X00<00?d08@00o`000`0000000?l0003o000`003o0=00oooo001H0?ooo`8008<0
00@00940002f0000]P000;H00`00a005003S00<00>P01P00o@0M003o000300000000o`000?l002l0
0?l0dP3oool005X0oooo0P00P`05002f00P00><02@00o@0J003o000300000000o`000?l002d00?l0
e03oool005`0oooo00<007@000230000Z0000`00]P04003L00@00><01000n`05003m01800?l00`00
00001000o`00000000000000000^003o0=H0oooo001N0?ooo`05001d0000P`000:P0002X0000]P00
1`00g009003k01<00?l000<00000003o0000o`000P00000]003o0=P0oooo001P0?ooo`04001d0000
Z0000:P0002X00P00=`02000n00B003o000500000000o`000000003o00000000:P00o`000`00o@00
oooo0?ooo`3H0?ooo`00H@3oool2001d00800:0000<00:P0003E0000e@001@00e@09003h01000?l0
00D00000003o000000000?l00000000Y003o0=`0oooo001T0?ooo`04001d0000X0000:00002P00L0
0=D02000mP0?003o000500000000o`000000003o000000009`00o`3N0?ooo`00I`3oool4002P00D0
0<l02000mP0>003o008000000P00o`000`0000000?l0003o000S003o0>00oooo001Z0?ooo`<009T0
1@00c`08003e00`00?l00P000002003o000300000000o`000?l002000?l0h`3oool006d0oooo0`00
V@03003900X00?@02000o`0300000004003o000000000000000001h00?l0iP3oool00740oooo00<0
09<000390000b@000`00b@09003d02@00?l00`00i@3Y0?ooo`00M03oool00`00T`000<H000360005
003600H00?H01@00nP0J003o00800>D0k@3oool007P0oooo2@00aP06003j00h00?l02@00n`3b0?oo
o`00OP3oool8003:00X00?l02000jP000`000000oooo0?ooo`3e0?ooo`00Q@3oool6003A0?l0oooo
1P3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {401.75, 0}} -> {0.0974796, -4.4466*^-06, \
0.00221361, 0.00221361}}]
}, Open  ]],

Cell["\<\
Sterographic mapping, maps circles in the complex plane to circles on the \
Riemann sphere. We can easily demonstrate this with the following code which \
generates random circles in the complex plane.\
\>", "Text"],

Cell[BoxData[
    \(circle[\[Theta]_] := {Random[Real, {\(-3\), 3}], 
          Random[Real, {\(-3\), 3}], 0} + 
        Random[Real, {0.5, 2}] {Cos[\[Theta]], Sin[\[Theta]], 0}\)], "Input",
  CellLabel->"In[254]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Black, 
          ParametricDraw3D[
              Evaluate[\(sphere[1]\)[\[Phi], \[Theta]]], {\[Phi], 
                0, \[Pi]}, {\[Theta], 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 31}] // 
            UseWireFrame, \[IndentingNewLine]IndianRed, 
          g3 = ParametricDraw3D[
              Evaluate[circle[\[Theta]]], {\[Theta], 0, 
                2  \[Pi]}], \[IndentingNewLine]Orange, 
          g3 /. transform}, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]Background \[Rule] 
          SteelBlue];\)\)], "Input",
  CellLabel->"In[255]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.01472 
%%ImageSize: 400 405.89 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.274 .51 .706 r
MFill
% Scaling calculations
-0.0266917 1.08973 1.37694e-017 1.08973 [
[ 0 0 0 0 ]
[ 1 1.01472 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.01472 L
0 1.01472 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.43286 .54937 m
.47413 .55259 L
s
.47413 .55259 m
.47507 .49626 L
s
.47323 .60938 m
.47413 .55259 L
s
.47413 .55259 m
.51549 .55069 L
s
1 .5 0 r
.46784 .57853 m
.43872 .5667 L
s
.49664 .5893 m
.46784 .57853 L
s
.52471 .59891 m
.49664 .5893 L
s
0 0 0 r
.51549 .55069 m
.50816 .49469 L
s
.52098 .60726 m
.51549 .55069 L
s
.51549 .55069 m
.55546 .54374 L
s
1 .5 0 r
.43872 .5667 m
.40974 .55393 L
s
0 0 0 r
.42557 .60578 m
.47323 .60938 L
s
.47241 .66464 m
.47323 .60938 L
s
.47323 .60938 m
.52098 .60726 L
s
.39312 .54113 m
.43286 .54937 L
s
.43286 .54937 m
.44205 .4936 L
s
.42557 .60578 m
.43286 .54937 L
s
1 .5 0 r
.55172 .60733 m
.52471 .59891 L
s
0 0 0 r
.52443 .66241 m
.52098 .60726 L
s
.52098 .60726 m
.56718 .59949 L
s
.44205 .4936 m
.47507 .49626 L
s
.47507 .49626 m
.47602 .44236 L
s
.47507 .49626 m
.50816 .49469 L
s
.37962 .59656 m
.42557 .60578 L
s
.42047 .66085 m
.42557 .60578 L
s
1 .5 0 r
.40974 .55393 m
.38142 .54038 L
s
0 0 0 r
.50816 .49469 m
.49924 .44123 L
s
.50816 .49469 m
.5401 .48896 L
s
.55546 .54374 m
.5401 .48896 L
s
.56718 .59949 m
.55546 .54374 L
s
.55546 .54374 m
.59261 .53192 L
s
.41032 .48681 m
.44205 .4936 L
s
.44205 .4936 m
.45285 .44044 L
s
1 .5 0 r
.57738 .61452 m
.55172 .60733 L
s
0 0 0 r
.35637 .5281 m
.39312 .54113 L
s
.39312 .54113 m
.41032 .48681 L
s
.37962 .59656 m
.39312 .54113 L
s
.57481 .65421 m
.56718 .59949 L
s
.56718 .59949 m
.61023 .58624 L
s
.5401 .48896 m
.52161 .43709 L
s
.5401 .48896 m
.56968 .47923 L
s
1 .5 0 r
.38142 .54038 m
.35427 .52626 L
s
0 0 0 r
.42047 .66085 m
.47241 .66464 L
s
.47169 .71639 m
.47241 .66464 L
s
.47241 .66464 m
.52443 .66241 L
s
.38109 .47609 m
.41032 .48681 L
s
.41032 .48681 m
.43064 .43554 L
s
.33699 .58195 m
.37962 .59656 L
s
.37034 .65113 m
.37962 .59656 L
s
.52569 .71415 m
.52443 .66241 L
s
.52443 .66241 m
.57481 .65421 L
s
1 .5 0 r
.60148 .6205 m
.57738 .61452 L
s
0 0 0 r
.37034 .65113 m
.42047 .66085 L
s
.41778 .71258 m
.42047 .66085 L
s
.59261 .53192 m
.56968 .47923 L
s
.61023 .58624 m
.59261 .53192 L
s
.59261 .53192 m
.62552 .51557 L
s
.45285 .44044 m
.47602 .44236 L
s
.47602 .44236 m
.47694 .39291 L
s
.47602 .44236 m
.49924 .44123 L
s
.56968 .47923 m
.54225 .43009 L
s
.56968 .47923 m
.59574 .46581 L
s
.49924 .44123 m
.48901 .39231 L
s
.49924 .44123 m
.52161 .43709 L
s
.43064 .43554 m
.45285 .44044 L
s
.45285 .44044 m
.4649 .39189 L
s
.32402 .51064 m
.35637 .5281 L
s
.35637 .5281 m
.38109 .47609 L
s
.33699 .58195 m
.35637 .5281 L
s
1 .5 0 r
.35427 .52626 m
.32884 .5118 L
s
0 0 0 r
.35551 .46178 m
.38109 .47609 L
s
.38109 .47609 m
.41027 .42783 L
s
.578 .7059 m
.57481 .65421 L
s
.57481 .65421 m
.62184 .64023 L
s
.52161 .43709 m
.50061 .3901 L
s
.52161 .43709 m
.54225 .43009 L
s
.62184 .64023 m
.61023 .58624 L
s
.61023 .58624 m
.64852 .56788 L
s
1 .5 0 r
.62387 .6253 m
.60148 .6205 L
s
0 0 0 r
.41027 .42783 m
.43064 .43554 L
s
.43064 .43554 m
.45339 .38928 L
s
.32374 .63569 m
.37034 .65113 L
s
.36571 .7028 m
.37034 .65113 L
s
.2993 .56233 m
.33699 .58195 L
s
.32374 .63569 m
.33699 .58195 L
s
.54225 .43009 m
.51127 .38638 L
s
.54225 .43009 m
.56032 .42047 L
s
.39257 .41758 m
.41027 .42783 L
s
.41027 .42783 m
.44289 .38519 L
s
.59574 .46581 m
.56032 .42047 L
s
.62552 .51557 m
.59574 .46581 L
s
.59574 .46581 m
.61719 .44914 L
s
.41778 .71258 m
.47169 .71639 L
s
.4711 .76257 m
.47169 .71639 L
s
.47169 .71639 m
.52569 .71415 L
s
.64852 .56788 m
.62552 .51557 L
s
.62552 .51557 m
.65283 .49517 L
s
1 .5 0 r
.64445 .62897 m
.62387 .6253 L
s
0 0 0 r
.52461 .76041 m
.52569 .71415 L
s
.52569 .71415 m
.578 .7059 L
s
1 .5 0 r
.32884 .5118 m
.30564 .49726 L
s
0 0 0 r
.33468 .44436 m
.35551 .46178 L
s
.35551 .46178 m
.39257 .41758 L
s
.32402 .51064 m
.35551 .46178 L
s
.36571 .7028 m
.41778 .71258 L
s
.41768 .7589 m
.41778 .71258 L
s
.62686 .69183 m
.62184 .64023 L
s
.62184 .64023 m
.66379 .62079 L
s
.29743 .48929 m
.32402 .51064 L
s
.2993 .56233 m
.32402 .51064 L
s
.56032 .42047 m
.52052 .38129 L
s
.56032 .42047 m
.57504 .40857 L
s
.37832 .40517 m
.39257 .41758 L
s
.39257 .41758 m
.43384 .37977 L
s
.66379 .62079 m
.64852 .56788 L
s
.64852 .56788 m
.68052 .5449 L
s
.4649 .39189 m
.47694 .39291 L
s
.47694 .39291 m
.4778 .34996 L
s
.47694 .39291 m
.48901 .39231 L
s
.28241 .61492 m
.32374 .63569 L
s
.31727 .68726 m
.32374 .63569 L
s
.48901 .39231 m
.4778 .34996 L
s
.48901 .39231 m
.50061 .3901 L
s
.45339 .38928 m
.4649 .39189 L
s
.4649 .39189 m
.4778 .34996 L
s
.57644 .75247 m
.578 .7059 L
s
.578 .7059 m
.62686 .69183 L
s
.50061 .3901 m
.4778 .34996 L
s
.50061 .3901 m
.51127 .38638 L
s
.44289 .38519 m
.45339 .38928 L
s
.45339 .38928 m
.4778 .34996 L
s
1 .5 0 r
.66317 .63158 m
.64445 .62897 L
s
0 0 0 r
.2681 .53826 m
.2993 .56233 L
s
.28241 .61492 m
.2993 .56233 L
s
.31727 .68726 m
.36571 .7028 L
s
.36608 .74949 m
.36571 .7028 L
s
.61719 .44914 m
.57504 .40857 L
s
.65283 .49517 m
.61719 .44914 L
s
.61719 .44914 m
.63306 .42981 L
s
.51127 .38638 m
.4778 .34996 L
s
.51127 .38638 m
.52052 .38129 L
s
.43384 .37977 m
.44289 .38519 L
s
.44289 .38519 m
.4778 .34996 L
s
.57504 .40857 m
.52798 .37504 L
s
.57504 .40857 m
.58575 .39486 L
s
1 .5 0 r
.30564 .49726 m
.28513 .4829 L
s
0 0 0 r
.31957 .42444 m
.33468 .44436 L
s
.33468 .44436 m
.37832 .40517 L
s
.29743 .48929 m
.33468 .44436 L
s
.52052 .38129 m
.4778 .34996 L
s
.52052 .38129 m
.52798 .37504 L
s
.36815 .39106 m
.37832 .40517 L
s
.37832 .40517 m
.42664 .37325 L
s
.68052 .5449 m
.65283 .49517 L
s
.65283 .49517 m
.6733 .47139 L
s
.42664 .37325 m
.43384 .37977 L
s
.43384 .37977 m
.4778 .34996 L
s
.6705 .67226 m
.66379 .62079 L
s
.66379 .62079 m
.69898 .59643 L
s
.52798 .37504 m
.4778 .34996 L
s
.52798 .37504 m
.53331 .36787 L
s
.27786 .46476 m
.29743 .48929 L
s
.2681 .53826 m
.29743 .48929 L
s
.62484 .73893 m
.62686 .69183 L
s
.62686 .69183 m
.6705 .67226 L
s
1 .5 0 r
.68002 .63318 m
.66317 .63158 L
s
0 0 0 r
.4216 .3659 m
.42664 .37325 L
s
.42664 .37325 m
.4778 .34996 L
s
.41768 .7589 m
.4711 .76257 L
s
.47068 .80108 m
.4711 .76257 L
s
.4711 .76257 m
.52461 .76041 L
s
.58575 .39486 m
.53331 .36787 L
s
.63306 .42981 m
.58575 .39486 L
s
.58575 .39486 m
.59192 .37985 L
s
.52114 .7991 m
.52461 .76041 L
s
.52461 .76041 m
.57644 .75247 L
s
.24804 .58939 m
.28241 .61492 L
s
.27424 .66634 m
.28241 .61492 L
s
.27424 .66634 m
.31727 .68726 L
s
.31809 .73454 m
.31727 .68726 L
s
.69898 .59643 m
.68052 .5449 L
s
.68052 .5449 m
.70473 .51801 L
s
.53331 .36787 m
.4778 .34996 L
s
.53331 .36787 m
.53626 .36009 L
s
.36608 .74949 m
.41768 .7589 L
s
.42031 .79771 m
.41768 .7589 L
s
.36259 .37582 m
.36815 .39106 L
s
.36815 .39106 m
.4216 .3659 L
s
.31957 .42444 m
.36815 .39106 L
s
.6733 .47139 m
.63306 .42981 L
s
.63306 .42981 m
.6425 .40853 L
s
.41898 .358 m
.4216 .3659 L
s
.4216 .3659 m
.4778 .34996 L
s
1 .5 0 r
.28513 .4829 m
.2677 .46898 L
s
0 0 0 r
.31097 .40279 m
.31957 .42444 L
s
.27786 .46476 m
.31957 .42444 L
s
.24488 .51049 m
.2681 .53826 L
s
.24804 .58939 m
.2681 .53826 L
s
.53626 .36009 m
.4778 .34996 L
s
.59192 .37985 m
.53626 .36009 L
s
.53626 .36009 m
.53667 .35202 L
s
.56998 .7918 m
.57644 .75247 L
s
.57644 .75247 m
.62484 .73893 L
s
1 .5 0 r
.695 .63387 m
.68002 .63318 L
s
0 0 0 r
.4778 .34996 m
.4778 .34996 L
s
.4778 .34996 m
.5298 .33643 L
s
.42644 .33458 m
.4778 .34996 L
s
.42142 .34199 m
.4778 .34996 L
s
.41891 .34992 m
.4778 .34996 L
s
.41898 .358 m
.4778 .34996 L
s
.53667 .35202 m
.4778 .34996 L
s
.5345 .34401 m
.4778 .34996 L
s
.52276 .32962 m
.4778 .34996 L
s
.51368 .32389 m
.4778 .34996 L
s
.50296 .31952 m
.4778 .34996 L
s
.49107 .31671 m
.4778 .34996 L
s
.47856 .3156 m
.4778 .34996 L
s
.46602 .31626 m
.4778 .34996 L
s
.45401 .31863 m
.4778 .34996 L
s
.4431 .32262 m
.4778 .34996 L
s
.43377 .32802 m
.4778 .34996 L
s
.41891 .34992 m
.41898 .358 L
s
.36259 .37582 m
.41898 .358 L
s
.70473 .51801 m
.6733 .47139 L
s
.6733 .47139 m
.68582 .44506 L
s
.6425 .40853 m
.59192 .37985 L
s
.59192 .37985 m
.59318 .36418 L
s
.31809 .73454 m
.36608 .74949 L
s
.37169 .78905 m
.36608 .74949 L
s
.59318 .36418 m
.53667 .35202 L
s
.53667 .35202 m
.5345 .34401 L
s
.36199 .36009 m
.36259 .37582 L
s
.31097 .40279 m
.36259 .37582 L
s
.66806 .7201 m
.6705 .67226 L
s
.6705 .67226 m
.70718 .6477 L
s
.42142 .34199 m
.41891 .34992 L
s
.36199 .36009 m
.41891 .34992 L
s
.26638 .43793 m
.27786 .46476 L
s
.24488 .51049 m
.27786 .46476 L
s
.70718 .6477 m
.69898 .59643 L
s
.69898 .59643 m
.72579 .56784 L
s
.68582 .44506 m
.6425 .40853 L
s
.6425 .40853 m
.64492 .38613 L
s
.58934 .34851 m
.5345 .34401 L
s
.5345 .34401 m
.5298 .33643 L
s
.23838 .64059 m
.27424 .66634 L
s
.27547 .71441 m
.27424 .66634 L
s
1 .5 0 r
.70817 .6337 m
.695 .63387 L
s
0 0 0 r
.61553 .77936 m
.62484 .73893 L
s
.62484 .73893 m
.66806 .7201 L
s
.42644 .33458 m
.42142 .34199 L
s
.3665 .34454 m
.42142 .34199 L
s
1 .5 0 r
.2677 .46898 m
.25365 .45577 L
s
0 0 0 r
.22226 .55984 m
.24804 .58939 L
s
.23838 .64059 m
.24804 .58939 L
s
.64492 .38613 m
.59318 .36418 L
s
.59318 .36418 m
.58934 .34851 L
s
.3095 .38026 m
.31097 .40279 L
s
.26638 .43793 m
.31097 .40279 L
s
.72579 .56784 m
.70473 .51801 L
s
.70473 .51801 m
.71984 .4881 L
s
.69 .09 .12 r
.57355 .66177 m
.55222 .66161 L
s
.59488 .66092 m
.57355 .66177 L
s
.55222 .66161 m
.53099 .66046 L
s
.61608 .65908 m
.59488 .66092 L
s
0 0 0 r
.27547 .71441 m
.31809 .73454 L
s
.32653 .77532 m
.31809 .73454 L
s
.69 .09 .12 r
.53099 .66046 m
.50998 .65831 L
s
0 0 0 r
.58047 .33356 m
.5298 .33643 L
s
.5298 .33643 m
.52276 .32962 L
s
.3665 .34454 m
.36199 .36009 L
s
.3095 .38026 m
.36199 .36009 L
s
.69 .09 .12 r
.63703 .65624 m
.61608 .65908 L
s
0 0 0 r
.43377 .32802 m
.42644 .33458 L
s
.37604 .32988 m
.42644 .33458 L
s
.69 .09 .12 r
.50998 .65831 m
.4893 .65517 L
s
0 0 0 r
.42031 .79771 m
.47068 .80108 L
s
.47045 .82983 m
.47068 .80108 L
s
.47068 .80108 m
.52114 .7991 L
s
.69 .09 .12 r
.65763 .65243 m
.63703 .65624 L
s
.4893 .65517 m
.46907 .65106 L
s
0 0 0 r
.23094 .47998 m
.24488 .51049 L
s
.22226 .55984 m
.24488 .51049 L
s
.56686 .32002 m
.52276 .32962 L
s
.52276 .32962 m
.51368 .32389 L
s
.51526 .8281 m
.52114 .7991 L
s
.52114 .7991 m
.56998 .7918 L
s
.4431 .32262 m
.43377 .32802 L
s
.39026 .31683 m
.43377 .32802 L
s
.71984 .4881 m
.68582 .44506 L
s
.68582 .44506 m
.68952 .4172 L
s
.37169 .78905 m
.42031 .79771 L
s
.42572 .82689 m
.42031 .79771 L
s
.69 .09 .12 r
.67775 .64765 m
.65763 .65243 L
s
1 .5 0 r
.71957 .63276 m
.70817 .6337 L
s
.69 .09 .12 r
.46907 .65106 m
.44941 .64599 L
s
0 0 0 r
.54905 .30857 m
.51368 .32389 L
s
.51368 .32389 m
.50296 .31952 L
s
.63994 .36359 m
.58934 .34851 L
s
.58934 .34851 m
.58047 .33356 L
s
.45401 .31863 m
.4431 .32262 L
s
.40859 .30601 m
.4431 .32262 L
s
.68952 .4172 m
.64492 .38613 L
s
.64492 .38613 m
.63994 .36359 L
s
.70436 .69648 m
.70718 .6477 L
s
.70718 .6477 m
.73522 .61884 L
s
.69 .09 .12 r
.69729 .64192 m
.67775 .64765 L
s
0 0 0 r
.26385 .40986 m
.26638 .43793 L
s
.23094 .47998 m
.26638 .43793 L
s
.37604 .32988 m
.3665 .34454 L
s
.31547 .35784 m
.3665 .34454 L
s
.55859 .82174 m
.56998 .7918 L
s
.56998 .7918 m
.61553 .77936 L
s
.52782 .29979 m
.50296 .31952 L
s
.50296 .31952 m
.49107 .31671 L
s
.69 .09 .12 r
.44941 .64599 m
.43043 .63997 L
s
0 0 0 r
.65611 .76208 m
.66806 .7201 L
s
.66806 .7201 m
.70436 .69648 L
s
.46602 .31626 m
.45401 .31863 L
s
.43022 .298 m
.45401 .31863 L
s
.50415 .29413 m
.49107 .31671 L
s
.49107 .31671 m
.47856 .3156 L
s
.47856 .3156 m
.46602 .31626 L
s
.45414 .29321 m
.46602 .31626 L
s
1 .5 0 r
.25365 .45577 m
.24318 .44348 L
s
0 0 0 r
.32653 .77532 m
.37169 .78905 L
s
.3826 .81935 m
.37169 .78905 L
s
.47919 .29189 m
.47856 .3156 L
s
.31547 .35784 m
.3095 .38026 L
s
.26385 .40986 m
.3095 .38026 L
s
.73522 .61884 m
.72579 .56784 L
s
.72579 .56784 m
.74274 .53596 L
s
.69 .09 .12 r
.71612 .63527 m
.69729 .64192 L
s
0 0 0 r
.21139 .61076 m
.23838 .64059 L
s
.23997 .68964 m
.23838 .64059 L
s
.69 .09 .12 r
.43043 .63997 m
.41224 .63304 L
s
0 0 0 r
.23997 .68964 m
.27547 .71441 L
s
.28651 .75686 m
.27547 .71441 L
s
1 .5 0 r
.72928 .63112 m
.71957 .63276 L
s
0 0 0 r
.62754 .34192 m
.58047 .33356 L
s
.58047 .33356 m
.56686 .32002 L
s
.69 .09 .12 r
.73412 .62772 m
.71612 .63527 L
s
0 0 0 r
.20656 .52728 m
.22226 .55984 L
s
.21139 .61076 m
.22226 .55984 L
s
.74274 .53596 m
.71984 .4881 L
s
.71984 .4881 m
.72475 .4563 L
s
.39026 .31683 m
.37604 .32988 L
s
.32885 .33656 m
.37604 .32988 L
s
.69 .09 .12 r
.41224 .63304 m
.39496 .62522 L
s
0 0 0 r
.5989 .81092 m
.61553 .77936 L
s
.61553 .77936 m
.65611 .76208 L
s
.68384 .38897 m
.63994 .36359 L
s
.63994 .36359 m
.62754 .34192 L
s
.28651 .75686 m
.32653 .77532 L
s
.34265 .80742 m
.32653 .77532 L
s
.72475 .4563 m
.68952 .4172 L
s
.68952 .4172 m
.68384 .38897 L
s
.69 .09 .12 r
.75119 .6193 m
.73412 .62772 L
s
0 0 0 r
.22737 .4479 m
.23094 .47998 L
s
.20656 .52728 m
.23094 .47998 L
s
.60806 .32217 m
.56686 .32002 L
s
.56686 .32002 m
.54905 .30857 L
s
.69 .09 .12 r
.39496 .62522 m
.37871 .61655 L
s
1 .5 0 r
.73737 .62884 m
.72928 .63112 L
s
0 0 0 r
.32885 .33656 m
.31547 .35784 L
s
.27078 .38174 m
.31547 .35784 L
s
.40859 .30601 m
.39026 .31683 L
s
.34925 .31749 m
.39026 .31683 L
s
1 .5 0 r
.24318 .44348 m
.23638 .43231 L
s
0 0 0 r
.27078 .38174 m
.26385 .40986 L
s
.22737 .4479 m
.26385 .40986 L
s
.6901 .74044 m
.70436 .69648 L
s
.70436 .69648 m
.73207 .66873 L
s
.69 .09 .12 r
.76721 .61005 m
.75119 .6193 L
s
0 0 0 r
.73207 .66873 m
.73522 .61884 L
s
.73522 .61884 m
.75304 .58662 L
s
.42572 .82689 m
.47045 .82983 L
s
.47044 .84679 m
.47045 .82983 L
s
.47045 .82983 m
.51526 .8281 L
s
.69 .09 .12 r
.37871 .61655 m
.36358 .60705 L
s
0 0 0 r
.58224 .30536 m
.54905 .30857 L
s
.54905 .30857 m
.52782 .29979 L
s
.50708 .84539 m
.51526 .8281 L
s
.51526 .8281 m
.55859 .82174 L
s
.3826 .81935 m
.42572 .82689 L
s
.43386 .84442 m
.42572 .82689 L
s
.63468 .79594 m
.65611 .76208 L
s
.65611 .76208 m
.6901 .74044 L
s
.43022 .298 m
.40859 .30601 L
s
.37587 .3016 m
.40859 .30601 L
s
.21327 .66096 m
.23997 .68964 L
s
.25328 .73418 m
.23997 .68964 L
s
.75304 .58662 m
.74274 .53596 L
s
.74274 .53596 m
.74857 .50194 L
s
.19483 .57784 m
.21139 .61076 L
s
.21327 .66096 m
.21139 .61076 L
s
1 .5 0 r
.74392 .62599 m
.73737 .62884 L
s
.69 .09 .12 r
.78206 .60002 m
.76721 .61005 L
s
0 0 0 r
.66864 .36166 m
.62754 .34192 L
s
.62754 .34192 m
.60806 .32217 L
s
.55121 .29241 m
.52782 .29979 L
s
.52782 .29979 m
.50415 .29413 L
s
.25328 .73418 m
.28651 .75686 L
s
.30739 .79142 m
.28651 .75686 L
s
.54246 .84026 m
.55859 .82174 L
s
.55859 .82174 m
.5989 .81092 L
s
.69 .09 .12 r
.36358 .60705 m
.34971 .59679 L
s
0 0 0 r
.45414 .29321 m
.43022 .298 L
s
.40752 .28978 m
.43022 .298 L
s
.34265 .80742 m
.3826 .81935 L
s
.39867 .83833 m
.3826 .81935 L
s
.74857 .50194 m
.72475 .4563 L
s
.72475 .4563 m
.71871 .42392 L
s
.34925 .31749 m
.32885 .33656 L
s
.28725 .35489 m
.32885 .33656 L
s
.20216 .49293 m
.20656 .52728 L
s
.19483 .57784 m
.20656 .52728 L
s
.51643 .28404 m
.50415 .29413 L
s
.50415 .29413 m
.47919 .29189 L
s
.71871 .42392 m
.68384 .38897 L
s
.68384 .38897 m
.66864 .36166 L
s
.47919 .29189 m
.45414 .29321 L
s
.4427 .28268 m
.45414 .29321 L
s
.47963 .28073 m
.47919 .29189 L
s
.69 .09 .12 r
.79563 .58924 m
.78206 .60002 L
s
1 .5 0 r
.23638 .43231 m
.23323 .42241 L
s
0 0 0 r
.23485 .4156 m
.22737 .4479 L
s
.20216 .49293 m
.22737 .4479 L
s
.28725 .35489 m
.27078 .38174 L
s
.23485 .4156 m
.27078 .38174 L
s
.69 .09 .12 r
.34971 .59679 m
.33718 .5858 L
s
1 .5 0 r
.749 .62262 m
.74392 .62599 L
s
0 0 0 r
.57527 .83154 m
.5989 .81092 L
s
.5989 .81092 m
.63468 .79594 L
s
.64424 .33664 m
.60806 .32217 L
s
.60806 .32217 m
.58224 .30536 L
s
.71592 .71507 m
.73207 .66873 L
s
.73207 .66873 m
.74966 .63775 L
s
.30739 .79142 m
.34265 .80742 L
s
.36619 .82872 m
.34265 .80742 L
s
.66447 .77721 m
.6901 .74044 L
s
.6901 .74044 m
.71592 .71507 L
s
.69 .09 .12 r
.80782 .57778 m
.79563 .58924 L
s
0 0 0 r
.37587 .3016 m
.34925 .31749 L
s
.31286 .33069 m
.34925 .31749 L
s
.74966 .63775 m
.75304 .58662 L
s
.75304 .58662 m
.75932 .55218 L
s
.69 .09 .12 r
.33718 .5858 m
.32612 .57414 L
s
0 0 0 r
.19691 .62932 m
.21327 .66096 L
s
.22841 .70797 m
.21327 .66096 L
s
.22841 .70797 m
.25328 .73418 L
s
.27828 .77181 m
.25328 .73418 L
s
1 .5 0 r
.75271 .61879 m
.749 .62262 L
s
0 0 0 r
.75932 .55218 m
.74857 .50194 L
s
.74857 .50194 m
.74239 .46719 L
s
.70144 .39245 m
.66864 .36166 L
s
.66864 .36166 m
.64424 .33664 L
s
.60422 .8195 m
.63468 .79594 L
s
.63468 .79594 m
.66447 .77721 L
s
.6115 .31524 m
.58224 .30536 L
s
.58224 .30536 m
.55121 .29241 L
s
.19002 .54305 m
.19483 .57784 L
s
.19691 .62932 m
.19483 .57784 L
s
.69 .09 .12 r
.81851 .5657 m
.80782 .57778 L
s
1 .5 0 r
.23323 .42241 m
.23361 .41389 L
s
0 0 0 r
.74239 .46719 m
.71871 .42392 L
s
.71871 .42392 m
.70144 .39245 L
s
.40752 .28978 m
.37587 .3016 L
s
.34666 .31043 m
.37587 .3016 L
s
.69 .09 .12 r
.32612 .57414 m
.31661 .56187 L
s
0 0 0 r
.43386 .84442 m
.47044 .84679 L
s
.47066 .85023 m
.47044 .84679 L
s
.47044 .84679 m
.50708 .84539 L
s
.27828 .77181 m
.30739 .79142 L
s
.33768 .81587 m
.30739 .79142 L
s
.31286 .33069 m
.28725 .35489 L
s
.25362 .38462 m
.28725 .35489 L
s
.49683 .84923 m
.50708 .84539 L
s
.50708 .84539 m
.54246 .84026 L
s
.20992 .45824 m
.20216 .49293 L
s
.19002 .54305 m
.20216 .49293 L
s
.39867 .83833 m
.43386 .84442 L
s
.44454 .84853 m
.43386 .84442 L
s
1 .5 0 r
.75512 .61454 m
.75271 .61879 L
s
0 0 0 r
.25362 .38462 m
.23485 .4156 L
s
.20992 .45824 m
.23485 .4156 L
s
.57186 .29867 m
.55121 .29241 L
s
.55121 .29241 m
.51643 .28404 L
s
.69 .09 .12 r
.82761 .55305 m
.81851 .5657 L
s
0 0 0 r
.52205 .84557 m
.54246 .84026 L
s
.54246 .84026 m
.57527 .83154 L
s
.4427 .28268 m
.40752 .28978 L
s
.38715 .29529 m
.40752 .28978 L
s
.36619 .82872 m
.39867 .83833 L
s
.41947 .84421 m
.39867 .83833 L
s
.6869 .75534 m
.71592 .71507 L
s
.71592 .71507 m
.73215 .6868 L
s
.69 .09 .12 r
.31661 .56187 m
.30875 .54907 L
s
0 0 0 r
.52721 .28793 m
.51643 .28404 L
s
.51643 .28404 m
.47963 .28073 L
s
.73215 .6868 m
.74966 .63775 L
s
.74966 .63775 m
.75581 .60467 L
s
.47963 .28073 m
.4427 .28268 L
s
.43233 .28619 m
.4427 .28268 L
s
.62813 .80451 m
.66447 .77721 L
s
.66447 .77721 m
.6869 .75534 L
s
.67323 .36347 m
.64424 .33664 L
s
.64424 .33664 m
.6115 .31524 L
s
.47986 .28368 m
.47963 .28073 L
s
1 .5 0 r
.75629 .60993 m
.75512 .61454 L
s
0 0 0 r
.54533 .83939 m
.57527 .83154 L
s
.57527 .83154 m
.60422 .8195 L
s
1 .5 0 r
.23361 .41389 m
.23731 .40681 L
s
0 0 0 r
.21333 .67912 m
.22841 .70797 L
s
.25671 .74924 m
.22841 .70797 L
s
.69 .09 .12 r
.83503 .53991 m
.82761 .55305 L
s
0 0 0 r
.75581 .60467 m
.75932 .55218 L
s
.75932 .55218 m
.75308 .51695 L
s
.33768 .81587 m
.36619 .82872 L
s
.39644 .83739 m
.36619 .82872 L
s
.34666 .31043 m
.31286 .33069 L
s
.28328 .35656 m
.31286 .33069 L
s
.25671 .74924 m
.27828 .77181 L
s
.31435 .80021 m
.27828 .77181 L
s
.19218 .5959 m
.19691 .62932 L
s
.21333 .67912 m
.19691 .62932 L
s
.69 .09 .12 r
.30875 .54907 m
.30264 .5358 L
s
0 0 0 r
.72379 .43329 m
.70144 .39245 L
s
.70144 .39245 m
.67323 .36347 L
s
.75308 .51695 m
.74239 .46719 L
s
.74239 .46719 m
.72379 .43329 L
s
.19787 .50787 m
.19002 .54305 L
s
.19218 .5959 m
.19002 .54305 L
s
1 .5 0 r
.75631 .60498 m
.75629 .60993 L
s
0 0 0 r
.56574 .83087 m
.60422 .8195 L
s
.60422 .8195 m
.62813 .80451 L
s
.69 .09 .12 r
.84066 .52637 m
.83503 .53991 L
s
0 0 0 r
.28328 .35656 m
.25362 .38462 L
s
.23017 .42485 m
.25362 .38462 L
s
.63501 .33858 m
.6115 .31524 L
s
.6115 .31524 m
.57186 .29867 L
s
.23017 .42485 m
.20992 .45824 L
s
.19787 .50787 m
.20992 .45824 L
s
.31435 .80021 m
.33768 .81587 L
s
.37638 .82832 m
.33768 .81587 L
s
.69 .09 .12 r
.30264 .5358 m
.29836 .52215 L
s
0 0 0 r
.38715 .29529 m
.34666 .31043 L
s
.32278 .33298 m
.34666 .31043 L
s
1 .5 0 r
.23731 .40681 m
.24408 .40119 L
s
0 0 0 r
.6459 .7871 m
.6869 .75534 L
s
.6869 .75534 m
.70075 .73106 L
s
.70075 .73106 m
.73215 .6868 L
s
.73215 .6868 m
.73759 .65668 L
s
1 .5 0 r
.75522 .59973 m
.75631 .60498 L
s
0 0 0 r
.44454 .84853 m
.47066 .85023 L
s
.47112 .83885 m
.47066 .85023 L
s
.47066 .85023 m
.49683 .84923 L
s
.69 .09 .12 r
.84444 .5125 m
.84066 .52637 L
s
0 0 0 r
.48489 .83832 m
.49683 .84923 L
s
.49683 .84923 m
.52205 .84557 L
s
.24388 .72448 m
.25671 .74924 L
s
.2973 .78225 m
.25671 .74924 L
s
.41947 .84421 m
.44454 .84853 L
s
.45738 .83795 m
.44454 .84853 L
s
.73759 .65668 m
.75581 .60467 L
s
.75581 .60467 m
.74957 .57082 L
s
.58241 .82034 m
.62813 .80451 L
s
.62813 .80451 m
.6459 .7871 L
s
.2092 .64871 m
.21333 .67912 L
s
.24388 .72448 m
.21333 .67912 L
s
.58844 .31926 m
.57186 .29867 L
s
.57186 .29867 m
.52721 .28793 L
s
.69 .09 .12 r
.29836 .52215 m
.29597 .5082 L
s
0 0 0 r
.49813 .83639 m
.52205 .84557 L
s
.52205 .84557 m
.54533 .83939 L
s
.43233 .28619 m
.38715 .29529 L
s
.37037 .31531 m
.38715 .29529 L
s
.69302 .40199 m
.67323 .36347 L
s
.67323 .36347 m
.63501 .33858 L
s
.39644 .83739 m
.41947 .84421 L
s
.44423 .83566 m
.41947 .84421 L
s
.2973 .78225 m
.31435 .80021 L
s
.36015 .81732 m
.31435 .80021 L
s
.74957 .57082 m
.75308 .51695 L
s
.75308 .51695 m
.73388 .48253 L
s
1 .5 0 r
.75309 .59422 m
.75522 .59973 L
s
0 0 0 r
.2 .5621 m
.19218 .5959 L
s
.2092 .64871 m
.19218 .5959 L
s
.73388 .48253 m
.72379 .43329 L
s
.72379 .43329 m
.69302 .40199 L
s
.51029 .83312 m
.54533 .83939 L
s
.54533 .83939 m
.56574 .83087 L
s
.32278 .33298 m
.28328 .35656 L
s
.26254 .39451 m
.28328 .35656 L
s
.53579 .3067 m
.52721 .28793 L
s
.52721 .28793 m
.47986 .28368 L
s
.69 .09 .12 r
.84629 .4984 m
.84444 .5125 L
s
0 0 0 r
.47986 .28368 m
.43233 .28619 L
s
.42368 .30465 m
.43233 .28619 L
s
1 .5 0 r
.24408 .40119 m
.25361 .39701 L
s
0 0 0 r
.37638 .82832 m
.39644 .83739 L
s
.43222 .83207 m
.39644 .83739 L
s
.47985 .30172 m
.47986 .28368 L
s
.69 .09 .12 r
.29597 .5082 m
.29554 .49405 L
s
0 0 0 r
.21877 .47395 m
.19787 .50787 L
s
.2 .5621 m
.19787 .50787 L
s
.26254 .39451 m
.23017 .42485 L
s
.21877 .47395 m
.23017 .42485 L
s
1 .5 0 r
.74998 .58846 m
.75309 .59422 L
s
0 0 0 r
.65657 .76787 m
.70075 .73106 L
s
.70075 .73106 m
.70502 .70531 L
s
.52086 .82865 m
.56574 .83087 L
s
.56574 .83087 m
.58241 .82034 L
s
.59459 .80816 m
.6459 .7871 L
s
.6459 .7871 m
.65657 .76787 L
s
.36015 .81732 m
.37638 .82832 L
s
.42185 .82731 m
.37638 .82832 L
s
.70502 .70531 m
.73759 .65668 L
s
.73759 .65668 m
.73141 .62595 L
s
.69 .09 .12 r
.84616 .48417 m
.84629 .4984 L
s
0 0 0 r
.24075 .69851 m
.24388 .72448 L
s
.28745 .76268 m
.24388 .72448 L
s
.65106 .37503 m
.63501 .33858 L
s
.63501 .33858 m
.58844 .31926 L
s
.28745 .76268 m
.2973 .78225 L
s
.3485 .80479 m
.2973 .78225 L
s
.69 .09 .12 r
.29554 .49405 m
.29712 .47979 L
s
1 .5 0 r
.74592 .58249 m
.74998 .58846 L
s
0 0 0 r
.37037 .31531 m
.32278 .33298 L
s
.30594 .36894 m
.32278 .33298 L
s
1 .5 0 r
.25361 .39701 m
.26554 .39423 L
s
0 0 0 r
.52938 .82315 m
.58241 .82034 L
s
.58241 .82034 m
.59459 .80816 L
s
.21683 .61804 m
.2092 .64871 L
s
.24075 .69851 m
.2092 .64871 L
s
.73141 .62595 m
.74957 .57082 L
s
.74957 .57082 m
.7305 .53778 L
s
.3485 .80479 m
.36015 .81732 L
s
.41357 .82158 m
.36015 .81732 L
s
.69 .09 .12 r
.84399 .46991 m
.84616 .48417 L
s
0 0 0 r
.70192 .45069 m
.69302 .40199 L
s
.69302 .40199 m
.65106 .37503 L
s
.7305 .53778 m
.73388 .48253 L
s
.73388 .48253 m
.70192 .45069 L
s
1 .5 0 r
.74097 .57633 m
.74592 .58249 L
s
0 0 0 r
.22072 .52954 m
.2 .5621 L
s
.21683 .61804 m
.2 .5621 L
s
.60165 .79482 m
.65657 .76787 L
s
.65657 .76787 m
.65944 .7476 L
s
.69 .09 .12 r
.29712 .47979 m
.30074 .46554 L
s
0 0 0 r
.45738 .83795 m
.47112 .83885 L
s
.47182 .81215 m
.47112 .83885 L
s
.47112 .83885 m
.48489 .83832 L
s
.59971 .35404 m
.58844 .31926 L
s
.58844 .31926 m
.53579 .3067 L
s
.47182 .81215 m
.48489 .83832 L
s
.48489 .83832 m
.49813 .83639 L
s
.44423 .83566 m
.45738 .83795 L
s
.47182 .81215 m
.45738 .83795 L
s
.47182 .81215 m
.49813 .83639 L
s
.49813 .83639 m
.51029 .83312 L
s
.30594 .36894 m
.26254 .39451 L
s
.25239 .44308 m
.26254 .39451 L
s
.43222 .83207 m
.44423 .83566 L
s
.47182 .81215 m
.44423 .83566 L
s
.42368 .30465 m
.37037 .31531 L
s
.35843 .34974 m
.37037 .31531 L
s
.53548 .81684 m
.59459 .80816 L
s
.59459 .80816 m
.60165 .79482 L
s
.65944 .7476 m
.70502 .70531 L
s
.70502 .70531 m
.69908 .67914 L
s
.25239 .44308 m
.21877 .47395 L
s
.22072 .52954 m
.21877 .47395 L
s
.2855 .74227 m
.28745 .76268 L
s
.34203 .79123 m
.28745 .76268 L
s
.47182 .81215 m
.51029 .83312 L
s
.51029 .83312 m
.52086 .82865 L
s
1 .5 0 r
.26554 .39423 m
.27954 .39276 L
s
0 0 0 r
.34203 .79123 m
.3485 .80479 L
s
.40776 .8151 m
.3485 .80479 L
s
.42185 .82731 m
.43222 .83207 L
s
.47182 .81215 m
.43222 .83207 L
s
1 .5 0 r
.73515 .56999 m
.74097 .57633 L
s
.69 .09 .12 r
.83976 .45573 m
.84399 .46991 L
s
0 0 0 r
.54151 .34037 m
.53579 .3067 L
s
.53579 .3067 m
.47985 .30172 L
s
.24794 .67243 m
.24075 .69851 L
s
.2855 .74227 m
.24075 .69851 L
s
.47182 .81215 m
.52086 .82865 L
s
.52086 .82865 m
.52938 .82315 L
s
.47985 .30172 m
.42368 .30465 L
s
.41738 .33815 m
.42368 .30465 L
s
.69 .09 .12 r
.30074 .46554 m
.30642 .45141 L
s
0 0 0 r
.41357 .82158 m
.42185 .82731 L
s
.47182 .81215 m
.42185 .82731 L
s
.69908 .67914 m
.73141 .62595 L
s
.73141 .62595 m
.71325 .59601 L
s
.47957 .33495 m
.47985 .30172 L
s
.47182 .81215 m
.52938 .82315 L
s
.52938 .82315 m
.53548 .81684 L
s
1 .5 0 r
.72851 .56349 m
.73515 .56999 L
s
0 0 0 r
.53886 .80998 m
.60165 .79482 L
s
.60165 .79482 m
.60316 .78085 L
s
.40776 .8151 m
.41357 .82158 L
s
.47182 .81215 m
.41357 .82158 L
s
.65822 .42324 m
.65106 .37503 L
s
.65106 .37503 m
.59971 .35404 L
s
.2365 .58856 m
.21683 .61804 L
s
.24794 .67243 m
.21683 .61804 L
s
.60316 .78085 m
.65944 .7476 L
s
.65944 .7476 m
.65407 .72713 L
s
.69 .09 .12 r
.83345 .44174 m
.83976 .45573 L
s
0 0 0 r
.34116 .7772 m
.34203 .79123 L
s
.40469 .80814 m
.34203 .79123 L
s
.71325 .59601 m
.7305 .53778 L
s
.7305 .53778 m
.69882 .50722 L
s
1 .5 0 r
.27954 .39276 m
.29525 .39253 L
s
0 0 0 r
.47182 .81215 m
.53548 .81684 L
s
.53548 .81684 m
.53886 .80998 L
s
.35843 .34974 m
.30594 .36894 L
s
.2976 .41704 m
.30594 .36894 L
s
.69 .09 .12 r
.30642 .45141 m
.31417 .4375 L
s
0 0 0 r
.69882 .50722 m
.70192 .45069 L
s
.70192 .45069 m
.65822 .42324 L
s
.40469 .80814 m
.40776 .8151 L
s
.47182 .81215 m
.40776 .8151 L
s
.29185 .7219 m
.2855 .74227 L
s
.34116 .7772 m
.2855 .74227 L
s
1 .5 0 r
.72107 .55685 m
.72851 .56349 L
s
0 0 0 r
.25402 .49991 m
.22072 .52954 L
s
.2365 .58856 m
.22072 .52954 L
s
.65407 .72713 m
.69908 .67914 L
s
.69908 .67914 m
.68269 .65376 L
s
.47182 .81215 m
.53886 .80998 L
s
.53886 .80998 m
.53935 .80286 L
s
.2976 .41704 m
.25239 .44308 L
s
.25402 .49991 m
.25239 .44308 L
s
.53935 .80286 m
.60316 .78085 L
s
.60316 .78085 m
.5989 .76686 L
s
.69 .09 .12 r
.82507 .42806 m
.83345 .44174 L
s
0 0 0 r
.40454 .80101 m
.40469 .80814 L
s
.47182 .81215 m
.40469 .80814 L
s
1 .5 0 r
.71285 .55007 m
.72107 .55685 L
s
0 0 0 r
.60462 .40184 m
.59971 .35404 L
s
.59971 .35404 m
.54151 .34037 L
s
1 .5 0 r
.29525 .39253 m
.31235 .39342 L
s
0 0 0 r
.34609 .76331 m
.34116 .7772 L
s
.40454 .80101 m
.34116 .7772 L
s
.69 .09 .12 r
.31417 .4375 m
.32397 .42394 L
s
0 0 0 r
.26561 .64746 m
.24794 .67243 L
s
.29185 .7219 m
.24794 .67243 L
s
.47182 .81215 m
.53935 .80286 L
s
.53935 .80286 m
.53687 .79579 L
s
.47182 .81215 m
.47182 .81215 L
s
.53149 .78909 m
.47182 .81215 L
s
.47182 .81215 m
.52343 .78306 L
s
.47182 .81215 m
.51302 .77798 L
s
.47182 .81215 m
.50072 .7741 L
s
.47182 .81215 m
.48707 .77161 L
s
.47182 .81215 m
.47272 .77063 L
s
.47182 .81215 m
.45832 .77121 L
s
.47182 .81215 m
.44456 .77332 L
s
.47182 .81215 m
.43207 .77685 L
s
.47182 .81215 m
.42141 .78164 L
s
.47182 .81215 m
.41305 .78745 L
s
.47182 .81215 m
.40736 .794 L
s
.47182 .81215 m
.40454 .80101 L
s
.47182 .81215 m
.53687 .79579 L
s
.41738 .33815 m
.35843 .34974 L
s
.35239 .39746 m
.35843 .34974 L
s
.40736 .794 m
.40454 .80101 L
s
.68269 .65376 m
.71325 .59601 L
s
.71325 .59601 m
.68338 .56839 L
s
.5989 .76686 m
.65407 .72713 L
s
.65407 .72713 m
.64039 .7074 L
s
1 .5 0 r
.70387 .54318 m
.71285 .55007 L
s
.69 .09 .12 r
.81463 .4148 m
.82507 .42806 L
s
0 0 0 r
.53687 .79579 m
.5989 .76686 L
s
.53687 .79579 m
.53149 .78909 L
s
.30653 .70253 m
.29185 .7219 L
s
.34609 .76331 m
.29185 .7219 L
s
.5989 .76686 m
.58891 .75348 L
s
.54379 .3879 m
.54151 .34037 L
s
.54151 .34037 m
.47957 .33495 L
s
.41305 .78745 m
.40736 .794 L
s
.40736 .794 m
.34609 .76331 L
s
.69 .09 .12 r
.32397 .42394 m
.33578 .41084 L
s
0 0 0 r
.26785 .56179 m
.2365 .58856 L
s
.26561 .64746 m
.2365 .58856 L
s
.65554 .48087 m
.65822 .42324 L
s
.65822 .42324 m
.60462 .40184 L
s
1 .5 0 r
.31235 .39342 m
.33052 .39533 L
s
0 0 0 r
.68338 .56839 m
.69882 .50722 L
s
.69882 .50722 m
.65554 .48087 L
s
.47957 .33495 m
.41738 .33815 L
s
.414 .38563 m
.41738 .33815 L
s
1 .5 0 r
.69416 .53619 m
.70387 .54318 L
s
0 0 0 r
.35675 .75019 m
.34609 .76331 L
s
.47903 .38237 m
.47957 .33495 L
s
.53149 .78909 m
.58891 .75348 L
s
.53149 .78909 m
.52343 .78306 L
s
.35239 .39746 m
.2976 .41704 L
s
.29876 .47493 m
.2976 .41704 L
s
.64039 .7074 m
.68269 .65376 L
s
.68269 .65376 m
.65617 .63045 L
s
.42141 .78164 m
.41305 .78745 L
s
.41305 .78745 m
.35675 .75019 L
s
.29876 .47493 m
.25402 .49991 L
s
.26785 .56179 m
.25402 .49991 L
s
.69 .09 .12 r
.80219 .4021 m
.81463 .4148 L
s
1 .5 0 r
.68372 .5291 m
.69416 .53619 L
s
.69 .09 .12 r
.33578 .41084 m
.34955 .39833 L
s
0 0 0 r
.52343 .78306 m
.5735 .74134 L
s
.52343 .78306 m
.51302 .77798 L
s
1 .5 0 r
.33052 .39533 m
.3495 .39815 L
s
0 0 0 r
.29337 .6249 m
.26561 .64746 L
s
.30653 .70253 m
.26561 .64746 L
s
.58891 .75348 m
.64039 .7074 L
s
.58891 .75348 m
.5735 .74134 L
s
.43207 .77685 m
.42141 .78164 L
s
.42141 .78164 m
.37277 .73847 L
s
.64039 .7074 m
.61875 .68939 L
s
1 .5 0 r
.67258 .52192 m
.68372 .5291 L
s
0 0 0 r
.37277 .73847 m
.35675 .75019 L
s
.35675 .75019 m
.30653 .70253 L
s
.51302 .77798 m
.55329 .73106 L
s
.51302 .77798 m
.50072 .7741 L
s
.44456 .77332 m
.43207 .77685 L
s
.43207 .77685 m
.39352 .72876 L
s
.32912 .68511 m
.30653 .70253 L
s
.69 .09 .12 r
.78781 .39006 m
.80219 .4021 L
s
0 0 0 r
.60249 .46035 m
.60462 .40184 L
s
.60462 .40184 m
.54379 .3879 L
s
.65617 .63045 m
.68338 .56839 L
s
.68338 .56839 m
.64276 .54463 L
s
.50072 .7741 m
.52915 .72316 L
s
.50072 .7741 m
.48707 .77161 L
s
.69 .09 .12 r
.34955 .39833 m
.36519 .38652 L
s
1 .5 0 r
.3495 .39815 m
.36901 .40178 L
s
0 0 0 r
.45832 .77121 m
.44456 .77332 L
s
.44456 .77332 m
.41807 .72155 L
s
.414 .38563 m
.35239 .39746 L
s
.35298 .45615 m
.35239 .39746 L
s
1 .5 0 r
.66073 .51468 m
.67258 .52192 L
s
0 0 0 r
.48707 .77161 m
.50221 .71806 L
s
.48707 .77161 m
.47272 .77063 L
s
.47272 .77063 m
.45832 .77121 L
s
.45832 .77121 m
.44526 .71724 L
s
.64276 .54463 m
.65554 .48087 L
s
.65554 .48087 m
.60249 .46035 L
s
.47272 .77063 m
.47378 .71605 L
s
.30978 .53927 m
.26785 .56179 L
s
.29337 .6249 m
.26785 .56179 L
s
.5735 .74134 m
.61875 .68939 L
s
.5735 .74134 m
.55329 .73106 L
s
.39352 .72876 m
.37277 .73847 L
s
.37277 .73847 m
.32912 .68511 L
s
1 .5 0 r
.6482 .50738 m
.66073 .51468 L
s
.69 .09 .12 r
.77158 .37881 m
.78781 .39006 L
s
0 0 0 r
.61875 .68939 m
.65617 .63045 L
s
.65617 .63045 m
.62044 .61047 L
s
.35298 .45615 m
.29876 .47493 L
s
.30978 .53927 m
.29876 .47493 L
s
1 .5 0 r
.36901 .40178 m
.38885 .4061 L
s
0 0 0 r
.54231 .44698 m
.54379 .3879 L
s
.54379 .3879 m
.47903 .38237 L
s
.61875 .68939 m
.58993 .67402 L
s
.69 .09 .12 r
.36519 .38652 m
.38261 .37553 L
s
0 0 0 r
.47903 .38237 m
.414 .38563 L
s
.41392 .4448 m
.414 .38563 L
s
1 .5 0 r
.63497 .50003 m
.6482 .50738 L
s
0 0 0 r
.3302 .60597 m
.29337 .6249 L
s
.32912 .68511 m
.29337 .6249 L
s
.47824 .44167 m
.47903 .38237 L
s
.35876 .67057 m
.32912 .68511 L
s
.55329 .73106 m
.58993 .67402 L
s
.55329 .73106 m
.52915 .72316 L
s
1 .5 0 r
.38885 .4061 m
.40883 .41102 L
s
.69 .09 .12 r
.7536 .36845 m
.77158 .37881 L
s
0 0 0 r
.41807 .72155 m
.39352 .72876 L
s
.39352 .72876 m
.35876 .67057 L
s
1 .5 0 r
.62108 .49266 m
.63497 .50003 L
s
0 0 0 r
.62044 .61047 m
.64276 .54463 L
s
.64276 .54463 m
.59315 .52615 L
s
.69 .09 .12 r
.38261 .37553 m
.40168 .36547 L
s
0 0 0 r
.59315 .52615 m
.60249 .46035 L
s
.60249 .46035 m
.54231 .44698 L
s
1 .5 0 r
.60652 .48527 m
.62108 .49266 L
s
.40883 .41102 m
.42878 .41647 L
s
0 0 0 r
.52915 .72316 m
.5552 .66215 L
s
.52915 .72316 m
.50221 .71806 L
s
.36045 .52237 m
.30978 .53927 L
s
.3302 .60597 m
.30978 .53927 L
s
.44526 .71724 m
.41807 .72155 L
s
.41807 .72155 m
.39413 .65974 L
s
.41392 .4448 m
.35298 .45615 L
s
.36045 .52237 m
.35298 .45615 L
s
.58993 .67402 m
.62044 .61047 L
s
.58993 .67402 m
.5552 .66215 L
s
.69 .09 .12 r
.73401 .3591 m
.7536 .36845 L
s
1 .5 0 r
.5913 .47788 m
.60652 .48527 L
s
.42878 .41647 m
.44857 .42234 L
s
0 0 0 r
.62044 .61047 m
.57705 .59497 L
s
.50221 .71806 m
.51622 .65447 L
s
.50221 .71806 m
.47378 .71605 L
s
.69 .09 .12 r
.40168 .36547 m
.42225 .35645 L
s
0 0 0 r
.47378 .71605 m
.44526 .71724 L
s
.44526 .71724 m
.43353 .65323 L
s
.39413 .65974 m
.35876 .67057 L
s
.35876 .67057 m
.3302 .60597 L
s
1 .5 0 r
.57543 .47053 m
.5913 .47788 L
s
0 0 0 r
.47378 .71605 m
.47495 .65144 L
s
1 .5 0 r
.44857 .42234 m
.46808 .42858 L
s
0 0 0 r
.37446 .59181 m
.3302 .60597 L
s
1 .5 0 r
.55894 .46322 m
.57543 .47053 L
s
0 0 0 r
.53698 .51412 m
.54231 .44698 L
s
.54231 .44698 m
.47824 .44167 L
s
.69 .09 .12 r
.71296 .35085 m
.73401 .3591 L
s
1 .5 0 r
.46808 .42858 m
.48724 .43512 L
s
.54185 .45599 m
.55894 .46322 L
s
0 0 0 r
.47824 .44167 m
.41392 .4448 L
s
.4173 .51217 m
.41392 .4448 L
s
1 .5 0 r
.48724 .43512 m
.50595 .4419 L
s
.52417 .44887 m
.54185 .45599 L
s
.69 .09 .12 r
.42225 .35645 m
.44417 .34855 L
s
1 .5 0 r
.50595 .4419 m
.52417 .44887 L
s
0 0 0 r
.57705 .59497 m
.59315 .52615 L
s
.59315 .52615 m
.53698 .51412 L
s
.5552 .66215 m
.57705 .59497 L
s
.5552 .66215 m
.51622 .65447 L
s
.47726 .50936 m
.47824 .44167 L
s
.43353 .65323 m
.39413 .65974 L
s
.39413 .65974 m
.37446 .59181 L
s
.4173 .51217 m
.36045 .52237 L
s
.37446 .59181 m
.36045 .52237 L
s
.69 .09 .12 r
.69063 .34379 m
.71296 .35085 L
s
0 0 0 r
.57705 .59497 m
.52809 .58491 L
s
.69 .09 .12 r
.44417 .34855 m
.46724 .34187 L
s
0 0 0 r
.51622 .65447 m
.52809 .58491 L
s
.51622 .65447 m
.47495 .65144 L
s
.42398 .58328 m
.37446 .59181 L
s
.47495 .65144 m
.43353 .65323 L
s
.43353 .65323 m
.42398 .58328 L
s
.69 .09 .12 r
.66721 .33799 m
.69063 .34379 L
s
0 0 0 r
.52809 .58491 m
.53698 .51412 L
s
.53698 .51412 m
.47726 .50936 L
s
.47495 .65144 m
.47613 .58093 L
s
.69 .09 .12 r
.46724 .34187 m
.49127 .33648 L
s
0 0 0 r
.47726 .50936 m
.4173 .51217 L
s
.42398 .58328 m
.4173 .51217 L
s
.69 .09 .12 r
.6429 .33353 m
.66721 .33799 L
s
0 0 0 r
.52809 .58491 m
.47613 .58093 L
s
.47613 .58093 m
.47726 .50936 L
s
.69 .09 .12 r
.49127 .33648 m
.51604 .33244 L
s
0 0 0 r
.47613 .58093 m
.42398 .58328 L
s
.69 .09 .12 r
.61792 .33045 m
.6429 .33353 L
s
.51604 .33244 m
.54133 .32979 L
s
.59251 .32879 m
.61792 .33045 L
s
.54133 .32979 m
.5669 .32857 L
s
.5669 .32857 m
.59251 .32879 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[255]:=",
  ImageSize->{400, 405.875},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001UB000`400?l00000o`00003oo`16P[B@
04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo
003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900
AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool0
0?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016
P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00
o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2
]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o
04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d
0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0
AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@1
0?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16
P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040
oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2
]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3o
ool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:d
T016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?oo
o`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@
04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo
003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900
AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool0
0?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016
P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00
o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2
]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o
04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d
0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0
AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@1
0?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16
P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040
oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2
]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3o
ool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo002^04J2]1T00000b016P[@10?ooo`00
ZP16P[@60000000304J2]0000000AX:d00<0AX:d3P00000304J2]0X00000_P16P[@10?ooo`00Y@16
P[@A000000T0AX:d00<0000004J2]016P[@00P16P[@:0000000304J2]0000000000000@00000^P16
P[@10?ooo`00X@16P[@900000080AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]009
04J2]00300000016P[@0AX:d00T0AX:d0P0000000`16P[@000000000000900000;H0AX:d0@3oool0
09d0AX:d2@00000504J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@01016P[@90000
00H0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00800000;80AX:d0@3oool009T0
AX:d1P00000704J2]08000000`16P[@00`000000AX:d04J2]00504J2]0P000001016P[@00`000000
AX:d04J2]00204J2]0P000001`16P[@010000000AX:d04J2]016P[@900000:l0AX:d0@3oool009L0
AX:d1@00000<04J2]0<000000`16P[@500000080AX:d00<0000004J2]016P[@01`16P[@00`000000
AX:d04J2]00604J2]00400000016P[@0AX:d04J2]0@000000`16P[@4000000L0AX:d1@00002/04J2
]040oooo002D04J2]0D000004@16P[@4000000P0AX:d00<0000004J2]016P[@01P16P[@00`000000
AX:d04J2]00604J2]00300000016P[@0AX:d00D0AX:d1@00000=04J2]0@00000Z@16P[@10?ooo`00
T@16P[@8000000l0AX:d0P00000204J2]00300000016P[@0AX:d00H0AX:d4000000204J2]0030000
0016P[@0AX:d00L0AX:d00<0000004J2]016P[@00P00000?04J2]0<00000Y`16P[@10?ooo`00S`16
P[@60000000404J2]0000000AX:d04J2]0L000001@16P[@@00000080AX:d00<0000004J2]016P[@0
1016P[@2000000D0AX:d3000000404J2]0<000003@16P[@600000:@0AX:d0@3oool008`0AX:d1000
00000`16P[@000000000000304J2]00300000016P[@0AX:d00L0AX:d1`00000204J2]00300000016
P[@0AX:d00<0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00404J2]08000001P16
P[@00`000000AX:d04J2]00504J2]00300000016P[@0000000T000001@16P[@60000000404J2]000
0000AX:d04J2]0@00000XP16P[@10?ooo`00RP16P[@2000000@0AX:d00<0000004J2]016P[@00P16
P[@00`000000AX:d04J2]00404J2]0L000000P16P[@200000080AX:d00<0000004J2]016P[@01016
P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00<0AX:d0P00000504J2]00300000016
P[@0AX:d00D0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]007000000P0AX:d00H0
000004J2]016P[@0AX:d00000016P[@3000009l0AX:d0@3oool008P0AX:d0P00000404J2]0800000
1016P[@00`000000AX:d00000005000000<0AX:d0P00000604J2]08000002016P[@00`000000AX:d
04J2]00404J2]00300000016P[@0AX:d00<0AX:d0P00000404J2]00300000016P[@0AX:d00D0AX:d
00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00200000080AX:d1000000804J2]0050000
0016P[@0AX:d04J2]00000000P16P[@3000009d0AX:d0@3oool008L0AX:d0P00000304J2]0800000
1016P[@4000000L0AX:d0P00000904J2]0<000001`16P[@2000000D0AX:d00<0000004J2]016P[@0
0P16P[@2000000@0AX:d00<0000004J2]016P[@00`16P[@2000000T0AX:d0`00000604J2]0H00000
1016P[@00`000000AX:d04J2]00204J2]08000000`16P[@2000009/0AX:d0@3oool008D0AX:d0`00
000204J2]1<000002`16P[@00`000000AX:d04J2]002000000L0AX:d00@0000004J2]016P[@0AX:d
3P00000304J2]00300000016P[@0AX:d00L0AX:d0P0000000`16P[@0000004J2]00804J2]0800000
0P16P[@40000000304J2]0000000AX:d00@0AX:d00<0000004J2]016P[@00P16P[@2000009T0AX:d
0@3oool008@0AX:d00@0000004J2]0000000AX:d0`00000204J2]08000000`16P[@00`000000AX:d
04J2]00504J2]00300000016P[@0AX:d00@000001`16P[@00`000000AX:d04J2]00204J2]0800000
1016P[@50000000304J2]0000000AX:d00<0AX:d0P00000304J2]00300000016P[@0AX:d00<00000
1`16P[@3000000<0AX:d00<0000004J2]016P[@01`16P[@<000000@0AX:d0P00000304J2]0800000
V016P[@10?ooo`00PP16P[@60000000304J2]00000000000008000001@16P[@00`000000AX:d04J2
]00404J2]00300000016P[@0AX:d00D0AX:d0`00000304J2]00300000016P[@0AX:d00D0AX:d1000
000304J2]00500000016P[@0AX:d04J2]00000000`16P[@200000080AX:d00<0000004J2]016P[@0
0P16P[@010000000AX:d00000000000304J2]08000001P16P[@00`000000AX:d04J2]00304J2]0@0
00000`16P[@00`000000AX:d04J2]00404J2]0X000000P16P[@3000009H0AX:d0@3oool00800AX:d
0P0000000`16P[@000000000000204J2]0<000002016P[@00`000000AX:d04J2]00304J2]0030000
0016P[@0AX:d00T0AX:d1000000704J2]00300000016P[@0000000@0AX:d00D0000004J2]016P[@0
AX:d0000000304J2]08000000P16P[@01@000000AX:d04J2]016P[@0000000@0AX:d0`00000904J2
]0D000002016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d008000000`16P[@30000
000404J2]0000000AX:d000009D0AX:d0@3oool007l0AX:d1000000204J2]0<000002P16P[@00`00
0000AX:d04J2]00204J2]00300000016P[@0AX:d00d0AX:d1@00000204J2]00400000016P[@0AX:d
04J2]08000000`16P[@01@000000AX:d04J2]016P[@000000080AX:d0P0000000`16P[@0000004J2
]00204J2]00300000016P[@0AX:d0080AX:d0P0000000`16P[@000000000000404J2]0D000003016
P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d0080AX:d0`0000000`16P[@0000004J2
]0030000000304J2]0000000000009<0AX:d0@3oool007d0AX:d0`0000000`16P[@0000000000002
0000000304J2]0000000AX:d00T0AX:d00<0000004J2]00000001`00000<04J2]00300000016P[@0
AX:d0080AX:d0`00000504J2]00500000016P[@0AX:d04J2]00000000P16P[@00`000000AX:d04J2
]0020000000304J2]0000000AX:d0080AX:d00D0000004J2]016P[@0AX:d0000000504J2]0@00000
9P2`5ah20000000304J2]000000000000940AX:d0@3oool007`0AX:d0P00000204J2]08000000`16
P[@00`000000AX:d04J2]00504J2]0H000000P16P[@00`000000AX:d04J2]00304J2]0X000000P16
P[@010000000AX:d04J2]016P[@200000080AX:d0P00000404J2]00700000016P[@0AX:d04J2]000
0000AX:d0000000204J2]080000000D0AX:d00000016P[@0AX:d0000000304J2]00300000016P[@0
AX:d00P0/1LN1016P[@00`000000AX:d04J2]00<04J2]00300000016P[@0AX:d00<0AX:d00<00000
04J2]016P[@01P16P[@30000000304J2]02`5ah0/1LN00<0/1LN00<0000004J2]016P[@0SP16P[@1
0?ooo`00N`16P[@00`000000AX:d04J2]003000000<0AX:d00<0000004J2]016P[@01P00000404J2
]00500000016P[@0AX:d04J2]00000003`16P[@7000000D0AX:d0P00000304J2]00300000016P[@0
AX:d00h00000102`5ah2000000D0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]003
04J2]0d0000000<0AX:d00000016P[@02@16P[@30000000404J2]0000000AX:d04J2]0L0/1LNRP16
P[@10?ooo`00NP16P[@01P000000AX:d04J2]0000000AX:d00000080AX:d1@00000904J2]0050000
0016P[@0AX:d04J2]00000004@16P[@010000000AX:d04J2]000000204J2]0d0000000D0AX:d0000
0016P[@0000004J2]0030000000304J2]02`5ah0/1LN00<0/1LN5`00000:04J2]00300000016P[@0
AX:d00H000001`16P[@00`000000AX:d00000002000000<0AX:d0P00000304J2]0L0/1LNP`16P[@1
0?ooo`00N@16P[@010000000AX:d00000000000204J2]0@000003@16P[@010000000AX:d04J2]000
000@04J2]0T000000P16P[@400000080AX:d0P00000204J2]00400000016P[@00000000000D0/1LN
00@0AX:d000000000000AX:d0`00000404J2]0@0000000<0AX:d0000000000001P00000>04J2]003
00000016P[@0AX:d0080AX:d00@0000004J2]016P[@0AX:d1P00000204J2]00300000016P[@0AX:d
008000001016P[@00`000000AX:d04J2]00704J2]0<0/1LNP016P[@10?ooo`00N016P[@00`000000
AX:d0000000204J2]0<0000000<0AX:d00000016P[@03@16P[@010000000AX:d04J2]000000:04J2
]0h000001`16P[@30000000304J2]0000000000000@0/1LN100000000`16P[@0000004J2]0020000
00<0AX:d1000000704J2]00600000016P[@0AX:d04J2]0000000AX:d1000000;04J2]00500000016
P[@0AX:d04J2]00000002@16P[@400000080AX:d0`00000304J2]00300000016P[@0AX:d00T0AX:d
0`2`5aim04J2]040oooo001f04J2]0@0000000D0AX:d000000000000AX:d0000000204J2]0030000
0016P[@0AX:d00`0AX:d3P00000804J2]00300000016P[@0000000<0AX:d1`00000304J2]0<0/1LN
2`0000000`16P[@0000000000002000000L0AX:d2`00000304J2]0@000002016P[@01@000000AX:d
04J2]016P[@0000000`0AX:d0P0000001016P[@0000004J2]000000304J2]00300000016P[@0AX:d
00/0AX:d0`2`5aij04J2]040oooo001e04J2]00400000016P[@0000004J2]08000000`16P[@00`00
0000AX:d0000000;04J2]0@000000P16P[@6000000h0AX:d0P00000;04J2]0<0/1LN6P00000504J2
]00400000016P[@0AX:d00000080AX:d2`00000404J2]00500000016P[@0AX:d04J2]00000003016
P[@010000000AX:d00000000000204J2]08000000P16P[@00`000000AX:d04J2]00=04J2]0<0/1LN
M`16P[@10?ooo`00M016P[@5000000@0AX:d00<0000004J2]00000002016P[@400000080AX:d1000
000C04J2]0/000000`2`5ahG000000`0AX:d00<0000004J2]00000003@16P[@70000000304J2]000
0000AX:d00`0AX:d00<0000004J2]016P[@00P00000204J2]00400000016P[@0000000000140AX:d
0`2`5aid04J2]040oooo001c04J2]0<000001`16P[@2000000D0AX:d1000000404J2]080000000@0
AX:d00000016P[@000003@16P[@60000000304J2]0000000000000D0AX:d0`2`5ah304J2]1@00000
0`16P[@?00000140AX:d1P00000<04J2]00500000016P[@0AX:d00000016P[@00P0000000`16P[@0
000000000002000001<0AX:d0`2`5aia04J2]040oooo001b04J2]08000002016P[@010000000AX:d
00000016P[@4000000D0AX:d0`00000304J2]00300000016P[@0000000L0AX:d1P00000704J2]080
00000P16P[@30;0G7PH000001016P[@?0000000304J2]0000000000000@000002@16P[@00`000000
AX:d00000004000000h0AX:d00<0000004J2]016P[@01P00000904J2]00400000016P[@0AX:d0000
0080AX:d0P0000001016P[@0000000000000000E04J2]080/1LNK`16P[@10?ooo`00L@16P[@00`00
0000AX:d04J2]00804J2]0@000001P16P[@3000000H0AX:d0P00000204J2]0H000003@16P[@01@00
0000/1LN0;0G7P2`5ah0000000T0AX:d0`0000000`16P[@000000000000;0000000404J2]0000000
0000000000@0AX:d1P00000204J2]00400000016P[@0AX:d000000@0AX:d1000000:04J2]0060000
0016P[@0AX:d04J2]0000000AX:d0P0000001016P[@0000000000000000604J2]00400000016P[@0
AX:d000000@0AX:d1@00000F04J2]0<0/1LNK016P[@10?ooo`00L016P[@2000000T0AX:d0`000006
04J2]08000002016P[@500000100AX:d0P0000020;0G7P0300000016P[@0AX:d00H0AX:d10000002
04J2]0H0000000<0AX:d0000000000000`0000000`16P[@0000004J2]00200000080AX:d10000006
04J2]0@0000000<0AX:d00000016P[@01`16P[@5000000H0AX:d00@0000004J2]016P[@000000`16
P[@30000000404J2]00000000000000000@0AX:d00<0000004J2]00000001P16P[@4000001P0AX:d
0P2`5aiZ04J2]040oooo001_04J2]08000002016P[@30000000304J2]0000000AX:d0080AX:d0`00
000904J2]080000000<0AX:d00000016P[@03P16P[@2000000<0/1LN00<0000004J2]00000001@16
P[@3000000@0AX:d0P0000001`16P[@0000004J2]0000000AX:d00000016P[@00`0000001016P[@0
000000000016P[@20000000304J2]0000000000000@0AX:d0`00000504J2]00300000016P[@00000
008000003016P[@400000080AX:d00@0000004J2]016P[@000001P16P[@200000080AX:d1@000002
04J2]00300000016P[@0AX:d00D0AX:d0`00000I04J2]080/1LNJ016P[@10?ooo`00KP16P[@30000
00L0AX:d00<0000004J2]016P[@00P0000001016P[@0000000000000000904J2]0<0000000@0AX:d
00000016P[@000003016P[@300000080/1LN0`16P[@01@000000AX:d04J2]0000000AX:d00<00000
1@16P[@20000000:04J2]0000000000004J2]0000000AX:d00000016P[@0000004J2]0@0000000D0
AX:d00000016P[@0AX:d0000000204J2]08000001@16P[@30000000304J2]0000000AX:d0080AX:d
00<0000004J2]00000000P00000=04J2]0@0000000<0AX:d00000016P[@01`16P[@3000000<0AX:d
0P0000000`16P[@0000004J2]00804J2]08000006P16P[@20;0G7VH0AX:d0@3oool006d0AX:d00<0
000004J2]00000001P16P[@200000080AX:d00@0000004J2]000000000002@16P[@3000000@0AX:d
00<0000004J2]00000002P16P[@20000000304J2]02`5ah0/1LN00D0AX:d00<0000004J2]0000000
0P00000604J2]08000000P16P[@010000000AX:d04J2]000000204J2]00400000016P[@0000004J2
]0<0000000@0AX:d00000016P[@000000P16P[@010000000AX:d04J2]016P[@2000000H0AX:d0P00
000304J2]00300000016P[@0AX:d0080AX:d0`00000<04J2]00300000016P[@00000008000002P16
P[@200000080AX:d1000000804J2]0<000006`16P[@20;0G7V@0AX:d0@3oool006/0AX:d0P000000
0`16P[@000000000000404J2]08000001016P[@3000000P0AX:d0P00000704J2]00300000016P[@0
000000L0AX:d0`0000000`16P[@0/1LN0;0G7P0704J2]08000000P16P[@00`000000AX:d04J2]002
04J2]08000000P16P[@200000080AX:d00@0000004J2]016P[@000000P16P[@00`000000AX:d0000
00020000000504J2]0000000AX:d04J2]00000000P16P[@2000000<0AX:d0P00000404J2]0060000
0016P[@0000000000016P[@000001`16P[@2000000X0AX:d00@0000004J2]016P[@0AX:d0P00000;
04J2]0<000000P16P[@2000000P0AX:d0`00000L04J2]080/1LNHP16P[@10?ooo`00JP16P[@20000
000304J2]0000000000000<0AX:d0P00000404J2]0<0000000<0AX:d00000016P[@01016P[@30000
00T0AX:d00<0000004J2]00000001016P[@300000080AX:d0P2`5ah704J2]0<000000`16P[@00`00
0000AX:d04J2]002000000<0AX:d00D0000004J2]016P[@0AX:d0000000204J2]00400000016P[@0
AX:d00000080AX:d0P0000001016P[@0000004J2]000000204J2]00500000016P[@0AX:d04J2]000
00001016P[@200000080AX:d00@0000004J2]016P[@0AX:d0P00000904J2]0<000001`16P[@01P00
0000AX:d04J2]016P[@0000004J2]0<000002`16P[@20000000304J2]0000000000000L0AX:d00@0
000004J2]000000000007@16P[@20;0G7V00AX:d0@3oool006T0AX:d00@0000004J2]016P[@0AX:d
0P00000204J2]00300000016P[@0AX:d0080AX:d0P00000204J2]08000000`16P[@3000000/0AX:d
00D0000004J2]016P[@0000004J2]003000000<0AX:d0P2`5ah704J2]08000000P16P[@00`000000
AX:d04J2]00204J2]08000001016P[@01@000000AX:d04J2]016P[@0000000<0AX:d00@0000004J2
]016P[@000000P16P[@20000000504J2]0000000AX:d04J2]00000000P16P[@01@000000AX:d04J2
]016P[@0000000D0AX:d0P00000504J2]0<000002P16P[@3000000@0AX:d00D0000004J2]016P[@0
AX:d0000000404J2]08000002@16P[@01@000000AX:d000000000000AX:d008000001P16P[@40000
01h0AX:d0P2`5aiN04J2]040oooo001X04J2]00400000016P[@0AX:d04J2]080000000<0AX:d0000
000000000`16P[@2000000<0AX:d00@0000004J2]0000000AX:d0P00000>04J2]00300000016P[@0
AX:d008000001016P[@20;0G7PL0AX:d0P00000404J2]00300000016P[@0AX:d0080000000@0AX:d
000000000000AX:d0P00000304J2]00500000016P[@0AX:d04J2]00000000`16P[@00`000000AX:d
04J2]0020000000504J2]0000000AX:d04J2]00000000`16P[@010000000AX:d04J2]016P[@20000
00<0AX:d00@0000004J2]000000000000`16P[@00`000000AX:d04J2]002000000/0AX:d0`000000
0`16P[@0000004J2]00204J2]00300000016P[@0AX:d00@0AX:d0P00000704J2]00300000016P[@0
AX:d00<0000000<0AX:d0000000000001016P[@00`000000AX:d00000002000001l0AX:d0P2`5aiL
04J2]040oooo001W04J2]00300000016P[@0AX:d0080AX:d0`00000304J2]08000001@16P[@01000
0000AX:d00000000000@04J2]0@000001016P[@00`2`5ah0AX:d04J2]00404J2]0<000001P16P[@3
000000D0AX:d00<0000004J2]016P[@00P16P[@01@000000AX:d04J2]016P[@0000000<0AX:d00@0
000004J2]016P[@0AX:d0P00000204J2]00400000016P[@0AX:d00000080AX:d00<0000004J2]016
P[@00`16P[@00`000000AX:d0000000404J2]00400000016P[@0AX:d000000@0AX:d0P00000<04J2
]08000000`16P[@00`000000AX:d04J2]00604J2]0<000001016P[@010000000AX:d04J2]0000002
04J2]00300000016P[@0AX:d008000000`16P[@200000080AX:d00<0000004J2]016P[@07P16P[@0
0`2`5ah0AX:d04J2]01I04J2]040oooo001V04J2]00300000016P[@0AX:d0080AX:d0P00000404J2
]00300000016P[@0AX:d00D0AX:d0`00000@04J2]08000000`16P[@010000000AX:d04J2]02`5ah5
04J2]08000002@16P[@00`000000AX:d04J2]00404J2]00700000016P[@0000000000016P[@00000
04J2]00C000000<0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00404J2]0030000
0016P[@0000000H0AX:d0P00000:04J2]00600000016P[@0000000000016P[@000002`16P[@20000
00<0AX:d00<0000004J2]00000000`16P[@200000080AX:d00H0000004J2]016P[@0000004J2]000
000204J2]00300000016P[@0AX:d01h0AX:d0P2`5aiI04J2]040oooo001U04J2]00300000016P[@0
AX:d0080AX:d0`00000204J2]08000001`16P[@20000000304J2]0000000AX:d00d0AX:d0P000000
0`16P[@0000004J2]00204J2]0030000002`5ah0/1LN00@0AX:d0P00000904J2]10000000P16P[@0
0`000000AX:d04J2]00204J2]00400000016P[@0AX:d04J2]08000000P16P[@010000000AX:d04J2
]016P[@<000000D0AX:d0P00000804J2]08000002016P[@010000000AX:d04J2]016P[@2000000d0
AX:d0P0000001@16P[@0000004J2]016P[@0000000@0AX:d00<0000004J2]016P[@00P0000000`16
P[@000000000000304J2]00300000016P[@0AX:d01l0AX:d0P2`5aiG04J2]040oooo001T04J2]003
00000016P[@0AX:d00<0AX:d0P0000000`16P[@000000000000704J2]080000000@0AX:d00000016
P[@000003016P[@2000000<0AX:d00D0000004J2]016P[@0AX:d0;0G7P0404J2]08000001P16P[@5
00000080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00204J2]00400000016P[@0
000000000080AX:d00<0000004J2]016P[@00P16P[@010000000AX:d04J2]016P[@200000080AX:d
00D0000004J2]016P[@0AX:d0000000304J2]0<000001016P[@:000000P0AX:d0P00000504J2]003
00000016P[@0AX:d00<0AX:d0P00000>04J2]08000000P16P[@00`000000AX:d04J2]00304J2]080
00000P16P[@20000000304J2]0000000AX:d0080AX:d00<0000004J2]016P[@08016P[@20;0G7UD0
AX:d0@3oool006@0AX:d00@0000004J2]016P[@0AX:d0P0000000`16P[@000000000000804J2]004
00000016P[@0AX:d00000080AX:d00<0000004J2]016P[@02016P[@2000000@0AX:d00P0000004J2
]016P[@0AX:d0;0G7P16P[@0000004J2]08000000`16P[@500000080AX:d00<0000004J2]016P[@0
0P16P[@00`000000AX:d04J2]002000000@0AX:d00<0000004J2]016P[@00P16P[@400000080AX:d
00<0000004J2]016P[@00P16P[@2000000<0AX:d00<0000004J2]016P[@01000000204J2]0030000
0016P[@0AX:d00<0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d00000004000000H0AX:d
0P00000304J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]000000000003@16P[@4000000L0
AX:d0P00000204J2]08000001016P[@00`000000AX:d04J2]00Q04J2]0030;0G7P16P[@0AX:d0580
AX:d0@3oool006<0AX:d00H0000004J2]016P[@0AX:d00000016P[@30000000304J2]03oO`00ogl0
00X0ogl00`16P[@00`000000AX:d04J2]00504J2]08000001P16P[@010000000AX:d04J2]02`5ah2
04J2]0L000001@16P[@2000000D0AX:d00<0000004J2]00000001P16P[@00`000000AX:d04J2]002
04J2]00400000016P[@0AX:d04J2]0l0000000<0AX:d00000016P[@01016P[@00`000000AX:d04J2
]00304J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@00P00000204J2]0@000001016
P[@3000000L0AX:d00<0000004J2]016P[@00P00000;04J2]00400000016P[@0AX:d000000T0AX:d
00<0000004J2]00000000P00000404J2]00300000016P[@0AX:d0240AX:d00<0/1LN04J2]016P[@0
D@16P[@10?ooo`00HP16P[@01`000000AX:d04J2]016P[@0000004J2]0000000103oO`0504J2]003
00000016P[@0AX:d00<0AX:d00<000000?mo003oO`00303oO`0504J2]0030000002`5ah0/1LN00D0
00002016P[@2000000L0AX:d0P00000604J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016
P[@00`16P[@00`000000AX:d04J2]00204J2]08000000`16P[@00`000000AX:d04J2]00204J2]003
00000016P[@0AX:d0080AX:d00<0000004J2]016P[@01016P[@01@000000AX:d04J2]016P[@00000
00@0AX:d00<0000004J2]016P[@00`16P[@400000080AX:d00<0000004J2]016P[@01@16P[@00`00
0000AX:d04J2]00204J2]00300000016P[@0AX:d00P0AX:d00<0000004J2]016P[@00`00000804J2
]0@000001@16P[@00`000000AX:d04J2]00Q04J2]0030;0G7P16P[@0AX:d0500AX:d0@3oool00680
AX:d00<0000004J2]016P[@00`3oO`000`000000AX:d0000000504J2]08000001P16P[@01@000000
AX:d04J2]016P[@0000000<0AX:d0P00000504J2]0D0ogl01000000404J2]00300000016P[@0AX:d
00@0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d
00<0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00304J2]08000000`16P[@00`00
0000AX:d04J2]00204J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01016P[@01000
0000AX:d04J2]000000504J2]00300000016P[@0AX:d00H0AX:d1@00000504J2]00300000016P[@0
AX:d00<0AX:d0P00000804J2]00400000016P[@0AX:d00000080AX:d00<0000004J2]016P[@01`16
P[@00`000000AX:d0000000404J2]00300000016P[@0AX:d0280AX:d0P2`5ai@04J2]040oooo001Q
04J2]00:00000016P[@0ogl00?mo0016P[@0000004J2]0000000AX:d000000@0AX:d00<0000004J2
]016P[@01@16P[@00`000000AX:d04J2]00204J2]00400000016P[@00000000000P0AX:d0`000000
0`2`5ah000000?mo00030?mo00<0AX:d00<0000004J2]016P[@00P16P[@2000000T0AX:d0P000005
04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]003
04J2]08000001016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00<0AX:d00<00000
04J2]016P[@01016P[@00`000000AX:d0000000604J2]08000001`16P[@00`000000AX:d04J2]004
00000080AX:d00<0000004J2]016P[@01@16P[@2000000D0AX:d00<0000004J2]016P[@00P16P[@0
0`000000AX:d04J2]002000000L0AX:d1000000404J2]00300000016P[@0AX:d02<0AX:d00<0/1LN
04J2]016P[@0C@16P[@10?ooo`00H016P[@020000000ogl00?mo00000000AX:d00000016P[@00000
0P16P[@00`000000AX:d04J2]002000000P0AX:d00<0000004J2]016P[@00P16P[@2000000P0AX:d
0P00000204J2]0030;0G7P16P[@0000000@0AX:d103oO`0010000000AX:d00000000000:04J2]003
00000016P[@0000000D0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00404J2]003
00000016P[@0AX:d00<0AX:d0P00000404J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016
P[@01016P[@00`000000AX:d04J2]00404J2]08000002016P[@00`000000AX:d04J2]00304J2]003
00000016P[@0AX:d00<0AX:d00<0000004J2]00000000`00000804J2]00300000016P[@0AX:d0080
AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00@0
AX:d00<0000004J2]016P[@00P00000304J2]00300000016P[@0AX:d02@0AX:d00<0/1LN04J2]016
P[@0C016P[@10?ooo`00G`16P[@20?mo000404J2]0000000AX:d00000080AX:d00H0000004J2]016
P[@0000004J2]000000:04J2]00400000016P[@0AX:d04J2]08000001P16P[@3000000<0AX:d00@0
/1LN00000000000000002016P[@40?mo00T0AX:d00@0000004J2]016P[@000001016P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@00`16P[@2000000@0
AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00D0
AX:d0P00000804J2]00500000016P[@0AX:d04J2]00000001`16P[@20000000304J2]0000000AX:d
008000001`16P[@200000080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00304J2
]08000001@16P[@00`000000AX:d00000002000000<0AX:d00<0000004J2]016P[@09016P[@00`2`
5ah0AX:d04J2]01;04J2]040oooo001N04J2]0060?mo00000000000000000016P[@000000`16P[@0
0`000000AX:d00000002000000/0AX:d00@0000004J2]000000000000P16P[@00`000000AX:d04J2
]003000000@0AX:d0P2`5ah010000000AX:d04J2]000000804J2]00400000016P[@0000004J2]0@0
ogl00`16P[@2000000<0AX:d00D0000004J2]016P[@0AX:d0000000604J2]00300000016P[@0AX:d
00@0AX:d00<0000004J2]016P[@01016P[@2000000@0AX:d00<0000004J2]016P[@00`16P[@00`00
0000AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]00000002016P[@20000
000304J2]0000000AX:d00P0AX:d0P00000304J2]0<000001P16P[@3000000@0AX:d00<0000004J2
]016P[@01@16P[@00`000000AX:d04J2]00204J2]00400000016P[@0000004J2]08000000P16P[@0
0`000000AX:d04J2]00U04J2]0030;0G7P16P[@0AX:d04X0AX:d0@3oool005h0AX:d00<0ogl00000
0016P[@00P00000404J2]00300000016P[@0000000d0AX:d0P00000404J2]0<000001P16P[@00`2`
5ah0AX:d0000000304J2]00300000016P[@0AX:d00D0AX:d00D0000004J2]016P[@0AX:d00000004
04J2]0@0ogl01016P[@010000000AX:d04J2]000000704J2]00300000016P[@0AX:d00@0AX:d00<0
000004J2]016P[@01016P[@2000000@0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2
]00404J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]016P[@000002@16P[@00`000000AX:d
04J2]00904J2]00300000016P[@0AX:d00@0AX:d0`00000504J2]00300000016P[@0AX:d0080AX:d
00<0000004J2]016P[@01P16P[@200000080AX:d00D0000004J2]016P[@0000004J2]00200000080
AX:d00<0000004J2]016P[@09@16P[@00`2`5ah0AX:d04J2]01904J2]040oooo001M04J2]0040?mo
00000000AX:d000000H0AX:d0`00000<04J2]08000000`16P[@3000000L0AX:d00<0/1LN00000000
00001016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00<0AX:d0P00000304J2]003
00000016P[@0AX:d00@0ogl000@0000004J2]016P[@000001P16P[@00`000000AX:d04J2]00504J2
]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00304J2
]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@00P16P[@01@000000AX:d04J2]016P[@0
000000H0AX:d0P0000000`16P[@0000004J2]00904J2]0<000001`16P[@200000080AX:d00<00000
04J2]00000000`16P[@00`000000AX:d04J2]00804J2]00300000016P[@000000080AX:d00<00000
04J2]016P[@00P0000000`16P[@0000004J2]00W04J2]0030;0G7P16P[@0AX:d04P0AX:d0@3oool0
05d0AX:d00<0000004J2]00000001P16P[@20000000304J2]0000000AX:d00X0AX:d0P0000001016
P[@0000000000000000304J2]00300000016P[@0AX:d00<0AX:d00<0/1LN00000016P[@01@16P[@0
0`000000AX:d04J2]00304J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]00000001`16P[@4
0?mo00H0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00404J2]00300000016P[@0
AX:d00@0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00404J2]00300000016P[@0
AX:d0080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0
AX:d0080AX:d00<0000004J2]016P[@01`16P[@010000000AX:d04J2]000000804J2]0<000000P16
P[@200000080AX:d00<0000004J2]016P[@02016P[@30000000304J2]0000000AX:d0080AX:d0P00
00000`16P[@0000004J2]00W04J2]0030;0G7P16P[@0AX:d04L0AX:d0@3oool005`0AX:d0`000007
04J2]00400000016P[@0AX:d000000X0AX:d00@0000004J2]000000000001P16P[@00`000000AX:d
04J2]00204J2]0030;0G7P000000AX:d00H0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d
04J2]00804J2]00300000016P[@0AX:d00H0AX:d0P00000204J2]0@0ogl000<0AX:d00000016P[@0
1P16P[@00`000000AX:d04J2]00404J2]08000001P16P[@00`000000AX:d04J2]00404J2]0030000
0016P[@0AX:d00D0AX:d00D0000004J2]016P[@0AX:d0000000504J2]00400000016P[@000000000
00H0AX:d00<0000004J2]016P[@01P16P[@01@000000AX:d04J2]016P[@0000000P0AX:d00<00000
04J2]00000000P0000001016P[@0000004J2]000000<04J2]00300000016P[@0000000@0AX:d0`00
000Y04J2]0030;0G7P16P[@0AX:d04H0AX:d0@3oool005`0AX:d0P00000704J2]08000000P16P[@0
0`000000AX:d04J2]00704J2]0@000001`16P[@01P000000AX:d04J2]016P[@000000;0G7PP0AX:d
00D0000004J2]016P[@0AX:d0000000:04J2]00400000016P[@00000000000H0AX:d00<0000004J2
]016P[@01@16P[@40?mo00D0AX:d00<0000004J2]016P[@01016P[@2000000H0AX:d00<0000004J2
]016P[@01@16P[@00`000000AX:d04J2]00504J2]00400000016P[@0AX:d000000H0AX:d00<00000
04J2]016P[@01`16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d0080AX:d0P000006
04J2]00300000016P[@0AX:d0080AX:d1000000<04J2]0<000001016P[@010000000AX:d00000000
000Y04J2]0030;0G7P16P[@0AX:d04D0AX:d0@3oool005/0AX:d0P0000000`3oO`00AX:d04J2]004
04J2]00300000016P[@000000080AX:d00<0000004J2]016P[@01P16P[@200000080AX:d00<00000
04J2]016P[@01P16P[@3000000030;0G7P16P[@0AX:d00L0AX:d00@0000004J2]016P[@000002P16
P[@00`000000AX:d04J2]00204J2]08000001016P[@00`000000AX:d04J2]00504J2]00400000016
P[@0AX:d04J2]0<0ogl00P16P[@00`000000AX:d04J2]00404J2]08000001P16P[@00`000000AX:d
04J2]00504J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]00000001016P[@20000000304J2
]0000000AX:d00P0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00404J2]0030000
0016P[@0AX:d0080AX:d00<0000004J2]016P[@01@16P[@2000000`0AX:d00@0000004J2]0000000
00001016P[@00`000000AX:d0000000Y04J2]0030;0G7P16P[@0AX:d04D0AX:d0@3oool005/0AX:d
0P0000000`3oO`00AX:d04J2]00304J2]00300000016P[@0000000@0AX:d00<0000004J2]016P[@0
0`16P[@2000000@0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d0;0G7P0:04J2]0<00000
2P16P[@00`000000AX:d04J2]00504J2]080000000<0AX:d0000000000001`16P[@00`000000AX:d
04J2]00404J2]080ogl000<0000004J2]016P[@01016P[@2000000L0AX:d00<0000004J2]016P[@0
1@16P[@00`000000AX:d04J2]00504J2]00300000016P[@000000080AX:d0P00000404J2]0030000
0016P[@0AX:d00L0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00504J2]0050000
0016P[@0AX:d04J2]00000002016P[@3000000T0AX:d00D0000004J2]016P[@0AX:d0000000504J2
]00300000016P[@0000002T0AX:d00<0/1LN04J2]016P[@0A016P[@10?ooo`00FP16P[@300000003
0?mo0016P[@0AX:d0080AX:d00@0000004J2]016P[@000001016P[@010000000AX:d04J2]016P[@2
000000H0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d0;0G7P0;04J2]00300000016P[@0
AX:d00X0AX:d00<0000004J2]016P[@01`16P[@3000000H0AX:d00<0000004J2]016P[@01P16P[@0
10000000ogl00?mo003oO`0404J2]08000001`16P[@00`000000AX:d04J2]00504J2]00300000016
P[@0AX:d00H0AX:d1000000604J2]00300000016P[@0AX:d00P0AX:d00<0000004J2]016P[@00P16
P[@00`000000AX:d04J2]00604J2]0<000002@16P[@00`000000AX:d00000002000000L0AX:d00D0
000004J2]016P[@0AX:d0000000604J2]0<00000:@16P[@00`2`5ah0AX:d04J2]01304J2]040oooo
001I04J2]0@0000000D0AX:d0?mo0016P[@0AX:d0000000304J2]00300000016P[@0AX:d0080AX:d
00<0000004J2]016P[@00P00000704J2]00300000016P[@0AX:d00@0AX:d00@0000004J2]02`5ah0
00002P16P[@2000000/0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]002000000D0
AX:d00<0000004J2]016P[@01P16P[@010000000AX:d04J2]016P[@30?mo000304J2]00000000000
00L0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00504J2]08000002@16P[@00`00
0000AX:d04J2]00804J2]08000000P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d
00L0AX:d00@0000004J2]016P[@0AX:d0P00000604J2]00400000016P[@0AX:d04J2]08000001P16
P[@2000002T0AX:d00<0/1LN04J2]016P[@0@`16P[@10?ooo`00F@16P[@300000080AX:d00<0ogl0
04J2]00000001016P[@00`000000AX:d04J2]00204J2]0@000002016P[@00`000000AX:d04J2]003
04J2]00600000016P[@0AX:d0;0G7P16P[@000002016P[@00`000000AX:d0000000:04J2]0030000
0016P[@0AX:d00P0AX:d00D0000004J2]016P[@0000004J2]0030000000304J2]0000000AX:d00P0
AX:d00<0000004J2]016P[@01016P[@40?mo00H0AX:d00<0000004J2]016P[@01P16P[@00`000000
AX:d04J2]00304J2]080000000<0AX:d0000000000002@16P[@00`000000AX:d04J2]00904J2]080
00002P16P[@00`000000AX:d0000000804J2]00300000016P[@0AX:d0080AX:d0`00000404J2]003
00000016P[@0AX:d0080AX:d0P00000604J2]0800000:@16P[@00`2`5ah0AX:d04J2]01204J2]040
oooo001H04J2]0@000000`16P[@00`000000AX:d04J2]00304J2]00400000016P[@0AX:d04J2]0<0
00002P16P[@00`000000AX:d04J2]00204J2]00400000016P[@0AX:d0;0G7P<0AX:d00<0000004J2
]016P[@01016P[@010000000AX:d04J2]000000904J2]00300000016P[@0AX:d00P0AX:d00D00000
04J2]016P[@0AX:d0000000404J2]0@000001`16P[@00`000000AX:d04J2]00504J2]080000000<0
AX:d0?mo003oO`000P3oO`0204J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]00000000P00
000304J2]08000002P16P[@00`000000AX:d04J2]00904J2]00300000016P[@0AX:d00L0AX:d00D0
000004J2]016P[@0AX:d0000000704J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]0000000
0`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0000000D0AX:d0P00000Y04J2]0030;0G
7P16P[@0AX:d0480AX:d0@3oool005P0AX:d00@0000004J2]000000000000P16P[@00`000000ogl0
04J2]00304J2]00300000016P[@0AX:d0080000000<0AX:d00000016P[@02P16P[@01@000000AX:d
04J2]016P[@000000080AX:d00<0/1LN04J2]016P[@00`16P[@00`000000AX:d04J2]00204J2]005
00000016P[@0AX:d04J2]00000002016P[@00`000000AX:d04J2]00904J2]00500000016P[@0AX:d
04J2]00000001@16P[@00`000000AX:d04J2]00400000080AX:d00<0000004J2]016P[@01P16P[@2
000000D0AX:d0P3oO`000`16P[@0000004J2]00504J2]0@000001P16P[@00`000000AX:d00000009
04J2]00300000016P[@0AX:d00T0AX:d0P00000804J2]00300000016P[@0AX:d0080AX:d00<00000
04J2]016P[@01016P[@00`000000AX:d04J2]00404J2]00600000016P[@0000000000016P[@00000
1016P[@010000000AX:d04J2]000000404J2]0<00000:@16P[@00`2`5ah0AX:d04J2]01104J2]040
oooo001G04J2]00300000016P[@0AX:d0080000000D0AX:d00000016P[@0AX:d0?mo000304J2]0<0
00000P16P[@2000000/0AX:d00@0000004J2]016P[@000000P16P[@00`2`5ah0AX:d04J2]00404J2
]00500000016P[@0AX:d04J2]00000001016P[@00`000000AX:d04J2]00504J2]00300000016P[@0
AX:d00T0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0
AX:d00D0AX:d1`00000404J2]08000001`16P[@20?mo0080AX:d1000000204J2]00300000016P[@0
AX:d00D0AX:d00<0000004J2]00000002P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0
000000H0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00304J2]00300000016P[@0
AX:d00D0AX:d0P0000000`16P[@000000000000404J2]00500000016P[@0AX:d04J2]00000000`16
P[@4000002P0AX:d00<0/1LN04J2]016P[@0@@16P[@10?ooo`00E`16P[@01P000000AX:d04J2]000
0000AX:d000000<0AX:d00D0ogl004J2]016P[@0AX:d0000000304J2]00400000016P[@0AX:d0000
00X0AX:d00<0000004J2]00000000`16P[@00`2`5ah0AX:d04J2]00504J2]00300000016P[@00000
00D0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00904J2]00300000016P[@0AX:d
0080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00504J2]1H000000`3oO`0604J2
]00300000016P[@0AX:d00@0AX:d00@0000004J2]016P[@000002P16P[@00`000000AX:d04J2]007
04J2]00400000016P[@0AX:d000000@0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2
]00204J2]00300000016P[@0AX:d00L0AX:d0P0000000`16P[@0000004J2]00204J2]00300000016
P[@0AX:d0080AX:d00@0000004J2]016P[@0AX:d0`00000Y04J2]0030;0G7P16P[@0AX:d0400AX:d
0@3oool005H0AX:d00<0000004J2]016P[@00`00000504J2]0040?mo0016P[@00000000000<0AX:d
00@0000004J2]016P[@000002P16P[@2000000<0AX:d00<0/1LN04J2]016P[@01`16P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02@16P[@010000000
AX:d04J2]016P[@?00000080AX:d00<0000004J2]016P[@01P16P[@2000000H0AX:d1P0000020?mo
00D000001P16P[@010000000AX:d04J2]000000;04J2]00300000016P[@0AX:d00H0AX:d00D00000
04J2]016P[@0AX:d0000000204J2]00300000016P[@0AX:d00P0AX:d00D0000004J2]016P[@0AX:d
0000000:04J2]00300000016P[@0AX:d008000000P16P[@00`000000AX:d04J2]00204J2]0030000
0016P[@0AX:d00@00000:@16P[@00`2`5ah0AX:d04J2]00o04J2]040oooo001E04J2]00400000016
P[@0AX:d04J2]08000001`16P[@00`000000AX:d0000000204J2]00500000016P[@0AX:d04J2]000
00002@16P[@00`000000AX:d0000000304J2]0030;0G7P16P[@0AX:d00H0AX:d00<0000004J2]000
00001@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00T0AX:d1@00000204J2]005
00000016P[@0AX:d04J2]00000002@16P[@00`000000AX:d04J2]00704J2]08000002016P[@00`00
0000AX:d04J2]00304J2]0<0ogl000<0AX:d000000000000200000000`16P[@0000004J2]00:04J2
]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d0000000;04J2
]00400000016P[@0AX:d000000X0AX:d0P00000304J2]0<000001016P[@00`000000AX:d04J2]002
0000000304J2]0000000AX:d02P0AX:d00<0/1LN04J2]016P[@0?`16P[@10?ooo`00E@16P[@01000
0000AX:d04J2]016P[@2000000H0AX:d00H0000004J2]03oO`00000004J2]000000504J2]0030000
0016P[@0AX:d00D0AX:d00@0000004J2]016P[@000000P16P[@00`2`5ah0AX:d04J2]00604J2]005
00000016P[@0AX:d04J2]00000001016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d
00D0AX:d1P00000604J2]00500000016P[@0AX:d04J2]00000002@16P[@00`000000AX:d04J2]007
04J2]08000002016P[@00`000000AX:d04J2]00604J2]0<0ogl01@16P[@00`000000AX:d04J2]005
000000P0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0
AX:d00/0AX:d00<0000004J2]00000002@16P[@010000000AX:d04J2]000000404J2]00300000016
P[@0AX:d00<0AX:d00@0000004J2]000000000000P16P[@00`000000AX:d04J2]00W04J2]0030;0G
7P16P[@0AX:d03h0AX:d0@3oool005@0AX:d00<0000004J2]016P[@00P16P[@2000000D0AX:d00@0
000004J2]016P[@0AX:d0P00000604J2]00300000016P[@0AX:d00@0AX:d00D0000004J2]016P[@0
AX:d0000000204J2]0030;0G7P16P[@0AX:d00D0AX:d00<0000004J2]016P[@00`16P[@01@000000
AX:d04J2]016P[@0000000<0AX:d00@0000004J2]016P[@0AX:d1@00000404J2]00300000016P[@0
AX:d00D0AX:d00@0000004J2]016P[@000002P16P[@00`000000AX:d04J2]00704J2]08000002@16
P[@00`000000AX:d04J2]00704J2]0030000003oO`00ogl000<0AX:d00<0000004J2]016P[@00P16
P[@00`000000AX:d04J2]004000000D0AX:d00<0000004J2]016P[@01016P[@010000000AX:d04J2
]016P[@20000000304J2]0000000AX:d00/0AX:d0P00000:04J2]00400000016P[@0AX:d000000@0
AX:d0P00000504J2]00300000016P[@000000080AX:d00<0000004J2]016P[@09`16P[@00`2`5ah0
AX:d04J2]00n04J2]040oooo001D04J2]00400000016P[@0AX:d04J2]0<000001016P[@00`000000
AX:d04J2]00204J2]0030000003oO`00AX:d00H0AX:d00<0000004J2]016P[@00P16P[@00`000000
AX:d04J2]00204J2]00300000016P[@0/1LN00P0AX:d00<0000004J2]016P[@01016P[@200000004
04J2]0000000AX:d04J2]0D000002@16P[@00`000000AX:d04J2]00504J2]00400000016P[@0AX:d
000000X0AX:d00<0000004J2]016P[@01`16P[@2000000T0AX:d00<0000004J2]016P[@01`16P[@0
0`000000AX:d04J2]0020?mo000304J2]0000000AX:d00<0AX:d00<0000004J2]016P[@01016P[@5
0000000304J2]0000000AX:d00@0AX:d00@0000004J2]016P[@000001016P[@00`000000AX:d04J2
]00:04J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016P[@00P16P[@01`000000AX:d04J2
]016P[@0000004J2]00000001@16P[@300000080AX:d00<0000004J2]016P[@09`16P[@00`2`5ah0
AX:d04J2]00m04J2]040oooo001C04J2]00300000016P[@0AX:d0080AX:d00@0000004J2]016P[@0
00000P16P[@00`000000AX:d04J2]00204J2]080000000<0AX:d0?mo0016P[@01@16P[@01@000000
AX:d04J2]016P[@0000000D0AX:d00<0000004J2]02`5ah01`16P[@00`000000AX:d04J2]00704J2
]0D000003016P[@00`000000AX:d04J2]00604J2]00400000016P[@0AX:d000000X0AX:d00<00000
04J2]016P[@01`16P[@2000000T0AX:d00<0000004J2]016P[@02016P[@010000000AX:d04J2]016
P[@30?mo00@0AX:d00<0000004J2]016P[@02016P[@500000080AX:d0`00000504J2]00300000016
P[@0AX:d00X0AX:d0P00000804J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]016P[@00000
0P16P[@00`000000AX:d04J2]00304J2]08000000`16P[@00`000000AX:d04J2]00V04J2]0030;0G
7P16P[@0AX:d03d0AX:d0@3oool005<0AX:d00@0000004J2]016P[@0AX:d0P00000204J2]0030000
0016P[@0000000D0AX:d0P00000204J2]0030?mo0016P[@0AX:d00<0AX:d00@0000004J2]016P[@0
00001P16P[@00`000000/1LN04J2]00604J2]00300000016P[@0AX:d00D0AX:d0`0000001016P[@0
000004J2]000000=04J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]00000002`16P[@00`00
0000AX:d04J2]00704J2]08000002@16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d
0080AX:d00<0000004J2]03oO`000`3oO`000`16P[@0000004J2]00:04J2]00300000016P[@0AX:d
00@000001`16P[@00`000000AX:d04J2]00904J2]00300000016P[@0000000H0AX:d00<0000004J2
]016P[@01@16P[@00`000000AX:d0000000304J2]00300000016P[@0AX:d0080AX:d0P00000304J2
]00300000016P[@0AX:d02H0AX:d00<0/1LN04J2]016P[@0?@16P[@10?ooo`00DP16P[@2000000<0
AX:d0P00000204J2]08000001@16P[@00`000000AX:d0000000204J2]0030?mo0016P[@0AX:d00@0
AX:d0P00000704J2]0030000002`5ah0AX:d00D0AX:d00<0000004J2]016P[@00`16P[@3000000@0
AX:d0P00000=04J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]00000002P16P[@00`000000
AX:d04J2]00804J2]08000002@16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080
AX:d00<0000004J2]016P[@00`16P[@20?mo00`0AX:d00<0000004J2]00000000P0000000`16P[@0
00000000000604J2]00300000016P[@0AX:d00P0AX:d00@0000004J2]016P[@000001@16P[@00`00
0000AX:d04J2]00604J2]08000001016P[@010000000AX:d04J2]016P[@2000000@0AX:d00<00000
04J2]016P[@09@16P[@00`2`5ah0AX:d04J2]00m04J2]040oooo001B04J2]00700000016P[@0AX:d
04J2]0000000AX:d0000000204J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]016P[@00000
0`16P[@00`3oO`00AX:d04J2]00304J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@0
1016P[@010000000AX:d04J2]016P[@3000000L0AX:d00@0000004J2]000000000002`16P[@00`00
0000AX:d04J2]00704J2]08000002`16P[@00`000000AX:d04J2]00804J2]08000002@16P[@00`00
0000AX:d04J2]00904J2]00400000016P[@0AX:d000000P0AX:d0P3oO`0;04J2]00400000016P[@0
AX:d000000<0AX:d0`00000404J2]00300000016P[@0AX:d00L0AX:d00D0000004J2]016P[@0AX:d
0000000304J2]00300000016P[@0AX:d00L0AX:d0P00000504J2]00400000016P[@0000004J2]080
00000`16P[@00`000000AX:d04J2]00V04J2]0030;0G7P16P[@0AX:d03`0AX:d0@3oool00580AX:d
00P0000004J2]016P[@0AX:d00000016P[@0000004J2]08000001016P[@01@000000AX:d04J2]016
P[@0000000@0AX:d00L0ogl004J2]016P[@0AX:d00000016P[@0000000L0AX:d00<0000004J2]016
P[@00`16P[@00`000000AX:d00000002000000X0AX:d00@0000004J2]016P[@0AX:d0P00000804J2
]00300000016P[@0AX:d00P0AX:d0P00000;04J2]00300000016P[@0AX:d00P0AX:d0P00000904J2
]00300000016P[@0AX:d00T0AX:d00@0000004J2]016P[@000002016P[@010000000AX:d0?mo003o
O`0704J2]080000000@0AX:d00000016P[@000001P16P[@30000000304J2]0000000AX:d00P0AX:d
00<0000004J2]016P[@00P16P[@010000000AX:d04J2]000000904J2]08000001@16P[@00`000000
AX:d0000000204J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@09@16P[@00`2`5ah0
AX:d04J2]00l04J2]040oooo001B04J2]00:00000016P[@0AX:d00000016P[@0000004J2]0000000
AX:d000000<0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00304J2]0040?mo0016
P[@0AX:d00000080AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00204J2]0<00000
3016P[@00`000000AX:d0000000404J2]08000001P16P[@00`000000AX:d04J2]00804J2]0800000
2`16P[@00`000000AX:d04J2]00804J2]08000002P16P[@00`000000AX:d04J2]00804J2]0040000
0016P[@0AX:d000000T0AX:d00<0000004J2]016P[@00P3oO`0304J2]08000000`16P[@2000000X0
AX:d0`00000804J2]00300000016P[@0AX:d00<0AX:d0P00000:04J2]00300000016P[@0000000D0
AX:d0P00000204J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@09@16P[@00`2`5ah0
AX:d04J2]00l04J2]040oooo001A04J2]080000000@0AX:d00000016P[@0AX:d0P00000304J2]003
00000016P[@0000000H0AX:d00<0000004J2]016P[@00`16P[@00`3oO`00000004J2]00204J2]003
00000016P[@0AX:d00<0AX:d00<0/1LN00000016P[@01000000=04J2]00400000016P[@0AX:d0000
00H0AX:d0P00000304J2]00300000016P[@0AX:d00T0AX:d00<0000004J2]016P[@02P16P[@00`00
0000AX:d04J2]00804J2]08000002P16P[@00`000000AX:d04J2]00904J2]00300000016P[@00000
00T0AX:d00<0000004J2]016P[@00P16P[@20?mo000300000016P[@0AX:d00@0AX:d00<0000004J2
]016P[@02P16P[@3000000H0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00804J2
]00400000016P[@0AX:d000000D0AX:d00<0000004J2]016P[@00P00000304J2]00300000016P[@0
AX:d02D0AX:d00<0/1LN04J2]016P[@0?016P[@10?ooo`00D@16P[@010000000AX:d04J2]0000002
04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]00000001P16P[@00`000000AX:d04J2]003
04J2]00300000016P[@0ogl000<0AX:d00<0000004J2]016P[@00P16P[@00`2`5ah0000000000002
04J2]00300000016P[@0AX:d00`0AX:d00@0000004J2]016P[@000002016P[@20000000304J2]000
0000AX:d00X0AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00904J2]08000002P16
P[@00`000000AX:d04J2]00904J2]00300000016P[@0000000X0AX:d00@0000004J2]016P[@0AX:d
0P0000020?mo00D0AX:d00<0000004J2]016P[@03016P[@4000000<0AX:d00<0000004J2]016P[@0
0`16P[@00`000000AX:d0000000904J2]00500000016P[@0AX:d04J2]00000001016P[@200000003
04J2]0000000000000<0AX:d0P00000V04J2]0030;0G7P16P[@0AX:d03`0AX:d0@3oool00540AX:d
00<0000004J2]00000000P16P[@2000000@0AX:d0P00000704J2]00300000016P[@0AX:d0080AX:d
00D0000004J2]016P[@0AX:d0?mo000304J2]00300000016P[@0AX:d00<000000P16P[@00`000000
AX:d04J2]00<04J2]00500000016P[@0AX:d04J2]00000002P16P[@2000000/0AX:d00<0000004J2
]016P[@02@16P[@00`000000AX:d04J2]00904J2]08000002P16P[@00`000000AX:d04J2]00904J2
]00300000016P[@0000000X0AX:d00@0000004J2]000000000001016P[@30?mo0080AX:d0P00000>
04J2]00300000016P[@0AX:d0080000000<0AX:d00000016P[@00`16P[@010000000AX:d04J2]000
000904J2]00300000016P[@0AX:d0080AX:d00P0000004J2]016P[@0AX:d00000016P[@0000004J2
]08000000`16P[@00`000000AX:d04J2]00T04J2]0030;0G7P16P[@0AX:d03`0AX:d0@3oool00540
AX:d00<0000004J2]00000000P16P[@2000000@0AX:d00<0000004J2]016P[@01P16P[@00`000000
AX:d04J2]00204J2]00300000016P[@0AX:d0080AX:d0P3oO`0204J2]080000000D0AX:d0;0G7P00
0000AX:d0000000?04J2]00500000016P[@0AX:d04J2]00000002@16P[@00`000000AX:d04J2]003
000000L0AX:d00<0000004J2]00000002P16P[@00`000000AX:d04J2]00904J2]08000002P16P[@0
0`000000AX:d04J2]00:04J2]08000002P16P[@2000000T0AX:d0P3oO`000`000000AX:d0000000=
04J2]00300000016P[@0AX:d0080AX:d0P00000304J2]00300000016P[@0AX:d0080AX:d00<00000
04J2]016P[@01P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0000000<0AX:d0`000003
04J2]00300000016P[@0AX:d02D0AX:d00<0/1LN04J2]016P[@0>`16P[@10?ooo`00D016P[@30000
0080AX:d00<0000004J2]00000000`16P[@2000000P0AX:d00D0000004J2]016P[@0AX:d00000007
04J2]080000000@0AX:d00000016P[@0/1LN0P00000?04J2]00300000016P[@0AX:d0080AX:d00<0
000004J2]016P[@01`16P[@00`000000AX:d04J2]00304J2]08000001@16P[@00`000000AX:d0000
000:04J2]00300000016P[@0AX:d00T0AX:d0P00000:04J2]00300000016P[@0AX:d00X0AX:d0P00
000704J2]0<0000000<0AX:d00000016P[@02P16P[@20?mo000300000016P[@0AX:d00`0AX:d00<0
000004J2]016P[@00P16P[@4000000H0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2
]00304J2]00300000016P[@0000000@0AX:d00<0000004J2]00000000P16P[@00`000000AX:d04J2
]00U04J2]0030;0G7P16P[@0AX:d03/0AX:d0@3oool00500AX:d0`0000001@16P[@0000004J2]016
P[@0000000<0AX:d00<0000004J2]00000001`16P[@010000000AX:d04J2]000000604J2]0800000
00P0AX:d0?mo0016P[@0000004J2]02`5ah0AX:d000000h0AX:d00<0000004J2]016P[@00`16P[@0
0`000000AX:d04J2]00604J2]00300000016P[@0AX:d00H0AX:d0`0000001@16P[@0000004J2]016
P[@0000000X0AX:d00<0000004J2]016P[@02@16P[@2000000X0AX:d00<0000004J2]016P[@02P16
P[@2000000@0AX:d0`00000504J2]00300000016P[@0AX:d00P0AX:d00@0000004J2]03oO`00ogl0
3P16P[@01@000000AX:d04J2]016P[@000000080AX:d00<0000004J2]016P[@01@16P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d0P00000404J2]0<000000P16P[@00`000000
AX:d04J2]00U04J2]0030;0G7P16P[@0AX:d03/0AX:d0@3oool00500AX:d0P00000204J2]0040000
0016P[@0AX:d00000080AX:d00@0000004J2]016P[@000001`16P[@00`000000AX:d0000000604J2
]00300000016P[@0AX:d0080AX:d0P3oO`00102`5ah0AX:d00000000000>04J2]00300000016P[@0
AX:d00<0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00904J2]0D000002P16P[@0
0`000000AX:d04J2]00904J2]08000002`16P[@00`000000AX:d04J2]00:04J2]00300000016P[@0
0000008000002016P[@00`000000AX:d04J2]00704J2]00500000016P[@0AX:d04J2]00000000P3o
O`0=04J2]00300000016P[@000000080AX:d00@0000004J2]000000000001@16P[@00`000000AX:d
04J2]00404J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@00P16P[@20000000304J2
]0000000AX:d008000009P16P[@00`2`5ah0AX:d04J2]00k04J2]040oooo001@04J2]080000000<0
AX:d00000016P[@00P16P[@010000000AX:d04J2]000000304J2]00300000016P[@0AX:d00@0AX:d
00<0000004J2]00000001016P[@2000000L0AX:d00@0/1LN00000016P[@000003@16P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@02`16P[@00`000000
AX:d04J2]004000000H0AX:d00<0000004J2]016P[@02P16P[@2000000/0AX:d00<0000004J2]016
P[@01`16P[@5000000`0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00204J2]004
00000016P[@0ogl00?mo00/0AX:d00D0000004J2]0000000AX:d0000000404J2]00300000016P[@0
AX:d00<0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00404J2]08000001016P[@0
1@000000AX:d000000000000AX:d008000009P16P[@00`2`5ah0AX:d04J2]00k04J2]040oooo001?
04J2]080000000<0AX:d00000016P[@00`16P[@00`000000AX:d0000000404J2]00300000016P[@0
AX:d00@0AX:d0P00000304J2]08000002@16P[@0102`5ah0ogl000000000000<04J2]00300000016
P[@0AX:d00H0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00:04J2]00500000016
P[@0AX:d04J2]00000000`16P[@400000080AX:d00<0000004J2]016P[@02P16P[@2000000/0AX:d
00@0000004J2]016P[@0AX:d1P00000304J2]00300000016P[@0AX:d00/0AX:d00<0000004J2]016
P[@01P16P[@00`000000AX:d04J2]00304J2]00400000016P[@0AX:d0?mo00/0AX:d0`00000604J2
]08000001016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00@0AX:d00<0000004J2
]00000000`16P[@010000000AX:d00000016P[@3000002H0AX:d00<0/1LN04J2]016P[@0>`16P[@1
0?ooo`00C`16P[@3000000D0AX:d00<0000004J2]00000001016P[@00`000000AX:d04J2]00404J2
]00300000016P[@0AX:d008000002`16P[@00`2`5ah0AX:d0?mo0002000000/0AX:d00<0000004J2
]016P[@01P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00/0AX:d00D0000004J2
]016P[@0AX:d0000000704J2]0T000001P16P[@2000000D0AX:d2P00000904J2]08000003@16P[@0
0`000000AX:d04J2]00504J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]016P[@0AX:d0P3o
O`0:04J2]00300000016P[@0AX:d00L0AX:d0P00000204J2]00500000016P[@0AX:d04J2]0000000
1P16P[@010000000AX:d04J2]000000304J2]00300000016P[@0AX:d0080000000<0AX:d00000016
P[@09@16P[@00`2`5ah0AX:d04J2]00k04J2]040oooo001?04J2]0<000001@16P[@2000000H0AX:d
00<0000004J2]016P[@00`16P[@3000000`0AX:d00L000000;0G7P16P[@0AX:d0000003oO`000000
00T0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d
00/0AX:d00D0000004J2]016P[@0AX:d0000000904J2]00300000016P[@0AX:d00@0AX:d3@000006
04J2]00300000016P[@0AX:d00X0AX:d0P00000=04J2]00300000016P[@0AX:d00D0AX:d00<00000
04J2]016P[@01016P[@00`000000AX:d04J2]00204J2]080ogl01P16P[@4000000X0AX:d00@00000
04J2]016P[@000000P16P[@00`000000AX:d04J2]00404J2]00500000016P[@0AX:d04J2]0000000
0P16P[@01@000000AX:d04J2]0000000AX:d008000009P16P[@00`2`5ah0AX:d04J2]00k04J2]040
oooo001?04J2]08000001P16P[@2000000H0AX:d00<0000004J2]016P[@00P16P[@2000000d0AX:d
00<0000004J2]02`5ah00`16P[@010000000ogl000000000000704J2]00300000016P[@0AX:d00L0
AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00;04J2]00300000016P[@0AX:d0080
AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00:04J2]08000002`16P[@00`000000
AX:d04J2]00904J2]00300000016P[@0000000d0AX:d00<0000004J2]016P[@01@16P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d0P3oO`0304J2]00500000016P[@0000004J2
]00000002`16P[@20000000404J2]0000000AX:d000000D0AX:d00<0000004J2]016P[@00P16P[@0
10000000AX:d04J2]000000304J2]0@000009@16P[@00`2`5ah0AX:d04J2]00k04J2]040oooo001>
04J2]080000000<0AX:d00000016P[@01016P[@00`000000AX:d04J2]00604J2]00300000016P[@0
AX:d00<000003@16P[@010000000AX:d04J2]02`5ah204J2]00500000016P[@0AX:d0?mo00000000
1@16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@0
2`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@0
2`16P[@2000000/0AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d0000000>04J2]0030000
0016P[@0AX:d00<0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00504J2]080ogl0
00@0000004J2]016P[@000000P16P[@00`000000AX:d04J2]00:04J2]00400000016P[@000000000
00D0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d0000000404J2]0<000009@16P[@00`2`
5ah0AX:d04J2]00k04J2]040oooo001>04J2]080000000<0AX:d00000016P[@01016P[@2000000L0
AX:d00H0000004J2]0000000000004J2]000000<04J2]00500000016P[@0AX:d04J2]02`5ah00P16
P[@00`000000AX:d04J2]00204J2]00500000016P[@0AX:d04J2]00000002`16P[@01@000000AX:d
04J2]016P[@0000000h0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00604J2]003
00000016P[@0AX:d00/0AX:d0P00000<04J2]00300000016P[@0AX:d00P0AX:d00@0000004J2]016
P[@000003@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00L0AX:d00<0000004J2
]016P[@01016P[@200000080ogl000D0AX:d00000016P[@0AX:d0000000=04J2]0<000001016P[@0
0`000000AX:d04J2]00404J2]00300000016P[@0000000@0AX:d0`00000T04J2]0030;0G7P16P[@0
AX:d03`0AX:d0@3oool004h0AX:d00@0000004J2]016P[@000001016P[@00`000000AX:d00000008
04J2]08000000`16P[@00`000000AX:d04J2]00904J2]00500000016P[@0AX:d04J2]02`5ah00P16
P[@00`000000AX:d04J2]00304J2]080000000<0AX:d00000016P[@02P16P[@01@000000AX:d04J2
]016P[@0000000d0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00604J2]0030000
0016P[@0AX:d00/0AX:d0P00000<04J2]00300000016P[@0AX:d00P0AX:d00@0000004J2]016P[@0
00003P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016
P[@00`16P[@00`000000AX:d04J2]00204J2]0030?mo00000000AX:d0080AX:d00<0000004J2]016
P[@03016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00D0AX:d0P00000504J2]080
00009016P[@00`2`5ah0AX:d04J2]00l04J2]040oooo001>04J2]00400000016P[@0AX:d000000@0
AX:d00<0000004J2]00000002016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00P0
AX:d00<0000004J2]016P[@00P16P[@0102`5ah0AX:d04J2]000000704J2]0030000003oO`00AX:d
00X0AX:d00@0000004J2]016P[@000003P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0
AX:d00H0AX:d00@0000004J2]016P[@0AX:d4@00000704J2]00300000016P[@0AX:d00P0AX:d00@0
000004J2]016P[@000003P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00P0AX:d
00D0000004J2]016P[@0AX:d0000000604J2]080ogl00P16P[@00`000000AX:d04J2]00<04J2]080
00000P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00@0AX:d0P00000T04J2]003
0;0G7P16P[@0AX:d03`0AX:d0@3oool004h0AX:d00@0000004J2]016P[@000000`16P[@010000000
AX:d04J2]000000704J2]0<000000`16P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d
00<0AX:d00@0/1LN04J2]016P[@000001`16P[@2000000030?mo0016P[@0AX:d00T0AX:d00<00000
04J2]00000003P16P[@010000000AX:d04J2]016P[@?000000X0AX:d0P00000504J2]0`000001P16
P[@010000000AX:d04J2]000000?04J2]00500000016P[@0AX:d04J2]00000002P16P[@010000000
AX:d00000000000604J2]00300000016P[@0AX:d0080ogl000<0AX:d00000016P[@02`16P[@01P00
0000AX:d04J2]0000000AX:d000000P0AX:d0P00000404J2]00400000016P[@00000000002<0AX:d
00<0/1LN04J2]016P[@0?016P[@10?ooo`00C@16P[@200000080AX:d00D0000004J2]016P[@0AX:d
0000000204J2]00300000016P[@0AX:d00<0AX:d0`00000204J2]00400000016P[@0AX:d000000T0
AX:d00<0000004J2]016P[@00`16P[@0102`5ah0AX:d04J2]000000604J2]00400000016P[@0AX:d
04J2]080ogl02@16P[@2000000d0AX:d1P00000204J2]00300000016P[@0AX:d00H0AX:d00<00000
04J2]016P[@02`16P[@2000000`0AX:d00<0000004J2]016P[@00P16P[@90000000304J2]0000000
AX:d00d0AX:d00D0000004J2]016P[@0AX:d0000000;04J2]00300000016P[@0AX:d00H0AX:d00<0
000004J2]016P[@00P16P[@00`3oO`00000004J2]00;04J2]00300000016P[@0AX:d008000002@16
P[@2000000@0AX:d00@0000004J2]000000000008`16P[@00`2`5ah0AX:d04J2]00l04J2]040oooo
001=04J2]08000000P16P[@010000000AX:d04J2]000000304J2]00300000016P[@0AX:d0080AX:d
00@0000004J2]016P[@000000P16P[@010000000AX:d04J2]000000804J2]00300000016P[@0AX:d
00D0AX:d00@0/1LN04J2]016P[@000001@16P[@00`000000AX:d04J2]00304J2]080ogl01`16P[@2
000000L0AX:d1P0000000`16P[@0000004J2]00504J2]00300000016P[@0AX:d00D0AX:d00<00000
04J2]016P[@03016P[@2000000`0AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2]004
000000`0AX:d00D0000004J2]016P[@0AX:d0000000904J2]0<000002016P[@00`000000AX:d04J2
]00304J2]080ogl02`16P[@010000000AX:d04J2]016P[@2000000P0AX:d00<0000004J2]0000000
0`16P[@010000000AX:d00000000000S04J2]0030;0G7P16P[@0AX:d03`0AX:d0@3oool004d0AX:d
0P00000304J2]00300000016P[@0000000<0AX:d00D0000004J2]016P[@0AX:d0000000204J2]003
00000016P[@0AX:d0080AX:d00@0000004J2]016P[@000001P16P[@00`000000AX:d04J2]00604J2
]0040;0G7P16P[@0AX:d000000@0AX:d00<0000004J2]016P[@01P16P[@00`3oO`00000004J2]004
04J2]00300000016P[@0AX:d00H000001`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0
AX:d00D0AX:d00<0000004J2]016P[@03016P[@2000000`0AX:d00<0000004J2]016P[@02016P[@0
1@000000AX:d04J2]016P[@000000080AX:d1000000904J2]00300000016P[@0000000P0AX:d0P00
000304J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@01016P[@00`000000ogl00?mo
000904J2]00300000016P[@0AX:d0080000000<0AX:d00000016P[@01P16P[@00`000000AX:d0000
000304J2]00400000016P[@0000000000280AX:d00<0/1LN04J2]016P[@0?@16P[@10?ooo`00C@16
P[@2000000<0AX:d0P00000404J2]00400000016P[@0AX:d000000<0AX:d00<0000004J2]016P[@0
0`16P[@00`000000AX:d0000000604J2]00300000016P[@0AX:d00H0AX:d00@0/1LN04J2]016P[@0
00001016P[@00`000000AX:d04J2]00704J2]080ogl000<0000004J2]016P[@01000000=04J2]003
00000016P[@0AX:d00@0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00<04J2]080
00003016P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016
P[@00`16P[@5000000@0AX:d00<0000004J2]00000001P16P[@2000000D0AX:d00<0000004J2]016
P[@01@16P[@00`000000AX:d04J2]00504J2]00300000016P[@0ogl000L0AX:d00@0000004J2]016
P[@000000P16P[@010000000AX:d00000000000504J2]00400000016P[@0AX:d00000080AX:d00@0
000004J2]016P[@000008P16P[@00`2`5ah0AX:d04J2]00m04J2]040oooo001<04J2]0<000000`16
P[@2000000@0AX:d00<0000004J2]00000000`16P[@00`000000AX:d04J2]00504J2]08000001@16
P[@00`000000AX:d04J2]00704J2]0040;0G7P16P[@0AX:d000000<0AX:d00<0000004J2]016P[@0
2P16P[@5000000h0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00404J2]0030000
0016P[@0AX:d00`0AX:d0P00000=04J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@0
0`16P[@00`000000AX:d04J2]00804J2]0@0000000<0AX:d0000000000001016P[@2000000P0AX:d
00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00604J2]00300000016P[@0ogl000H0AX:d
00<0000004J2]00000000`16P[@01@000000AX:d04J2]016P[@0000000@0AX:d00@0000004J2]016
P[@000000P16P[@010000000AX:d04J2]000000R04J2]0030;0G7P16P[@0AX:d03d0AX:d0@3oool0
04`0AX:d00<0000004J2]00000000`16P[@00`000000AX:d04J2]00304J2]08000001016P[@00`00
0000AX:d04J2]00604J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01`16P[@0102`
5ah0AX:d04J2]000000304J2]00300000016P[@0AX:d00L0AX:d0`00000204J2]0030?mo00000000
000000h0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00404J2]00300000016P[@0
AX:d00`0AX:d0P00000=04J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@00`16P[@0
0`000000AX:d04J2]00<04J2]0@0000000<0AX:d0000000000002P16P[@00`000000AX:d04J2]003
04J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016P[@00P3oO`0404J2]08000001@16P[@0
1@000000AX:d04J2]016P[@0000000<0AX:d00@0000004J2]016P[@0AX:d0P00000304J2]0800000
8@16P[@00`2`5ah0AX:d04J2]00m04J2]040oooo001<04J2]00300000016P[@0000000<0AX:d00<0
000004J2]016P[@00`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00L0AX:d0P00
000304J2]00300000016P[@0AX:d00T0AX:d00<0/1LN04J2]00000000P16P[@00`000000AX:d04J2
]00604J2]08000001P16P[@010000000ogl000000000000<04J2]00300000016P[@0AX:d00H0AX:d
00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00=04J2]08000003@16P[@00`000000AX:d
04J2]00604J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@03P16P[@5000000/0AX:d
00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00804J2]00500000016P[@0AX:d04J2]03o
O`000`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d0080AX:d00@0000004J2]016
P[@000000`16P[@2000000<0AX:d0P00000Q04J2]0030;0G7P16P[@0AX:d03d0AX:d0@3oool004`0
AX:d00<0000004J2]00000000P16P[@00`000000AX:d0000000304J2]08000001016P[@00`000000
AX:d04J2]00804J2]00400000016P[@0AX:d000000`0AX:d00H0/1LN04J2]016P[@0000004J2]000
000504J2]0<000001`16P[@010000000AX:d04J2]00000020?mo000300000016P[@0AX:d00L0AX:d
00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00d0AX:d
0P00000=04J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d
04J2]00<04J2]08000001016P[@3000000P0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d
04J2]00804J2]00300000016P[@0AX:d0080AX:d00@0ogl004J2]000000000001P16P[@00`000000
AX:d04J2]00304J2]00300000016P[@0000000@0AX:d00@0000004J2]016P[@0AX:d0P00000P04J2
]0030;0G7P16P[@0AX:d03h0AX:d0@3oool004`0AX:d00<0000004J2]00000000P16P[@00`000000
AX:d0000000304J2]00300000016P[@000000080AX:d00<0000004J2]016P[@02@16P[@200000003
04J2]0000000AX:d00/0AX:d00<0/1LN04J2]016P[@00P00000304J2]0<000002P16P[@010000000
AX:d04J2]000000204J2]080ogl00P00000604J2]00300000016P[@0AX:d00L0AX:d00<0000004J2
]016P[@00`16P[@00`000000AX:d04J2]00=04J2]08000003@16P[@00`000000AX:d04J2]00604J2
]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02@16P[@5000000L0AX:d0P00000604J2
]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00204J2
]080ogl02016P[@00`000000AX:d04J2]00304J2]08000001016P[@010000000AX:d04J2]016P[@2
00000200AX:d00<0/1LN04J2]016P[@0?P16P[@10?ooo`00B`16P[@01`000000AX:d04J2]016P[@0
000004J2]00000000P16P[@00`000000AX:d0000000204J2]00400000016P[@0AX:d000000/0AX:d
00<0000004J2]00000003@16P[@00`2`5ah0AX:d04J2]005000000d0AX:d00@0000004J2]016P[@0
00001016P[@20?mo008000001016P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d00<0
AX:d00<0000004J2]016P[@03@16P[@2000000d0AX:d00<0000004J2]016P[@01P16P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00H0AX:d0`00000304J2]00300000016P[@0000000P0
AX:d0`00000404J2]00500000016P[@0AX:d04J2]00000002`16P[@00`000000AX:d04J2]00204J2
]080000000<0ogl004J2]016P[@01@16P[@00`000000AX:d04J2]00404J2]00400000016P[@0AX:d
04J2]08000000`16P[@2000001l0AX:d00<0/1LN04J2]016P[@0?`16P[@10?ooo`00B`16P[@01`00
0000AX:d04J2]016P[@0000004J2]00000000P16P[@2000000<0AX:d00@0000004J2]016P[@00000
2`16P[@010000000AX:d00000000000=04J2]0040;0G7P16P[@00000000000l0AX:d00D0000004J2
]016P[@0AX:d0000000604J2]080ogl00P0000000`16P[@0000004J2]00904J2]00300000016P[@0
AX:d00<0AX:d00<0000004J2]016P[@03@16P[@2000000d0AX:d00<0000004J2]016P[@01P16P[@0
0`000000AX:d04J2]00404J2]00300000016P[@0AX:d00<0AX:d0`00000604J2]00300000016P[@0
000000/0AX:d0`0000001@16P[@0000004J2]016P[@0000000d0AX:d00L0000004J2]016P[@00000
04J2]0000000AX:d0080ogl01P16P[@00`000000AX:d04J2]00304J2]08000000P16P[@2000000<0
AX:d0P00000O04J2]0030;0G7P16P[@0AX:d03l0AX:d0@3oool004/0AX:d00@0000004J2]016P[@0
AX:d0P00000404J2]00700000016P[@0AX:d04J2]0000000AX:d0000000<04J2]08000000P16P[@2
000000/0AX:d0`00000@04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01@16P[@2
0?mo00@000002016P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00d0AX:d0P00000>
04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d00000002
000000T0AX:d00<0000004J2]00000003P16P[@30000000304J2]0000000AX:d00`0AX:d00D00000
04J2]0000000AX:d0000000404J2]080ogl01016P[@00`000000AX:d04J2]00204J2]00500000016
P[@0000004J2]00000000P16P[@00`000000AX:d04J2]002000001h0AX:d00<0/1LN04J2]016P[@0
@016P[@10?ooo`00B`16P[@010000000AX:d04J2]016P[@2000000<0AX:d0P00000404J2]0800000
3@16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00H0AX:d0P0000001016P[@0/1LN
04J2]000000>04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01`16P[@0103oO`00
000004J2]016P[@5000000<0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00>04J2
]00300000016P[@0AX:d00d0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00304J2
]0D000002`16P[@01@000000AX:d04J2]016P[@0000000l0AX:d0`00000>04J2]00400000016P[@0
AX:d000000H0AX:d00D0ogl004J2]016P[@0AX:d0000000404J2]00300000016P[@0AX:d00800000
0P16P[@010000000AX:d00000016P[@2000001d0AX:d00<0/1LN04J2]016P[@0@016P[@10?ooo`00
B`16P[@010000000AX:d04J2]016P[@200000080AX:d00@0000004J2]016P[@000000`16P[@00`00
0000AX:d04J2]00;04J2]08000001@16P[@00`000000AX:d04J2]00304J2]08000000`16P[@00`2`
5ah0AX:d0000000>04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@02016P[@00`00
0000ogl00?mo000504J2]0H000000P16P[@00`000000AX:d04J2]00>04J2]00300000016P[@0AX:d
00d0AX:d00<0000004J2]016P[@00P16P[@8000000<0AX:d00<0000004J2]016P[@02P16P[@01@00
0000AX:d04J2]016P[@000000100AX:d1000000:04J2]0<000000P16P[@00`000000AX:d04J2]005
04J2]080ogl00P16P[@01@000000AX:d04J2]016P[@000000080AX:d00L0000004J2]016P[@0AX:d
00000016P[@000000080AX:d00<0000004J2]016P[@06P16P[@00`2`5ah0AX:d04J2]01104J2]040
oooo001;04J2]00400000016P[@0AX:d04J2]080000000<0AX:d00000016P[@00P16P[@01@000000
AX:d04J2]016P[@0000000d0AX:d0P00000604J2]080000000<0AX:d0000000000001016P[@01000
0000AX:d0;0G7P00000>04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01`16P[@0
10000000AX:d04J2]016P[@20?mo00L0AX:d00<0000004J2]00000002P00000804J2]00300000016
P[@0AX:d00H0AX:d3000000204J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@02P16
P[@01@000000AX:d04J2]016P[@000000100AX:d00@0000004J2]016P[@0AX:d0P00000704J2]007
00000016P[@0AX:d04J2]0000000AX:d0000000904J2]0030?mo0016P[@000000080AX:d00@00000
04J2]016P[@0AX:d0P00000204J2]00300000016P[@000000080AX:d00<0000004J2]016P[@06P16
P[@00`2`5ah0AX:d04J2]01104J2]040oooo001;04J2]08000000P16P[@010000000AX:d04J2]000
000404J2]00400000016P[@00000000000d0AX:d0P00000704J2]08000001P16P[@01@000000AX:d
04J2]02`5ah0000000`0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00604J2]003
00000016P[@0AX:d00<0AX:d0P3oO`0504J2]00500000016P[@0AX:d04J2]00000002016P[@A0000
00L0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d
00T0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00=04J2]00300000016P[@0AX:d
00<0AX:d0P00000304J2]08000001016P[@2000000/0AX:d00D0ogl004J2]0000000AX:d00000002
04J2]00800000016P[@0AX:d00000016P[@0000004J2]000000204J2]00300000016P[@0AX:d01T0
AX:d00<0/1LN04J2]016P[@0@P16P[@10?ooo`00B`16P[@200000080AX:d00<0000004J2]0000000
1@16P[@01@000000AX:d00000016P[@0000000/0AX:d00<0000004J2]00000001@16P[@200000080
AX:d00<0000004J2]016P[@00P16P[@01P000000AX:d04J2]016P[@0/1LN000000`0AX:d00<00000
04J2]016P[@01@16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00D0AX:d0P3oO`03
04J2]00500000016P[@0AX:d04J2]00000004016P[@00`000000AX:d04J2]00=04J2]00300000016
P[@0AX:d00@0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00904J2]00300000016
P[@0AX:d0080AX:d00<0000004J2]016P[@03@16P[@2000000H0AX:d00<0000004J2]00000001P16
P[@2000000`0AX:d00@0ogl000000016P[@000000P16P[@010000000AX:d04J2]000000204J2]080
00000P16P[@00`000000AX:d04J2]00H04J2]0030;0G7P16P[@0AX:d04<0AX:d0@3oool004/0AX:d
0P00000204J2]08000001`16P[@010000000AX:d04J2]000000;04J2]00400000016P[@0AX:d0000
0080AX:d0P00000504J2]08000000P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d
00X0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d
00L0AX:d0P3oO`000`16P[@0000004J2]00204J2]00300000016P[@0AX:d00h0AX:d00<0000004J2
]016P[@03@16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00L0AX:d00<0000004J2
]016P[@02016P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00`0AX:d00<0000004J2
]00000001`16P[@2000000L0AX:d00<0000004J2]016P[@02`16P[@01@3oO`00AX:d00000016P[@0
000000@0AX:d00@0000004J2]000000000000P16P[@00`000000AX:d04J2]00G04J2]0030;0G7P16
P[@0AX:d04@0AX:d0@3oool004/0AX:d0P00000204J2]08000001`16P[@010000000AX:d04J2]000
000;04J2]00300000016P[@0AX:d00<000002@16P[@2000000D0AX:d00<0000004J2]016P[@02@16
P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@02P16
P[@01@3oO`00000004J2]016P[@000000140AX:d00<0000004J2]016P[@03@16P[@00`000000AX:d
04J2]00304J2]00300000016P[@0AX:d00P0AX:d00<0000004J2]016P[@02016P[@00`000000AX:d
04J2]00304J2]00300000016P[@0AX:d00`0AX:d00@0000004J2]016P[@000001016P[@200000080
AX:d0P00000504J2]00300000016P[@0AX:d00`0AX:d0P3oO`000`16P[@0000004J2]00404J2]0<0
00000P16P[@00`000000AX:d04J2]00G04J2]0030;0G7P16P[@0AX:d04@0AX:d0@3oool004/0AX:d
0P0000000`16P[@000000000000804J2]080000000<0AX:d00000016P[@02@16P[@01@000000AX:d
04J2]016P[@0000000`0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00804J2]003
00000016P[@0AX:d00H0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00;04J2]004
0000003oO`00ogl000000140AX:d00<0000004J2]016P[@03@16P[@00`000000AX:d04J2]00304J2
]00300000016P[@0AX:d00T0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00404J2
]00300000016P[@0AX:d00/0AX:d00@0000004J2]016P[@000000`16P[@00`000000AX:d04J2]004
04J2]08000000P16P[@2000000h0AX:d00<0000004J2]03oO`001P16P[@30000000304J2]0000000
000001P0AX:d00<0/1LN04J2]016P[@0A@16P[@10?ooo`00B`16P[@20000000304J2]00000000000
00P0AX:d00D0000004J2]0000000AX:d0000000904J2]00300000016P[@0AX:d008000003016P[@3
000000@0AX:d00<000000;0G7P16P[@02016P[@00`000000AX:d04J2]00704J2]00300000016P[@0
AX:d00@0AX:d00<0000004J2]016P[@02`16P[@010000000AX:d04J2]00000020?mo00l0AX:d00<0
000004J2]016P[@03P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00T0AX:d00<0
000004J2]016P[@01`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00X0AX:d00<0
000004J2]016P[@00P16P[@3000000T0AX:d0`0000000`16P[@0000004J2]00<04J2]0<0000000<0
ogl004J2]016P[@01016P[@20000000304J2]0000000000001L0AX:d00<0/1LN04J2]016P[@0AP16
P[@10?ooo`00B`16P[@20000000404J2]00000000000000000H0AX:d00H0000004J2]016P[@00000
04J2]000000804J2]00400000016P[@0AX:d00000080AX:d00<0000004J2]016P[@02016P[@01000
0000AX:d04J2]016P[@200000080AX:d00<0000004J2]02`5ah01`16P[@00`000000AX:d04J2]008
04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02`16P[@010000000AX:d04J2]000
000204J2]0<0ogl03016P[@00`000000AX:d04J2]00>04J2]00300000016P[@0AX:d0080AX:d00<0
000004J2]016P[@02@16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00D0AX:d00<0
000004J2]016P[@02P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00/0AX:d00<0
000004J2]00000003016P[@00`000000AX:d0000000204J2]0030?mo0016P[@0AX:d00<0AX:d0P00
00000`16P[@000000000000F04J2]0030;0G7P16P[@0AX:d04L0AX:d0@3oool004`0AX:d0`000000
0`16P[@0000004J2]00504J2]00400000016P[@0AX:d04J2]08000002016P[@3000000<0AX:d00<0
000004J2]016P[@02016P[@00`000000AX:d04J2]00304J2]080000000<0AX:d0000002`5ah01`16
P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@03016
P[@010000000AX:d04J2]000000504J2]0<0ogl02@16P[@00`000000AX:d04J2]00>04J2]0030000
0016P[@0AX:d0080AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00604J2]0030000
0016P[@0AX:d00H0AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]003000000d0AX:d
0`00000<04J2]0<000000`16P[@00`3oO`00AX:d04J2]00304J2]00400000016P[@00000000001D0
AX:d00<0/1LN04J2]016P[@0B016P[@10?ooo`00C016P[@30000000304J2]0000000AX:d00D0AX:d
00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00@0AX:d
00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00504J2]080000000<0AX:d0;0G7P16P[@0
1016P[@00`000000AX:d04J2]00904J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@0
3@16P[@00`000000AX:d0000000804J2]080ogl01`16P[@00`000000AX:d04J2]00>04J2]0030000
0016P[@0AX:d0080AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00604J2]0030000
0016P[@0AX:d00H0AX:d00<0000004J2]016P[@02016P[@010000000AX:d00000000000304J2]003
00000016P[@0AX:d00T0AX:d00<0000004J2]016P[@00P00000;04J2]00300000016P[@0000000@0
AX:d00<0ogl004J2]016P[@00P16P[@010000000AX:d00000000000E04J2]0030;0G7P16P[@0AX:d
04P0AX:d0@3oool004`0AX:d0`00000204J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016
P[@00`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016
P[@01P16P[@00`000000AX:d04J2]00704J2]0<0000000<0/1LN04J2]016P[@00P16P[@00`000000
AX:d04J2]00904J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@03@16P[@00`000000
AX:d0000000:04J2]0<0ogl01016P[@00`000000AX:d04J2]00>04J2]00300000016P[@0AX:d0080
AX:d00<0000004J2]016P[@02P16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00H0
AX:d00<0000004J2]016P[@02016P[@2000000D0AX:d00<0000004J2]016P[@02@16P[@01@000000
AX:d04J2]016P[@0000000X0AX:d00D0000004J2]016P[@0AX:d0000000304J2]0040?mo0016P[@0
AX:d04J2]080000000<0AX:d0000000000005016P[@00`2`5ah0AX:d04J2]01904J2]040oooo001<
04J2]0<000000P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00<0AX:d0P000004
04J2]08000002016P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00P0AX:d00@00000
04J2]0000000/1LN0`16P[@00`000000AX:d04J2]00:04J2]00300000016P[@0AX:d0080AX:d00<0
000004J2]016P[@03@16P[@2000000h0AX:d0`3oO`000`16P[@0000004J2]00?04J2]00500000016
P[@0AX:d04J2]00000003@16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00L0AX:d
00<0000004J2]016P[@01@16P[@2000000L0AX:d00<0000004J2]016P[@02016P[@00`000000AX:d
04J2]00204J2]08000002016P[@2000000<0AX:d00<0000004J2]016P[@00P16P[@00`3oO`00AX:d
04J2]0020000000304J2]0000000000001<0AX:d00<0/1LN04J2]016P[@0BP16P[@10?ooo`00C016
P[@300000080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00404J2]00300000016
P[@000000080AX:d00<0000004J2]00000002016P[@00`000000AX:d04J2]00504J2]00300000016
P[@0AX:d00P0AX:d00D0000004J2]016P[@0AX:d0;0G7P02000000d0AX:d00<0000004J2]016P[@0
0P16P[@00`000000AX:d04J2]00=04J2]08000002@16P[@?000000/0AX:d00D0000004J2]016P[@0
AX:d0000000=04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02016P[@00`000000
AX:d04J2]00304J2]080000000<0AX:d00000016P[@01P16P[@00`000000AX:d04J2]00804J2]003
00000016P[@0AX:d00<0AX:d0P00000604J2]00300000016P[@0000000<0AX:d00<0000004J2]016
P[@00`16P[@00`3oO`00AX:d00000003000001<0AX:d00<0/1LN04J2]016P[@0B`16P[@10?ooo`00
C016P[@3000000<0AX:d00D0000004J2]016P[@0AX:d0000000604J2]00300000016P[@000000080
000000<0AX:d00000016P[@02@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00T0
AX:d00<0000004J2]016P[@00P16P[@00`2`5ah000000000000<04J2]00500000016P[@0AX:d04J2
]00000003P16P[@=000000P0AX:d0P0000020?mo00<0AX:d2P0000000`16P[@0000004J2]00204J2
]00300000016P[@0AX:d00/0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00804J2
]00400000016P[@0AX:d04J2]08000000`16P[@00`000000AX:d04J2]00604J2]00300000016P[@0
AX:d00H0AX:d00<0000004J2]016P[@01016P[@010000000AX:d00000000000304J2]00400000016
P[@0AX:d000000<0AX:d00<0000004J2]016P[@01016P[@00`3oO`00AX:d04J2]00200000180AX:d
00<0/1LN04J2]016P[@0C016P[@10?ooo`00C016P[@20000000504J2]0000000AX:d04J2]0000000
0`16P[@00`000000AX:d04J2]00504J2]0<000000P16P[@00`000000AX:d04J2]00804J2]0030000
0016P[@0AX:d00<0AX:d00<0000004J2]016P[@02P16P[@00`000000AX:d04J2]00204J2]0030;0G
7P16P[@00000008000002@16P[@01@000000AX:d04J2]016P[@0000000T0AX:d1@00000204J2]080
00004@16P[@200000080AX:d0`3oO`0:04J2]0P000003016P[@00`000000AX:d04J2]00304J2]003
00000016P[@0AX:d00T0AX:d0`00000404J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016
P[@01P16P[@00`000000AX:d04J2]00404J2]00500000016P[@0AX:d04J2]00000000P16P[@00`00
0000AX:d0000000404J2]00300000016P[@0AX:d00@0AX:d00<000000?mo0016P[@00P00000A04J2
]0030;0G7P16P[@0AX:d04d0AX:d0@3oool004`0AX:d0P0000001@16P[@0000004J2]016P[@00000
00<0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]002000000/0AX:d00<0000004J2
]016P[@00`16P[@00`000000AX:d04J2]00:04J2]00300000016P[@0AX:d0080AX:d00<000000;0G
7P16P[@00P16P[@3000000L0AX:d00@0000004J2]016P[@000001016P[@5000000L0AX:d0P00000A
04J2]08000001@16P[@20?mo00T0AX:d00D0000004J2]016P[@0AX:d0000000204J2]0D000001`16
P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00P0AX:d0P00000604J2]00300000016
P[@0AX:d00L0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00604J2]00400000016
P[@0AX:d04J2]08000000P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d0080AX:d
00@0000004J2]016P[@0ogl00P00000@04J2]0030;0G7P16P[@0AX:d04h0AX:d0@3oool004`0AX:d
0P00000204J2]00300000016P[@0000000<0AX:d00<0000004J2]016P[@01016P[@2000000<0AX:d
00<0000004J2]016P[@02P16P[@01@000000AX:d04J2]016P[@0000000d0AX:d00D0000004J2]016
P[@0AX:d0000000204J2]0030;0G7P16P[@0AX:d00<0AX:d0P00000504J2]00300000016P[@0AX:d
00D000003016P[@200000140AX:d0P00000704J2]0<0ogl01P16P[@01@000000AX:d04J2]016P[@0
000000L0AX:d1@00000204J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01@16P[@4
0000000304J2]0000000AX:d00D0AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2]004
04J2]00300000016P[@0AX:d00H0AX:d00@0000004J2]016P[@0AX:d0P00000204J2]00300000016
P[@0AX:d00<0AX:d00<0000004J2]016P[@00P16P[@010000000AX:d04J2]03oO`02000000l0AX:d
00<0/1LN04J2]016P[@0C`16P[@10?ooo`00C016P[@200000080AX:d00H0000004J2]016P[@00000
04J2]000000704J2]00300000016P[@000000080AX:d0`00000:04J2]00500000016P[@0AX:d04J2
]00000003@16P[@01@000000AX:d04J2]016P[@0000000<0AX:d00<0/1LN04J2]016P[@01016P[@3
0000000304J2]00000000000008000004@16P[@200000140AX:d0P00000:04J2]0<0ogl00`16P[@0
10000000AX:d04J2]000000=04J2]0D000000P16P[@00`000000AX:d04J2]00204J2]0<000001@16
P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00T0AX:d00<0000004J2]016P[@01016
P[@00`000000AX:d04J2]00604J2]00400000016P[@0AX:d00000080AX:d0P00000604J2]0030000
0016P[@0AX:d0080AX:d00H0000004J2]016P[@000000?mo0000000>04J2]0030;0G7P16P[@0AX:d
0500AX:d0@3oool004`0AX:d0P00000304J2]00500000016P[@0000004J2]00000001P16P[@01000
0000AX:d04J2]000000204J2]00400000016P[@0AX:d000000X0AX:d00@0000004J2]016P[@00000
3P16P[@010000000AX:d04J2]000000404J2]0030;0G7P16P[@0AX:d00<0AX:d1P0000000`16P[@0
000004J2]00A04J2]00300000016P[@0AX:d00l0AX:d0P00000=04J2]080ogl00P16P[@00`000000
AX:d0000000@04J2]00300000016P[@0000000H000002@16P[@00`000000AX:d04J2]00204J2]003
00000016P[@0AX:d00T0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00804J2]080
00001016P[@00`000000AX:d04J2]00404J2]00500000016P[@0AX:d04J2]00000000P16P[@01000
0000AX:d0?mo0000000<04J2]080/1LND`16P[@10?ooo`00C016P[@2000000<0AX:d00D0000004J2
]0000000AX:d0000000504J2]00300000016P[@0AX:d0080AX:d00<0000004J2]00000000`16P[@0
0`000000AX:d04J2]00704J2]00300000016P[@0000000l0AX:d00@0000004J2]016P[@000001@16
P[@00`2`5ah0AX:d00000002000000H0AX:d1000000?04J2]08000004@16P[@2000000l0AX:d0P3o
O`000`000000AX:d0000000@04J2]00300000016P[@0000000H000002@16P[@00`000000AX:d04J2
]00204J2]00300000016P[@0AX:d00T0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2
]00804J2]00300000016P[@0AX:d0080AX:d00<0000004J2]00000001@16P[@01@000000AX:d04J2
]016P[@000000080AX:d00@0000004J2]03oO`0000002`16P[@00`2`5ah0AX:d04J2]01C04J2]040
oooo001<04J2]08000001016P[@010000000AX:d00000000000504J2]00300000016P[@0AX:d0080
AX:d0P00000504J2]08000002016P[@2000000l0AX:d00<0000004J2]00000001016P[@400000003
0;0G7P16P[@0AX:d00H0AX:d0P00000204J2]0H000002@16P[@200000140AX:d0P00000A04J2]004
0000003oO`0000000?mo00`0AX:d1@0000000`16P[@0000004J2]00404J2]0<000001P16P[@01@00
0000AX:d04J2]016P[@0000000d0AX:d00D0000004J2]016P[@0AX:d0000000904J2]0<000001016
P[@00`000000AX:d0000000504J2]00700000016P[@0AX:d04J2]0000000AX:d0000000204J2]003
0000003oO`00AX:d00T0AX:d00<0/1LN04J2]016P[@0E016P[@10?ooo`00C016P[@2000000@0AX:d
00@0000004J2]000000000001016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00D0
AX:d00<0000004J2]016P[@01@16P[@200000100AX:d1P00000504J2]0030;0G7P16P[@0AX:d00D0
AX:d0P00000804J2]0H000000`16P[@200000140AX:d0P00000A04J2]00400000016P[@0000004J2
]0@0ogl00P16P[@6000000<0AX:d00@0000004J2]016P[@000002016P[@2000000@0AX:d00D00000
04J2]016P[@0AX:d0000000=04J2]00500000016P[@0AX:d04J2]00000002016P[@010000000AX:d
04J2]000000304J2]00500000016P[@0AX:d04J2]00000001@16P[@00`000000AX:d0000000204J2
]00300000016P[@0AX:d008000002016P[@20;0G7UL0AX:d0@3oool004d0AX:d0P00000404J2]080
00001016P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00H0AX:d0P00000504J2]003
00000016P[@0AX:d00l0AX:d0P00000:04J2]080/1LN1@16P[@00`000000AX:d04J2]00=04J2]0P0
00003P16P[@200000140AX:d00@0000004J2]0000000AX:d1P0000020?mo00L0AX:d00@0000004J2
]016P[@000002P16P[@300000080AX:d00@0000004J2]016P[@000003@16P[@010000000AX:d04J2
]000000704J2]08000001016P[@010000000AX:d04J2]000000304J2]00300000016P[@0AX:d00<0
AX:d00D0000004J2]0000000AX:d0000000304J2]08000001`16P[@00`2`5ah0AX:d04J2]01G04J2
]040oooo001=04J2]08000001016P[@3000000<0AX:d00<0000004J2]016P[@01@16P[@2000000T0
AX:d00<0000004J2]016P[@00P16P[@2000000h0AX:d1000000<04J2]0030;0G7P16P[@0AX:d0080
AX:d0P00000A04J2]08000000`16P[@:000000@0AX:d0P00000804J2]0d000002016P[@30?mo00@0
AX:d00<0000004J2]00000003P16P[@30000000304J2]0000000AX:d00h0AX:d00<0000004J2]000
00001P16P[@00`000000AX:d04J2]00404J2]00300000016P[@0000000D0AX:d00<0000004J2]016
P[@00P16P[@01@000000AX:d00000016P[@0000000<0AX:d0P00000504J2]080/1LNFP16P[@10?oo
o`00C@16P[@2000000D0AX:d0P00000204J2]00300000016P[@0AX:d00H0AX:d0P00000:04J2]004
00000016P[@0AX:d04J2]08000003016P[@200000080AX:d0P00000=04J2]080/1LN0P16P[@20000
0140AX:d0P00000=04J2]0h000002@16P[@2000000d0AX:d0`3oO`0204J2]08000004016P[@30000
00l0AX:d00<0000004J2]00000001016P[@2000000L0AX:d00<0000004J2]00000001@16P[@00`00
0000AX:d04J2]00204J2]080000000<0AX:d00000016P[@00`16P[@00`000000ogl004J2]00304J2
]0030;0G7P16P[@0AX:d05X0AX:d0@3oool004d0AX:d0P00000504J2]080000000<0AX:d00000016
P[@02016P[@00`000000AX:d0000000:04J2]0<000000P16P[@00`000000AX:d04J2]00704J2]080
00001016P[@2000000l0AX:d00@0/1LN04J2]000000000004@16P[@200000140AX:d0P00000A04J2
]08000004016P[@20?mo008000004016P[@00`000000AX:d00000002000000d0AX:d0P00000304J2
]08000002@16P[@2000000L0AX:d00@0000004J2]016P[@0AX:d0P0000000`16P[@0000004J2]002
04J2]080000000<0ogl004J2]016P[@00P2`5aiM04J2]040oooo001=04J2]0<000001016P[@01000
0000AX:d00000000000804J2]00400000016P[@0AX:d000000`0AX:d0P0000000`16P[@0000004J2
]00704J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]00000003`16P[@20;0G7P0304J2]000
0000AX:d00l0AX:d0P00000A04J2]08000004@16P[@200000180AX:d00<0000004J2]03oO`000`3o
O`0=04J2]00400000016P[@0AX:d04J2]08000002`16P[@200000080AX:d00<0000004J2]016P[@0
2@16P[@2000000P0AX:d00<0000004J2]016P[@00`00000404J2]080000000<0ogl00;0G7P2`5ah0
G`16P[@10?ooo`00C@16P[@3000000@0AX:d00@0000004J2]000000000002016P[@010000000AX:d
04J2]000000<04J2]00300000016P[@00000008000001@16P[@2000000L0AX:d00<0000004J2]000
00003`16P[@010000000AX:d0;0G7P00000@04J2]08000004@16P[@200000140AX:d0P00000B04J2
]00300000016P[@0AX:d00<0AX:d103oO`0904J2]00300000016P[@0AX:d00<0AX:d0P00000904J2
]0@000003016P[@2000000P0AX:d00<0000004J2]016P[@00`00000404J2]080000000<0/1LN04J2
]016P[@0G`16P[@10?ooo`00C@16P[@3000000@0AX:d00<0000004J2]00000000P00000704J2]005
00000016P[@0AX:d04J2]00000002`16P[@010000000AX:d04J2]016P[@200000080AX:d0P000008
04J2]00500000016P[@0AX:d04J2]00000003P16P[@01@000000AX:d04J2]0000000/1LN00h0AX:d
00@0000004J2]016P[@000004016P[@200000140AX:d00<0000004J2]016P[@04@16P[@00`000000
AX:d04J2]00704J2]0D0ogl00`16P[@2000000L0AX:d00<0000004J2]016P[@01P16P[@2000000h0
AX:d0P00000904J2]00400000016P[@00000000000@0AX:d00<0/1LN000000000000HP16P[@10?oo
o`00CP16P[@00`000000AX:d0000000304J2]080000000@0AX:d00000016P[@000001P16P[@01@00
0000AX:d04J2]016P[@0000000/0AX:d00<0000004J2]016P[@00P16P[@3000000X0AX:d00D00000
04J2]016P[@0AX:d0000000>04J2]00500000016P[@0AX:d04J2]00000000P2`5ah<04J2]0040000
0016P[@0AX:d00000100AX:d0P00000A04J2]08000004@16P[@2000000h0AX:d0`3oO`02000000P0
AX:d0P00000504J2]0<000003@16P[@00`000000AX:d0000000904J2]0@000000P16P[@20;0G7P03
0?mo0000000000000680AX:d0@3oool004h0AX:d00<0000004J2]00000000`16P[@200000080AX:d
0P00000604J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d
04J2]00304J2]00300000016P[@0AX:d008000002016P[@00`000000AX:d04J2]00204J2]0030000
0016P[@0AX:d00/0AX:d00D0000004J2]016P[@0AX:d0000000204J2]0<0/1LN2@16P[@010000000
AX:d04J2]000000@04J2]08000004@16P[@200000140AX:d0P00000@04J2]00300000016P[@0ogl0
00@0ogl01P16P[@20000000604J2]0000000000000000016P[@000003@16P[@00`000000AX:d0000
000:04J2]00300000016P[@000000080/1LN0P3oO`0300000680AX:d0@3oool004h0AX:d00<00000
04J2]00000000`16P[@200000080AX:d00<0000004J2]00000001@16P[@00`000000AX:d04J2]002
04J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d00000003
04J2]08000001P16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00/0AX:d00D00000
04J2]016P[@0AX:d0000000504J2]080/1LN1`16P[@010000000AX:d04J2]000000@04J2]0800000
4@16P[@200000140AX:d0P00000@04J2]00400000016P[@0AX:d000000<0AX:d103oO`0304J2]0@0
00000P16P[@00`000000AX:d04J2]00:04J2]00400000016P[@0AX:d000000T0AX:d0P000000102`
5ah0000004J2]03oO`0204J2]0<00000HP16P[@10?ooo`00CP16P[@010000000AX:d04J2]0000002
04J2]08000000`16P[@00`000000AX:d0000000404J2]00300000016P[@0AX:d00<0AX:d00<00000
04J2]016P[@01P16P[@00`000000AX:d04J2]00200000080AX:d00<0000004J2]016P[@00`16P[@2
000000<0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00:04J2]00500000016P[@0
AX:d04J2]00000001`16P[@20;0G7PD0AX:d00@0000004J2]016P[@000004016P[@200000140AX:d
0P00000@04J2]00400000016P[@0AX:d000000h0AX:d00D0000004J2]016P[@0AX:d0000000704J2
]0030?mo00000000ogl000<0ogl000D0000004J2]016P[@0AX:d0000000;04J2]00500000016P[@0
AX:d04J2]00000001`16P[@01P2`5ah000000000003oO`0000000?mo00<0AX:d0P00001S04J2]040
oooo001>04J2]080000000D0AX:d00000016P[@0AX:d0000000404J2]00400000016P[@0AX:d0000
0080AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00604J2]00300000016P[@00000
00D0AX:d00<0000004J2]016P[@01016P[@20000000304J2]0000000AX:d00D0AX:d00<0000004J2
]016P[@02@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00H0AX:d0`2`5ah204J2
]00400000016P[@0AX:d00000100AX:d0P00000A04J2]08000004016P[@010000000AX:d04J2]000
000>04J2]00500000016P[@0AX:d04J2]00000001P16P[@2000000@0AX:d00<000000?mo00000000
2`3oO`0204J2]00400000016P[@0AX:d04J2]0L0ogl00P2`5ah00`000000AX:d04J2]002000000<0
AX:d00<0000004J2]0000000H`16P[@10?ooo`00C`16P[@00`000000AX:d0000000204J2]0030000
0016P[@0AX:d00<0AX:d00H0000004J2]016P[@0000004J2]000000704J2]00300000016P[@0AX:d
00D0AX:d0P00000604J2]00300000016P[@0AX:d00H0AX:d0`00000604J2]00300000016P[@0AX:d
00P0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00904J2]080/1LN00@0000004J2
]016P[@000004016P[@200000100AX:d00<0000004J2]00000004016P[@010000000AX:d04J2]000
000=04J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]016P[@0AX:d0P00000604J2]0030000
0016P[@0AX:d00<000002016P[@20?mo00060000003oO`00ogl00?mo0016P[@000000P16P[@30;0G
7P0300000016P[@000000080AX:d0P00000304J2]00300000016P[@0000006<0AX:d0@3oool004l0
AX:d0P0000000`16P[@0000004J2]002000000@0AX:d00@0000004J2]016P[@0AX:d0P00000704J2
]00300000016P[@0AX:d00@0AX:d0P00000804J2]00300000016P[@0AX:d00H0AX:d00<0000004J2
]00000000P00000304J2]00300000016P[@0AX:d00P0AX:d00<0000004J2]016P[@00`16P[@00`00
0000AX:d04J2]00;04J2]080/1LN00<0AX:d00000016P[@03`16P[@200000100AX:d00<0000004J2
]00000003`16P[@01@000000AX:d04J2]016P[@0000000d0AX:d00<0000004J2]016P[@00`16P[@0
10000000AX:d00000000000704J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01`16
P[@00`000000AX:d04J2]00304J2]0030000002`5ah0/1LN0080AX:d00<0000004J2]00000000`16
P[@2000000<0AX:d00<0000004J2]0000000H`16P[@10?ooo`00C`16P[@20000000304J2]0000000
AX:d008000001@16P[@01@000000AX:d04J2]016P[@0000000P0AX:d00<0000004J2]016P[@00P16
P[@2000000T0AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00204J2]0@000002P16
P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00X0AX:d00D0000004J2]02`5ah00000
0;0G7P0?04J2]08000004016P[@00`000000AX:d0000000?04J2]00500000016P[@0AX:d04J2]000
00003016P[@00`000000AX:d04J2]00304J2]0<000002016P[@00`000000AX:d04J2]00404J2]080
00002016P[@00`000000AX:d04J2]00204J2]080/1LN0`16P[@00`000000AX:d0000000404J2]080
00000P16P[@010000000AX:d00000000001S04J2]040oooo001@04J2]0@0000000<0AX:d00000016
P[@01016P[@010000000AX:d04J2]016P[@3000000H0AX:d00L0000004J2]016P[@0AX:d00000016
P[@0000000X0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00504J2]0<000002016
P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00X0AX:d00D0000004J2]016P[@0AX:d
000000040;0G7P/0AX:d0P00000@04J2]00300000016P[@0000000l0AX:d00D0000004J2]016P[@0
AX:d0000000<04J2]00300000016P[@0AX:d00<0000000<0AX:d00000016P[@02016P[@00`000000
AX:d04J2]00404J2]00300000016P[@0000000H0AX:d00<0000004J2]016P[@00`2`5ah204J2]003
00000016P[@000000080AX:d00<0000004J2]016P[@00`16P[@01P000000AX:d04J2]0000000AX:d
000006@0AX:d0@3oool00500AX:d0P0000001016P[@0000004J2]000000604J2]00400000016P[@0
AX:d00000080AX:d00<0000004J2]016P[@01016P[@300000080AX:d00<0000004J2]016P[@02@16
P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]00000000P00
000404J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@02P16P[@01@000000AX:d04J2
]016P[@0000000@0AX:d102`5ah704J2]08000004016P[@00`000000AX:d0000000>04J2]0030000
0016P[@0AX:d0080AX:d00<0000004J2]016P[@02P16P[@3000000@0AX:d00<0000004J2]016P[@0
1P16P[@00`000000AX:d04J2]00504J2]00400000016P[@0AX:d000000@0AX:d00@0/1LN0000002`
5ah0/1LN1@16P[@200000080AX:d00<0000004J2]016P[@00`16P[@200000080AX:d0`00001T04J2
]040oooo001@04J2]00600000016P[@0000000000016P[@000001`16P[@00`000000AX:d00000003
04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]009
04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@02016P[@010000000AX:d04J2]016
P[@30000000304J2]0000000AX:d00L0AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2
]00204J2]00300000016P[@0AX:d00H0AX:d102`5ah304J2]08000004016P[@00`000000AX:d0000
000>04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@01@16P[@4000000L0AX:d00<0
000004J2]016P[@01P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d008000000P2`
5ah00`000000AX:d04J2]00604J2]00500000016P[@0AX:d04J2]00000001@16P[@20000000304J2
]0000000AX:d00800000I016P[@10?ooo`00D@16P[@00`000000AX:d00000002000000L0AX:d00<0
000004J2]00000001016P[@200000080AX:d00<0000004J2]00000000`16P[@00`000000AX:d04J2
]00:04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2
]00404J2]0@000001P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080AX:d00<0
000004J2]016P[@02P16P[@40;0G7P0300000016P[@0AX:d00d0AX:d00D0000004J2]016P[@0AX:d
0000000=04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@00P16P[@3000000<0AX:d
00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00H0AX:d
102`5ah204J2]00300000016P[@0000000H0AX:d0`00000204J2]00300000016P[@0AX:d00@0AX:d
0P0000001016P[@0000000000000001U04J2]040oooo001A04J2]00300000016P[@0000000800000
2016P[@2000000H0AX:d00<0000004J2]00000000P16P[@010000000AX:d04J2]000000<04J2]003
00000016P[@0AX:d0080AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00404J2]003
00000016P[@0AX:d00D0000000<0AX:d00000016P[@02@16P[@00`000000AX:d04J2]00K000000P0
AX:d00D0000004J2]016P[@0AX:d0000000<04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2
]00000000P00000504J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@01016P[@01000
0000AX:d04J2]016P[@60;0G7P0304J2]0000000AX:d00@0AX:d00<0000004J2]016P[@01016P[@0
1P000000AX:d04J2]0000000AX:d000000L0AX:d00H0000004J2]0000000000004J2]000001U04J2
]040oooo001A04J2]00300000016P[@00000008000002016P[@2000000L0AX:d0P00000204J2]004
00000016P[@0AX:d000000d0AX:d00D0000004J2]016P[@0AX:d0000000;04J2]00300000016P[@0
AX:d00@0AX:d00<0000004J2]016P[@01@16P[@5000000D0AX:d1@00000204J2]00300000016P[@0
AX:d00d0AX:d0P00000304J2]0@0/1LN2`0000000`16P[@0000004J2]00;04J2]00400000016P[@0
AX:d04J2]0D000002016P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d00<0/1LN00@0
00000;0G7P2`5ah0/1LN1`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0000000<0AX:d
0P00000304J2]00300000016P[@0000000L0AX:d00H0000004J2]0000000000004J2]000001U04J2
]040oooo001B04J2]00300000016P[@00000008000002016P[@00`000000AX:d04J2]00404J2]004
00000016P[@0AX:d00000080AX:d0P00000?04J2]00400000016P[@0AX:d000000`0AX:d00<00000
04J2]016P[@00`16P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d00D000000P16P[@0
0`000000AX:d04J2]00204J2]00300000016P[@0AX:d00d0AX:d0P00000904J2]0H0/1LN00<00000
0;0G7P16P[@01@00000704J2]0H000000`16P[@00`000000AX:d04J2]00604J2]00300000016P[@0
AX:d00L0AX:d102`5ah204J2]00300000016P[@0AX:d00T0AX:d00D0000004J2]016P[@0AX:d0000
000204J2]00400000016P[@0AX:d000000D0AX:d0P00000804J2]00500000016P[@0000004J2]000
0000IP16P[@10?ooo`00DP16P[@00`000000AX:d00000002000000P0AX:d00<0000004J2]016P[@0
0`16P[@00`000000AX:d04J2]00204J2]00400000016P[@0AX:d000000l0AX:d00@0000004J2]016
P[@000003016P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00H0AX:d1000000504J2
]0T000003P16P[@2000000l0AX:d00<0000004J2]02`5ah01@2`5ah70000000304J2]0000000AX:d
00H0AX:d00@0000004J2]016P[@0AX:d1@2`5ah00`000000/1LN0;0G7P070;0G7P0304J2]0000000
AX:d0080AX:d00<0000004J2]016P[@02P16P[@01@000000AX:d04J2]016P[@0000000<0AX:d0P00
000604J2]08000002016P[@30000000304J2]0000000AX:d06D0AX:d0@3oool005<0AX:d1@000007
04J2]08000001016P[@00`000000AX:d04J2]00304J2]0@000003`16P[@2000000h0AX:d00<00000
04J2]016P[@00P16P[@00`000000AX:d04J2]00204J2]0@0000000<0AX:d00000016P[@02016P[@0
0`000000AX:d04J2]00304J2]0X000001@16P[@2000000T0AX:d3P00000304J2]0<0/1LN1000000:
0;0G7P@0AX:d00<0000004J2]016P[@02@16P[@01@000000AX:d04J2]016P[@0000000`0AX:d00@0
000004J2]016P[@000000`16P[@2000000L0AX:d00<0000004J2]016P[@01`16P[@4000006L0AX:d
0@3oool005<0AX:d0P0000001016P[@0000000000000000604J2]08000000`16P[@00`000000AX:d
04J2]00604J2]08000003`16P[@2000000h0AX:d00D0000004J2]016P[@0AX:d0000000204J2]0<0
00001P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016
P[@01`16P[@@000000D0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00904J2]003
00000016P[@00000008000000`16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00T0
AX:d00@0000004J2]016P[@000003P16P[@200000080AX:d0P00000204J2]00300000016P[@0AX:d
00@0AX:d00<0000004J2]016P[@01`16P[@20000000304J2]0000000AX:d06H0AX:d0@3oool005<0
AX:d0P0000001016P[@0000000000000000604J2]00500000016P[@0000004J2]00000002@16P[@3
000000l0AX:d00<0000004J2]016P[@03@16P[@00`000000AX:d00000003000000T0AX:d00<00000
04J2]016P[@01P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00`0AX:d0P00000>
04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2]003
04J2]080000000<0AX:d00000016P[@01@16P[@00`000000AX:d04J2]00:04J2]00400000016P[@0
AX:d000000h0AX:d00@0000004J2]016P[@000001016P[@00`000000AX:d04J2]00304J2]0800000
2016P[@30000000304J2]0000000AX:d06H0AX:d0@3oool005@0AX:d00@0000004J2]0000000AX:d
0P00000504J2]00500000016P[@0000004J2]00000002@16P[@00`000000AX:d04J2]002000000d0
AX:d00<0000004J2]016P[@03@16P[@20000000304J2]0000000AX:d00X0AX:d00<0000004J2]016
P[@01P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00`0AX:d0P00000>04J2]003
00000016P[@0AX:d0080AX:d00<0000004J2]016P[@02016P[@00`000000AX:d04J2]00504J2]0<0
00001@16P[@00`000000AX:d04J2]00:04J2]00300000016P[@0000000l0AX:d0`00000604J2]007
00000016P[@0AX:d04J2]0000000AX:d0000000804J2]0@00000J016P[@10?ooo`00E016P[@20000
000404J2]0000000AX:d000000D0AX:d00@0000004J2]016P[@000002P16P[@010000000AX:d04J2
]016P[@3000000/0AX:d0P00000<04J2]080000000@0AX:d00000016P[@000003016P[@00`000000
AX:d04J2]00504J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02`16P[@2000000h0
AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d00L0
AX:d00<0000004J2]00000000P0000000`16P[@0000004J2]00<04J2]08000003`16P[@2000000P0
AX:d00@0000004J2]016P[@0AX:d0P00000804J2]080000000<0AX:d000000000000J016P[@10?oo
o`00E016P[@20000000504J2]0000000AX:d04J2]00000001016P[@00`000000AX:d04J2]0020000
00T0AX:d00D0000004J2]016P[@0AX:d0000000204J2]08000002@16P[@00`000000AX:d00000009
04J2]08000000`16P[@00`000000AX:d0000000<04J2]00300000016P[@0AX:d00D0AX:d00<00000
04J2]016P[@01016P[@00`000000AX:d04J2]00;04J2]08000003@16P[@00`000000AX:d04J2]003
04J2]00300000016P[@0AX:d00L0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]002
04J2]08000003@16P[@2000000d0AX:d0P0000000`16P[@0000004J2]00804J2]00500000016P[@0
000004J2]00000001`16P[@010000000AX:d00000016P[@2000006P0AX:d0@3oool005D0AX:d00<0
000004J2]00000000`16P[@01@000000AX:d04J2]016P[@000000080AX:d00<0000004J2]0000000
2016P[@00`000000AX:d04J2]00204J2]00400000016P[@0AX:d04J2]08000001`16P[@00`000000
AX:d0000000704J2]08000001P16P[@2000000d0AX:d00<0000004J2]016P[@01016P[@00`000000
AX:d04J2]00404J2]00300000016P[@0AX:d00/0AX:d0P00000=04J2]00300000016P[@0AX:d00<0
AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080
AX:d00@0000004J2]000000000002`16P[@00`000000AX:d04J2]00:04J2]0<000000P16P[@00`00
0000AX:d04J2]00704J2]00500000016P[@0000004J2]00000001P16P[@20000000404J2]0000000
AX:d000006T0AX:d0@3oool005D0AX:d00@0000004J2]016P[@000000P16P[@200000080AX:d00<0
000004J2]00000000`16P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00<0AX:d00<0
000004J2]016P[@00P16P[@2000000@0AX:d00D0000004J2]016P[@0AX:d0000000404J2]0800000
2016P[@2000000d0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00404J2]0030000
0016P[@0AX:d00/0AX:d0P00000=04J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@0
1P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d0080AX:d00@0000004J2]016P[@0
AX:d0P00000804J2]00300000016P[@0000000T0AX:d0P0000000`16P[@0000004J2]00204J2]003
00000016P[@0AX:d00P0AX:d00@0000004J2]016P[@000001@16P[@20000000304J2]0000000AX:d
00800000J@16P[@10?ooo`00EP16P[@00`000000AX:d0000000304J2]00600000016P[@0AX:d0000
0016P[@000001016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<00000
04J2]016P[@00`16P[@200000080AX:d00D0000004J2]016P[@0AX:d0000000204J2]08000002`16
P[@00`000000AX:d04J2]00;04J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@01016
P[@00`000000AX:d04J2]00;04J2]08000003@16P[@00`000000AX:d04J2]00304J2]00300000016
P[@0AX:d00H0AX:d00<0000004J2]016P[@02@16P[@010000000AX:d04J2]000000604J2]0800000
1P16P[@00`000000AX:d0000000704J2]08000000`16P[@01@000000AX:d04J2]016P[@0000000T0
AX:d0P00000204J2]00300000016P[@0AX:d0080AX:d0P00000204J2]00400000016P[@000000000
06T0AX:d0@3oool005H0AX:d00<0000004J2]00000001016P[@01@000000AX:d00000016P[@00000
00@0AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d
00@0AX:d0`00000404J2]08000003@16P[@2000000d0AX:d00<0000004J2]016P[@00`16P[@00`00
0000AX:d04J2]00404J2]00300000016P[@0AX:d00/0AX:d0P00000=04J2]00300000016P[@0AX:d
00<0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00:04J2]00300000016P[@00000
00T0AX:d0P00000304J2]00400000016P[@0AX:d000000D0AX:d0P00000404J2]00300000016P[@0
AX:d0080AX:d00<0000004J2]016P[@01P16P[@01P000000AX:d04J2]0000000AX:d000000@0AX:d
00@0000004J2]016P[@000000P16P[@00`000000AX:d04J2]01X04J2]040oooo001G04J2]0800000
1016P[@30000000304J2]0000000AX:d00@0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d
04J2]00504J2]00300000016P[@0AX:d00H0AX:d0P00000204J2]00300000016P[@0000000d0AX:d
0P00000=04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d
04J2]00:04J2]08000003016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00D0AX:d
00<0000004J2]016P[@02P16P[@00`000000AX:d0000000;04J2]080000000D0AX:d00000016P[@0
AX:d0000000304J2]08000001@16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00D0
AX:d00L0000004J2]016P[@0AX:d00000016P[@0000000<0AX:d0P00000204J2]00400000016P[@0
AX:d000006X0AX:d0@3oool005L0AX:d0`00000404J2]080000000<0AX:d00000016P[@01@16P[@0
0`000000AX:d04J2]00204J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]016P[@01@16P[@0
0`000000AX:d0000000200000080AX:d00<0000004J2]016P[@02@16P[@010000000AX:d04J2]000
000<04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2
]00:04J2]08000003016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<0
000004J2]016P[@02`16P[@2000000h0AX:d00H0000004J2]016P[@0AX:d00000016P[@2000000H0
AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d0080
AX:d00<0000004J2]00000000P16P[@2000000<0AX:d00<0000004J2]0000000J`16P[@10?ooo`00
F016P[@2000000D0AX:d0`00000704J2]00500000016P[@0AX:d04J2]00000002@16P[@00`000000
AX:d04J2]00404J2]08000000`16P[@3000000/0AX:d00@0000004J2]016P[@000003@16P[@01@00
0000AX:d04J2]016P[@0000000P0AX:d00<0000004J2]016P[@02P16P[@2000000`0AX:d00<00000
04J2]016P[@01016P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00/0AX:d00<00000
04J2]016P[@03016P[@010000000AX:d00000016P[@3000000P0AX:d00<0000004J2]016P[@01016
P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00<0AX:d00@0000004J2]0000000AX:d
0P00000304J2]00400000016P[@00000000006/0AX:d0@3oool005P0AX:d0P00000504J2]0800000
00<0AX:d00000016P[@01P16P[@010000000AX:d04J2]000000:04J2]00300000016P[@0AX:d00<0
AX:d00<0000004J2]016P[@01@16P[@4000000L0AX:d00D0000004J2]016P[@0AX:d0000000<04J2
]00500000016P[@0AX:d04J2]00000002016P[@00`000000AX:d04J2]00:04J2]08000003016P[@0
0`000000AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02`16P[@0
0`000000AX:d04J2]00;04J2]0L000002016P[@00`000000AX:d04J2]00504J2]00300000016P[@0
AX:d0080AX:d00<0000004J2]016P[@01@16P[@30000000304J2]0000000AX:d0080AX:d00<00000
04J2]0000000K016P[@10?ooo`00F@16P[@2000000D0AX:d00@0000004J2]016P[@000001`16P[@0
0`000000AX:d0000000:04J2]00400000016P[@0AX:d04J2]0<000002016P[@00`000000AX:d04J2
]003000000@0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00904J2]00500000016
P[@0AX:d04J2]00000002016P[@00`000000AX:d04J2]00:04J2]08000003016P[@00`000000AX:d
04J2]00404J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@02`16P[@2000000X0AX:d
1000000504J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d
04J2]00204J2]00300000016P[@0AX:d00H0AX:d0P0000000`16P[@0000004J2]00304J2]0800000
K@16P[@10?ooo`00F@16P[@2000000D0AX:d0P00000204J2]08000001P16P[@2000000/0AX:d00<0
000004J2]00000000P16P[@00`000000AX:d04J2]00704J2]00300000016P[@0AX:d0080AX:d0`00
00000`16P[@0000004J2]00304J2]00300000016P[@0AX:d00X0AX:d00@0000004J2]016P[@00000
2@16P[@00`000000AX:d04J2]00904J2]08000002`16P[@00`000000AX:d04J2]00504J2]0030000
0016P[@0AX:d00<0AX:d00<0000004J2]016P[@02P16P[@00`000000AX:d0000000604J2]0@00000
00<0AX:d00000016P[@01P16P[@2000000D0AX:d00<0000004J2]016P[@01P16P[@01@000000AX:d
04J2]016P[@0000000P0AX:d1000000404J2]0<00000K@16P[@10?ooo`00FP16P[@2000000@0AX:d
0`00000304J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@02P16P[@01@000000AX:d
04J2]016P[@0000000X0AX:d00<0000004J2]016P[@01016P[@4000000<0AX:d00<0000004J2]016
P[@02@16P[@010000000AX:d04J2]000000904J2]00300000016P[@0AX:d00T0AX:d0P00000;04J2
]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00:04J2
]00400000016P[@0AX:d00000080AX:d1000000404J2]00300000016P[@0AX:d00H0AX:d00@00000
04J2]000000000000`16P[@00`000000AX:d04J2]00604J2]00400000016P[@0AX:d000000L0AX:d
0P0000001016P[@0000000000000000404J2]0800000KP16P[@10?ooo`00FP16P[@3000000<0AX:d
0P0000000`16P[@0000004J2]00204J2]08000001016P[@2000000X0AX:d00<0000004J2]0000000
0P16P[@00`000000AX:d04J2]00804J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@0
1@00000:04J2]00400000016P[@0AX:d000000T0AX:d00<0000004J2]016P[@02@16P[@2000000/0
AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00X0
AX:d1P00000804J2]00300000016P[@0AX:d00H0AX:d00L0000004J2]016P[@0AX:d00000016P[@0
000000T0AX:d00@0000004J2]016P[@000001P16P[@010000000AX:d04J2]016P[@2000000@0AX:d
0`00001^04J2]040oooo001K04J2]08000000`16P[@200000080AX:d00<0000004J2]016P[@00P16
P[@01`000000AX:d04J2]016P[@0000004J2]00000002016P[@01`000000AX:d04J2]016P[@00000
04J2]00000002`16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d00@0AX:d1`000005
04J2]00300000016P[@0000000T0AX:d00<0000004J2]016P[@02@16P[@2000000/0AX:d00<00000
04J2]016P[@01@16P[@01@000000AX:d04J2]016P[@0000000T0AX:d1@00000204J2]00300000016
P[@0AX:d00L0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00204J2]00300000016
P[@0AX:d00P0AX:d00<0000004J2]00000001@16P[@2000000@0AX:d0P00000404J2]0800000K`16
P[@10?ooo`00G016P[@200000080AX:d00<0000004J2]00000000P16P[@00`000000AX:d04J2]002
04J2]00600000016P[@0AX:d00000016P[@000002016P[@00`000000AX:d04J2]00204J2]0800000
3016P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@0
0`16P[@60000000304J2]0000000AX:d00P0AX:d00<0000004J2]016P[@02@16P[@2000000/0AX:d
00<0000004J2]016P[@01@16P[@01@000000AX:d04J2]016P[@0000000<0AX:d1P00000204J2]003
00000016P[@0AX:d0080AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d04J2]00804J2]007
00000016P[@0AX:d04J2]0000000AX:d0000000904J2]08000001016P[@2000000D0AX:d00<00000
04J2]00000000`16P[@200000700AX:d0@3oool005`0AX:d0`00000204J2]08000000`16P[@00`00
0000AX:d04J2]00204J2]0<000000P16P[@00`000000AX:d04J2]00404J2]00300000016P[@0AX:d
00@0AX:d00<0000004J2]016P[@02`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d
00D0AX:d00<0000004J2]016P[@02016P[@>000000X0AX:d0P00000:04J2]00300000016P[@0AX:d
00H0AX:d00<0000004J2]016P[@01@00000804J2]00300000016P[@0AX:d0080AX:d00<0000004J2
]016P[@01@16P[@00`000000AX:d04J2]00904J2]00400000016P[@0AX:d00000080AX:d00<00000
04J2]016P[@01`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00@0AX:d0`000003
04J2]0<00000L016P[@10?ooo`00G@16P[@200000080AX:d0P00000404J2]00300000016P[@0AX:d
00<0AX:d0P00000204J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01@16P[@20000
00d0AX:d00D0000004J2]016P[@0AX:d0000000804J2]00300000016P[@0AX:d00P0AX:d0P00000:
04J2]2@000002`16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00@0AX:d00<00000
04J2]016P[@02@16P[@010000000AX:d00000000000404J2]00300000016P[@0AX:d00D0AX:d0P00
000204J2]08000001P16P[@010000000AX:d00000000000304J2]0800000L@16P[@10?ooo`00GP16
P[@20000000404J2]0000000AX:d000000@0AX:d00<0000004J2]016P[@00P16P[@01P000000AX:d
000000000000AX:d00000080AX:d00<0000004J2]016P[@01P16P[@00`000000AX:d0000000=04J2
]00400000016P[@0AX:d000000T0AX:d00<0000004J2]016P[@01`16P[@2000000P0AX:d2@000004
04J2]08000001@16P[@8000000H0AX:d00@0000004J2]016P[@000002P16P[@00`000000AX:d04J2
]00404J2]00300000016P[@0AX:d00<0AX:d00<0000004J2]016P[@02P16P[@2000000H0AX:d00<0
000004J2]016P[@01016P[@00`000000AX:d00000002000000L0AX:d00D0000004J2]0000000AX:d
0000000204J2]0800000LP16P[@10?ooo`00GP16P[@01P000000AX:d000000000000AX:d000000@0
AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]0030000000304J2]0000000AX:d00L0
AX:d00@0000004J2]016P[@000003016P[@010000000AX:d04J2]000000904J2]00300000016P[@0
AX:d00P0AX:d00<0000004J2]016P[@01P00000204J2]00300000016P[@0AX:d00P0AX:d0P00000:
04J2]00300000016P[@0AX:d00L0000000<0AX:d00000016P[@02P16P[@00`000000AX:d04J2]004
04J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@02`16P[@00`000000AX:d04J2]006
04J2]00300000016P[@0AX:d0080AX:d00@0000004J2]000000000002016P[@01`000000AX:d04J2
]0000000AX:d00000016P[@00`00001b04J2]040oooo001O04J2]0<0000000<0AX:d00000016P[@0
1016P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d0080AX:d0P00000904J2]0050000
0016P[@0AX:d04J2]00000003016P[@00`000000AX:d0000000:04J2]00300000016P[@0AX:d00D0
AX:d1@00000804J2]00300000016P[@0AX:d00P0AX:d0P00000904J2]00300000016P[@0AX:d00L0
AX:d1000000904J2]00300000016P[@0AX:d00D0AX:d00D0000004J2]016P[@0AX:d0000000=04J2
]08000002@16P[@00`000000AX:d04J2]0030000000304J2]0000000AX:d00H0AX:d00@0000004J2
]016P[@000000P16P[@4000007<0AX:d0@3oool00600AX:d0P00000204J2]00300000016P[@0AX:d
00<0AX:d00D0000004J2]016P[@0AX:d0000000504J2]0<000001`16P[@00`000000AX:d04J2]002
04J2]00300000016P[@0AX:d00X0AX:d0P00000:04J2]00400000016P[@0AX:d04J2]0@000000P16
P[@2000000X0AX:d00<0000004J2]016P[@01`16P[@2000000T0AX:d00<0000004J2]016P[@01`16
P[@200000080AX:d0`00000504J2]00300000016P[@0AX:d00H0AX:d00@0000004J2]016P[@00000
3@16P[@00`000000AX:d0000000904J2]0@000000P16P[@00`000000AX:d04J2]00504J2]0080000
0016P[@0AX:d04J2]0000000AX:d00000016P[@2000007@0AX:d0@3oool00600AX:d0`0000000`16
P[@0000004J2]00504J2]00400000016P[@0AX:d000000@0AX:d00@0000004J2]016P[@0AX:d0P00
000504J2]00300000016P[@0AX:d00<0AX:d0P00000;04J2]08000002@16P[@4000000H0AX:d0P00
000:04J2]00300000016P[@0AX:d00L0AX:d0P00000904J2]00300000016P[@0AX:d00L0AX:d0P00
000504J2]0<000000P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0000000d0AX:d00@0
000004J2]016P[@000002016P[@3000000@0AX:d00<0000004J2]016P[@00`16P[@2000000@0AX:d
00H0000004J2]0000000000004J2]000001d04J2]040oooo001Q04J2]0@000001`16P[@010000000
AX:d04J2]000000304J2]00300000016P[@0AX:d0080AX:d0`00000304J2]00300000016P[@0AX:d
00D0AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d04J2]00504J2]08000000P16P[@00`00
0000AX:d04J2]00504J2]00300000016P[@0000000T0AX:d00<0000004J2]016P[@01`16P[@20000
00T0AX:d00<0000004J2]016P[@01`16P[@00`000000AX:d04J2]00704J2]08000002@16P[@00`00
0000AX:d0000000;04J2]08000000`16P[@00`000000AX:d04J2]00404J2]0D000001016P[@00`00
0000AX:d04J2]00204J2]00300000016P[@0AX:d00<0AX:d00H0000004J2]016P[@0000004J2]000
001e04J2]040oooo001Q04J2]080000000<0AX:d0000000000001`16P[@00`000000AX:d00000002
04J2]00300000016P[@0AX:d00@0AX:d100000000`16P[@0000004J2]00704J2]00300000016P[@0
AX:d00P0AX:d00<0000004J2]016P[@00`16P[@2000000@0AX:d00<0000004J2]016P[@01@16P[@0
0`000000AX:d0000000904J2]00300000016P[@0AX:d00L0AX:d0P00000804J2]00300000016P[@0
AX:d00P0AX:d00<0000004J2]016P[@01`16P[@010000000AX:d00000000000704J2]08000002`16
P[@00`000000AX:d04J2]00304J2]00400000016P[@0AX:d04J2]0<0000000<0AX:d00000016P[@0
0P16P[@01@000000AX:d04J2]016P[@0000000<0AX:d00<0000004J2]016P[@01016P[@01@000000
AX:d00000016P[@0000007H0AX:d0@3oool00680AX:d0P0000000`16P[@000000000000704J2]080
00000P16P[@00`000000AX:d04J2]00604J2]00300000016P[@00000008000002016P[@00`000000
AX:d04J2]00704J2]08000000P16P[@2000000L0AX:d00<0000004J2]016P[@01016P[@010000000
AX:d04J2]000000904J2]00300000016P[@0AX:d00H0AX:d0P00000804J2]00300000016P[@0AX:d
00L0AX:d0P00000804J2]00300000016P[@0AX:d0080AX:d0P00000504J2]00300000016P[@0AX:d
00T0AX:d00<0000004J2]016P[@01016P[@010000000AX:d00000000000304J2]00300000016P[@0
AX:d0080AX:d00@0000004J2]016P[@000000`16P[@00`000000AX:d04J2]00504J2]0@00000M`16
P[@10?ooo`00H`16P[@00`000000AX:d04J2]002000000L0AX:d0P0000000`16P[@0000004J2]008
04J2]00400000016P[@0000004J2]0<000001P16P[@00`000000AX:d04J2]00604J2]00400000016
P[@00000000000X0AX:d00<0000004J2]016P[@00`16P[@010000000AX:d04J2]000000904J2]003
00000016P[@0AX:d00H0AX:d0P00000804J2]00300000016P[@0AX:d00H0AX:d00<0000004J2]000
00001`16P[@00`000000AX:d04J2]00504J2]08000000P16P[@2000000X0AX:d00<0000004J2]016
P[@01016P[@3000000<0AX:d0P00000504J2]00400000016P[@0AX:d00000080AX:d00<0000004J2
]016P[@01@16P[@30000000304J2]0000000AX:d07H0AX:d0@3oool006<0AX:d0P0000001016P[@0
000004J2]000000704J2]08000002`16P[@2000000@0AX:d1000000304J2]00300000016P[@0AX:d
00D0AX:d0P0000000`16P[@0000004J2]00:04J2]00300000016P[@0AX:d0080AX:d00D0000004J2
]016P[@0AX:d0000000804J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]00000001`16P[@0
0`000000AX:d04J2]00704J2]00300000016P[@0000000L0AX:d00<0000004J2]016P[@01`16P[@2
0000000304J2]0000000AX:d00P0AX:d00<0000004J2]016P[@00P16P[@30000000304J2]0000000
AX:d0080AX:d00<0000004J2]016P[@01P16P[@01@000000AX:d00000016P[@0000000L0AX:d0P00
00000`16P[@000000000001h04J2]040oooo001T04J2]00500000016P[@0AX:d00000016P[@00P00
000504J2]08000003@16P[@00`000000AX:d04J2]00504J2]0<0000000<0AX:d00000016P[@01@16
P[@01@000000AX:d04J2]016P[@0000000X0AX:d00<0000004J2]016P[@00P16P[@01@000000AX:d
04J2]016P[@0000000P0AX:d00<0000004J2]016P[@01@16P[@2000000P0AX:d00<0000004J2]016
P[@01P16P[@010000000AX:d04J2]000000604J2]00300000016P[@0AX:d00P0AX:d00@0000004J2
]000000000002016P[@00`000000AX:d04J2]003000000@0AX:d00@0000004J2]016P[@000002@16
P[@20000000304J2]0000000AX:d00H0AX:d0P0000000`16P[@000000000001i04J2]040oooo001U
04J2]00500000016P[@0AX:d00000016P[@00P00000504J2]0<000002`16P[@3000000P0AX:d0`00
000304J2]0<000001016P[@2000000T0AX:d00D0000004J2]016P[@0AX:d0000000404J2]0030000
0016P[@0AX:d00H0AX:d00<0000004J2]016P[@01016P[@2000000P0AX:d00<0000004J2]016P[@0
1P16P[@010000000AX:d04J2]000000504J2]00300000016P[@0AX:d00P0AX:d00D0000004J2]016
P[@0AX:d0000000604J2]0D000001P16P[@010000000AX:d00000000000;04J2]08000001`16P[@0
10000000AX:d00000016P[@2000007T0AX:d0@3oool006D0AX:d00@0000004J2]016P[@000000P16
P[@2000000@0AX:d00<0000004J2]016P[@00P00000904J2]00400000016P[@0AX:d000000X0AX:d
100000000`16P[@0000004J2]00504J2]00300000016P[@0AX:d00L0AX:d00@0000004J2]016P[@0
00001016P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00@0AX:d0P00000804J2]003
00000016P[@0AX:d00D0AX:d00D0000004J2]016P[@0AX:d0000000404J2]00300000016P[@0AX:d
00L0AX:d0P00000404J2]0<000000P16P[@3000000X0AX:d0P00000=04J2]00300000016P[@0AX:d
00@0AX:d0P0000000`16P[@0000004J2]002000007X0AX:d0@3oool006H0AX:d00@0000004J2]016
P[@000000P16P[@300000080AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00604J2
]00500000016P[@0AX:d04J2]00000002P16P[@00`000000AX:d04J2]005000000@0AX:d00<00000
04J2]016P[@01`16P[@00`000000AX:d0000000504J2]00300000016P[@0AX:d00D0AX:d00<00000
04J2]016P[@01016P[@2000000L0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]002
04J2]00500000016P[@0AX:d04J2]00000002@16P[@00`000000AX:d04J2]00404J2]00300000016
P[@0000000<000002`16P[@2000000`0AX:d0`00000504J2]080000000D0AX:d00000016P[@0AX:d
0000001k04J2]040oooo001W04J2]00400000016P[@0AX:d00000080AX:d0`0000000`16P[@00000
04J2]00404J2]08000001`16P[@010000000AX:d04J2]016P[@2000000L0AX:d00H0000004J2]000
0000000004J2]000000304J2]0H000002016P[@00`000000AX:d0000000604J2]00300000016P[@0
AX:d00@0AX:d00<0000004J2]016P[@01016P[@2000000L0AX:d00<0000004J2]016P[@01@16P[@0
0`000000AX:d04J2]00204J2]00400000016P[@0AX:d000000T0AX:d00<0000004J2]016P[@00P16
P[@500000080AX:d00<0000004J2]016P[@02@16P[@00`000000AX:d0000000:04J2]080000000<0
AX:d00000016P[@00`16P[@2000000<0AX:d00@0000004J2]00000000000N`16P[@10?ooo`00J016
P[@3000000@0AX:d1000000604J2]08000001@16P[@00`000000AX:d04J2]00304J2]00300000016
P[@0AX:d00<0AX:d00<0000004J2]016P[@00P16P[@2000000T0AX:d1`00000204J2]08000001P16
P[@00`000000AX:d04J2]00504J2]00300000016P[@0AX:d00<0AX:d0P00000704J2]00300000016
P[@0AX:d00@0AX:d00<0000004J2]016P[@00`16P[@010000000AX:d04J2]000000704J2]0L00000
0`16P[@01P000000AX:d000000000000AX:d000000T0AX:d00<0000004J2]00000002@16P[@20000
00<0AX:d00<0000004J2]016P[@00`00000304J2]00400000016P[@0AX:d000007`0AX:d0@3oool0
06T0AX:d0`00000404J2]00400000016P[@00000000000L0AX:d00<0000004J2]016P[@00P16P[@0
0`000000AX:d04J2]00404J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@00`16P[@2
000000T0AX:d00<0000004J2]016P[@00`16P[@900000080AX:d00<0000004J2]016P[@01016P[@0
0`000000AX:d04J2]00304J2]08000001P16P[@00`000000AX:d04J2]00504J2]00300000016P[@0
AX:d00<0AX:d00@0000004J2]0000000AX:d2000000904J2]08000000`16P[@00`000000AX:d04J2
]00504J2]08000000P16P[@00`000000AX:d04J2]00604J2]00300000016P[@0AX:d00<0AX:d00D0
000004J2]0000000AX:d0000000304J2]00400000016P[@0AX:d000007d0AX:d0@3oool006X0AX:d
0`00000404J2]0D000001P16P[@200000080AX:d00<0000004J2]016P[@01@16P[@20000000304J2
]0000000AX:d00H0AX:d0P00000904J2]08000001P16P[@2000000@0AX:d2P00000504J2]0800000
1P16P[@010000000AX:d04J2]016P[@>000000H0AX:d00<0000004J2]016P[@01`16P[@2000000D0
AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00204J2]00300000016P[@0AX:d00@0
AX:d0P00000504J2]0<0000000<0AX:d00000016P[@00`16P[@3000007h0AX:d0@3oool006/0AX:d
0P00000504J2]08000000P16P[@2000000H0AX:d00@0000004J2]016P[@000002016P[@00`000000
AX:d04J2]00604J2]00400000016P[@00000000000T0AX:d00<0000004J2]016P[@00`16P[@20000
00L0AX:d00<0000004J2]016P[@00`16P[@B00000080AX:d00<0000004J2]016P[@01@16P[@00`00
0000AX:d04J2]00504J2]08000002016P[@3000000L0AX:d00D0000004J2]016P[@0AX:d00000005
04J2]00300000016P[@0AX:d0080AX:d0P00000604J2]080000000<0AX:d0000000000001016P[@3
000007l0AX:d0@3oool006`0AX:d0P00000404J2]0<000000`16P[@2000000D0AX:d0`00000804J2
]0<000001P16P[@01@000000AX:d04J2]016P[@0000000T0AX:d00<0000004J2]016P[@00P16P[@0
0`000000AX:d0000000604J2]00300000016P[@0AX:d00@0AX:d00<0000004J2]016P[@00P16P[@2
000000H0AX:d00<0000004J2]016P[@00`16P[@00`000000AX:d04J2]00404J2]08000001P16P[@0
0`000000AX:d04J2]00704J2]00400000016P[@0AX:d000000L0AX:d00@0000004J2]00000000000
1@16P[@010000000AX:d04J2]016P[@2000000H0AX:d1@00000504J2]0<00000P016P[@10?ooo`00
K@16P[@3000000<0AX:d1000000304J2]0<000001016P[@2000000H0AX:d00@0000004J2]016P[@0
AX:d0P00000404J2]00300000016P[@0AX:d0080AX:d00<0000004J2]016P[@01`16P[@01@000000
AX:d04J2]016P[@000000080AX:d00<0000004J2]016P[@01016P[@00`000000AX:d04J2]00304J2
]00300000016P[@0AX:d0080AX:d0P00000504J2]00300000016P[@0AX:d00<0AX:d00<0000004J2
]016P[@01016P[@00`000000AX:d0000000504J2]00300000016P[@0AX:d00H0AX:d0P00000304J2
]00300000016P[@0AX:d00D0AX:d0P00000704J2]00400000016P[@00000000000H0AX:d0P000002
04J2]08000001@16P[@300000840AX:d0@3oool006h0AX:d00<0000004J2]00000000P16P[@01000
0000AX:d00000016P[@2000000@0AX:d0P00000204J2]00300000016P[@0000000D0AX:d00<00000
04J2]016P[@00`16P[@200000080AX:d00<0000004J2]016P[@00`16P[@2000000P0AX:d00@00000
04J2]016P[@000000`16P[@00`000000AX:d04J2]00304J2]00400000016P[@0AX:d04J2]1400000
0`16P[@00`000000AX:d04J2]00404J2]08000001@16P[@00`000000AX:d04J2]00604J2]0030000
0016P[@0AX:d00<0AX:d00<0000004J2]016P[@00`16P[@20000000304J2]0000000AX:d00H0AX:d
0P00000604J2]08000000`16P[@2000000D0AX:d0`00002204J2]040oooo001_04J2]00300000016
P[@000000080AX:d00<0000004J2]00000000P16P[@2000000@0AX:d0P0000000`16P[@0000004J2
]002000000<0AX:d00<0000004J2]016P[@01@16P[@3000000L0AX:d00<0000004J2]016P[@01P16
P[@3000000<0AX:d00<0000004J2]016P[@00`16P[@400000080AX:d00<0000004J2]016P[@00P16
P[@2000000D0AX:d00<0000004J2]016P[@01000000504J2]00300000016P[@0000000@0AX:d00<0
000004J2]016P[@01@16P[@2000000D0AX:d00<0000004J2]016P[@00P16P[@2000000@0AX:d00<0
000004J2]016P[@00`16P[@2000000@0AX:d0`00000304J2]0@000001016P[@3000008<0AX:d0@3o
ool00700AX:d0`0000001016P[@0000004J2]000000404J2]08000001016P[@300000080AX:d0`00
000:04J2]08000001`16P[@2000000P0AX:d00<0000004J2]016P[@00P16P[@00`000000AX:d04J2
]00200000080AX:d00<0000004J2]016P[@00P16P[@010000000AX:d04J2]016P[@2000000@0AX:d
00<0000004J2]016P[@00P16P[@00`000000AX:d04J2]00200000080AX:d00@0000004J2]016P[@0
00000P16P[@2000000L0AX:d00<0000004J2]016P[@01@16P[@00`000000AX:d04J2]002000000H0
AX:d00@0000004J2]016P[@0AX:d0`00000304J2]08000001016P[@20000000304J2]00000000000
00<0AX:d0P0000000`16P[@0000004J2]02304J2]040oooo001a04J2]0D0000000<0AX:d00000016
P[@01016P[@2000000<0AX:d00<0000004J2]00000001@00000904J2]00400000016P[@000000000
00L0AX:d00<0000004J2]016P[@01@16P[@2000000<0AX:d0`00000404J2]00300000016P[@0AX:d
0080AX:d00@0000004J2]016P[@0AX:d0P00000404J2]00300000016P[@0AX:d0080AX:d00<00000
04J2]016P[@00P16P[@2000000<0AX:d00<0000004J2]00000001`16P[@2000000P0AX:d0`000009
04J2]0<000000P16P[@010000000AX:d00000000000404J2]08000000P16P[@00`000000AX:d0000
000204J2]00400000016P[@0AX:d000008D0AX:d0@3oool007<0AX:d0`00000204J2]00300000016
P[@0AX:d00@0AX:d0P00000204J2]00300000016P[@0AX:d0080AX:d1@00000704J2]00300000016
P[@0AX:d008000001P16P[@2000000H0AX:d1000000204J2]00300000016P[@0AX:d00<0AX:d00D0
000004J2]016P[@0AX:d0000000304J2]08000001016P[@01@000000AX:d04J2]016P[@0000000D0
AX:d00D0000004J2]0000000000004J2]002000000H0AX:d0P00000904J2]08000002P16P[@20000
00<0AX:d0`00000404J2]08000001016P[@200000080AX:d00@0000004J2]00000000000QP16P[@1
0?ooo`00M016P[@5000000P0AX:d0`00000404J2]00300000016P[@0AX:d00@000001@16P[@00`00
0000AX:d04J2]00204J2]08000001P16P[@00`000000AX:d04J2]00304J2]00400000016P[@00000
000000<0AX:d00<0000004J2]016P[@00`16P[@01@000000AX:d04J2]016P[@000000080AX:d0P00
000304J2]00500000016P[@0AX:d04J2]00000001@16P[@00`000000AX:d04J2]00204J2]0800000
1P16P[@00`000000AX:d04J2]00604J2]0<0000000<0AX:d00000016P[@01P16P[@30000000304J2
]0000000000000<000001016P[@2000000D0AX:d00<0000004J2]00000001000002804J2]040oooo
001e04J2]00300000016P[@00000008000002@16P[@2000000<0AX:d00<0000004J2]016P[@01016
P[@40000000304J2]0000000AX:d00D0AX:d0P00000504J2]080000000@0AX:d0000000000000000
0`16P[@01@000000AX:d04J2]016P[@0000000@0AX:d00D0000004J2]016P[@0AX:d0000000204J2
]08000000`16P[@01@000000AX:d04J2]016P[@0000000@0AX:d00<0000004J2]016P[@00P16P[@5
00000080AX:d0P00000704J2]08000001016P[@00`000000AX:d04J2]00304J2]080000000<0AX:d
0000000000000P00000304J2]00300000016P[@0AX:d008000001P16P[@01@000000AX:d00000000
0000AX:d00800000R@16P[@10?ooo`00MP16P[@6000000P0AX:d0`0000000`16P[@0000004J2]008
04J2]0D000001P16P[@2000000D0AX:d0P0000000`16P[@0000004J2]00304J2]08000000P16P[@2
000000<0AX:d00@0000004J2]016P[@000000P16P[@2000000<0AX:d00@0000004J2]016P[@00000
0`16P[@2000000<0AX:d0P00000204J2]00300000016P[@0AX:d008000001`16P[@2000000D0AX:d
00@0000004J2]016P[@0AX:d1P00000304J2]00500000016P[@0AX:d00000016P[@00P00000804J2
]0H00000RP16P[@10?ooo`00N016P[@30000000404J2]00000000000000000H0AX:d00<0000004J2
]00000000P00000:04J2]0P000000`16P[@200000080AX:d00<0000004J2]016P[@00P00000604J2
]00500000016P[@0AX:d04J2]00000000`16P[@01@000000AX:d04J2]0000000AX:d008000000P16
P[@010000000AX:d04J2]000000304J2]00300000016P[@0AX:d0080AX:d00H0000004J2]016P[@0
AX:d00000016P[@200000080AX:d00<0000004J2]016P[@00P16P[@2000000L0AX:d1P00000704J2
]00300000016P[@0AX:d008000002@16P[@5000008`0AX:d0@3oool007T0AX:d1000000204J2]080
00001016P[@01@000000AX:d04J2]0000000AX:d00@000001`16P[@00`000000AX:d04J2]0030000
000304J2]000000000000080000000@0AX:d00000000000000000`16P[@3000000D0AX:d0P000002
04J2]00400000016P[@0AX:d00000080AX:d00@0000004J2]000000000000P16P[@00`000000AX:d
0000000304J2]00400000016P[@0AX:d04J2]08000001016P[@2000000@0AX:d00<0000004J2]016
P[@00P00000504J2]0H000002`16P[@3000000P0AX:d1@0000000`16P[@0000004J2]02<04J2]040
oooo001j04J2]0D000000P16P[@2000000<0AX:d00@0000004J2]016P[@000001016P[@3000000@0
AX:d00<0000004J2]016P[@00`16P[@2000000<0AX:d2000000204J2]0<000001016P[@010000000
AX:d04J2]000000204J2]00300000016P[@0AX:d00<0000000D0AX:d00000016P[@0AX:d00000002
04J2]00300000016P[@0AX:d008000000`16P[@4000000D0AX:d3000000204J2]00300000016P[@0
AX:d00P0AX:d1000000704J2]080000000<0AX:d0000000000000`00002>04J2]040oooo001l04J2
]0D000000P16P[@400000080AX:d00<0000004J2]016P[@01@16P[@5000000L0AX:d0`0000000`16
P[@0000004J2]00204J2]0`0000000D0AX:d000000000000AX:d0000000204J2]00300000016P[@0
00000080000000@0AX:d00000016P[@000000P16P[@00`000000AX:d04J2]00?0000000304J2]000
0000AX:d00@0AX:d0P00000404J2]00300000016P[@0AX:d00D0AX:d100000001016P[@0000004J2
]000000404J2]0<0000000<0AX:d0000000000000`00002@04J2]040oooo001m04J2]0<0000000<0
AX:d0000000000000`16P[@200000080AX:d00<0000004J2]016P[@02016P[@4000000L0AX:d1000
000304J2]00400000016P[@0AX:d04J2]0<0000000<0AX:d0000000000005@0000001016P[@00000
00000000000304J2]0@000001P16P[@00`000000AX:d00000002000000H0AX:d00@0000004J2]016
P[@0AX:d1000000504J2]08000000`16P[@20000000504J2]0000000000000000016P[@00`00002A
04J2]040oooo001n04J2]0<000000P16P[@200000080AX:d1000000;04J2]00300000016P[@0AX:d
00<000001@16P[@00`000000AX:d04J2]006000000@0AX:d0`0000000`16P[@000000000000204J2
]080000000<0AX:d00000016P[@00`0000000`16P[@0000004J2]0030000000304J2]00000000000
00<0AX:d0`00000204J2]00300000016P[@0AX:d0080AX:d1@00000804J2]0D000002016P[@00`00
0000AX:d000000030000000304J2]000000000000080AX:d1000002B04J2]040oooo002004J2]0@0
000000H0AX:d000000000000AX:d00000016P[@4000000P0AX:d00<0000004J2]016P[@00`16P[@4
0000000304J2]0000000AX:d00@0AX:d00<0000004J2]016P[@01@00000204J2]0D0000000<0AX:d
0000000000002@0000001016P[@0000000000016P[@4000000<0AX:d1`00000304J2]00300000016
P[@0AX:d00@0AX:d1000000<04J2]0<0000000@0AX:d00000000000000000`16P[@3000009@0AX:d
0@3oool00840AX:d0P0000001016P[@0000000000016P[@300000080AX:d00<0000004J2]0000000
1@00000204J2]00300000016P[@0AX:d00L0AX:d2@00000604J2]1L0000000<0AX:d000000000000
100000000`16P[@0000004J2]00704J2]00300000016P[@0AX:d00@000000P16P[@00`000000AX:d
04J2]00804J2]0L000001016P[@4000009D0AX:d0@3oool008<0AX:d0P0000000`16P[@000000000
0006000000H0AX:d1P00000704J2]00300000016P[@0AX:d00@0AX:d7`00000304J2]10000001P16
P[@00`000000AX:d04J2]00204J2]0H0000000<0AX:d0000000000000P00000304J2]0D00000U`16
P[@10?ooo`00Q016P[@2000000<0AX:d0`0000001016P[@0000000000000000704J2]00300000016
P[@0AX:d00H000000P16P[@00`000000AX:d04J2]00304J2]00300000016P[@0AX:d00D0AX:d6P00
000404J2]00300000016P[@0AX:d00D0AX:d00<0000004J2]016P[@01P16P[@6000000@0AX:d1@00
000204J2]0<000000P16P[@2000009P0AX:d0@3oool008H0AX:d0P00000404J2]0<0000000<0AX:d
0000000000000P00000304J2]00300000016P[@0AX:d00H0AX:d400000000`16P[@000000000000L
000000L0AX:d00<0000004J2]016P[@01`00000504J2]0@0000000<0AX:d00000016P[@010000003
04J2]0800000VP16P[@10?ooo`00R016P[@300000080AX:d3@00000904J2]08000000`16P[@90000
00<0AX:d400000000`16P[@0000000000004000000<0AX:d2`00000504J2]00300000016P[@0AX:d
00@000001016P[@4000000D0AX:d0P00002K04J2]040oooo002:04J2]0D0000000<0AX:d00000000
00001@16P[@B000000P0AX:d0`00000204J2]0<0000000<0AX:d0000000000000P0000000`16P[@0
000004J2]0020000000304J2]00000000000008000000`16P[@6000000<0AX:d00<0000004J2]016
P[@01@16P[@?000000D0AX:d0P00002M04J2]040oooo002<04J2]0P000001@16P[@00`000000AX:d
00000005000000D0AX:d00@0000004J2]016P[@000001016P[@3000000<0AX:d0P0000001016P[@0
000004J2]016P[@30000000404J2]0000000AX:d00000080AX:d0P00000304J2]0<000000P16P[@0
10000000AX:d04J2]016P[@=000000P0AX:d0`00000304J2]0@00000W`16P[@10?ooo`00S`16P[@7
000000@0AX:d00<0000004J2]016P[@01016P[@70000000304J2]0000000000000<000001016P[@2
00000080AX:d00H0000004J2]016P[@0000004J2]000000204J2]00300000016P[@0AX:d00800000
0P16P[@2000000@0AX:d0`00000204J2]0H000001P16P[@00`000000AX:d04J2]00504J2]0800000
00<0AX:d0000000000001000002R04J2]040oooo002A04J2]0<0000000<0AX:d0000000000006`00
000304J2]00400000016P[@0AX:d00000080AX:d00D0000004J2]016P[@0AX:d0000000304J2]003
00000016P[@00000018000001016P[@00`000000AX:d04J2]00304J2]0P00000Y@16P[@10?ooo`00
U016P[@5000000<0AX:d00<0000004J2]016P[@02P16P[@2000000<0AX:d0P00000204J2]1<00000
1016P[@200000080AX:d0P00000904J2]0l00000Z016P[@10?ooo`00U`16P[@400000080AX:d00<0
000004J2]016P[@02@16P[@6000000<0AX:d00<0000004J2]016P[@00P16P[@01@000000AX:d04J2
]016P[@0000000@0AX:d00<0000004J2]016P[@00P16P[@010000000AX:d04J2]016P[@5000000`0
AX:d00<0000004J2]016P[@00P16P[@500000:/0AX:d0@3oool009X0AX:d1@00000304J2]0L00000
0P16P[@010000000AX:d04J2]016P[@5000000<0AX:d00D0000004J2]016P[@0AX:d0000000404J2
]00400000016P[@0AX:d04J2]0D000000`16P[@00`000000AX:d00000003000000L0AX:d00@00000
04J2]016P[@0AX:d1000002^04J2]040oooo002M04J2]0D000002@16P[@00`000000AX:d00000002
000000@0AX:d4000000404J2]080000000<0AX:d00000016P[@01@16P[@500000080AX:d1@00002a
04J2]040oooo002Q04J2]0D000000`16P[@4000000P0AX:d00<0000004J2]016P[@00`16P[@00`00
0000AX:d04J2]00404J2]00300000016P[@0AX:d00D0AX:d0`00000804J2]0H00000]016P[@10?oo
o`00Y@16P[@60000000304J2]0000000AX:d00D0AX:d0P00000604J2]00300000016P[@0AX:d00D0
AX:d0P00000504J2]00300000016P[@0AX:d00X00000^016P[@10?ooo`00ZP16P[@Y00000;`0AX:d
0@3oool00:l0AX:d1`00000504J2]00300000016P[@0AX:d00<0AX:d2`00003304J2]040oooo002f
04J2]0/00000cP16P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:d
T016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?oo
o`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@
04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo
003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900
AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool0
0?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016
P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00
o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2
]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o
04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d
0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0
AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@1
0?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16
P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040
oooo003o04J2]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2
]900AX:d0@3oool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3o
ool00?l0AX:dT016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00?l0AX:d
T016P[@10?ooo`00o`16P[B@04J2]040oooo003o04J2]900AX:d0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {404.875, 0}} -> {0.0244893, -6.63381*^-06, \
0.00229992, 0.00229992}}]
}, Open  ]],

Cell["Reevaluate to obtain other random examples.", "Text"],

Cell[BoxData[
    \(Clear[g1, g2, g3, sphere, circle]\)], "Input",
  CellLabel->"In[245]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{567, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 65, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1844, 56, 373, 11, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 502885, 22100}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1844, 56, 373, 11, 50, "Usage",
  CellTags->"Function?"],
Cell[2220, 69, 120, 4, 41, "MathCaption"],
Cell[2343, 75, 203, 6, 59, "MathCaption"],
Cell[2549, 83, 64, 0, 41, "MathCaption"],
Cell[2616, 85, 172, 3, 58, "MathCaption"],
Cell[2791, 90, 249, 6, 58, "MathCaption"],
Cell[3043, 98, 224, 4, 58, "MathCaption"],
Cell[3270, 104, 165, 3, 58, "MathCaption"],
Cell[3438, 109, 372, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3835, 127, 34, 0, 39, "ExampleSection"],
Cell[3872, 129, 99, 2, 29, "Input"],
Cell[3974, 133, 616, 15, 76, "Text"],
Cell[4593, 150, 113, 2, 29, "Input"],
Cell[4709, 154, 85, 2, 25, "Text"],
Cell[4797, 158, 121, 3, 29, "Input"],
Cell[4921, 163, 1020, 24, 144, "Text"],

Cell[CellGroupData[{
Cell[5966, 191, 296, 6, 70, "Input"],
Cell[6265, 199, 181, 3, 44, "Output"],
Cell[6449, 204, 187, 3, 44, "Output"]
}, Open  ]],
Cell[6651, 210, 166, 3, 42, "Text"],
Cell[6820, 215, 184, 4, 29, "Input"],
Cell[7007, 221, 304, 8, 150, "Text"],

Cell[CellGroupData[{
Cell[7336, 233, 1284, 24, 354, "Input"],
Cell[8623, 259, 336252, 17116, 409, 265121, 16233, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[344890, 17378, 225, 4, 42, "Text"],
Cell[345118, 17384, 216, 4, 49, "Input"],

Cell[CellGroupData[{
Cell[345359, 17392, 746, 15, 209, "Input"],
Cell[346108, 17409, 155929, 4663, 412, 35367, 3171, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[502052, 22075, 59, 0, 25, "Text"],
Cell[502114, 22077, 92, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

