(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7064,        224]*)
(*NotebookOutlinePosition[      7995,        257]*)
(*  CellTagsIndexPosition[      7921,        251]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["RaiseTo3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"RaiseTo3D", 
          StyleBox["[",
            "MR"], "f", "]"}], "[", "graphics", "]"}]]],
  " applies the rule {x_?NumericQ, y_NumericQ} \[RuleDelayed] {x, y, f[x, y]} \
to the graphics."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
MakePolyGrid and RaiseTo3D are really equivalent to Plot3D but less \
efficient.  They become useful when TrimPolygons, or some transformation of \
the grid are used.\
\>", "MathCaption"],

Cell["\<\
To raise to a general parametric surface you will need to write your own \
transformation rule instead of using RaiseTo3D.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MakePolyGrid",
    ButtonData:>{"MakePolyGrid"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TrimPolygons",
    ButtonData:>{"TrimPolygons"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example - Plotting Around 3D Singularities", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here is a 2-variable function with a singularity at zero.", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[x_, \ y_]\  := \ 1\/\(x\^2 + y\^2\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
A regular Plot3D image isn't too satisfactory. The coordinate system becomes \
greatly distorted around the singularity. (Not to speak of the error \
messages!)\
\>", "Text"],

Cell[BoxData[
    \(\(Plot3D[\[IndentingNewLine]f[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 
          25, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            1}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {0, 
            15}, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
One solution is to cut out a circle around the singularity and use a polar \
coordinate system there. This is a grid of polygons which covers the \
rectangular region.\
\>", "Text"],

Cell[BoxData[
    \(\(polygrid1 = 
        MakePolyGrid[{25, 25}, \ {{\(-3\), \(-3\)}, {3, 3}}] // 
          N;\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["This trims out a circular region of radius 1.", "Text"],

Cell[BoxData[
    \(\(polys1 = 
        polygrid1 // 
          TrimPolygons[\((#1)\)\^2 + \((#2)\)\^2 &, {1, 20}];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "This is a grid of polygons in the r\[Theta]-plane that goes from ",
  Cell[BoxData[
      \(r \[Equal] 1/4\)]],
  " to ",
  Cell[BoxData[
      \(r \[Equal] 1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(polygrid2 = 
        MakePolyGrid[{10, 20}, {{1/4, 0}, {1, 2  \[Pi]}}] // N;\)\)], "Input",\

  CellLabel->"In[7]:="],

Cell[TextData[{
  "The initial grid of polygons is evenly spaced, but the final plot looks \
better if the polygons are more closely spaced near ",
  Cell[BoxData[
      \(r \[Equal] 1/4\)]],
  ".  The first function of r in the DrawingTransform does that."
}], "Text"],

Cell[BoxData[
    \(\(polygrid2a = 
        polygrid2 /. 
          DrawingTransform[5\/21 + \(16\ #1\^3\)\/21 &, #2 &];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["Finally, the polar grid is mapped to the xy-plane.", "Text"],

Cell[BoxData[
    \(\(polys2 = 
        polygrid2a /. 
          DrawingTransform[#1  Cos[#2] &, #1\ Sin[#2] &];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
This is a 2D plot of the resulting polygons. Notice the closer radial spacing \
near the singularity. \
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{LightSteelBlue, 
          polys1, \[IndentingNewLine]polys1 // 
            PolygonOutline[Black], \[IndentingNewLine]Wheat, 
          polys2, \[IndentingNewLine]polys2 // 
            PolygonOutline[Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}}, \[IndentingNewLine]ImageSize \[Rule] 300];\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "Here we raise the polygons to a 3D surface using ",
  Cell[BoxData[
      \(RaiseTo3D[f]\)]],
  ". We give the two regions different surface colors as above. The \
NeutralLighting \"option\" allows the pastel colors to display well without \
being overwhelmed by the default light colors."
}], "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[LightSteelBlue], 
            polys1, \[IndentingNewLine]SurfaceColor[Wheat], polys2} // 
          RaiseTo3D[f], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            1}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0.1], \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Clear[f, polygrid1, polygrid2, polygrid2a, polys1, polys2]\)], "Input",
  CellLabel->"In[12]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{643, 720},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 56, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1835, 56, 320, 10, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7750, 242}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 56, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1835, 56, 320, 10, 32, "Usage",
  CellTags->"Function?"],
Cell[2158, 68, 197, 4, 48, "MathCaption"],
Cell[2358, 74, 153, 3, 48, "MathCaption"],
Cell[2514, 79, 362, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2901, 97, 68, 0, 40, "ExampleSection"],
Cell[2972, 99, 97, 2, 29, "Input"],
Cell[3072, 103, 73, 0, 25, "Text"],
Cell[3148, 105, 126, 3, 64, "Input"],
Cell[3277, 110, 184, 4, 42, "Text"],
Cell[3464, 116, 403, 7, 149, "Input"],
Cell[3870, 125, 191, 4, 42, "Text"],
Cell[4064, 131, 151, 4, 29, "Input"],
Cell[4218, 137, 61, 0, 25, "Text"],
Cell[4282, 139, 154, 4, 30, "Input"],
Cell[4439, 145, 200, 8, 25, "Text"],
Cell[4642, 155, 139, 4, 29, "Input"],
Cell[4784, 161, 269, 6, 42, "Text"],
Cell[5056, 169, 159, 4, 44, "Input"],
Cell[5218, 175, 66, 0, 25, "Text"],
Cell[5287, 177, 151, 4, 29, "Input"],
Cell[5441, 183, 126, 3, 25, "Text"],
Cell[5570, 188, 533, 9, 189, "Input"],
Cell[6106, 199, 320, 7, 59, "Text"],
Cell[6429, 208, 488, 8, 169, "Input"],
Cell[6920, 218, 116, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

